/****************************************************************************
** Meta object code from reading C++ file 'statusadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "statusadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi__StatusAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi__StatusAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Agent.Status",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.Agent.Status\">\n    <"
        "signal name=\"status\">\n      <arg direction=\"out\" type=\"i\" n"
        "ame=\"status\"/>\n      <arg direction=\"out\" type=\"s\" name=\"m"
        "essage\"/>\n    </signal>\n    <signal name=\"percent\">\n      <a"
        "rg direction=\"out\" type=\"i\" name=\"percent\"/>\n    </signal>\n"
        "    <signal name=\"warning\">\n      <arg direction=\"out\" type=\""
        "s\" name=\"message\"/>\n    </signal>\n    <signal name=\"error\">"
        "\n      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n    "
        "</signal>\n    <signal name=\"onlineChanged\">\n      <arg directi"
        "on=\"out\" type=\"b\" name=\"state\"/>\n    </signal>\n    <signal"
        " name=\"advancedStatus\">\n      <annotation value=\"QVariantMap\""
        " name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <annotatio"
        "n value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0"
        "\"/>\n      <arg direction=\"out\" type=\"a{sv}\" name=\"status\"/"
        ">\n    </signal>\n    <method name=\"status\">\n      <arg directi"
        "on=\"out\" type=\"i\"/>\n    </method>\n    <method name=\"statusM"
        "essage\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method"
        ">\n    <method name=\"progress\">\n      <arg direction=\"out\" ty"
        "pe=\"i\"/>\n    </method>\n    <method name=\"isOnline\">\n      <"
        "arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method nam"
        "e=\"setOnline\">\n      <arg direction=\"in\" type=\"b\" name=\"st"
        "ate\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.D"
        "Bus.Method.NoReply\"/>\n    </method>\n  </interface>\n",
        "advancedStatus",
        "",
        "QVariantMap",
        "status",
        "error",
        "message",
        "onlineChanged",
        "state",
        "percent",
        "warning",
        "isOnline",
        "progress",
        "setOnline",
        "Q_NOREPLY",
        "statusMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'advancedStatus'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'onlineChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'percent'
        QtMocHelpers::SignalData<void(int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'isOnline'
        QtMocHelpers::SlotData<bool()>(15, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'progress'
        QtMocHelpers::SlotData<int()>(16, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setOnline'
        QtMocHelpers::SlotData<void(bool)>(17, 18, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'status'
        QtMocHelpers::SlotData<int()>(8, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'statusMessage'
        QtMocHelpers::SlotData<QString()>(19, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Akonadi__StatusAdaptor, qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi__StatusAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>.metaTypes,
    nullptr
} };

void Akonadi__StatusAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Akonadi__StatusAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->advancedStatus((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onlineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->percent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { bool _r = _t->isOnline();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->progress();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setOnline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { int _r = _t->status();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->statusMessage();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(const QVariantMap & )>(_a, &Akonadi__StatusAdaptor::advancedStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(const QString & )>(_a, &Akonadi__StatusAdaptor::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(bool )>(_a, &Akonadi__StatusAdaptor::onlineChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(int )>(_a, &Akonadi__StatusAdaptor::percent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(int , const QString & )>(_a, &Akonadi__StatusAdaptor::status, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__StatusAdaptor::*)(const QString & )>(_a, &Akonadi__StatusAdaptor::warning, 5))
            return;
    }
}

const QMetaObject *Akonadi__StatusAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi__StatusAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22Akonadi__StatusAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Akonadi__StatusAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Akonadi__StatusAdaptor::advancedStatus(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi__StatusAdaptor::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Akonadi__StatusAdaptor::onlineChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi__StatusAdaptor::percent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Akonadi__StatusAdaptor::status(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Akonadi__StatusAdaptor::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
