/****************************************************************************
** Meta object code from reading C++ file 'setup.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../akonadi-26.07.90/autotests/libs/testrunner/setup.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'setup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9SetupTestE_t {};
} // unnamed namespace

template <> constexpr inline auto SetupTest::qt_create_metaobjectdata<qt_meta_tag_ZN9SetupTestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SetupTest",
        "D-Bus Interface",
        "org.kde.Akonadi.Testrunner",
        "setupDone",
        "",
        "serverExited",
        "exitCode",
        "shutdown",
        "shutdownHarder",
        "restartAkonadiServer",
        "trackAkonadiProcess",
        "track",
        "serverStateChanged",
        "Akonadi::ServerManager::State",
        "state",
        "slotAkonadiDaemonProcessFinished",
        "agentCreationResult",
        "KJob*",
        "job",
        "synchronizationResult"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupDone'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverExited'
        QtMocHelpers::SignalData<void(int)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'shutdown'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'shutdownHarder'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'restartAkonadiServer'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'trackAkonadiProcess'
        QtMocHelpers::SlotData<void(bool)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'serverStateChanged'
        QtMocHelpers::SlotData<void(Akonadi::ServerManager::State)>(12, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'slotAkonadiDaemonProcessFinished'
        QtMocHelpers::SlotData<void(int)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'agentCreationResult'
        QtMocHelpers::SlotData<void(KJob *)>(16, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'synchronizationResult'
        QtMocHelpers::SlotData<void(KJob *)>(19, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SetupTest, qt_meta_tag_ZN9SetupTestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SetupTest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SetupTestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SetupTestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9SetupTestE_t>.metaTypes,
    nullptr
} };

void SetupTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SetupTest *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupDone(); break;
        case 1: _t->serverExited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->shutdown(); break;
        case 3: _t->shutdownHarder(); break;
        case 4: _t->restartAkonadiServer(); break;
        case 5: _t->trackAkonadiProcess((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->serverStateChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::ServerManager::State>>(_a[1]))); break;
        case 7: _t->slotAkonadiDaemonProcessFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->agentCreationResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->synchronizationResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::ServerManager::State >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SetupTest::*)()>(_a, &SetupTest::setupDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SetupTest::*)(int )>(_a, &SetupTest::serverExited, 1))
            return;
    }
}

const QMetaObject *SetupTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SetupTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SetupTestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SetupTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SetupTest::setupDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SetupTest::serverExited(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
