/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.AgentManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "agentmanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AgentManagerAdaptor
 */

AgentManagerAdaptor::AgentManagerAdaptor(AgentManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AgentManagerAdaptor::~AgentManagerAdaptor()
{
    // destructor
}

QStringList AgentManagerAdaptor::agentCapabilities(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentCapabilities
    return parent()->agentCapabilities(identifier);
}

QString AgentManagerAdaptor::agentComment(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentComment
    return parent()->agentComment(identifier);
}

QVariantMap AgentManagerAdaptor::agentCustomProperties(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentCustomProperties
    return parent()->agentCustomProperties(identifier);
}

QString AgentManagerAdaptor::agentIcon(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentIcon
    return parent()->agentIcon(identifier);
}

QString AgentManagerAdaptor::agentInstanceAccountId(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceAccountId
    return parent()->agentInstanceAccountId(identifier);
}

QStringList AgentManagerAdaptor::agentInstanceActivities(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceActivities
    return parent()->agentInstanceActivities(identifier);
}

bool AgentManagerAdaptor::agentInstanceActivitiesEnabled(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceActivitiesEnabled
    return parent()->agentInstanceActivitiesEnabled(identifier);
}

void AgentManagerAdaptor::agentInstanceConfigure(const QString &identifier, qlonglong windowId)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceConfigure
    parent()->agentInstanceConfigure(identifier, windowId);
}

QString AgentManagerAdaptor::agentInstanceName(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceName
    return parent()->agentInstanceName(identifier);
}

bool AgentManagerAdaptor::agentInstanceOnline(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceOnline
    return parent()->agentInstanceOnline(identifier);
}

uint AgentManagerAdaptor::agentInstanceProgress(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceProgress
    return parent()->agentInstanceProgress(identifier);
}

QString AgentManagerAdaptor::agentInstanceProgressMessage(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceProgressMessage
    return parent()->agentInstanceProgressMessage(identifier);
}

int AgentManagerAdaptor::agentInstanceStatus(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceStatus
    return parent()->agentInstanceStatus(identifier);
}

QString AgentManagerAdaptor::agentInstanceStatusMessage(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceStatusMessage
    return parent()->agentInstanceStatusMessage(identifier);
}

void AgentManagerAdaptor::agentInstanceSynchronize(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceSynchronize
    parent()->agentInstanceSynchronize(identifier);
}

void AgentManagerAdaptor::agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection, bool recursive)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceSynchronizeCollection
    parent()->agentInstanceSynchronizeCollection(identifier, collection, recursive);
}

void AgentManagerAdaptor::agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceSynchronizeCollection
    parent()->agentInstanceSynchronizeCollection(identifier, collection);
}

void AgentManagerAdaptor::agentInstanceSynchronizeCollectionTree(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceSynchronizeCollectionTree
    parent()->agentInstanceSynchronizeCollectionTree(identifier);
}

void AgentManagerAdaptor::agentInstanceSynchronizeTags(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceSynchronizeTags
    parent()->agentInstanceSynchronizeTags(identifier);
}

QString AgentManagerAdaptor::agentInstanceType(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstanceType
    return parent()->agentInstanceType(identifier);
}

QStringList AgentManagerAdaptor::agentInstances()
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentInstances
    return parent()->agentInstances();
}

QStringList AgentManagerAdaptor::agentMimeTypes(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentMimeTypes
    return parent()->agentMimeTypes(identifier);
}

QString AgentManagerAdaptor::agentName(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentName
    return parent()->agentName(identifier);
}

QStringList AgentManagerAdaptor::agentTypes()
{
    // handle method call org.freedesktop.Akonadi.AgentManager.agentTypes
    return parent()->agentTypes();
}

QString AgentManagerAdaptor::createAgentInstance(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.createAgentInstance
    return parent()->createAgentInstance(identifier);
}

void AgentManagerAdaptor::removeAgentInstance(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.removeAgentInstance
    parent()->removeAgentInstance(identifier);
}

void AgentManagerAdaptor::restartAgentInstance(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.restartAgentInstance
    parent()->restartAgentInstance(identifier);
}

void AgentManagerAdaptor::setAgentInstanceActivities(const QString &identifier, const QStringList &activities)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.setAgentInstanceActivities
    parent()->setAgentInstanceActivities(identifier, activities);
}

void AgentManagerAdaptor::setAgentInstanceActivitiesEnabled(const QString &identifier, bool en)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.setAgentInstanceActivitiesEnabled
    parent()->setAgentInstanceActivitiesEnabled(identifier, en);
}

void AgentManagerAdaptor::setAgentInstanceName(const QString &identifier, const QString &name)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.setAgentInstanceName
    parent()->setAgentInstanceName(identifier, name);
}

void AgentManagerAdaptor::setAgentInstanceOnline(const QString &identifier, bool state)
{
    // handle method call org.freedesktop.Akonadi.AgentManager.setAgentInstanceOnline
    parent()->setAgentInstanceOnline(identifier, state);
}


#include "moc_agentmanageradaptor.cpp"
