
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_tagfetchscope_wrapper.h"

// Argument includes
#include <QSet>
#include <qbytearray.h>
#include <tagfetchscope.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_TagFetchScope_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_TagFetchScope_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::TagFetchScope >()))
        return -1;

    ::Akonadi::TagFetchScope *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "TagFetchScope", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: TagFetchScope::TagFetchScope()
    // 1: TagFetchScope::TagFetchScope(const Akonadi::TagFetchScope&)
    if (numArgs == 0) {
        overloadId = 0; // TagFetchScope()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), (pyArgs[0])))) {
        overloadId = 1; // TagFetchScope::TagFetchScope(const Akonadi::TagFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // TagFetchScope()
        {

            // TagFetchScope::TagFetchScope()
            cptr = new ::Akonadi::TagFetchScope();
            break;
        }
        case 1: // TagFetchScope(const Akonadi::TagFetchScope &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::TagFetchScope cppArg0_local;
            ::Akonadi::TagFetchScope *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // TagFetchScope::TagFetchScope(const Akonadi::TagFetchScope&)
                cptr = new ::Akonadi::TagFetchScope(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::TagFetchScope >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagFetchScope::attributes()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::TagFetchScope *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_fetchAllAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagFetchScope::fetchAllAttributes()const->bool
        bool cppResult = const_cast<const ::Akonadi::TagFetchScope *>(cppSelf)->fetchAllAttributes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_fetchAttribute(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fetchAttribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: TagFetchScope::fetchAttribute(const QByteArray&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fetchAttribute(QByteArray,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // TagFetchScope::fetchAttribute(const QByteArray&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagFetchScope::fetchAttribute(const QByteArray&,bool=)
            cppSelf->fetchAttribute(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_fetchIdOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagFetchScope::fetchIdOnly()const->bool
        bool cppResult = const_cast<const ::Akonadi::TagFetchScope *>(cppSelf)->fetchIdOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_fetchRemoteId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagFetchScope::fetchRemoteId()const->bool
        bool cppResult = const_cast<const ::Akonadi::TagFetchScope *>(cppSelf)->fetchRemoteId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_setFetchAllAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagFetchScope::setFetchAllAttributes(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // TagFetchScope::setFetchAllAttributes(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchAllAttributes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagFetchScope::setFetchAllAttributes(bool)
            cppSelf->setFetchAllAttributes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_setFetchIdOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagFetchScope::setFetchIdOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // TagFetchScope::setFetchIdOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchIdOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagFetchScope::setFetchIdOnly(bool)
            cppSelf->setFetchIdOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagFetchScopeFunc_setFetchRemoteId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagFetchScope::setFetchRemoteId(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // TagFetchScope::setFetchRemoteId(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchRemoteId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagFetchScope::setFetchRemoteId(bool)
            cppSelf->setFetchRemoteId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagFetchScope__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_TagFetchScope_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_TagFetchScope_methods[] = {
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_attributes), METH_NOARGS, nullptr},
    {"fetchAllAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_fetchAllAttributes), METH_NOARGS, nullptr},
    {"fetchAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_fetchAttribute), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchIdOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_fetchIdOnly), METH_NOARGS, nullptr},
    {"fetchRemoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_fetchRemoteId), METH_NOARGS, nullptr},
    {"setFetchAllAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_setFetchAllAttributes), METH_O, nullptr},
    {"setFetchIdOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_setFetchIdOnly), METH_O, nullptr},
    {"setFetchRemoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScopeFunc_setFetchRemoteId), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagFetchScope__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_TagFetchScope_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_TagFetchScope_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_TagFetchScope_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_TagFetchScope_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_TagFetchScope_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_TagFetchScope_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_TagFetchScope_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_TagFetchScope_spec = {
    "1:AkonadiCore.Akonadi.TagFetchScope",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_TagFetchScope_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void TagFetchScope_PythonToCpp_TagFetchScope_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_TagFetchScope_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_TagFetchScope_PythonToCpp_TagFetchScope_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_TagFetchScope_TypeF()))
        return TagFetchScope_PythonToCpp_TagFetchScope_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *TagFetchScope_PTR_CppToPython_TagFetchScope(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_TagFetchScope_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_TagFetchScope_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *TagFetchScope_COPY_CppToPython_TagFetchScope(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::TagFetchScope *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_TagFetchScope_TypeF(), new ::Akonadi::TagFetchScope(*source), true, true);
}

// Python to C++ copy conversion.
static void TagFetchScope_PythonToCpp_TagFetchScope_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::TagFetchScope *>(cppOut) = *reinterpret_cast< ::Akonadi::TagFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_TagFetchScope_PythonToCpp_TagFetchScope_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_TagFetchScope_TypeF()))
        return TagFetchScope_PythonToCpp_TagFetchScope_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_TagFetchScope_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.TagFetchScope(self)",
    "0:AkonadiCore.Akonadi.TagFetchScope(self,other:AkonadiCore.Akonadi.TagFetchScope)",
    "AkonadiCore.Akonadi.TagFetchScope.attributes(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.TagFetchScope.fetchAllAttributes(self)->bool",
    "AkonadiCore.Akonadi.TagFetchScope.fetchAttribute(self,type:typing.Union[PySide6.QtCore.QByteArray, char*],fetch:bool=true)",
    "AkonadiCore.Akonadi.TagFetchScope.fetchIdOnly(self)->bool",
    "AkonadiCore.Akonadi.TagFetchScope.fetchRemoteId(self)->bool",
    "AkonadiCore.Akonadi.TagFetchScope.setFetchAllAttributes(self,fetchAllAttributes:bool)",
    "AkonadiCore.Akonadi.TagFetchScope.setFetchIdOnly(self,fetchIdOnly:bool)",
    "AkonadiCore.Akonadi.TagFetchScope.setFetchRemoteId(self,fetchRemoteId:bool)",
    "AkonadiCore.Akonadi.TagFetchScope.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_TagFetchScope_SignatureByteSize = 226;
static constexpr uint8_t Akonadi_TagFetchScope_SignatureBytes[226] = {
    0x78, 0xda, 0x9d, 0x91, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x0a, 0x47, 0x2b, 0x31,
    0xe8, 0xe2, 0x50, 0x50, 0xa8, 0x42, 0xa1, 0x93, 0xd6, 0xea, 0x24, 0x12, 0x62, 0x7b, 0xda, 0x60,
    0x4c, 0x24, 0x3d, 0x87, 0xfc, 0x7b, 0x6b, 0xb5, 0xa0, 0xa8, 0x98, 0xba, 0x24, 0x17, 0xb8, 0xf7,
    0xdd, 0xbd, 0x97, 0x61, 0x10, 0x1e, 0xb5, 0xe2, 0xb9, 0x98, 0x69, 0x03, 0xf4, 0x51, 0xd3, 0x15,
    0x3f, 0x44, 0x80, 0x59, 0x91, 0x66, 0xfa, 0x0c, 0xdd, 0x12, 0xe4, 0xde, 0xf7, 0x06, 0x8e, 0x9d,
    0x44, 0x63, 0x01, 0xe6, 0x77, 0xb3, 0xef, 0xfd, 0x6c, 0xa1, 0x1c, 0xd1, 0x88, 0xdd, 0x05, 0xa1,
    0xbc, 0x2f, 0xd1, 0x9f, 0x24, 0x29, 0xe0, 0x66, 0x61, 0x53, 0x91, 0xc3, 0x88, 0x26, 0x58, 0x6b,
    0x93, 0xa9, 0x45, 0x08, 0x8d, 0xe1, 0x76, 0xeb, 0xc0, 0xdc, 0xdf, 0xca, 0x50, 0xca, 0xf0, 0x8d,
    0xbd, 0xd3, 0x5a, 0x3a, 0x03, 0x1a, 0xf5, 0xdd, 0x33, 0xda, 0x33, 0x04, 0xd5, 0x21, 0xd4, 0x81,
    0xae, 0x95, 0xd0, 0xea, 0xfb, 0x8e, 0xa4, 0x93, 0x15, 0xdc, 0xf4, 0xb6, 0xa4, 0xe6, 0x04, 0xb7,
    0xa1, 0x63, 0x34, 0x17, 0xa7, 0x3c, 0x6a, 0x49, 0x9c, 0xcf, 0x95, 0xb4, 0xff, 0x2c, 0xbd, 0x84,
    0x93, 0x46, 0x88, 0xf3, 0x96, 0xda, 0x12, 0x30, 0xfa, 0x1c, 0x1a, 0x79, 0x0f, 0xb3, 0x36, 0xe4,
    0xb7, 0xa0, 0x3e, 0xd9, 0x21, 0x4f, 0xfe, 0x5a, 0x73, 0x5e, 0xcc, 0x91, 0x17, 0xbf, 0xce, 0x2c,
    0xc6, 0xaa, 0xcb, 0x32, 0xd6, 0x04, 0xf4, 0xf8, 0x51, 0x96, 0x56, 0x4f, 0xef, 0x0a, 0xc0, 0x76,
    0x28, 0x73
};
#endif

PyTypeObject *init_Akonadi_TagFetchScope(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_TagFetchScope_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "TagFetchScope",
        "Akonadi::TagFetchScope",
        &Sbk_Akonadi_TagFetchScope_spec,
        &Shiboken::callCppDestructor< ::Akonadi::TagFetchScope >,
        Sbk_Akonadi_TagFetchScope_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_TagFetchScope_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_TagFetchScope_SignatureBytes, Akonadi_TagFetchScope_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_TagFetchScope_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        TagFetchScope_PythonToCpp_TagFetchScope_PTR,
        is_TagFetchScope_PythonToCpp_TagFetchScope_PTR_Convertible,
        TagFetchScope_PTR_CppToPython_TagFetchScope,
        TagFetchScope_COPY_CppToPython_TagFetchScope);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagFetchScope");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagFetchScope*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagFetchScope&");
    Shiboken::Conversions::registerConverterAlias(converter, "TagFetchScope");
    Shiboken::Conversions::registerConverterAlias(converter, "TagFetchScope*");
    Shiboken::Conversions::registerConverterAlias(converter, "TagFetchScope&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::TagFetchScope).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        TagFetchScope_PythonToCpp_TagFetchScope_COPY,
        is_TagFetchScope_PythonToCpp_TagFetchScope_COPY_Convertible);

    qRegisterMetaType< ::Akonadi::TagFetchScope >("TagFetchScope");
    qRegisterMetaType< ::Akonadi::TagFetchScope >("Akonadi::TagFetchScope");

    return pyType;
}
