#ifndef SBK_ACCOUNTACTIVITIESABSTRACTWRAPPER_H
#define SBK_ACCOUNTACTIVITIESABSTRACTWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <accountactivitiesabstract.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class AccountActivitiesAbstractWrapper : public Akonadi::AccountActivitiesAbstract
{
public:
    AccountActivitiesAbstractWrapper(::QObject * parent = nullptr);
    AccountActivitiesAbstractWrapper(const AccountActivitiesAbstractWrapper &) = delete;
    AccountActivitiesAbstractWrapper& operator=(const AccountActivitiesAbstractWrapper &) = delete;
    AccountActivitiesAbstractWrapper(AccountActivitiesAbstractWrapper &&) = delete;
    AccountActivitiesAbstractWrapper& operator=(AccountActivitiesAbstractWrapper &&) = delete;
    ~AccountActivitiesAbstractWrapper() override;

    void childEvent(::QChildEvent * event) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QString currentActivity() const override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    bool filterAcceptsRow(const ::QStringList & activities) const override;
    static bool sbk_o_filterAcceptsRow([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QStringList & activities);
    bool hasActivitySupport() const override;
    void timerEvent(::QTimerEvent * event) override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable std::array<PyObject *, 10> m_PyMethodCache = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};
};

#endif // SBK_ACCOUNTACTIVITIESABSTRACTWRAPPER_H
