/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Account.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "accountadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__AccountAdaptor
 */

Akonadi__AccountAdaptor::Akonadi__AccountAdaptor(Akonadi::AccountBasePrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__AccountAdaptor::~Akonadi__AccountAdaptor()
{
    // destructor
}

QString Akonadi__AccountAdaptor::accountId()
{
    // handle method call org.freedesktop.Akonadi.Agent.Account.accountId
    return parent()->accountId();
}

void Akonadi__AccountAdaptor::setAccountId(const QString &accountId)
{
    // handle method call org.freedesktop.Akonadi.Agent.Account.setAccountId
    parent()->setAccountId(accountId);
}


#include "moc_accountadaptor.cpp"
