/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.ResourceManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "resourcemanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ResourceManagerAdaptor
 */

ResourceManagerAdaptor::ResourceManagerAdaptor(Akonadi::Server::ResourceManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ResourceManagerAdaptor::~ResourceManagerAdaptor()
{
    // destructor
}

void ResourceManagerAdaptor::addResourceInstance(const QString &identifier, const QStringList &capabilities)
{
    // handle method call org.freedesktop.Akonadi.ResourceManager.addResourceInstance
    parent()->addResourceInstance(identifier, capabilities);
}

void ResourceManagerAdaptor::removeResourceInstance(const QString &identifier)
{
    // handle method call org.freedesktop.Akonadi.ResourceManager.removeResourceInstance
    parent()->removeResourceInstance(identifier);
}

QStringList ResourceManagerAdaptor::resourceInstances()
{
    // handle method call org.freedesktop.Akonadi.ResourceManager.resourceInstances
    return parent()->resourceInstances();
}


#include "moc_resourcemanageradaptor.cpp"
