
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_changenotification_wrapper.h"

// Argument includes
#include <QList>
#include <changenotification.h>
#include <qbytearray.h>
#include <qdatetime.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ChangeNotification_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_ChangeNotification_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::ChangeNotification >()))
        return -1;

    ::Akonadi::ChangeNotification *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ChangeNotification", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ChangeNotification::ChangeNotification()
    // 1: ChangeNotification::ChangeNotification(const Akonadi::ChangeNotification&)
    if (numArgs == 0) {
        overloadId = 0; // ChangeNotification()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), (pyArgs[0])))) {
        overloadId = 1; // ChangeNotification::ChangeNotification(const Akonadi::ChangeNotification&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // ChangeNotification()
        {

            // ChangeNotification::ChangeNotification()
            cptr = new ::Akonadi::ChangeNotification();
            break;
        }
        case 1: // ChangeNotification(const Akonadi::ChangeNotification &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::ChangeNotification cppArg0_local;
            ::Akonadi::ChangeNotification *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ChangeNotification::ChangeNotification(const Akonadi::ChangeNotification&)
                cptr = new ::Akonadi::ChangeNotification(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::ChangeNotification >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ChangeNotification::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::ChangeNotification *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_listeners(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ChangeNotification::listeners()const->QList<QByteArray>
        QList<QByteArray> cppResult = const_cast<const ::Akonadi::ChangeNotification *>(cppSelf)->listeners();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_setListeners(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ChangeNotification::setListeners(const QList<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // ChangeNotification::setListeners(const QList<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setListeners", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);

    // Call function/method
    {
        ::QList<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ChangeNotification::setListeners(const QList<QByteArray>&)
            cppSelf->setListeners(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_setTimestamp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ChangeNotification::setTimestamp(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // ChangeNotification::setTimestamp(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimestamp", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ChangeNotification::setTimestamp(const QDateTime&)
            cppSelf->setTimestamp(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ChangeNotification::setType(Akonadi::ChangeNotification::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_Type_IDX]))), (pyArg)))) {
        overloadId = 0; // ChangeNotification::setType(Akonadi::ChangeNotification::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]);

    // Call function/method
    {
        ::Akonadi::ChangeNotification::Type cppArg0{Akonadi::ChangeNotification::Items};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ChangeNotification::setType(Akonadi::ChangeNotification::Type)
            cppSelf->setType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_timestamp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ChangeNotification::timestamp()const->QDateTime
        QDateTime cppResult = const_cast<const ::Akonadi::ChangeNotification *>(cppSelf)->timestamp();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ChangeNotificationFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ChangeNotification::type()const->Akonadi::ChangeNotification::Type
        Akonadi::ChangeNotification::Type cppResult = const_cast<const ::Akonadi::ChangeNotification *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_Type_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ChangeNotification__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_ChangeNotification_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_ChangeNotification_EnumFlagInfo[] = {
    "Type:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ChangeNotification_methods[] = {
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_isValid), METH_NOARGS, nullptr},
    {"listeners", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_listeners), METH_NOARGS, nullptr},
    {"setListeners", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_setListeners), METH_O, nullptr},
    {"setTimestamp", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_setTimestamp), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_setType), METH_O, nullptr},
    {"timestamp", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_timestamp), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotificationFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ChangeNotification__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_ChangeNotification_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ChangeNotification_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ChangeNotification_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ChangeNotification_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ChangeNotification_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ChangeNotification_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ChangeNotification_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ChangeNotification_spec = {
    "1:AkonadiCore.Akonadi.ChangeNotification",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ChangeNotification_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_ChangeNotification_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ChangeNotification::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ChangeNotification::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ChangeNotification_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_Type_IDX])))
        return Enum_PythonToCpp_Akonadi_ChangeNotification_Type;
    return {};
}

static PyObject *Akonadi_ChangeNotification_Type_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ChangeNotification::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ChangeNotification::Type *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ChangeNotification_PythonToCpp_ChangeNotification_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ChangeNotification_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ChangeNotification_PythonToCpp_ChangeNotification_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ChangeNotification_TypeF()))
        return ChangeNotification_PythonToCpp_ChangeNotification_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ChangeNotification_PTR_CppToPython_ChangeNotification(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_ChangeNotification_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_ChangeNotification_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *ChangeNotification_COPY_CppToPython_ChangeNotification(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::ChangeNotification *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_ChangeNotification_TypeF(), new ::Akonadi::ChangeNotification(*source), true, true);
}

// Python to C++ copy conversion.
static void ChangeNotification_PythonToCpp_ChangeNotification_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::ChangeNotification *>(cppOut) = *reinterpret_cast< ::Akonadi::ChangeNotification *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_ChangeNotification_PythonToCpp_ChangeNotification_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ChangeNotification_TypeF()))
        return ChangeNotification_PythonToCpp_ChangeNotification_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ChangeNotification_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.ChangeNotification(self)",
    "0:AkonadiCore.Akonadi.ChangeNotification(self,other:AkonadiCore.Akonadi.ChangeNotification)",
    "AkonadiCore.Akonadi.ChangeNotification.isValid(self)->bool",
    "AkonadiCore.Akonadi.ChangeNotification.listeners(self)->QList[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.ChangeNotification.setListeners(self,listeners:QList[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.ChangeNotification.setTimestamp(self,timestamp:PySide6.QtCore.QDateTime)",
    "AkonadiCore.Akonadi.ChangeNotification.setType(self,type:AkonadiCore.Akonadi.ChangeNotification.Type)",
    "AkonadiCore.Akonadi.ChangeNotification.timestamp(self)->PySide6.QtCore.QDateTime",
    "AkonadiCore.Akonadi.ChangeNotification.type(self)->AkonadiCore.Akonadi.ChangeNotification.Type",
    "AkonadiCore.Akonadi.ChangeNotification.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ChangeNotification_SignatureByteSize = 210;
static constexpr uint8_t Akonadi_ChangeNotification_SignatureBytes[210] = {
    0x78, 0xda, 0x95, 0x91, 0xb1, 0x0a, 0xc2, 0x30, 0x10, 0x86, 0xf7, 0x3e, 0x89, 0x85, 0x1a, 0x74,
    0x71, 0xe8, 0x20, 0xd4, 0x3a, 0x16, 0xb1, 0x54, 0x5c, 0x44, 0x42, 0xb4, 0xd7, 0xf6, 0xb0, 0x4d,
    0x4a, 0x72, 0x4b, 0xde, 0xde, 0x54, 0xad, 0xa0, 0x20, 0xa6, 0x5b, 0x2e, 0xdc, 0xff, 0x7d, 0x3f,
    0xdc, 0x32, 0x4e, 0x6e, 0x4a, 0x8a, 0x12, 0x53, 0xa5, 0x81, 0xbd, 0xde, 0x2c, 0x6d, 0x84, 0xac,
    0x61, 0xa7, 0x08, 0x2b, 0xbc, 0x0a, 0x42, 0x25, 0x67, 0x06, 0xda, 0x2a, 0x0c, 0x16, 0x53, 0xd6,
    0x23, 0x45, 0x0d, 0x68, 0xcf, 0x44, 0x18, 0xf8, 0xed, 0x31, 0x34, 0x47, 0xd1, 0x62, 0xf9, 0x2c,
    0x34, 0x5f, 0x5f, 0x94, 0x6a, 0x7d, 0xa3, 0x2d, 0x1a, 0x02, 0x09, 0xda, 0x8c, 0xe1, 0x3c, 0x73,
    0x3f, 0xa7, 0xbd, 0x2d, 0xb0, 0x84, 0x15, 0xcb, 0xe9, 0x01, 0xc8, 0x37, 0x96, 0x20, 0xd1, 0x5a,
    0xd8, 0xb3, 0x2f, 0xd8, 0x00, 0x65, 0x1f, 0xec, 0xe8, 0xad, 0x8a, 0xff, 0x39, 0xc2, 0x09, 0x92,
    0x03, 0x76, 0x60, 0x48, 0x74, 0xfd, 0x53, 0x42, 0xe3, 0x18, 0x7f, 0xe3, 0xb7, 0x82, 0x60, 0x58,
    0x9e, 0x04, 0xb7, 0x3d, 0xbc, 0xb8, 0xee, 0xe5, 0x79, 0x36, 0x36, 0xa4, 0xbc, 0x2d, 0xf4, 0xd1,
    0xdf, 0x1d, 0xe0, 0x57, 0x6f, 0x6f, 0xe0, 0xd8, 0xd9, 0xb1, 0x26, 0x14, 0xf6, 0xc5, 0x73, 0x7e,
    0x55, 0xbd, 0xe5, 0x7c, 0x54, 0x38, 0x1d, 0xca, 0x9a, 0xf1, 0xc2, 0x8d, 0xc1, 0x1d, 0x86, 0x2f,
    0x31, 0x30
};
#endif

PyTypeObject *init_Akonadi_ChangeNotification(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_ChangeNotification_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ChangeNotification",
        "Akonadi::ChangeNotification",
        &Sbk_Akonadi_ChangeNotification_spec,
        &Shiboken::callCppDestructor< ::Akonadi::ChangeNotification >,
        Sbk_Akonadi_ChangeNotification_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ChangeNotification_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ChangeNotification_SignatureBytes, Akonadi_ChangeNotification_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ChangeNotification_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ChangeNotification_PythonToCpp_ChangeNotification_PTR,
        is_ChangeNotification_PythonToCpp_ChangeNotification_PTR_Convertible,
        ChangeNotification_PTR_CppToPython_ChangeNotification,
        ChangeNotification_COPY_CppToPython_ChangeNotification);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ChangeNotification");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ChangeNotification*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ChangeNotification&");
    Shiboken::Conversions::registerConverterAlias(converter, "ChangeNotification");
    Shiboken::Conversions::registerConverterAlias(converter, "ChangeNotification*");
    Shiboken::Conversions::registerConverterAlias(converter, "ChangeNotification&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ChangeNotification).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        ChangeNotification_PythonToCpp_ChangeNotification_COPY,
        is_ChangeNotification_PythonToCpp_ChangeNotification_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_ChangeNotification_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Items",
        "Collection",
        "Tag",
        "Relation",
        "Subscription",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(Akonadi::ChangeNotification::Type::Items),       //  0x00  0
        uint8_t(Akonadi::ChangeNotification::Type::Collection),  //  0x01  1
        uint8_t(Akonadi::ChangeNotification::Type::Tag),         //  0x02  2
        uint8_t(Akonadi::ChangeNotification::Type::Relation),    //  0x03  3
        uint8_t(Akonadi::ChangeNotification::Type::Subscription) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ChangeNotification.Type",
        Type_Initializer, Type_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_Type_IDX].type = EType;
    // Register converter for enum 'Akonadi::ChangeNotification::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ChangeNotification_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ChangeNotification_Type,
            is_Enum_PythonToCpp_Akonadi_ChangeNotification_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ChangeNotification::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "ChangeNotification::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::Akonadi::ChangeNotification >("ChangeNotification");
    qRegisterMetaType< ::Akonadi::ChangeNotification >("Akonadi::ChangeNotification");
    qRegisterMetaType< ::Akonadi::ChangeNotification::Type >("ChangeNotification::Type");
    qRegisterMetaType< ::Akonadi::ChangeNotification::Type >("Akonadi::ChangeNotification::Type");

    return pyType;
}
