
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_monitor_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <QList>
#include <QSet>
#include <QString>
#include <QStringList>
#include <changenotification.h>
#include <collection.h>
#include <collectionfetchscope.h>
#include <collectionstatistics.h>
#include <item.h>
#include <itemfetchscope.h>
#include <monitor.h>
#include <notificationsubscriber.h>
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <session.h>
#include <tag.h>
#include <tagfetchscope.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_Monitor_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void MonitorWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

MonitorWrapper::MonitorWrapper(::QObject * parent) : Akonadi::Monitor(parent)
{
}

void MonitorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("Monitor", funcName, gil, pyOverride, event);
}

void MonitorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Monitor::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("Monitor", funcName, gil, pyOverride, signal);
}

void MonitorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("Monitor", funcName, gil, pyOverride, event);
}

void MonitorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Monitor::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("Monitor", funcName, gil, pyOverride, signal);
}

bool MonitorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("Monitor", funcName, gil, pyOverride, event);
}

bool MonitorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("Monitor", funcName, gil, pyOverride, watched, event);
}

void MonitorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_Monitor_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("Monitor", funcName, gil, pyOverride, event);
}

const QMetaObject *MonitorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::Monitor::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int MonitorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::Monitor::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *MonitorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< MonitorWrapper *>(this));
    }
    return Akonadi::Monitor::qt_metacast(_clname);
}

MonitorWrapper::~MonitorWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_Monitor_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_Monitor_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::Monitor >()))
        return -1;

    MonitorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:Monitor", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Monitor::Monitor(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // Monitor(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Monitor::Monitor(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::Monitor(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) MonitorWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new MonitorWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::Monitor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_MonitorFunc_collectionFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::collectionFetchScope()->Akonadi::CollectionFetchScope&
        Akonadi::CollectionFetchScope & cppResult = cppSelf->collectionFetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_collectionsMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::collectionsMonitored()const->QList<Akonadi::Collection>
        QList<Akonadi::Collection> cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->collectionsMonitored();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Collection_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_connectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QObject::connectNotify(const QMetaMethod&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // QObject::connectNotify(const QMetaMethod&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "connectNotify", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QObject::connectNotify(const QMetaMethod&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::Monitor::connectNotify(*cppArg0)
                : cppSelf->connectNotify(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_disconnectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QObject::disconnectNotify(const QMetaMethod&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // QObject::disconnectNotify(const QMetaMethod&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "disconnectNotify", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QObject::disconnectNotify(const QMetaMethod&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::Monitor::disconnectNotify(*cppArg0)
                : cppSelf->disconnectNotify(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_exclusive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::exclusive()const->bool
        bool cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->exclusive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_fetchChangedOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::fetchChangedOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Monitor::fetchChangedOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetchChangedOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::fetchChangedOnly(bool)
            cppSelf->fetchChangedOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_fetchCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::fetchCollection(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Monitor::fetchCollection(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetchCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::fetchCollection(bool)
            cppSelf->fetchCollection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_fetchCollectionStatistics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::fetchCollectionStatistics(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Monitor::fetchCollectionStatistics(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetchCollectionStatistics", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::fetchCollectionStatistics(bool)
            cppSelf->fetchCollectionStatistics(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_ignoreSession(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::ignoreSession(Akonadi::Session*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Session_IDX]), (pyArg)))) {
        overloadId = 0; // Monitor::ignoreSession(Akonadi::Session*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "ignoreSession", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Session *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::ignoreSession(Akonadi::Session*)
            cppSelf->ignoreSession(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_isAllMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::isAllMonitored()const->bool
        bool cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->isAllMonitored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_itemFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::itemFetchScope()->Akonadi::ItemFetchScope&
        Akonadi::ItemFetchScope & cppResult = cppSelf->itemFetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_itemsMonitoredEx(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::itemsMonitoredEx()const->QList<long long>
        QList<long long> cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->itemsMonitoredEx();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_longlong_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_mimeTypesMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::mimeTypesMonitored()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->mimeTypesMonitored();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_numItemsMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::numItemsMonitored()const->int
        int cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->numItemsMonitored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_numMimeTypesMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::numMimeTypesMonitored()const->int
        int cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->numMimeTypesMonitored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_numResourcesMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::numResourcesMonitored()const->int
        int cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->numResourcesMonitored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_resourcesMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::resourcesMonitored()const->QList<QByteArray>
        QList<QByteArray> cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->resourcesMonitored();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_session(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::session()const->Akonadi::Session*
        Akonadi::Session * cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->session();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Session_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_setAllMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAllMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|O:setAllMonitored", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setAllMonitored(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setAllMonitored(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // Monitor::setAllMonitored(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAllMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setAllMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setAllMonitored(bool=)
            cppSelf->setAllMonitored(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setCollectionFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // Monitor::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::CollectionFetchScope cppArg0_local;
        ::Akonadi::CollectionFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
            cppSelf->setCollectionFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setCollectionMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCollectionMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setCollectionMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setCollectionMonitored(const Akonadi::Collection&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setCollectionMonitored(Akonadi::Collection,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setCollectionMonitored(const Akonadi::Collection&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCollectionMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setCollectionMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setCollectionMonitored(const Akonadi::Collection&,bool=)
            cppSelf->setCollectionMonitored(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setCollectionMoveTranslationEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::setCollectionMoveTranslationEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Monitor::setCollectionMoveTranslationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionMoveTranslationEnabled", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setCollectionMoveTranslationEnabled(bool)
            cppSelf->setCollectionMoveTranslationEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setExclusive(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setExclusive", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|O:setExclusive", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setExclusive(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setExclusive(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // Monitor::setExclusive(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setExclusive", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"exclusive", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setExclusive", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setExclusive(bool=)
            cppSelf->setExclusive(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setItemFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::setItemFetchScope(const Akonadi::ItemFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // Monitor::setItemFetchScope(const Akonadi::ItemFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::ItemFetchScope cppArg0_local;
        ::Akonadi::ItemFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setItemFetchScope(const Akonadi::ItemFetchScope&)
            cppSelf->setItemFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setItemMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setItemMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setItemMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setItemMonitored(const Akonadi::Item&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setItemMonitored(Akonadi::Item,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setItemMonitored(const Akonadi::Item&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setItemMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setItemMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setItemMonitored(const Akonadi::Item&,bool=)
            cppSelf->setItemMonitored(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setMimeTypeMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setMimeTypeMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setMimeTypeMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setMimeTypeMonitored(const QString&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setMimeTypeMonitored(QString,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setMimeTypeMonitored(const QString&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMimeTypeMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setMimeTypeMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setMimeTypeMonitored(const QString&,bool=)
            cppSelf->setMimeTypeMonitored(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setResourceMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setResourceMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setResourceMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setResourceMonitored(const QByteArray&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setResourceMonitored(QByteArray,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setResourceMonitored(const QByteArray&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setResourceMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setResourceMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setResourceMonitored(const QByteArray&,bool=)
            cppSelf->setResourceMonitored(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setSession(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::setSession(Akonadi::Session*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Session_IDX]), (pyArg)))) {
        overloadId = 0; // Monitor::setSession(Akonadi::Session*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSession", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Session *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setSession(Akonadi::Session*)
            cppSelf->setSession(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setTagFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Monitor::setTagFetchScope(const Akonadi::TagFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // Monitor::setTagFetchScope(const Akonadi::TagFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTagFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::TagFetchScope cppArg0_local;
        ::Akonadi::TagFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setTagFetchScope(const Akonadi::TagFetchScope&)
            cppSelf->setTagFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setTagMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setTagMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setTagMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setTagMonitored(const Akonadi::Tag&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setTagMonitored(Akonadi::Tag,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setTagMonitored(const Akonadi::Tag&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTagMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setTagMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Tag cppArg0_local;
        ::Akonadi::Tag *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setTagMonitored(const Akonadi::Tag&,bool=)
            cppSelf->setTagMonitored(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_setTypeMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setTypeMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setTypeMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Monitor::setTypeMonitored(Akonadi::Monitor::Type,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_Type_IDX]))), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setTypeMonitored(Akonadi::Monitor::Type,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Monitor::setTypeMonitored(Akonadi::Monitor::Type,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTypeMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setTypeMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]);
            }
        }
        ::Akonadi::Monitor::Type cppArg0 = static_cast< ::Akonadi::Monitor::Type>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Monitor::setTypeMonitored(Akonadi::Monitor::Type,bool=)
            cppSelf->setTypeMonitored(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MonitorFunc_tagFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::tagFetchScope()->Akonadi::TagFetchScope&
        Akonadi::TagFetchScope & cppResult = cppSelf->tagFetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_tagsMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::tagsMonitored()const->QList<long long>
        QList<long long> cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->tagsMonitored();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_longlong_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MonitorFunc_typesMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Monitor::typesMonitored()const->QList<Akonadi::Monitor::Type>
        QList<Akonadi::Monitor::Type> cppResult = const_cast<const ::Akonadi::Monitor *>(cppSelf)->typesMonitored();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Monitor_Type_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_Monitor_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_Monitor_EnumFlagInfo[] = {
    "Type:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_Monitor_methods[] = {
    {"collectionFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_collectionFetchScope), METH_NOARGS, nullptr},
    {"collectionsMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_collectionsMonitored), METH_NOARGS, nullptr},
    {"connectNotify", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_connectNotify), METH_O, nullptr},
    {"disconnectNotify", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_disconnectNotify), METH_O, nullptr},
    {"exclusive", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_exclusive), METH_NOARGS, nullptr},
    {"fetchChangedOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_fetchChangedOnly), METH_O, nullptr},
    {"fetchCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_fetchCollection), METH_O, nullptr},
    {"fetchCollectionStatistics", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_fetchCollectionStatistics), METH_O, nullptr},
    {"ignoreSession", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_ignoreSession), METH_O, nullptr},
    {"isAllMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_isAllMonitored), METH_NOARGS, nullptr},
    {"itemFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_itemFetchScope), METH_NOARGS, nullptr},
    {"itemsMonitoredEx", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_itemsMonitoredEx), METH_NOARGS, nullptr},
    {"mimeTypesMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_mimeTypesMonitored), METH_NOARGS, nullptr},
    {"numItemsMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_numItemsMonitored), METH_NOARGS, nullptr},
    {"numMimeTypesMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_numMimeTypesMonitored), METH_NOARGS, nullptr},
    {"numResourcesMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_numResourcesMonitored), METH_NOARGS, nullptr},
    {"resourcesMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_resourcesMonitored), METH_NOARGS, nullptr},
    {"session", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_session), METH_NOARGS, nullptr},
    {"setAllMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setAllMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCollectionFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setCollectionFetchScope), METH_O, nullptr},
    {"setCollectionMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setCollectionMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCollectionMoveTranslationEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setCollectionMoveTranslationEnabled), METH_O, nullptr},
    {"setExclusive", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setExclusive), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setItemFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setItemFetchScope), METH_O, nullptr},
    {"setItemMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setItemMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setMimeTypeMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setMimeTypeMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setResourceMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setResourceMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSession", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setSession), METH_O, nullptr},
    {"setTagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setTagFetchScope), METH_O, nullptr},
    {"setTagMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setTagMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTypeMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_setTypeMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"tagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_tagFetchScope), METH_NOARGS, nullptr},
    {"tagsMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_tagsMonitored), METH_NOARGS, nullptr},
    {"typesMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MonitorFunc_typesMonitored), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_Monitor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::Monitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<MonitorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_Monitor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_Monitor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_Monitor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_Monitor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_Monitor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_Monitor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_Monitor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_Monitor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_Monitor_spec = {
    "1:AkonadiCore.Akonadi.Monitor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_Monitor_slots
};

} //extern "C"

static void *Sbk_Akonadi_Monitor_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::Monitor *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_Monitor_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Monitor::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Monitor::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Monitor_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_Type_IDX])))
        return Enum_PythonToCpp_Akonadi_Monitor_Type;
    return {};
}

static PyObject *Akonadi_Monitor_Type_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Monitor::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Monitor::Type *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Monitor_PythonToCpp_Monitor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_Monitor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Monitor_PythonToCpp_Monitor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_Monitor_TypeF()))
        return Monitor_PythonToCpp_Monitor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Monitor_PTR_CppToPython_Monitor(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::Monitor *>(const_cast<void *>(cppIn)), Sbk_Akonadi_Monitor_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_Monitor_SignatureStrings[] = {
    "AkonadiCore.Akonadi.Monitor(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.Monitor.collectionFetchScope(self)->AkonadiCore.Akonadi.CollectionFetchScope",
    "AkonadiCore.Akonadi.Monitor.collectionsMonitored(self)->QList[AkonadiCore.Akonadi.Collection]",
    "AkonadiCore.Akonadi.Monitor.connectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "AkonadiCore.Akonadi.Monitor.disconnectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "AkonadiCore.Akonadi.Monitor.exclusive(self)->bool",
    "AkonadiCore.Akonadi.Monitor.fetchChangedOnly(self,enable:bool)",
    "AkonadiCore.Akonadi.Monitor.fetchCollection(self,enable:bool)",
    "AkonadiCore.Akonadi.Monitor.fetchCollectionStatistics(self,enable:bool)",
    "AkonadiCore.Akonadi.Monitor.ignoreSession(self,session:AkonadiCore.Akonadi.Session)",
    "AkonadiCore.Akonadi.Monitor.isAllMonitored(self)->bool",
    "AkonadiCore.Akonadi.Monitor.itemFetchScope(self)->AkonadiCore.Akonadi.ItemFetchScope",
    "AkonadiCore.Akonadi.Monitor.itemsMonitoredEx(self)->QList[long long]",
    "AkonadiCore.Akonadi.Monitor.mimeTypesMonitored(self)->QStringList",
    "AkonadiCore.Akonadi.Monitor.numItemsMonitored(self)->int",
    "AkonadiCore.Akonadi.Monitor.numMimeTypesMonitored(self)->int",
    "AkonadiCore.Akonadi.Monitor.numResourcesMonitored(self)->int",
    "AkonadiCore.Akonadi.Monitor.resourcesMonitored(self)->QList[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Monitor.session(self)->AkonadiCore.Akonadi.Session",
    "AkonadiCore.Akonadi.Monitor.setAllMonitored(self,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setCollectionFetchScope(self,fetchScope:AkonadiCore.Akonadi.CollectionFetchScope)",
    "AkonadiCore.Akonadi.Monitor.setCollectionMonitored(self,collection:AkonadiCore.Akonadi.Collection,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setCollectionMoveTranslationEnabled(self,enabled:bool)",
    "AkonadiCore.Akonadi.Monitor.setExclusive(self,exclusive:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setItemFetchScope(self,fetchScope:AkonadiCore.Akonadi.ItemFetchScope)",
    "AkonadiCore.Akonadi.Monitor.setItemMonitored(self,item:AkonadiCore.Akonadi.Item,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setMimeTypeMonitored(self,mimetype:QString,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setResourceMonitored(self,resource:typing.Union[PySide6.QtCore.QByteArray, char*],monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setSession(self,session:AkonadiCore.Akonadi.Session)",
    "AkonadiCore.Akonadi.Monitor.setTagFetchScope(self,fetchScope:AkonadiCore.Akonadi.TagFetchScope)",
    "AkonadiCore.Akonadi.Monitor.setTagMonitored(self,tag:AkonadiCore.Akonadi.Tag,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.setTypeMonitored(self,type:AkonadiCore.Akonadi.Monitor.Type,monitored:bool=true)",
    "AkonadiCore.Akonadi.Monitor.tagFetchScope(self)->AkonadiCore.Akonadi.TagFetchScope",
    "AkonadiCore.Akonadi.Monitor.tagsMonitored(self)->QList[long long]",
    "AkonadiCore.Akonadi.Monitor.typesMonitored(self)->QList[AkonadiCore.Akonadi.Monitor.Type]",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_Monitor_SignatureByteSize = 522;
static constexpr uint8_t Akonadi_Monitor_SignatureBytes[522] = {
    0x78, 0xda, 0xad, 0x56, 0x4d, 0x6f, 0xa3, 0x30, 0x10, 0xbd, 0xf7, 0x57, 0xf4, 0xb8, 0x59, 0xb1,
    0x1c, 0x7b, 0x40, 0x6a, 0x25, 0x36, 0xca, 0x4a, 0x91, 0x36, 0xed, 0xa6, 0x64, 0x4f, 0xab, 0x1c,
    0x1c, 0x98, 0x10, 0xb7, 0xc6, 0x8e, 0xec, 0xa1, 0x2a, 0xff, 0x7e, 0x0d, 0x01, 0x1a, 0x3e, 0x8c,
    0x81, 0xf6, 0x90, 0x28, 0xb6, 0xe6, 0xbd, 0x99, 0xbc, 0x99, 0x79, 0xe0, 0xbf, 0x0a, 0x4e, 0x22,
    0xba, 0x14, 0x12, 0x5c, 0xff, 0xf2, 0xdb, 0xdd, 0x08, 0x4e, 0x51, 0xc8, 0x6f, 0x0a, 0xd8, 0xd1,
    0x39, 0x13, 0x09, 0x1c, 0xbd, 0x3f, 0x59, 0x40, 0x23, 0xb8, 0x73, 0xb7, 0x58, 0x84, 0x6e, 0x9f,
    0x0e, 0x2f, 0x10, 0xe2, 0x3d, 0x4f, 0x19, 0x3b, 0xa3, 0x5c, 0xdc, 0xf8, 0x66, 0x1e, 0x37, 0x14,
    0x8c, 0xe9, 0x60, 0x2a, 0xf8, 0x2f, 0xc0, 0xf0, 0x14, 0x84, 0xe2, 0x0c, 0x05, 0xf9, 0xe2, 0xc7,
    0x43, 0x1f, 0x6e, 0xd9, 0x13, 0x3f, 0x32, 0x81, 0x2a, 0xaf, 0x20, 0xaa, 0x12, 0x6c, 0x7f, 0x53,
    0x85, 0xff, 0x86, 0xd3, 0xec, 0x2d, 0xec, 0x9c, 0xeb, 0xb8, 0x47, 0x81, 0xf4, 0x98, 0x5d, 0x44,
    0x51, 0x34, 0xe6, 0x84, 0x75, 0x44, 0xd9, 0x00, 0x12, 0xfd, 0x39, 0x89, 0x68, 0x58, 0x90, 0x88,
    0xaa, 0xaf, 0x27, 0x85, 0xf7, 0x90, 0xa5, 0x8a, 0xbe, 0xd5, 0xd2, 0x1e, 0x84, 0x60, 0x83, 0x88,
    0x63, 0xae, 0xee, 0xf2, 0x44, 0x78, 0x0c, 0xd1, 0x13, 0x67, 0x65, 0x19, 0xc0, 0xc9, 0x81, 0x81,
    0x97, 0xa3, 0x17, 0x23, 0xe0, 0xb5, 0x88, 0x9f, 0x43, 0x07, 0x48, 0x50, 0x37, 0x8a, 0x86, 0x6a,
    0x22, 0x8f, 0x16, 0x4d, 0x5f, 0x07, 0xa0, 0x54, 0x5d, 0x83, 0xba, 0x1c, 0xbc, 0x3e, 0x58, 0x19,
    0x68, 0xe1, 0x54, 0x3e, 0x63, 0x9d, 0x49, 0xb2, 0xea, 0x49, 0x11, 0x92, 0x71, 0x13, 0xbe, 0x6e,
    0x44, 0x5a, 0x49, 0x3f, 0xa6, 0x7a, 0xf5, 0xde, 0x9c, 0x6b, 0x26, 0x78, 0x7c, 0x9b, 0x7f, 0x0d,
    0x8f, 0x70, 0x42, 0x13, 0xd8, 0x65, 0x67, 0xe8, 0x59, 0x8f, 0x00, 0x25, 0xe5, 0x71, 0x4e, 0x36,
    0xc8, 0xc0, 0xd3, 0x64, 0xdd, 0xa8, 0xa4, 0x22, 0xa0, 0xdc, 0x0a, 0xdc, 0x18, 0xb3, 0x8f, 0x00,
    0x3f, 0x83, 0x12, 0xa9, 0x0c, 0x67, 0x80, 0xa5, 0x11, 0x79, 0xd1, 0xae, 0xbd, 0x68, 0x3f, 0x33,
    0x04, 0x5f, 0x4a, 0x92, 0x0d, 0x6b, 0xa9, 0xae, 0x46, 0xcd, 0xd0, 0xde, 0x72, 0xc8, 0x2c, 0x34,
    0xd8, 0x19, 0x32, 0x27, 0xa9, 0x8e, 0xc5, 0xe0, 0xdf, 0xa3, 0x4c, 0x61, 0x61, 0x63, 0x59, 0x9a,
    0xdc, 0xd5, 0x39, 0xd6, 0x67, 0x6f, 0xac, 0xcd, 0x4e, 0xc8, 0xd6, 0x2a, 0xfd, 0xc3, 0x83, 0x2d,
    0xc9, 0x3e, 0xf9, 0x27, 0x37, 0xe2, 0x0d, 0x76, 0x92, 0x70, 0xc5, 0x48, 0x7e, 0x5c, 0x15, 0x3e,
    0x11, 0x5d, 0x9b, 0x46, 0x34, 0xc2, 0x35, 0x34, 0xe5, 0xaa, 0xe1, 0x97, 0x4e, 0x6d, 0x9f, 0x13,
    0xaa, 0x5a, 0x77, 0x17, 0xde, 0x26, 0x7a, 0x13, 0x32, 0x2a, 0x43, 0x4b, 0xe8, 0xdc, 0x10, 0x8c,
    0xd4, 0xb3, 0xc4, 0xad, 0xf6, 0xb3, 0x3d, 0x8c, 0xfa, 0x1a, 0xf5, 0xb5, 0x57, 0x7a, 0xc4, 0x2c,
    0xee, 0x6a, 0x7d, 0x5b, 0xdc, 0xd5, 0x6e, 0x7a, 0x3a, 0x81, 0xa6, 0x76, 0xff, 0x72, 0xdd, 0x4b,
    0xf3, 0x46, 0x3a, 0xb7, 0xe1, 0x89, 0xc8, 0xef, 0xfb, 0x59, 0x25, 0x7c, 0xed, 0xb3, 0x41, 0x13,
    0xee, 0x48, 0x3c, 0xb1, 0xeb, 0x0d, 0xc4, 0x18, 0xfe, 0x96, 0x5c, 0x48, 0x62, 0x13, 0xef, 0x2c,
    0x49, 0x7a, 0xba, 0x5d, 0x74, 0x7a, 0x08, 0x96, 0x63, 0xa6, 0x27, 0xc3, 0x8e, 0x56, 0x06, 0xcf,
    0x6c, 0x48, 0x64, 0xa3, 0x34, 0x59, 0xfa, 0xc8, 0xc7, 0x21, 0xf6, 0x3f, 0x0a, 0x8d, 0x6f, 0x8a,
    0xd7, 0x12, 0xec, 0x6f, 0xfe, 0x03, 0x45, 0xfb, 0x2c, 0xaa
};
#endif

PyTypeObject *init_Akonadi_Monitor(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_Monitor_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Monitor",
        "Akonadi::Monitor*",
        &Sbk_Akonadi_Monitor_spec,
        &Shiboken::callCppDestructor< Akonadi::Monitor >,
        Sbk_Akonadi_Monitor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_Monitor_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_Monitor_SignatureBytes, Akonadi_Monitor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_Monitor_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Monitor_PythonToCpp_Monitor_PTR,
        is_Monitor_PythonToCpp_Monitor_PTR_Convertible,
        Monitor_PTR_CppToPython_Monitor);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Monitor");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Monitor*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Monitor&");
    Shiboken::Conversions::registerConverterAlias(converter, "Monitor");
    Shiboken::Conversions::registerConverterAlias(converter, "Monitor*");
    Shiboken::Conversions::registerConverterAlias(converter, "Monitor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::Monitor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(MonitorWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_Monitor_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_Monitor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Collections",
        "Items",
        "Tags",
        "Subscribers",
        "Notifications",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(Akonadi::Monitor::Type::Collections),  //  0x01  1
        uint8_t(Akonadi::Monitor::Type::Items),        //  0x02  2
        uint8_t(Akonadi::Monitor::Type::Tags),         //  0x03  3
        uint8_t(Akonadi::Monitor::Type::Subscribers),  //  0x04  4
        uint8_t(Akonadi::Monitor::Type::Notifications) //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Monitor.Type",
        Type_Initializer, Type_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_Type_IDX].type = EType;
    // Register converter for enum 'Akonadi::Monitor::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Monitor_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Monitor_Type,
            is_Enum_PythonToCpp_Akonadi_Monitor_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Monitor::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Monitor::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::Monitor::staticMetaObject);
    qRegisterMetaType< ::Akonadi::Monitor::Type >("Monitor::Type");
    qRegisterMetaType< ::Akonadi::Monitor::Type >("Akonadi::Monitor::Type");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::Monitor::staticMetaObject, sizeof(MonitorWrapper));

    return pyType;
}
