/****************************************************************************
** Meta object code from reading C++ file 'agentcontrolinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "agentcontrolinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentcontrolinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiAgentControlInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiAgentControlInterface",
        "configurationDialogAccepted",
        "",
        "configurationDialogRejected",
        "finished",
        "abort",
        "QDBusPendingReply<>",
        "cleanup",
        "configure",
        "Q_NOREPLY",
        "windowId",
        "quit",
        "reconfigure"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configurationDialogAccepted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationDialogRejected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(5, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(7, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'configure'
        QtMocHelpers::SlotData<void(qlonglong)>(8, 9, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 10 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(11, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(12, 2, QMC::AccessPublic, 0x80000000 | 6),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiAgentControlInterface, qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiAgentControlInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiAgentControlInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiAgentControlInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configurationDialogAccepted(); break;
        case 1: _t->configurationDialogRejected(); break;
        case 2: _t->finished(); break;
        case 3: { QDBusPendingReply<> _r = _t->abort();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->cleanup();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->configure((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 6: { QDBusPendingReply<> _r = _t->quit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->reconfigure();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentControlInterface::*)()>(_a, &OrgFreedesktopAkonadiAgentControlInterface::configurationDialogAccepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentControlInterface::*)()>(_a, &OrgFreedesktopAkonadiAgentControlInterface::configurationDialogRejected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentControlInterface::*)()>(_a, &OrgFreedesktopAkonadiAgentControlInterface::finished, 2))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiAgentControlInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiAgentControlInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentControlInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiAgentControlInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiAgentControlInterface::configurationDialogAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgFreedesktopAkonadiAgentControlInterface::configurationDialogRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgFreedesktopAkonadiAgentControlInterface::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
