/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.AgentManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef AGENTMANAGERADAPTOR_H
#define AGENTMANAGERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "agentmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.AgentManager
 */
class AgentManagerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.AgentManager")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.AgentManager\">\n"
"    <signal name=\"agentTypeAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentType\"/>\n"
"    </signal>\n"
"    <signal name=\"agentTypeRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentType\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceStatusChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"status\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceAdvancedStatusChanged\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"status\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceProgressChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"progress\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceNameChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceWarning\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceError\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"agentInstanceOnlineChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"state\"/>\n"
"    </signal>\n"
"    <method name=\"agentTypes\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"agentName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentComment\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentIcon\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentMimeTypes\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentCapabilities\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentCustomProperties\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"createAgentInstance\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"removeAgentInstance\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceType\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstances\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceStatus\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceStatusMessage\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceProgress\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceProgressMessage\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"setAgentInstanceName\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceConfigure\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"windowId\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceSynchronize\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceSynchronizeCollectionTree\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceSynchronizeCollection\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"collection\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceSynchronizeCollection\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"collection\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceSynchronizeTags\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceOnline\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"setAgentInstanceOnline\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"state\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceActivities\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"setAgentInstanceActivities\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"activities\"/>\n"
"    </method>\n"
"    <method name=\"restartAgentInstance\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"setAgentInstanceActivitiesEnabled\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"en\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceActivitiesEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <method name=\"agentInstanceAccountId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
"    </method>\n"
"    <signal name=\"agentInstanceAccountIdChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"accountId\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    AgentManagerAdaptor(AgentManager *parent);
    ~AgentManagerAdaptor() override;

    inline AgentManager *parent() const
    { return static_cast<AgentManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QStringList agentCapabilities(const QString &identifier);
    QString agentComment(const QString &identifier);
    QVariantMap agentCustomProperties(const QString &identifier);
    QString agentIcon(const QString &identifier);
    QString agentInstanceAccountId(const QString &identifier);
    QStringList agentInstanceActivities(const QString &identifier);
    bool agentInstanceActivitiesEnabled(const QString &identifier);
    void agentInstanceConfigure(const QString &identifier, qlonglong windowId);
    QString agentInstanceName(const QString &identifier);
    bool agentInstanceOnline(const QString &identifier);
    uint agentInstanceProgress(const QString &identifier);
    QString agentInstanceProgressMessage(const QString &identifier);
    int agentInstanceStatus(const QString &identifier);
    QString agentInstanceStatusMessage(const QString &identifier);
    void agentInstanceSynchronize(const QString &identifier);
    void agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection, bool recursive);
    void agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection);
    void agentInstanceSynchronizeCollectionTree(const QString &identifier);
    void agentInstanceSynchronizeTags(const QString &identifier);
    QString agentInstanceType(const QString &identifier);
    QStringList agentInstances();
    QStringList agentMimeTypes(const QString &identifier);
    QString agentName(const QString &identifier);
    QStringList agentTypes();
    QString createAgentInstance(const QString &identifier);
    void removeAgentInstance(const QString &identifier);
    void restartAgentInstance(const QString &identifier);
    void setAgentInstanceActivities(const QString &identifier, const QStringList &activities);
    void setAgentInstanceActivitiesEnabled(const QString &identifier, bool en);
    void setAgentInstanceName(const QString &identifier, const QString &name);
    void setAgentInstanceOnline(const QString &identifier, bool state);
Q_SIGNALS: // SIGNALS
    void agentInstanceAccountIdChanged(const QString &agentIdentifier, const QString &accountId);
    void agentInstanceAdded(const QString &agentIdentifier);
    void agentInstanceAdvancedStatusChanged(const QString &agentIdentifier, const QVariantMap &status);
    void agentInstanceError(const QString &agentIdentifier, const QString &message);
    void agentInstanceNameChanged(const QString &agentIdentifier, const QString &name);
    void agentInstanceOnlineChanged(const QString &agentIdentifier, bool state);
    void agentInstanceProgressChanged(const QString &agentIdentifier, uint progress, const QString &message);
    void agentInstanceRemoved(const QString &agentIdentifier);
    void agentInstanceStatusChanged(const QString &agentIdentifier, int status, const QString &message);
    void agentInstanceWarning(const QString &agentIdentifier, const QString &message);
    void agentTypeAdded(const QString &agentType);
    void agentTypeRemoved(const QString &agentType);
};

#endif
