/****************************************************************************
** Meta object code from reading C++ file 'agentconfiguration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/quick/agentconfiguration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentconfiguration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15AgentDataChangeE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentDataChange::qt_create_metaobjectdata<qt_meta_tag_ZN15AgentDataChangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentDataChange",
        "instanceId",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'instanceId'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'status'
        QtMocHelpers::PropertyData<int>(2, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AgentDataChange, qt_meta_tag_ZN15AgentDataChangeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AgentDataChange::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AgentDataChangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AgentDataChangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15AgentDataChangeE_t>.metaTypes,
    nullptr
} };

void AgentDataChange::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<AgentDataChange *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->instanceId; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->status; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->instanceId, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->status, *reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN18AgentConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentConfiguration::qt_create_metaobjectdata<qt_meta_tag_ZN18AgentConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentConfiguration",
        "QML.Element",
        "auto",
        "agentProgressChanged",
        "",
        "Akonadi::AgentInstance",
        "instance",
        "mimetypesChanged",
        "runningAgentsChanged",
        "availableAgentsChanged",
        "errorOccurred",
        "error",
        "specialCollectionsChanged",
        "createNew",
        "index",
        "edit",
        "editIdentifier",
        "resourceIdentifier",
        "remove",
        "removeIdentifier",
        "restart",
        "restartIdentifier",
        "isRemovable",
        "availableAgents",
        "Akonadi::AgentFilterProxyModel*",
        "runningAgents",
        "mimetypes",
        "specialCollections",
        "Akonadi::SpecialCollections*",
        "AgentStatuses",
        "Idle",
        "Running",
        "Broken",
        "NotConfigured"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agentProgressChanged'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'mimetypesChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runningAgentsChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableAgentsChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'specialCollectionsChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createNew'
        QtMocHelpers::SlotData<void(int)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'edit'
        QtMocHelpers::SlotData<void(int)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'editIdentifier'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(int)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'removeIdentifier'
        QtMocHelpers::SlotData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'restart'
        QtMocHelpers::SlotData<void(int)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'restartIdentifier'
        QtMocHelpers::SlotData<void(const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'isRemovable'
        QtMocHelpers::MethodData<bool(int)>(22, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'availableAgents'
        QtMocHelpers::PropertyData<Akonadi::AgentFilterProxyModel*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'runningAgents'
        QtMocHelpers::PropertyData<Akonadi::AgentFilterProxyModel*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'mimetypes'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'specialCollections'
        QtMocHelpers::PropertyData<Akonadi::SpecialCollections*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AgentStatuses'
        QtMocHelpers::EnumData<enum AgentStatuses>(29, 29, QMC::EnumFlags{}).add({
            {   30, AgentStatuses::Idle },
            {   31, AgentStatuses::Running },
            {   32, AgentStatuses::Broken },
            {   33, AgentStatuses::NotConfigured },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AgentConfiguration, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AgentConfiguration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AgentConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AgentConfigurationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AgentConfigurationE_t>.metaTypes,
    nullptr
} };

void AgentConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentConfiguration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agentProgressChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 1: _t->mimetypesChanged(); break;
        case 2: _t->runningAgentsChanged(); break;
        case 3: _t->availableAgentsChanged(); break;
        case 4: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->specialCollectionsChanged(); break;
        case 6: _t->createNew((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->edit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->editIdentifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->removeIdentifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->restart((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->restartIdentifier((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { bool _r = _t->isRemovable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)(const Akonadi::AgentInstance & )>(_a, &AgentConfiguration::agentProgressChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)()>(_a, &AgentConfiguration::mimetypesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)()>(_a, &AgentConfiguration::runningAgentsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)()>(_a, &AgentConfiguration::availableAgentsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)(const QString & )>(_a, &AgentConfiguration::errorOccurred, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentConfiguration::*)()>(_a, &AgentConfiguration::specialCollectionsChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::AgentFilterProxyModel* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Akonadi::SpecialCollections* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Akonadi::AgentFilterProxyModel**>(_v) = _t->availableAgents(); break;
        case 1: *reinterpret_cast<Akonadi::AgentFilterProxyModel**>(_v) = _t->runningAgents(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->mimetypes(); break;
        case 3: *reinterpret_cast<Akonadi::SpecialCollections**>(_v) = _t->specialCollections(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setMimetypes(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setSpecialCollections(*reinterpret_cast<Akonadi::SpecialCollections**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AgentConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AgentConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AgentConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AgentConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AgentConfiguration::agentProgressChanged(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AgentConfiguration::mimetypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AgentConfiguration::runningAgentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AgentConfiguration::availableAgentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AgentConfiguration::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AgentConfiguration::specialCollectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
