/****************************************************************************
** Meta object code from reading C++ file 'agentbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/agentbase/agentbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi9AgentBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::AgentBase::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi9AgentBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::AgentBase",
        "agentNameChanged",
        "",
        "name",
        "status",
        "message",
        "percent",
        "progress",
        "warning",
        "error",
        "advancedStatus",
        "QVariantMap",
        "abortRequested",
        "reloadConfiguration",
        "onlineChanged",
        "online",
        "configurationDialogAccepted",
        "configurationDialogRejected",
        "agentActivitiesChanged",
        "activities",
        "agentActivitiesEnabledChanged",
        "enabled",
        "configure",
        "WId",
        "windowId",
        "delayedInit",
        "slotStatus",
        "slotPercent",
        "slotWarning",
        "slotError",
        "slotNetworkStatusChange",
        "slotResumedFromSuspend",
        "slotTemporaryOfflineTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agentNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'percent'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'advancedStatus'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 4 },
        }}),
        // Signal 'abortRequested'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadConfiguration'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onlineChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'configurationDialogAccepted'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationDialogRejected'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'agentActivitiesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 19 },
        }}),
        // Signal 'agentActivitiesEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'configure'
        QtMocHelpers::SlotData<void(WId)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'delayedInit'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStatus'
        QtMocHelpers::SlotData<void(int, const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotPercent'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotWarning'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotError'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotNetworkStatusChange'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotResumedFromSuspend'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTemporaryOfflineTimeout'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AgentBase, qt_meta_tag_ZN7Akonadi9AgentBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::AgentBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi9AgentBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi9AgentBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi9AgentBaseE_t>.metaTypes,
    nullptr
} };

void Akonadi::AgentBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agentNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->percent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->advancedStatus((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: _t->abortRequested(); break;
        case 8: _t->reloadConfiguration(); break;
        case 9: _t->onlineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->configurationDialogAccepted(); break;
        case 11: _t->configurationDialogRejected(); break;
        case 12: _t->agentActivitiesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->agentActivitiesEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->configure((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        case 15: _t->d_func()->delayedInit(); break;
        case 16: _t->d_func()->slotStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->d_func()->slotPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->d_func()->slotWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->d_func()->slotError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->d_func()->slotNetworkStatusChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->d_func()->slotResumedFromSuspend(); break;
        case 22: _t->d_func()->slotTemporaryOfflineTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(const QString & )>(_a, &AgentBase::agentNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(int , const QString & )>(_a, &AgentBase::status, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(int )>(_a, &AgentBase::percent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(const QString & )>(_a, &AgentBase::warning, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(const QString & )>(_a, &AgentBase::error, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(const QVariantMap & )>(_a, &AgentBase::advancedStatus, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)()>(_a, &AgentBase::abortRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)()>(_a, &AgentBase::reloadConfiguration, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(bool )>(_a, &AgentBase::onlineChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)()>(_a, &AgentBase::configurationDialogAccepted, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)()>(_a, &AgentBase::configurationDialogRejected, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(const QStringList & )>(_a, &AgentBase::agentActivitiesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentBase::*)(bool )>(_a, &AgentBase::agentActivitiesEnabledChanged, 13))
            return;
    }
}

const QMetaObject *Akonadi::AgentBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::AgentBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi9AgentBaseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::AgentBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::AgentBase::agentNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::AgentBase::status(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 3
void Akonadi::AgentBase::percent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Akonadi::AgentBase::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Akonadi::AgentBase::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Akonadi::AgentBase::advancedStatus(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Akonadi::AgentBase::abortRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Akonadi::AgentBase::reloadConfiguration()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Akonadi::AgentBase::onlineChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Akonadi::AgentBase::configurationDialogAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Akonadi::AgentBase::configurationDialogRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Akonadi::AgentBase::agentActivitiesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Akonadi::AgentBase::agentActivitiesEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
