/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Status.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "statusadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__StatusAdaptor
 */

Akonadi__StatusAdaptor::Akonadi__StatusAdaptor(Akonadi::AgentBase *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__StatusAdaptor::~Akonadi__StatusAdaptor()
{
    // destructor
}

bool Akonadi__StatusAdaptor::isOnline()
{
    // handle method call org.freedesktop.Akonadi.Agent.Status.isOnline
    return parent()->isOnline();
}

int Akonadi__StatusAdaptor::progress()
{
    // handle method call org.freedesktop.Akonadi.Agent.Status.progress
    return parent()->progress();
}

void Akonadi__StatusAdaptor::setOnline(bool state)
{
    // handle method call org.freedesktop.Akonadi.Agent.Status.setOnline
    parent()->setOnline(state);
}

int Akonadi__StatusAdaptor::status()
{
    // handle method call org.freedesktop.Akonadi.Agent.Status.status
    return parent()->status();
}

QString Akonadi__StatusAdaptor::statusMessage()
{
    // handle method call org.freedesktop.Akonadi.Agent.Status.statusMessage
    return parent()->statusMessage();
}


#include "moc_statusadaptor.cpp"
