
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collectionannotationsattribute_wrapper.h"

// Wrappers providing overrides
#include "akonadi_exception_wrapper.h"
#include "akonadi_attribute_wrapper.h"

// Argument includes
#include <QMap>
#include <collectionannotationsattribute.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void CollectionAnnotationsAttributeWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

CollectionAnnotationsAttributeWrapper::CollectionAnnotationsAttributeWrapper()
{
}

CollectionAnnotationsAttributeWrapper::CollectionAnnotationsAttributeWrapper(const ::QMap<QByteArray,QByteArray> & annotations) : Akonadi::CollectionAnnotationsAttribute(annotations)
{
}

::Akonadi::CollectionAnnotationsAttribute * CollectionAnnotationsAttributeWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionAnnotationsAttribute::clone();
    }
    return sbk_o_clone("CollectionAnnotationsAttribute", funcName, gil, pyOverride);
}

::Akonadi::CollectionAnnotationsAttribute * CollectionAnnotationsAttributeWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< Akonadi::CollectionAnnotationsAttribute >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::Akonadi::CollectionAnnotationsAttribute *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void CollectionAnnotationsAttributeWrapper::deserialize(const ::QByteArray & data)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionAnnotationsAttribute::deserialize(data);
    }
    AttributeWrapper::sbk_o_deserialize("CollectionAnnotationsAttribute", funcName, gil, pyOverride, data);
}

::QByteArray CollectionAnnotationsAttributeWrapper::serialized() const
{
    static const char *funcName = "serialized";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionAnnotationsAttribute::serialized();
    }
    return ExceptionWrapper::sbk_o_type("CollectionAnnotationsAttribute", funcName, gil, pyOverride);
}

::QByteArray CollectionAnnotationsAttributeWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionAnnotationsAttribute::type();
    }
    return ExceptionWrapper::sbk_o_type("CollectionAnnotationsAttribute", funcName, gil, pyOverride);
}

CollectionAnnotationsAttributeWrapper::~CollectionAnnotationsAttributeWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_CollectionAnnotationsAttribute_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::CollectionAnnotationsAttribute >()))
        return -1;

    CollectionAnnotationsAttributeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "CollectionAnnotationsAttribute", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CollectionAnnotationsAttribute::CollectionAnnotationsAttribute()
    // 1: CollectionAnnotationsAttribute::CollectionAnnotationsAttribute(const QMap<QByteArray,QByteArray>&)
    if (numArgs == 0) {
        overloadId = 0; // CollectionAnnotationsAttribute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QMap_QByteArray_QByteArray_IDX], (pyArgs[0])))) {
        overloadId = 1; // CollectionAnnotationsAttribute::CollectionAnnotationsAttribute(const QMap<QByteArray,QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // CollectionAnnotationsAttribute()
        {

            // CollectionAnnotationsAttribute::CollectionAnnotationsAttribute()
            cptr = new CollectionAnnotationsAttributeWrapper();
            break;
        }
        case 1: // CollectionAnnotationsAttribute(const QMap<QByteArray,QByteArray> &annotations)
        {
            ::QMap<QByteArray,QByteArray> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CollectionAnnotationsAttribute::CollectionAnnotationsAttribute(const QMap<QByteArray,QByteArray>&)
                cptr = new CollectionAnnotationsAttributeWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::CollectionAnnotationsAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_annotations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionAnnotationsAttribute::annotations()const->QMap<QByteArray,QByteArray>
        QMap<QByteArray,QByteArray> cppResult = const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->annotations();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QMap_QByteArray_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::clone()const->Akonadi::CollectionAnnotationsAttribute*
        Akonadi::CollectionAnnotationsAttribute * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->::Akonadi::CollectionAnnotationsAttribute::clone()
            : const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attribute::deserialize(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Attribute::deserialize(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Attribute::deserialize(const QByteArray&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::CollectionAnnotationsAttribute::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_serialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::serialized()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->::Akonadi::CollectionAnnotationsAttribute::serialized()
            : const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->serialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_setAnnotations(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionAnnotationsAttribute::setAnnotations(const QMap<QByteArray,QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QMap_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // CollectionAnnotationsAttribute::setAnnotations(const QMap<QByteArray,QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAnnotations", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]);

    // Call function/method
    {
        ::QMap<QByteArray,QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionAnnotationsAttribute::setAnnotations(const QMap<QByteArray,QByteArray>&)
            cppSelf->setAnnotations(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionAnnotationsAttributeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::type()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->::Akonadi::CollectionAnnotationsAttribute::type()
            : const_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_CollectionAnnotationsAttribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CollectionAnnotationsAttribute_methods[] = {
    {"annotations", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_annotations), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_clone), METH_NOARGS, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_deserialize), METH_O, nullptr},
    {"serialized", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_serialized), METH_NOARGS, nullptr},
    {"setAnnotations", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_setAnnotations), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionAnnotationsAttributeFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_CollectionAnnotationsAttribute_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<CollectionAnnotationsAttributeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_Akonadi_CollectionAnnotationsAttribute_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::CollectionAnnotationsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]), (pyArg)))) {
                // CollectionAnnotationsAttribute::operator==(const Akonadi::CollectionAnnotationsAttribute&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::CollectionAnnotationsAttribute *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Akonadi_CollectionAnnotationsAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CollectionAnnotationsAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CollectionAnnotationsAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionAnnotationsAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CollectionAnnotationsAttribute_spec = {
    "1:AkonadiCore.Akonadi.CollectionAnnotationsAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CollectionAnnotationsAttribute_slots
};

} //extern "C"

static void *Sbk_Akonadi_CollectionAnnotationsAttribute_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::Akonadi::Attribute >())
        return dynamic_cast< ::Akonadi::CollectionAnnotationsAttribute *>(reinterpret_cast< ::Akonadi::Attribute *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CollectionAnnotationsAttribute_PythonToCpp_CollectionAnnotationsAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CollectionAnnotationsAttribute_PythonToCpp_CollectionAnnotationsAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF()))
        return CollectionAnnotationsAttribute_PythonToCpp_CollectionAnnotationsAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CollectionAnnotationsAttribute_PTR_CppToPython_CollectionAnnotationsAttribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::CollectionAnnotationsAttribute *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_CollectionAnnotationsAttribute_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_CollectionAnnotationsAttribute_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.CollectionAnnotationsAttribute(self)",
    "0:AkonadiCore.Akonadi.CollectionAnnotationsAttribute(self,annotations:QMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.annotations(self)->QMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.clone(self)->AkonadiCore.Akonadi.CollectionAnnotationsAttribute",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.deserialize(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.serialized(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.setAnnotations(self,annotations:QMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.type(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionAnnotationsAttribute.__eq__(self,other:AkonadiCore.Akonadi.CollectionAnnotationsAttribute)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_CollectionAnnotationsAttribute_SignatureByteSize = 208;
static constexpr uint8_t Akonadi_CollectionAnnotationsAttribute_SignatureBytes[208] = {
    0x78, 0xda, 0xc5, 0x93, 0x31, 0x0b, 0xc2, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x0a, 0x47, 0x95, 0x1a,
    0x74, 0x71, 0xe8, 0x20, 0x44, 0x67, 0xc1, 0x22, 0x4e, 0x22, 0xe5, 0xda, 0x9c, 0x1a, 0x0c, 0x39,
    0x4d, 0xcf, 0xa1, 0xfe, 0x7a, 0xab, 0x6d, 0x55, 0x84, 0x0a, 0x06, 0xc4, 0xed, 0xe0, 0x72, 0xf7,
    0xbd, 0xf7, 0x92, 0x8c, 0x22, 0x79, 0x20, 0x0b, 0x4a, 0xcf, 0xc8, 0xa1, 0xa8, 0x6b, 0x31, 0x23,
    0x63, 0x30, 0x63, 0x4d, 0x56, 0x5a, 0x4b, 0x0c, 0xb7, 0x2a, 0x97, 0xcc, 0x4e, 0xa7, 0x67, 0xc6,
    0x6e, 0x8e, 0x66, 0xdb, 0x0b, 0x86, 0xbe, 0xa3, 0x21, 0x3c, 0x3b, 0x51, 0x3c, 0x87, 0xe3, 0x7a,
    0x51, 0x2c, 0xb5, 0xc2, 0xb1, 0x88, 0xf9, 0xbe, 0x2b, 0x9e, 0x16, 0x8c, 0xd2, 0x39, 0x28, 0xc2,
    0x4e, 0x6b, 0x6b, 0xd3, 0x0b, 0xbe, 0xe7, 0x8b, 0x17, 0x74, 0x65, 0x63, 0x30, 0xf1, 0x57, 0xe0,
    0x23, 0x20, 0x33, 0x64, 0xb1, 0x41, 0x7f, 0x3f, 0xef, 0x83, 0x54, 0x98, 0xa3, 0xd3, 0x60, 0xf4,
    0xa5, 0xce, 0x5f, 0x01, 0x43, 0xc4, 0xc5, 0x51, 0xdb, 0x9d, 0x58, 0xd9, 0xf2, 0xf0, 0x27, 0xfb,
    0xd9, 0x1e, 0x5c, 0xdf, 0x2f, 0xec, 0x07, 0x56, 0x35, 0x86, 0x5b, 0x39, 0x7e, 0xeb, 0x59, 0xbe,
    0x5d, 0xe7, 0x3f, 0x9f, 0x56, 0x19, 0x28, 0xfe, 0xc4, 0x67, 0x92, 0xe0, 0x29, 0x49, 0x2a, 0x7f,
    0xc4, 0x7b, 0x74, 0x1e, 0x1f, 0xaf, 0xd4, 0x94, 0x12, 0x99, 0xe0, 0x0a, 0x4b, 0xb2, 0x78, 0xb5
};
#endif

PyTypeObject *init_Akonadi_CollectionAnnotationsAttribute(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_CollectionAnnotationsAttribute_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CollectionAnnotationsAttribute",
        "Akonadi::CollectionAnnotationsAttribute*",
        &Sbk_Akonadi_CollectionAnnotationsAttribute_spec,
        &Shiboken::callCppDestructor< Akonadi::CollectionAnnotationsAttribute >,
        Sbk_Akonadi_CollectionAnnotationsAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_CollectionAnnotationsAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_CollectionAnnotationsAttribute_SignatureBytes, Akonadi_CollectionAnnotationsAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CollectionAnnotationsAttribute_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CollectionAnnotationsAttribute_PythonToCpp_CollectionAnnotationsAttribute_PTR,
        is_CollectionAnnotationsAttribute_PythonToCpp_CollectionAnnotationsAttribute_PTR_Convertible,
        CollectionAnnotationsAttribute_PTR_CppToPython_CollectionAnnotationsAttribute);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionAnnotationsAttribute");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionAnnotationsAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionAnnotationsAttribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionAnnotationsAttribute");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionAnnotationsAttribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionAnnotationsAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::CollectionAnnotationsAttribute).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(CollectionAnnotationsAttributeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_CollectionAnnotationsAttribute_typeDiscovery);

    qRegisterMetaType< ::Akonadi::CollectionAnnotationsAttribute *>();

    return pyType;
}
