/********************************************************************************
** Form generated from reading UI file 'selftestdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELFTESTDIALOG_H
#define UI_SELFTESTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SelfTestDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *introductionLabel;
    QTreeView *testView;
    QGroupBox *detailsGroup;
    QVBoxLayout *verticalLayout;
    QLabel *detailsLabel;
    QLabel *label;

    void setupUi(QWidget *SelfTestDialog)
    {
        if (SelfTestDialog->objectName().isEmpty())
            SelfTestDialog->setObjectName("SelfTestDialog");
        SelfTestDialog->resize(412, 436);
        verticalLayout_2 = new QVBoxLayout(SelfTestDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        introductionLabel = new QLabel(SelfTestDialog);
        introductionLabel->setObjectName("introductionLabel");
        introductionLabel->setWordWrap(true);

        verticalLayout_2->addWidget(introductionLabel);

        testView = new QTreeView(SelfTestDialog);
        testView->setObjectName("testView");
        testView->setRootIsDecorated(false);
        testView->setHeaderHidden(true);

        verticalLayout_2->addWidget(testView);

        detailsGroup = new QGroupBox(SelfTestDialog);
        detailsGroup->setObjectName("detailsGroup");
        detailsGroup->setEnabled(false);
        verticalLayout = new QVBoxLayout(detailsGroup);
        verticalLayout->setObjectName("verticalLayout");
        detailsLabel = new QLabel(detailsGroup);
        detailsLabel->setObjectName("detailsLabel");
        detailsLabel->setWordWrap(true);
        detailsLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout->addWidget(detailsLabel);


        verticalLayout_2->addWidget(detailsGroup);

        label = new QLabel(SelfTestDialog);
        label->setObjectName("label");
        label->setWordWrap(true);
        label->setOpenExternalLinks(true);
        label->setTextInteractionFlags(Qt::TextBrowserInteraction);

        verticalLayout_2->addWidget(label);


        retranslateUi(SelfTestDialog);

        QMetaObject::connectSlotsByName(SelfTestDialog);
    } // setupUi

    void retranslateUi(QWidget *SelfTestDialog)
    {
        introductionLabel->setText(tr2i18n("An error occurred during the startup of the Akonadi server. The following self-tests are supposed to help with tracking down and solving this problem. When requesting support or reporting bugs, please always include this report.", nullptr));
        detailsGroup->setTitle(tr2i18n("Details", nullptr));
        detailsLabel->setText(QString());
        label->setText(tr2i18n("<p>For more troubleshooting tips please refer to <a href=\"https://userbase.kde.org/Akonadi\">userbase.kde.org/Akonadi</a>.</p>", nullptr));
        (void)SelfTestDialog;
    } // retranslateUi

};

namespace Ui {
    class SelfTestDialog: public Ui_SelfTestDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELFTESTDIALOG_H

