/****************************************************************************
** Meta object code from reading C++ file 'agentmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/agentmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi12AgentManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::AgentManager::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi12AgentManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::AgentManager",
        "typeAdded",
        "",
        "Akonadi::AgentType",
        "type",
        "typeRemoved",
        "instanceAdded",
        "Akonadi::AgentInstance",
        "instance",
        "instanceRemoved",
        "instanceStatusChanged",
        "instanceProgressChanged",
        "instanceNameChanged",
        "instanceError",
        "message",
        "instanceWarning",
        "instanceOnline",
        "online",
        "instanceAccountIdChanged",
        "accountId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeAdded'
        QtMocHelpers::SignalData<void(const Akonadi::AgentType &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'typeRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::AgentType &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'instanceAdded'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'instanceRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'instanceStatusChanged'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'instanceProgressChanged'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'instanceNameChanged'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'instanceError'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'instanceWarning'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'instanceOnline'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'instanceAccountIdChanged'
        QtMocHelpers::SignalData<void(const Akonadi::AgentInstance &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AgentManager, qt_meta_tag_ZN7Akonadi12AgentManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::AgentManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12AgentManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12AgentManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi12AgentManagerE_t>.metaTypes,
    nullptr
} };

void Akonadi::AgentManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentType>>(_a[1]))); break;
        case 1: _t->typeRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentType>>(_a[1]))); break;
        case 2: _t->instanceAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 3: _t->instanceRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 4: _t->instanceStatusChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 5: _t->instanceProgressChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 6: _t->instanceNameChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1]))); break;
        case 7: _t->instanceError((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->instanceWarning((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->instanceOnline((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->instanceAccountIdChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::AgentInstance>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentType >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentType >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::AgentInstance >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentType & )>(_a, &AgentManager::typeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentType & )>(_a, &AgentManager::typeRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & )>(_a, &AgentManager::instanceAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & )>(_a, &AgentManager::instanceRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & )>(_a, &AgentManager::instanceStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & )>(_a, &AgentManager::instanceProgressChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & )>(_a, &AgentManager::instanceNameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & , const QString & )>(_a, &AgentManager::instanceError, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & , const QString & )>(_a, &AgentManager::instanceWarning, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & , bool )>(_a, &AgentManager::instanceOnline, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const Akonadi::AgentInstance & , const QString & )>(_a, &AgentManager::instanceAccountIdChanged, 10))
            return;
    }
}

const QMetaObject *Akonadi::AgentManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::AgentManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12AgentManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::AgentManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::AgentManager::typeAdded(const Akonadi::AgentType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::AgentManager::typeRemoved(const Akonadi::AgentType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Akonadi::AgentManager::instanceAdded(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi::AgentManager::instanceRemoved(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Akonadi::AgentManager::instanceStatusChanged(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Akonadi::AgentManager::instanceProgressChanged(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Akonadi::AgentManager::instanceNameChanged(const Akonadi::AgentInstance & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Akonadi::AgentManager::instanceError(const Akonadi::AgentInstance & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Akonadi::AgentManager::instanceWarning(const Akonadi::AgentInstance & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Akonadi::AgentManager::instanceOnline(const Akonadi::AgentInstance & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Akonadi::AgentManager::instanceAccountIdChanged(const Akonadi::AgentInstance & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}
QT_WARNING_POP
