/****************************************************************************
** Meta object code from reading C++ file 'agentmanagerinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "agentmanagerinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentmanagerinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiAgentManagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiAgentManagerInterface",
        "agentInstanceAccountIdChanged",
        "",
        "agentIdentifier",
        "accountId",
        "agentInstanceAdded",
        "agentInstanceAdvancedStatusChanged",
        "QVariantMap",
        "status",
        "agentInstanceError",
        "message",
        "agentInstanceNameChanged",
        "name",
        "agentInstanceOnlineChanged",
        "state",
        "agentInstanceProgressChanged",
        "progress",
        "agentInstanceRemoved",
        "agentInstanceStatusChanged",
        "agentInstanceWarning",
        "agentTypeAdded",
        "agentType",
        "agentTypeRemoved",
        "agentCapabilities",
        "QDBusPendingReply<QStringList>",
        "identifier",
        "agentComment",
        "QDBusPendingReply<QString>",
        "agentCustomProperties",
        "QDBusPendingReply<QVariantMap>",
        "agentIcon",
        "agentInstanceAccountId",
        "agentInstanceActivities",
        "agentInstanceActivitiesEnabled",
        "QDBusPendingReply<bool>",
        "agentInstanceConfigure",
        "QDBusPendingReply<>",
        "windowId",
        "agentInstanceName",
        "agentInstanceOnline",
        "agentInstanceProgress",
        "QDBusPendingReply<uint>",
        "agentInstanceProgressMessage",
        "agentInstanceStatus",
        "QDBusPendingReply<int>",
        "agentInstanceStatusMessage",
        "agentInstanceSynchronize",
        "agentInstanceSynchronizeCollection",
        "collection",
        "recursive",
        "agentInstanceSynchronizeCollectionTree",
        "agentInstanceSynchronizeTags",
        "agentInstanceType",
        "agentInstances",
        "agentMimeTypes",
        "agentName",
        "agentTypes",
        "createAgentInstance",
        "removeAgentInstance",
        "restartAgentInstance",
        "setAgentInstanceActivities",
        "activities",
        "setAgentInstanceActivitiesEnabled",
        "en",
        "setAgentInstanceName",
        "setAgentInstanceOnline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agentInstanceAccountIdChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'agentInstanceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'agentInstanceAdvancedStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'agentInstanceError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'agentInstanceNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'agentInstanceOnlineChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'agentInstanceProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 16 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'agentInstanceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'agentInstanceStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 8 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'agentInstanceWarning'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'agentTypeAdded'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'agentTypeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'agentCapabilities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentComment'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentCustomProperties'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentIcon'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(30, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceAccountId'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceActivities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceActivitiesEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceConfigure'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, qlonglong)>(35, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::LongLong, 37 },
        }}),
        // Slot 'agentInstanceName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceOnline'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceProgress'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceProgressMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceStatus'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &)>(43, 2, QMC::AccessPublic, 0x80000000 | 44, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceStatusMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceSynchronize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(46, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceSynchronizeCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, qlonglong, bool)>(47, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::LongLong, 48 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'agentInstanceSynchronizeCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, qlonglong)>(47, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::LongLong, 48 },
        }}),
        // Slot 'agentInstanceSynchronizeCollectionTree'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(50, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceSynchronizeTags'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstanceType'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentInstances'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(53, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'agentMimeTypes'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(54, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(55, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentTypes'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(56, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'createAgentInstance'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(57, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'removeAgentInstance'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(58, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'restartAgentInstance'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(59, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'setAgentInstanceActivities'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QStringList &)>(60, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::QStringList, 61 },
        }}),
        // Slot 'setAgentInstanceActivitiesEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(62, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::Bool, 63 },
        }}),
        // Slot 'setAgentInstanceName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(64, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'setAgentInstanceOnline'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(65, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 25 }, { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiAgentManagerInterface, qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiAgentManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiAgentManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiAgentManagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agentInstanceAccountIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->agentInstanceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->agentInstanceAdvancedStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 3: _t->agentInstanceError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->agentInstanceNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->agentInstanceOnlineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->agentInstanceProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->agentInstanceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->agentInstanceStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->agentInstanceWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->agentTypeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->agentTypeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { QDBusPendingReply<QStringList> _r = _t->agentCapabilities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->agentComment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QVariantMap> _r = _t->agentCustomProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QString> _r = _t->agentIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QString> _r = _t->agentInstanceAccountId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QStringList> _r = _t->agentInstanceActivities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<bool> _r = _t->agentInstanceActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->agentInstanceConfigure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QString> _r = _t->agentInstanceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<bool> _r = _t->agentInstanceOnline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<uint> _r = _t->agentInstanceProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QString> _r = _t->agentInstanceProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<int> _r = _t->agentInstanceStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<QString> _r = _t->agentInstanceStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->agentInstanceSynchronize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->agentInstanceSynchronizeCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->agentInstanceSynchronizeCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<> _r = _t->agentInstanceSynchronizeCollectionTree((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<> _r = _t->agentInstanceSynchronizeTags((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<QString> _r = _t->agentInstanceType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<QStringList> _r = _t->agentInstances();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<QStringList> _r = _t->agentMimeTypes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<QString> _r = _t->agentName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<QStringList> _r = _t->agentTypes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<QString> _r = _t->createAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->removeAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->restartAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->setAgentInstanceActivities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->setAgentInstanceActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->setAgentInstanceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<> _r = _t->setAgentInstanceOnline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAccountIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , const QVariantMap & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAdvancedStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , bool )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceOnlineChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , uint , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceProgressChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , int , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceStatusChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & , const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceWarning, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentTypeAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentManagerInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentManagerInterface::agentTypeRemoved, 11))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiAgentManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiAgentManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopAkonadiAgentManagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiAgentManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAccountIdChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceAdvancedStatusChanged(const QString & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceOnlineChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceProgressChanged(const QString & _t1, uint _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceStatusChanged(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void OrgFreedesktopAkonadiAgentManagerInterface::agentInstanceWarning(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void OrgFreedesktopAkonadiAgentManagerInterface::agentTypeAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void OrgFreedesktopAkonadiAgentManagerInterface::agentTypeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
