/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Search.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "searchadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__SearchAdaptor
 */

Akonadi__SearchAdaptor::Akonadi__SearchAdaptor(Akonadi::AgentSearchInterfacePrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__SearchAdaptor::~Akonadi__SearchAdaptor()
{
    // destructor
}

void Akonadi__SearchAdaptor::addSearch(const QString &query, const QString &queryLanguage, qlonglong destination)
{
    // handle method call org.freedesktop.Akonadi.Agent.Search.addSearch
    parent()->addSearch(query, queryLanguage, destination);
}

void Akonadi__SearchAdaptor::removeSearch(qlonglong destination)
{
    // handle method call org.freedesktop.Akonadi.Agent.Search.removeSearch
    parent()->removeSearch(destination);
}

void Akonadi__SearchAdaptor::search(const QByteArray &searchId, const QString &query, qlonglong collection)
{
    // handle method call org.freedesktop.Akonadi.Agent.Search.search
    parent()->search(searchId, query, collection);
}


#include "moc_searchadaptor.cpp"
