

#ifndef SBK_AKONADICORE_PYTHON_H
#define SBK_AKONADICORE_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtcore_python.h>
#include <pyside6_qtgui_python.h>
#include <kcoreaddons_python.h>

// Bound library includes
#include <abstractdifferencesreporter.h>
#include <accountactivitiesabstract.h>
#include <agentconfigurationbase.h>
#include <agentfilterproxymodel.h>
#include <agentinstance.h>
#include <agentinstancecreatejob.h>
#include <agentinstancefilterproxymodel.h>
#include <agentinstancemodel.h>
#include <agentmanager.h>
#include <agenttype.h>
#include <agenttypemodel.h>
#include <attribute.h>
#include <attributefactory.h>
#include <cachepolicy.h>
#include <changenotification.h>
#include <changerecorder.h>
#include <collection.h>
#include <collectionannotationsattribute.h>
#include <collectionattributessynchronizationjob.h>
#include <collectioncolorattribute.h>
#include <collectioncopyjob.h>
#include <collectioncreatejob.h>
#include <collectiondeletejob.h>
#include <collectionfetchjob.h>
#include <collectionfetchscope.h>
#include <collectionfilterproxymodel.h>
#include <collectionidentificationattribute.h>
#include <collectionmodifyjob.h>
#include <collectionmovejob.h>
#include <collectionpathresolver.h>
#include <collectionquotaattribute.h>
#include <collectionstatistics.h>
#include <collectionstatisticsjob.h>
#include <collectionutils.h>
#include <colorproxymodel.h>
#include <control.h>
#include <differencesalgorithminterface.h>
#include <entityannotationsattribute.h>
#include <entitydeletedattribute.h>
#include <entitydisplayattribute.h>
#include <entityhiddenattribute.h>
#include <entitymimetypefiltermodel.h>
#include <entityorderproxymodel.h>
#include <entityrightsfiltermodel.h>
#include <entitytreemodel.h>
#include <exceptionbase.h>
#include <favoritecollectionattribute.h>
#include <favoritecollectionsmodel.h>
#include <gidextractorinterface.h>
#include <indexpolicyattribute.h>
#include <item.h>
#include <itemcopyjob.h>
#include <itemcreatejob.h>
#include <itemdeletejob.h>
#include <itemfetchjob.h>
#include <itemfetchscope.h>
#include <itemmodifyjob.h>
#include <itemmonitor.h>
#include <itemmovejob.h>
#include <itemsearchjob.h>
#include <itemsync.h>
#include <job.h>
#include <mimetypechecker.h>
#include <monitor.h>
#include <notificationsubscriber.h>
#include <partfetcher.h>
#include <persistentsearchattribute.h>
#include <recursivecollectionfilterproxymodel.h>
#include <recursiveitemfetchjob.h>
#include <resourcesynchronizationjob.h>
#include <searchcreatejob.h>
#include <searchquery.h>
#include <selectionproxymodel.h>
#include <servermanager.h>
#include <session.h>
#include <specialcollectionattribute.h>
#include <specialcollections.h>
#include <specialcollectionsdiscoveryjob.h>
#include <specialcollectionsrequestjob.h>
#include <statisticsproxymodel.h>
#include <tag.h>
#include <tagattribute.h>
#include <tagcache.h>
#include <tagcreatejob.h>
#include <tagdeletejob.h>
#include <tagfetchjob.h>
#include <tagfetchscope.h>
#include <tagmodel.h>
#include <tagmodifyjob.h>
#include <transactionjobs.h>
#include <transactionsequence.h>
#include <trashfilterproxymodel.h>
#include <trashjob.h>
#include <trashrestorejob.h>
#include <trashsettings.h>
#include "colorproxymodel.h"
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <qjsonobject.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_AkonadiCoreAkonadi_IDX                               = 0,
    SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX         = 2,
    SBK_Akonadi_AbstractDifferencesReporter_IDX              = 1,
    SBK_Akonadi_AccountActivitiesAbstract_IDX                = 3,
    SBK_Akonadi_AgentConfigurationBase_IDX                   = 4,
    SBK_Akonadi_AgentFilterProxyModel_IDX                    = 5,
    SBK_Akonadi_AgentInstance_Status_IDX                     = 7,
    SBK_Akonadi_AgentInstance_IDX                            = 6,
    SBK_Akonadi_AgentInstanceCreateJob_IDX                   = 8,
    SBK_Akonadi_AgentInstanceFilterProxyModel_IDX            = 9,
    SBK_Akonadi_AgentInstanceModel_Roles_IDX                 = 11,
    SBK_Akonadi_AgentInstanceModel_IDX                       = 10,
    SBK_Akonadi_AgentManager_IDX                             = 12,
    SBK_Akonadi_AgentType_IDX                                = 13,
    SBK_Akonadi_AgentTypeModel_Roles_IDX                     = 15,
    SBK_Akonadi_AgentTypeModel_IDX                           = 14,
    SBK_Akonadi_Attribute_IDX                                = 16,
    SBK_Akonadi_AttributeFactory_IDX                         = 17,
    SBK_Akonadi_CachePolicy_IDX                              = 18,
    SBK_Akonadi_ChangeNotification_Type_IDX                  = 20,
    SBK_Akonadi_ChangeNotification_IDX                       = 19,
    SBK_Akonadi_ChangeRecorder_IDX                           = 21,
    SBK_Akonadi_Collection_Right_IDX                         = 26,
    SBK_QFlags_Akonadi_Collection_Right_IDX                  = 133,
    SBK_Akonadi_Collection_CreateOption_IDX                  = 23,
    SBK_Akonadi_Collection_UrlType_IDX                       = 27,
    SBK_Akonadi_Collection_ListPreference_IDX                = 24,
    SBK_Akonadi_Collection_ListPurpose_IDX                   = 25,
    SBK_Akonadi_Collection_IDX                               = 22,
    SBK_Akonadi_CollectionAnnotationsAttribute_IDX           = 28,
    SBK_Akonadi_CollectionAttributesSynchronizationJob_IDX   = 29,
    SBK_Akonadi_CollectionColorAttribute_IDX                 = 30,
    SBK_Akonadi_CollectionCopyJob_IDX                        = 31,
    SBK_Akonadi_CollectionCreateJob_IDX                      = 32,
    SBK_Akonadi_CollectionDeleteJob_IDX                      = 33,
    SBK_Akonadi_CollectionFetchJob_Type_IDX                  = 35,
    SBK_Akonadi_CollectionFetchJob_IDX                       = 34,
    SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX   = 37,
    SBK_Akonadi_CollectionFetchScope_ListFilter_IDX          = 38,
    SBK_Akonadi_CollectionFetchScope_IDX                     = 36,
    SBK_Akonadi_CollectionFilterProxyModel_IDX               = 39,
    SBK_Akonadi_CollectionIdentificationAttribute_IDX        = 40,
    SBK_Akonadi_CollectionModifyJob_IDX                      = 41,
    SBK_Akonadi_CollectionMoveJob_IDX                        = 42,
    SBK_Akonadi_CollectionPathResolver_IDX                   = 43,
    SBK_Akonadi_CollectionQuotaAttribute_IDX                 = 44,
    SBK_Akonadi_CollectionStatistics_IDX                     = 45,
    SBK_Akonadi_CollectionStatisticsJob_IDX                  = 46,
    SBK_AkonadiCoreAkonadi_CollectionUtils_IDX               = 47,
    SBK_Akonadi_Control_IDX                                  = 48,
    SBK_Akonadi_DifferencesAlgorithmInterface_IDX            = 49,
    SBK_Akonadi_EntityAnnotationsAttribute_IDX               = 50,
    SBK_Akonadi_EntityDeletedAttribute_IDX                   = 51,
    SBK_Akonadi_EntityDisplayAttribute_IDX                   = 52,
    SBK_Akonadi_EntityHiddenAttribute_IDX                    = 53,
    SBK_Akonadi_EntityMimeTypeFilterModel_IDX                = 54,
    SBK_Akonadi_EntityOrderProxyModel_IDX                    = 55,
    SBK_Akonadi_EntityRightsFilterModel_IDX                  = 56,
    SBK_Akonadi_EntityTreeModel_Roles_IDX                    = 62,
    SBK_Akonadi_EntityTreeModel_FetchState_IDX               = 59,
    SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX              = 60,
    SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX   = 61,
    SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX  = 58,
    SBK_Akonadi_EntityTreeModel_IDX                          = 57,
    SBK_Akonadi_Exception_IDX                                = 63,
    SBK_Akonadi_FavoriteCollectionAttribute_IDX              = 64,
    SBK_Akonadi_FavoriteCollectionsModel_IDX                 = 65,
    SBK_Akonadi_GidExtractorInterface_IDX                    = 66,
    SBK_Akonadi_IndexPolicyAttribute_IDX                     = 67,
    SBK_Akonadi_Item_CreateOption_IDX                        = 69,
    SBK_Akonadi_Item_UrlType_IDX                             = 70,
    SBK_Akonadi_Item_IDX                                     = 68,
    SBK_Akonadi_ItemCopyJob_IDX                              = 71,
    SBK_Akonadi_ItemCreateJob_MergeOption_IDX                = 73,
    SBK_QFlags_Akonadi_ItemCreateJob_MergeOption_IDX         = 134,
    SBK_Akonadi_ItemCreateJob_IDX                            = 72,
    SBK_Akonadi_ItemDeleteJob_IDX                            = 74,
    SBK_Akonadi_ItemFetchJob_DeliveryOption_IDX              = 76,
    SBK_QFlags_Akonadi_ItemFetchJob_DeliveryOption_IDX       = 135,
    SBK_Akonadi_ItemFetchJob_IDX                             = 75,
    SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX         = 78,
    SBK_Akonadi_ItemFetchScope_IDX                           = 77,
    SBK_Akonadi_ItemModifyJob_IDX                            = 79,
    SBK_Akonadi_ItemMonitor_IDX                              = 80,
    SBK_Akonadi_ItemMoveJob_IDX                              = 81,
    SBK_Akonadi_ItemSearchJob_IDX                            = 82,
    SBK_Akonadi_ItemSync_MergeMode_IDX                       = 84,
    SBK_Akonadi_ItemSync_TransactionMode_IDX                 = 85,
    SBK_Akonadi_ItemSync_IDX                                 = 83,
    SBK_Akonadi_Job_Error_IDX                                = 87,
    SBK_Akonadi_Job_IDX                                      = 86,
    SBK_Akonadi_MimeTypeChecker_IDX                          = 88,
    SBK_Akonadi_Monitor_Type_IDX                             = 90,
    SBK_Akonadi_Monitor_IDX                                  = 89,
    SBK_Akonadi_NotificationSubscriber_IDX                   = 91,
    SBK_Akonadi_PartFetcher_IDX                              = 92,
    SBK_Akonadi_PersistentSearchAttribute_IDX                = 93,
    SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX      = 94,
    SBK_Akonadi_RecursiveItemFetchJob_IDX                    = 95,
    SBK_Akonadi_ResourceSynchronizationJob_IDX               = 96,
    SBK_Akonadi_SearchCreateJob_IDX                          = 97,
    SBK_Akonadi_SearchQuery_IDX                              = 98,
    SBK_Akonadi_SearchTerm_Relation_IDX                      = 101,
    SBK_Akonadi_SearchTerm_Condition_IDX                     = 100,
    SBK_Akonadi_SearchTerm_IDX                               = 99,
    SBK_Akonadi_SelectionProxyModel_IDX                      = 102,
    SBK_Akonadi_ServerManager_State_IDX                      = 107,
    SBK_Akonadi_ServerManager_ServiceType_IDX                = 106,
    SBK_Akonadi_ServerManager_ServiceAgentType_IDX           = 105,
    SBK_Akonadi_ServerManager_OpenMode_IDX                   = 104,
    SBK_Akonadi_ServerManager_IDX                            = 103,
    SBK_Akonadi_Session_IDX                                  = 108,
    SBK_Akonadi_SpecialCollectionAttribute_IDX               = 109,
    SBK_Akonadi_SpecialCollections_IDX                       = 110,
    SBK_Akonadi_SpecialCollectionsDiscoveryJob_IDX           = 111,
    SBK_Akonadi_SpecialCollectionsRequestJob_IDX             = 112,
    SBK_Akonadi_StatisticsProxyModel_IDX                     = 113,
    SBK_Akonadi_Tag_CreateOption_IDX                         = 115,
    SBK_Akonadi_Tag_IDX                                      = 114,
    SBK_Akonadi_TagAttribute_IDX                             = 116,
    SBK_Akonadi_TagCache_IDX                                 = 117,
    SBK_Akonadi_TagCreateJob_IDX                             = 118,
    SBK_Akonadi_TagDeleteJob_IDX                             = 119,
    SBK_Akonadi_TagFetchJob_IDX                              = 120,
    SBK_Akonadi_TagFetchScope_IDX                            = 121,
    SBK_Akonadi_TagModel_Roles_IDX                           = 123,
    SBK_Akonadi_TagModel_IDX                                 = 122,
    SBK_Akonadi_TagModifyJob_IDX                             = 124,
    SBK_Akonadi_TransactionJob_IDX                           = 125,
    SBK_Akonadi_TransactionSequence_IDX                      = 126,
    SBK_Akonadi_TrashFilterProxyModel_IDX                    = 127,
    SBK_Akonadi_TrashJob_IDX                                 = 128,
    SBK_Akonadi_TrashRestoreJob_IDX                          = 129,
    SBK_AkonadiCoreAkonadi_TrashSettings_IDX                 = 130,
    SBK_ColorProxyModel_Roles_IDX                            = 132,
    SBK_ColorProxyModel_IDX                                  = 131,
    SBK_AkonadiCore_IDX_COUNT                                = 136,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkAkonadiCoreTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkAkonadiCoreModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkAkonadiCoreTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_AKONADICORE_QLIST_INT_IDX                            = 0, // QList<int>
    SBK_AKONADICORE_QMAP_INT_QVARIANT_IDX                    = 1, // QMap<int,QVariant>
    SBK_AKONADICORE_QLIST_QMODELINDEX_IDX                    = 2, // QList<QModelIndex>
    SBK_AKONADICORE_QHASH_INT_QBYTEARRAY_IDX                 = 3, // QHash<int,QByteArray>
    SBK_AKONADICORE_QMAP_QBYTEARRAY_QBYTEARRAY_IDX           = 4, // QMap<QByteArray,QByteArray>
    SBK_AKONADICORE_QLIST_QINT64_IDX                         = 5, // QList<qint64>
    SBK_AKONADICORE_QLIST_AKONADI_COLLECTION_IDX             = 6, // QList<Akonadi::Collection>
    SBK_AKONADICORE_QLIST_AKONADI_ATTRIBUTEPTR_IDX           = 7, // QList<Akonadi::Attribute*>
    SBK_AKONADICORE_QSET_QBYTEARRAY_IDX                      = 8, // QSet<QByteArray>
    SBK_AKONADICORE_QLIST_LONGLONG_IDX                       = 9, // QList<long long>
    SBK_AKONADICORE_QLIST_AKONADI_ITEM_IDX                   = 10, // QList<Akonadi::Item>
    SBK_AKONADICORE_QMAP_QSTRING_QVARIANT_IDX                = 11, // QMap<QString,QVariant>
    SBK_AKONADICORE_QMAP_QBYTEARRAY_QSTRING_IDX              = 12, // QMap<QByteArray,QString>
    SBK_AKONADICORE_QLIST_QBYTEARRAY_IDX                     = 13, // QList<QByteArray>
    SBK_AKONADICORE_QLIST_AKONADI_TAG_IDX                    = 14, // QList<Akonadi::Tag>
    SBK_AKONADICORE_QLIST_QURL_IDX                           = 15, // QList<QUrl>
    SBK_AKONADICORE_QLIST_AKONADI_AGENTINSTANCE_IDX          = 16, // QList<Akonadi::AgentInstance>
    SBK_AKONADICORE_QLIST_AKONADI_AGENTTYPE_IDX              = 17, // QList<Akonadi::AgentType>
    SBK_AKONADICORE_QSET_AKONADI_TAG_IDX                     = 18, // QSet<Akonadi::Tag>
    SBK_AKONADICORE_QLIST_AKONADI_MONITOR_TYPE_IDX           = 19, // QList<Akonadi::Monitor::Type>
    SBK_AKONADICORE_QSET_QINT64_IDX                          = 20, // QSet<qint64>
    SBK_AKONADICORE_QSET_QSTRING_IDX                         = 21, // QSet<QString>
    SBK_AKONADICORE_QSET_AKONADI_MONITOR_TYPE_IDX            = 22, // QSet<Akonadi::Monitor::Type>
    SBK_AKONADICORE_QLIST_AKONADI_SEARCHTERM_IDX             = 23, // QList<Akonadi::SearchTerm>
    SBK_AKONADICORE_QLIST_QVARIANT_IDX                       = 24, // QList<QVariant>
    SBK_AKONADICORE_QLIST_QSTRING_IDX                        = 25, // QList<QString>
    SBK_AKONADICORE_CONVERTERS_IDX_COUNT                     = 26,
};

// Converter indices
enum : int {
    SBK_AkonadiCore_QList_int_IDX                            = 0, // QList<int>
    SBK_AkonadiCore_QMap_int_QVariant_IDX                    = 1, // QMap<int,QVariant>
    SBK_AkonadiCore_QList_QModelIndex_IDX                    = 2, // QList<QModelIndex>
    SBK_AkonadiCore_QHash_int_QByteArray_IDX                 = 3, // QHash<int,QByteArray>
    SBK_AkonadiCore_QMap_QByteArray_QByteArray_IDX           = 4, // QMap<QByteArray,QByteArray>
    SBK_AkonadiCore_QList_qint64_IDX                         = 5, // QList<qint64>
    SBK_AkonadiCore_QList_Akonadi_Collection_IDX             = 6, // QList<Akonadi::Collection>
    SBK_AkonadiCore_QList_Akonadi_AttributePTR_IDX           = 7, // QList<Akonadi::Attribute*>
    SBK_AkonadiCore_QSet_QByteArray_IDX                      = 8, // QSet<QByteArray>
    SBK_AkonadiCore_QList_longlong_IDX                       = 9, // QList<long long>
    SBK_AkonadiCore_QList_Akonadi_Item_IDX                   = 10, // QList<Akonadi::Item>
    SBK_AkonadiCore_QMap_QString_QVariant_IDX                = 11, // QMap<QString,QVariant>
    SBK_AkonadiCore_QMap_QByteArray_QString_IDX              = 12, // QMap<QByteArray,QString>
    SBK_AkonadiCore_QList_QByteArray_IDX                     = 13, // QList<QByteArray>
    SBK_AkonadiCore_QList_Akonadi_Tag_IDX                    = 14, // QList<Akonadi::Tag>
    SBK_AkonadiCore_QList_QUrl_IDX                           = 15, // QList<QUrl>
    SBK_AkonadiCore_QList_Akonadi_AgentInstance_IDX          = 16, // QList<Akonadi::AgentInstance>
    SBK_AkonadiCore_QList_Akonadi_AgentType_IDX              = 17, // QList<Akonadi::AgentType>
    SBK_AkonadiCore_QSet_Akonadi_Tag_IDX                     = 18, // QSet<Akonadi::Tag>
    SBK_AkonadiCore_QList_Akonadi_Monitor_Type_IDX           = 19, // QList<Akonadi::Monitor::Type>
    SBK_AkonadiCore_QSet_qint64_IDX                          = 20, // QSet<qint64>
    SBK_AkonadiCore_QSet_QString_IDX                         = 21, // QSet<QString>
    SBK_AkonadiCore_QSet_Akonadi_Monitor_Type_IDX            = 22, // QSet<Akonadi::Monitor::Type>
    SBK_AkonadiCore_QList_Akonadi_SearchTerm_IDX             = 23, // QList<Akonadi::SearchTerm>
    SBK_AkonadiCore_QList_QVariant_IDX                       = 24, // QList<QVariant>
    SBK_AkonadiCore_QList_QString_IDX                        = 25, // QList<QString>
    SBK_AkonadiCore_CONVERTERS_IDX_COUNT                     = 26,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::Akonadi::AbstractDifferencesReporter::Mode >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AbstractDifferencesReporter >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AccountActivitiesAbstract >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentConfigurationBase >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentConfigurationBase_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentFilterProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentFilterProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstance::Status >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_Status_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstance >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstanceCreateJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstanceCreateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstanceFilterProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstanceFilterProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstanceModel::Roles >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstanceModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentInstanceModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstanceModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentManager >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentType >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentTypeModel::Roles >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentTypeModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AgentTypeModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentTypeModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Attribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::AttributeFactory >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AttributeFactory_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CachePolicy >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CachePolicy_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ChangeNotification::Type >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ChangeNotification >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeNotification_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ChangeRecorder >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ChangeRecorder_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection::Right >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_Right_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<Akonadi::Collection::Right> >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_Collection_Right_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection::CreateOption >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_CreateOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection::UrlType >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_UrlType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection::ListPreference >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPreference_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection::ListPurpose >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Collection >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionAnnotationsAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAnnotationsAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionAttributesSynchronizationJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionAttributesSynchronizationJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionColorAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionColorAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionCopyJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionCopyJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionCreateJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionCreateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionDeleteJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionDeleteJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFetchJob::Type >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchJob_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFetchJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFetchScope::AncestorRetrieval >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFetchScope::ListFilter >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFetchScope >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionFilterProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFilterProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionIdentificationAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionModifyJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionModifyJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionMoveJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionMoveJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionPathResolver >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionPathResolver_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionQuotaAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionQuotaAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionStatistics >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::CollectionStatisticsJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatisticsJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Control >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Control_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::DifferencesAlgorithmInterface >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_DifferencesAlgorithmInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityAnnotationsAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityAnnotationsAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityDeletedAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityDeletedAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityDisplayAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityDisplayAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityHiddenAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityHiddenAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityMimeTypeFilterModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityMimeTypeFilterModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityOrderProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityOrderProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityRightsFilterModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityRightsFilterModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel::Roles >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel::FetchState >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_FetchState_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel::HeaderGroup >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel::ItemPopulationStrategy >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel::CollectionFetchStrategy >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::EntityTreeModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Exception >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Exception_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::FavoriteCollectionAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::FavoriteCollectionsModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::GidExtractorInterface >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_GidExtractorInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::IndexPolicyAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_IndexPolicyAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Item::CreateOption >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_CreateOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Item::UrlType >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_UrlType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Item >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemCopyJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemCopyJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemCreateJob::MergeOption >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemCreateJob_MergeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<Akonadi::ItemCreateJob::MergeOption> >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_ItemCreateJob_MergeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemCreateJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemCreateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemDeleteJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemDeleteJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemFetchJob::DeliveryOption >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchJob_DeliveryOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<Akonadi::ItemFetchJob::DeliveryOption> >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_ItemFetchJob_DeliveryOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemFetchJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemFetchScope::AncestorRetrieval >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemFetchScope >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemModifyJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemModifyJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemMonitor >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemMoveJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemSearchJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemSearchJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemSync::MergeMode >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemSync_MergeMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemSync::TransactionMode >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemSync_TransactionMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ItemSync >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemSync_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Job::Error >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Job_Error_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Job >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Job_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::MimeTypeChecker >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Monitor::Type >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Monitor >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::NotificationSubscriber >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::PartFetcher >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_PartFetcher_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::PersistentSearchAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_PersistentSearchAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::RecursiveCollectionFilterProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::RecursiveItemFetchJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveItemFetchJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ResourceSynchronizationJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ResourceSynchronizationJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SearchCreateJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SearchCreateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SearchQuery >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SearchQuery_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SearchTerm::Relation >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SearchTerm_Relation_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SearchTerm::Condition >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SearchTerm_Condition_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SearchTerm >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SearchTerm_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SelectionProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SelectionProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ServerManager::State >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_State_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ServerManager::ServiceType >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ServerManager::ServiceAgentType >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceAgentType_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ServerManager::OpenMode >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_OpenMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::ServerManager >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Session >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Session_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SpecialCollectionAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SpecialCollectionAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SpecialCollections >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SpecialCollections_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SpecialCollectionsDiscoveryJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SpecialCollectionsDiscoveryJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::SpecialCollectionsRequestJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_SpecialCollectionsRequestJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::StatisticsProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Tag::CreateOption >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_CreateOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::Tag >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagAttribute >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagCache >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagCache_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagCreateJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagCreateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagDeleteJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagDeleteJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagFetchJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagFetchScope >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagModel::Roles >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TagModifyJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagModifyJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TransactionJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TransactionJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TransactionSequence >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TransactionSequence_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TrashFilterProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TrashFilterProxyModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TrashJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TrashJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::Akonadi::TrashRestoreJob >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TrashRestoreJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::ColorProxyModel::Roles >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_ColorProxyModel_Roles_IDX]); }
template<> inline PyTypeObject *SbkType< ::ColorProxyModel >() { return Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_ColorProxyModel_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_AKONADICORE_PYTHON_H

