/****************************************************************************
** Meta object code from reading C++ file 'resourcescheduler_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/agentbase/resourcescheduler_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcescheduler_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::ResourceScheduler::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::ResourceScheduler",
        "executeFullSync",
        "",
        "executeCollectionAttributesSync",
        "Akonadi::Collection",
        "col",
        "executeCollectionSync",
        "executeCollectionTreeSync",
        "executeTagSync",
        "executeRelationSync",
        "executeItemFetch",
        "Akonadi::Item",
        "item",
        "QSet<QByteArray>",
        "parts",
        "executeItemsFetch",
        "QList<Akonadi::Item>",
        "items",
        "executeResourceCollectionDeletion",
        "executeCacheInvalidation",
        "collection",
        "executeChangeReplay",
        "executeRecursiveMoveReplay",
        "Akonadi::RecursiveMover*",
        "mover",
        "collectionTreeSyncComplete",
        "fullSyncComplete",
        "status",
        "message",
        "scheduleChangeReplay",
        "taskDone",
        "itemFetchDone",
        "msg",
        "deferTask",
        "collectionRemoved",
        "scheduleNext",
        "executeNext"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'executeFullSync'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeCollectionAttributesSync'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'executeCollectionSync'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'executeCollectionTreeSync'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeTagSync'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeRelationSync'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeItemFetch'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'executeItemsFetch'
        QtMocHelpers::SignalData<void(const QList<Akonadi::Item> &, const QSet<QByteArray> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'executeResourceCollectionDeletion'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeCacheInvalidation'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 20 },
        }}),
        // Signal 'executeChangeReplay'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeRecursiveMoveReplay'
        QtMocHelpers::SignalData<void(Akonadi::RecursiveMover *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'collectionTreeSyncComplete'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullSyncComplete'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::QString, 28 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'scheduleChangeReplay'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'taskDone'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'itemFetchDone'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'deferTask'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'collectionRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 20 },
        }}),
        // Slot 'scheduleNext'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'executeNext'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourceScheduler, qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::ResourceScheduler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>.metaTypes,
    nullptr
} };

void Akonadi::ResourceScheduler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourceScheduler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->executeFullSync(); break;
        case 1: _t->executeCollectionAttributesSync((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 2: _t->executeCollectionSync((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 3: _t->executeCollectionTreeSync(); break;
        case 4: _t->executeTagSync(); break;
        case 5: _t->executeRelationSync(); break;
        case 6: _t->executeItemFetch((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 7: _t->executeItemsFetch((*reinterpret_cast<std::add_pointer_t<QList<Akonadi::Item>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 8: _t->executeResourceCollectionDeletion(); break;
        case 9: _t->executeCacheInvalidation((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 10: _t->executeChangeReplay(); break;
        case 11: _t->executeRecursiveMoveReplay((*reinterpret_cast<std::add_pointer_t<Akonadi::RecursiveMover*>>(_a[1]))); break;
        case 12: _t->collectionTreeSyncComplete(); break;
        case 13: _t->fullSyncComplete(); break;
        case 14: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->scheduleChangeReplay(); break;
        case 17: _t->taskDone(); break;
        case 18: _t->itemFetchDone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->deferTask(); break;
        case 20: _t->collectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 21: _t->scheduleNext(); break;
        case 22: _t->executeNext(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Akonadi::Item> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeFullSync, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(const Akonadi::Collection & )>(_a, &ResourceScheduler::executeCollectionAttributesSync, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(const Akonadi::Collection & )>(_a, &ResourceScheduler::executeCollectionSync, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeCollectionTreeSync, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeTagSync, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeRelationSync, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(const Akonadi::Item & , const QSet<QByteArray> & )>(_a, &ResourceScheduler::executeItemFetch, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(const QList<Akonadi::Item> & , const QSet<QByteArray> & )>(_a, &ResourceScheduler::executeItemsFetch, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeResourceCollectionDeletion, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(const Akonadi::Collection & )>(_a, &ResourceScheduler::executeCacheInvalidation, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::executeChangeReplay, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(Akonadi::RecursiveMover * )>(_a, &ResourceScheduler::executeRecursiveMoveReplay, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::collectionTreeSyncComplete, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)()>(_a, &ResourceScheduler::fullSyncComplete, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceScheduler::*)(int , const QString & )>(_a, &ResourceScheduler::status, 14))
            return;
    }
}

const QMetaObject *Akonadi::ResourceScheduler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::ResourceScheduler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi17ResourceSchedulerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::ResourceScheduler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::ResourceScheduler::executeFullSync()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Akonadi::ResourceScheduler::executeCollectionAttributesSync(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Akonadi::ResourceScheduler::executeCollectionSync(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi::ResourceScheduler::executeCollectionTreeSync()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Akonadi::ResourceScheduler::executeTagSync()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Akonadi::ResourceScheduler::executeRelationSync()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Akonadi::ResourceScheduler::executeItemFetch(const Akonadi::Item & _t1, const QSet<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Akonadi::ResourceScheduler::executeItemsFetch(const QList<Akonadi::Item> & _t1, const QSet<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Akonadi::ResourceScheduler::executeResourceCollectionDeletion()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Akonadi::ResourceScheduler::executeCacheInvalidation(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Akonadi::ResourceScheduler::executeChangeReplay()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Akonadi::ResourceScheduler::executeRecursiveMoveReplay(Akonadi::RecursiveMover * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Akonadi::ResourceScheduler::collectionTreeSyncComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Akonadi::ResourceScheduler::fullSyncComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Akonadi::ResourceScheduler::status(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}
QT_WARNING_POP
