/********************************************************************************
** Form generated from reading UI file 'controlprogressindicator.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONTROLPROGRESSINDICATOR_H
#define UI_CONTROLPROGRESSINDICATOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ControlProgressIndicator
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *statusLabel;
    QProgressBar *progressBar;

    void setupUi(QWidget *ControlProgressIndicator)
    {
        if (ControlProgressIndicator->objectName().isEmpty())
            ControlProgressIndicator->setObjectName("ControlProgressIndicator");
        ControlProgressIndicator->resize(400, 52);
        verticalLayout = new QVBoxLayout(ControlProgressIndicator);
        verticalLayout->setObjectName("verticalLayout");
        statusLabel = new QLabel(ControlProgressIndicator);
        statusLabel->setObjectName("statusLabel");
        statusLabel->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(statusLabel);

        progressBar = new QProgressBar(ControlProgressIndicator);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);
        progressBar->setValue(775);
        progressBar->setTextVisible(false);

        verticalLayout->addWidget(progressBar);


        retranslateUi(ControlProgressIndicator);

        QMetaObject::connectSlotsByName(ControlProgressIndicator);
    } // setupUi

    void retranslateUi(QWidget *ControlProgressIndicator)
    {
        (void)ControlProgressIndicator;
    } // retranslateUi

};

namespace Ui {
    class ControlProgressIndicator: public Ui_ControlProgressIndicator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONTROLPROGRESSINDICATOR_H

