/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef RESOURCEADAPTOR_H
#define RESOURCEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "resourcebase.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Resource
 */
class Akonadi__ResourceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Resource")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Resource\">\n"
"    <signal name=\"nameChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"synchronized\"/>\n"
"    <signal name=\"attributesSynchronized\">\n"
"      <arg type=\"x\" name=\"collectionId\"/>\n"
"    </signal>\n"
"    <signal name=\"collectionTreeSynchronized\"/>\n"
"    <method name=\"taskList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"requestItemDelivery\">\n"
"      <annotation value=\"QList&lt;qlonglong&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"ax\" name=\"uids\"/>\n"
"      <annotation value=\"QByteArrayList\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"in\" type=\"aay\" name=\"parts\"/>\n"
"    </method>\n"
"    <method name=\"synchronize\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"synchronizeCollectionTree\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"synchronizeCollection\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"collectionId\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"synchronizeCollection\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"collectionId\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"recursive\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"synchronizeCollectionAttributes\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"collectionId\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"synchronizeTags\">\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"setName\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"name\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setActivities\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"activities\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setActivitiesEnabled\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"en\"/>\n"
"    </method>\n"
"    <method name=\"activitiesEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Akonadi__ResourceAdaptor(Akonadi::ResourceBase *parent);
    ~Akonadi__ResourceAdaptor() override;

    inline Akonadi::ResourceBase *parent() const
    { return static_cast<Akonadi::ResourceBase *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QStringList activities();
    bool activitiesEnabled();
    QString name();
    void requestItemDelivery(const QList<qlonglong> &uids, const QByteArrayList &parts);
    void setActivities(const QStringList &name);
    void setActivitiesEnabled(bool en);
    void setName(const QString &name);
    Q_NOREPLY void synchronize();
    Q_NOREPLY void synchronizeCollection(qlonglong collectionId, bool recursive);
    Q_NOREPLY void synchronizeCollection(qlonglong collectionId);
    Q_NOREPLY void synchronizeCollectionAttributes(qlonglong collectionId);
    Q_NOREPLY void synchronizeCollectionTree();
    Q_NOREPLY void synchronizeTags();
    QStringList taskList();
Q_SIGNALS: // SIGNALS
    void attributesSynchronized(qlonglong collectionId);
    void collectionTreeSynchronized();
    void nameChanged(const QString &name);
    void synchronized();
};

#endif
