/********************************************************************************
** Form generated from reading UI file 'cachepolicypage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CACHEPOLICYPAGE_H
#define UI_CACHEPOLICYPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "keditlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_CachePolicyPage
{
public:
    QFormLayout *verticalLayout_3;
    QCheckBox *inherit;
    QCheckBox *syncOnDemand;
    QLabel *label_2;
    QSpinBox *checkInterval;
    QLabel *localPartsLabel;
    KEditListWidget *localParts;
    QLabel *retrievalOptionsLabel;
    QRadioButton *retrieveFullMessages;
    QRadioButton *retrieveOnlyHeaders;
    QLabel *label;
    QSpinBox *localCacheTimeout;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CachePolicyPage)
    {
        if (CachePolicyPage->objectName().isEmpty())
            CachePolicyPage->setObjectName("CachePolicyPage");
        CachePolicyPage->setEnabled(true);
        CachePolicyPage->resize(602, 461);
        verticalLayout_3 = new QFormLayout(CachePolicyPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        inherit = new QCheckBox(CachePolicyPage);
        inherit->setObjectName("inherit");
        inherit->setChecked(false);
        inherit->setTristate(false);

        verticalLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, inherit);

        syncOnDemand = new QCheckBox(CachePolicyPage);
        syncOnDemand->setObjectName("syncOnDemand");

        verticalLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, syncOnDemand);

        label_2 = new QLabel(CachePolicyPage);
        label_2->setObjectName("label_2");

        verticalLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        checkInterval = new QSpinBox(CachePolicyPage);
        checkInterval->setObjectName("checkInterval");
        checkInterval->setMinimum(0);
        checkInterval->setMaximum(9999);
        checkInterval->setValue(0);

        verticalLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, checkInterval);

        localPartsLabel = new QLabel(CachePolicyPage);
        localPartsLabel->setObjectName("localPartsLabel");

        verticalLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, localPartsLabel);

        localParts = new KEditListWidget(CachePolicyPage);
        localParts->setObjectName("localParts");
        localParts->setMinimumSize(QSize(150, 0));
        localParts->setEnabled(false);
        localParts->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, localParts);

        retrievalOptionsLabel = new QLabel(CachePolicyPage);
        retrievalOptionsLabel->setObjectName("retrievalOptionsLabel");

        verticalLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, retrievalOptionsLabel);

        retrieveFullMessages = new QRadioButton(CachePolicyPage);
        retrieveFullMessages->setObjectName("retrieveFullMessages");
        retrieveFullMessages->setChecked(true);

        verticalLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, retrieveFullMessages);

        retrieveOnlyHeaders = new QRadioButton(CachePolicyPage);
        retrieveOnlyHeaders->setObjectName("retrieveOnlyHeaders");

        verticalLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, retrieveOnlyHeaders);

        label = new QLabel(CachePolicyPage);
        label->setObjectName("label");

        verticalLayout_3->setWidget(6, QFormLayout::ItemRole::LabelRole, label);

        localCacheTimeout = new QSpinBox(CachePolicyPage);
        localCacheTimeout->setObjectName("localCacheTimeout");
        localCacheTimeout->setMinimumSize(QSize(150, 0));
        localCacheTimeout->setMinimum(0);
        localCacheTimeout->setValue(0);

        verticalLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, localCacheTimeout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->setItem(7, QFormLayout::ItemRole::LabelRole, verticalSpacer);

#if QT_CONFIG(shortcut)
        localPartsLabel->setBuddy(localParts);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CachePolicyPage);
        QObject::connect(inherit, SIGNAL(toggled(bool)), localParts, SLOT(setDisabled(bool)));
        QObject::connect(retrieveOnlyHeaders, &QRadioButton::toggled, label, &QLabel::setEnabled);
        QObject::connect(retrieveOnlyHeaders, &QRadioButton::toggled, localCacheTimeout, &QSpinBox::setEnabled);
        QObject::connect(inherit, &QCheckBox::toggled, syncOnDemand, &QCheckBox::setDisabled);
        QObject::connect(inherit, &QCheckBox::toggled, label_2, &QLabel::setDisabled);
        QObject::connect(inherit, &QCheckBox::toggled, checkInterval, &QSpinBox::setDisabled);

        QMetaObject::connectSlotsByName(CachePolicyPage);
    } // setupUi

    void retranslateUi(QWidget *CachePolicyPage)
    {
        inherit->setText(tr2i18n("Use options from parent folder or account", nullptr));
        syncOnDemand->setText(tr2i18n("Synchronize when selecting this folder", nullptr));
        label_2->setText(tr2i18n("Synchronize after:", nullptr));
        checkInterval->setSpecialValueText(tr2i18n("Never", "never check the cache"));
        checkInterval->setSuffix(tr2i18n("minutes", nullptr));
        localPartsLabel->setText(tr2i18n("Locally cached parts:", nullptr));
        localParts->setProperty("title", QVariant(tr2i18n("Locally Cached Parts", nullptr)));
        retrievalOptionsLabel->setText(tr2i18n("Retrieval Options:", nullptr));
        retrieveFullMessages->setText(tr2i18n("Always retrieve full &messages", nullptr));
        retrieveOnlyHeaders->setText(tr2i18n("&Retrieve message bodies on demand", nullptr));
        label->setText(tr2i18n("Keep message bodies locally for:", nullptr));
        localCacheTimeout->setSpecialValueText(tr2i18n("Forever", "no cache timeout"));
        localCacheTimeout->setSuffix(tr2i18n("minutes", nullptr));
        (void)CachePolicyPage;
    } // retranslateUi

};

namespace Ui {
    class CachePolicyPage: public Ui_CachePolicyPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CACHEPOLICYPAGE_H

