/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Control.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CONTROLADAPTOR_H
#define CONTROLADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "agentbase.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Agent.Control
 */
class Akonadi__ControlAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Agent.Control")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Agent.Control\">\n"
"    <method name=\"quit\"/>\n"
"    <method name=\"cleanup\"/>\n"
"    <method name=\"configure\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"windowId\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"configurationDialogAccepted\"/>\n"
"    <signal name=\"configurationDialogRejected\"/>\n"
"    <signal name=\"finished\"/>\n"
"    <method name=\"reconfigure\"/>\n"
"    <method name=\"abort\"/>\n"
"  </interface>\n"
        "")
public:
    Akonadi__ControlAdaptor(Akonadi::AgentBase *parent);
    ~Akonadi__ControlAdaptor() override;

    inline Akonadi::AgentBase *parent() const
    { return static_cast<Akonadi::AgentBase *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void abort();
    void cleanup();
    Q_NOREPLY void configure(qlonglong windowId);
    void quit();
    void reconfigure();
Q_SIGNALS: // SIGNALS
    void configurationDialogAccepted();
    void configurationDialogRejected();
    void finished();
};

#endif
