/****************************************************************************
** Meta object code from reading C++ file 'agentmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "agentmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AgentManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19AgentManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentManagerAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.AgentManager",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.AgentManager\">\n    <"
        "signal name=\"agentTypeAdded\">\n      <arg direction=\"out\" type"
        "=\"s\" name=\"agentType\"/>\n    </signal>\n    <signal name=\"age"
        "ntTypeRemoved\">\n      <arg direction=\"out\" type=\"s\" name=\"a"
        "gentType\"/>\n    </signal>\n    <signal name=\"agentInstanceAdded"
        "\">\n      <arg direction=\"out\" type=\"s\" name=\"agentIdentifie"
        "r\"/>\n    </signal>\n    <signal name=\"agentInstanceRemoved\">\n"
        "      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>"
        "\n    </signal>\n    <signal name=\"agentInstanceStatusChanged\">\n"
        "      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>"
        "\n      <arg direction=\"out\" type=\"i\" name=\"status\"/>\n     "
        " <arg direction=\"out\" type=\"s\" name=\"message\"/>\n    </signa"
        "l>\n    <signal name=\"agentInstanceAdvancedStatusChanged\">\n    "
        "  <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.Qt"
        "TypeName.Out1\"/>\n      <annotation value=\"QVariantMap\" name=\""
        "org.qtproject.QtDBus.QtTypeName.In1\"/>\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"agentIdentifier\"/>\n      <arg direction=\""
        "out\" type=\"a{sv}\" name=\"status\"/>\n    </signal>\n    <signal"
        " name=\"agentInstanceProgressChanged\">\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"agentIdentifier\"/>\n      <arg direction=\""
        "out\" type=\"u\" name=\"progress\"/>\n      <arg direction=\"out\""
        " type=\"s\" name=\"message\"/>\n    </signal>\n    <signal name=\""
        "agentInstanceNameChanged\">\n      <arg direction=\"out\" type=\"s"
        "\" name=\"agentIdentifier\"/>\n      <arg direction=\"out\" type=\""
        "s\" name=\"name\"/>\n    </signal>\n    <signal name=\"agentInstan"
        "ceWarning\">\n      <arg direction=\"out\" type=\"s\" name=\"agent"
        "Identifier\"/>\n      <arg direction=\"out\" type=\"s\" name=\"mes"
        "sage\"/>\n    </signal>\n    <signal name=\"agentInstanceError\">\n"
        "      <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>"
        "\n      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n    "
        "</signal>\n    <signal name=\"agentInstanceOnlineChanged\">\n     "
        " <arg direction=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n   "
        "   <arg direction=\"out\" type=\"b\" name=\"state\"/>\n    </signa"
        "l>\n    <method name=\"agentTypes\">\n      <arg direction=\"out\""
        " type=\"as\"/>\n    </method>\n    <method name=\"agentName\">\n  "
        "    <arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"identifier\"/>\n    </method>\n    <method na"
        "me=\"agentComment\">\n      <arg direction=\"out\" type=\"s\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n    <"
        "/method>\n    <method name=\"agentIcon\">\n      <arg direction=\""
        "out\" type=\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "identifier\"/>\n    </method>\n    <method name=\"agentMimeTypes\""
        ">\n      <arg direction=\"out\" type=\"as\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n    <met"
        "hod name=\"agentCapabilities\">\n      <arg direction=\"out\" type"
        "=\"as\"/>\n      <arg direction=\"in\" type=\"s\" name=\"identifie"
        "r\"/>\n    </method>\n    <method name=\"agentCustomProperties\">\n"
        "      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBu"
        "s.QtTypeName.Out0\"/>\n      <annotation value=\"QVariantMap\" nam"
        "e=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <arg direction="
        "\"out\" type=\"a{sv}\"/>\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"identifier\"/>\n    </method>\n    <method name=\"createAgen"
        "tInstance\">\n      <arg direction=\"out\" type=\"s\"/>\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>"
        "\n    <method name=\"removeAgentInstance\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n    <metho"
        "d name=\"agentInstanceType\">\n      <arg direction=\"out\" type=\""
        "s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"identifier\"/"
        ">\n    </method>\n    <method name=\"agentInstances\">\n      <arg"
        " direction=\"out\" type=\"as\"/>\n    </method>\n    <method name="
        "\"agentInstanceStatus\">\n      <arg direction=\"out\" type=\"i\"/"
        ">\n      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n "
        "   </method>\n    <method name=\"agentInstanceStatusMessage\">\n  "
        "    <arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"identifier\"/>\n    </method>\n    <method na"
        "me=\"agentInstanceProgress\">\n      <arg direction=\"out\" type=\""
        "u\"/>\n      <arg direction=\"in\" type=\"s\" name=\"identifier\"/"
        ">\n    </method>\n    <method name=\"agentInstanceProgressMessage\""
        ">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direction"
        "=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n    <meth"
        "od name=\"setAgentInstanceName\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"identifier\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"name\"/>\n    </method>\n    <method name=\"agentInstan"
        "ceName\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n "
        "   <method name=\"agentInstanceConfigure\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"identifier\"/>\n      <arg direction=\"in"
        "\" type=\"x\" name=\"windowId\"/>\n    </method>\n    <method name"
        "=\"agentInstanceSynchronize\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"identifier\"/>\n    </method>\n    <method name=\"agent"
        "InstanceSynchronizeCollectionTree\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"identifier\"/>\n    </method>\n    <method name="
        "\"agentInstanceSynchronizeCollection\">\n      <arg direction=\"in"
        "\" type=\"s\" name=\"identifier\"/>\n      <arg direction=\"in\" t"
        "ype=\"x\" name=\"collection\"/>\n    </method>\n    <method name=\""
        "agentInstanceSynchronizeCollection\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"identifier\"/>\n      <arg direction=\"in\" typ"
        "e=\"x\" name=\"collection\"/>\n      <arg direction=\"in\" type=\""
        "b\" name=\"recursive\"/>\n    </method>\n    <method name=\"agentI"
        "nstanceSynchronizeTags\">\n      <arg direction=\"in\" type=\"s\" "
        "name=\"identifier\"/>\n    </method>\n    <method name=\"agentInst"
        "anceOnline\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"identifier\"/>\n    </method"
        ">\n    <method name=\"setAgentInstanceOnline\">\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"identifier\"/>\n      <arg direction="
        "\"in\" type=\"b\" name=\"state\"/>\n    </method>\n    <method nam"
        "e=\"agentInstanceActivities\">\n      <arg direction=\"out\" type="
        "\"as\"/>\n      <arg direction=\"in\" type=\"s\" name=\"identifier"
        "\"/>\n    </method>\n    <method name=\"setAgentInstanceActivities"
        "\">\n      <arg direction=\"in\" type=\"s\" name=\"identifier\"/>\n"
        "      <arg direction=\"in\" type=\"as\" name=\"activities\"/>\n   "
        " </method>\n    <method name=\"restartAgentInstance\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n"
        "    <method name=\"setAgentInstanceActivitiesEnabled\">\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"identifier\"/>\n      <arg di"
        "rection=\"in\" type=\"b\" name=\"en\"/>\n    </method>\n    <metho"
        "d name=\"agentInstanceActivitiesEnabled\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "identifier\"/>\n    </method>\n    <method name=\"agentInstanceAcc"
        "ountId\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"identifier\"/>\n    </method>\n "
        "   <signal name=\"agentInstanceAccountIdChanged\">\n      <arg dir"
        "ection=\"out\" type=\"s\" name=\"agentIdentifier\"/>\n      <arg d"
        "irection=\"out\" type=\"s\" name=\"accountId\"/>\n    </signal>\n "
        " </interface>\n",
        "agentInstanceAccountIdChanged",
        "",
        "agentIdentifier",
        "accountId",
        "agentInstanceAdded",
        "agentInstanceAdvancedStatusChanged",
        "QVariantMap",
        "status",
        "agentInstanceError",
        "message",
        "agentInstanceNameChanged",
        "name",
        "agentInstanceOnlineChanged",
        "state",
        "agentInstanceProgressChanged",
        "progress",
        "agentInstanceRemoved",
        "agentInstanceStatusChanged",
        "agentInstanceWarning",
        "agentTypeAdded",
        "agentType",
        "agentTypeRemoved",
        "agentCapabilities",
        "identifier",
        "agentComment",
        "agentCustomProperties",
        "agentIcon",
        "agentInstanceAccountId",
        "agentInstanceActivities",
        "agentInstanceActivitiesEnabled",
        "agentInstanceConfigure",
        "windowId",
        "agentInstanceName",
        "agentInstanceOnline",
        "agentInstanceProgress",
        "agentInstanceProgressMessage",
        "agentInstanceStatus",
        "agentInstanceStatusMessage",
        "agentInstanceSynchronize",
        "agentInstanceSynchronizeCollection",
        "collection",
        "recursive",
        "agentInstanceSynchronizeCollectionTree",
        "agentInstanceSynchronizeTags",
        "agentInstanceType",
        "agentInstances",
        "agentMimeTypes",
        "agentName",
        "agentTypes",
        "createAgentInstance",
        "removeAgentInstance",
        "restartAgentInstance",
        "setAgentInstanceActivities",
        "activities",
        "setAgentInstanceActivitiesEnabled",
        "en",
        "setAgentInstanceName",
        "setAgentInstanceOnline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agentInstanceAccountIdChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'agentInstanceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'agentInstanceAdvancedStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'agentInstanceError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'agentInstanceNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'agentInstanceOnlineChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'agentInstanceProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::UInt, 20 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'agentInstanceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'agentInstanceStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 12 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'agentInstanceWarning'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'agentTypeAdded'
        QtMocHelpers::SignalData<void(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'agentTypeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'agentCapabilities'
        QtMocHelpers::SlotData<QStringList(const QString &)>(27, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentComment'
        QtMocHelpers::SlotData<QString(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentCustomProperties'
        QtMocHelpers::SlotData<QVariantMap(const QString &)>(30, 6, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentIcon'
        QtMocHelpers::SlotData<QString(const QString &)>(31, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceAccountId'
        QtMocHelpers::SlotData<QString(const QString &)>(32, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceActivities'
        QtMocHelpers::SlotData<QStringList(const QString &)>(33, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceActivitiesEnabled'
        QtMocHelpers::SlotData<bool(const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceConfigure'
        QtMocHelpers::SlotData<void(const QString &, qlonglong)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::LongLong, 36 },
        }}),
        // Slot 'agentInstanceName'
        QtMocHelpers::SlotData<QString(const QString &)>(37, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceOnline'
        QtMocHelpers::SlotData<bool(const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceProgress'
        QtMocHelpers::SlotData<uint(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceProgressMessage'
        QtMocHelpers::SlotData<QString(const QString &)>(40, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceStatus'
        QtMocHelpers::SlotData<int(const QString &)>(41, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceStatusMessage'
        QtMocHelpers::SlotData<QString(const QString &)>(42, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceSynchronize'
        QtMocHelpers::SlotData<void(const QString &)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceSynchronizeCollection'
        QtMocHelpers::SlotData<void(const QString &, qlonglong, bool)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::LongLong, 45 }, { QMetaType::Bool, 46 },
        }}),
        // Slot 'agentInstanceSynchronizeCollection'
        QtMocHelpers::SlotData<void(const QString &, qlonglong)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::LongLong, 45 },
        }}),
        // Slot 'agentInstanceSynchronizeCollectionTree'
        QtMocHelpers::SlotData<void(const QString &)>(47, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceSynchronizeTags'
        QtMocHelpers::SlotData<void(const QString &)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstanceType'
        QtMocHelpers::SlotData<QString(const QString &)>(49, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentInstances'
        QtMocHelpers::SlotData<QStringList()>(50, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'agentMimeTypes'
        QtMocHelpers::SlotData<QStringList(const QString &)>(51, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentName'
        QtMocHelpers::SlotData<QString(const QString &)>(52, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'agentTypes'
        QtMocHelpers::SlotData<QStringList()>(53, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'createAgentInstance'
        QtMocHelpers::SlotData<QString(const QString &)>(54, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'removeAgentInstance'
        QtMocHelpers::SlotData<void(const QString &)>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'restartAgentInstance'
        QtMocHelpers::SlotData<void(const QString &)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setAgentInstanceActivities'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(57, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QStringList, 58 },
        }}),
        // Slot 'setAgentInstanceActivitiesEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Bool, 60 },
        }}),
        // Slot 'setAgentInstanceName'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(61, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'setAgentInstanceOnline'
        QtMocHelpers::SlotData<void(const QString &, bool)>(62, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::Bool, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AgentManagerAdaptor, qt_meta_tag_ZN19AgentManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AgentManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AgentManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AgentManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AgentManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void AgentManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agentInstanceAccountIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->agentInstanceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->agentInstanceAdvancedStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 3: _t->agentInstanceError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->agentInstanceNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->agentInstanceOnlineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->agentInstanceProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->agentInstanceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->agentInstanceStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->agentInstanceWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->agentTypeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->agentTypeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { QStringList _r = _t->agentCapabilities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->agentComment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QVariantMap _r = _t->agentCustomProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->agentIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->agentInstanceAccountId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QStringList _r = _t->agentInstanceActivities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->agentInstanceActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->agentInstanceConfigure((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 20: { QString _r = _t->agentInstanceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->agentInstanceOnline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { uint _r = _t->agentInstanceProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->agentInstanceProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->agentInstanceStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { QString _r = _t->agentInstanceStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->agentInstanceSynchronize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->agentInstanceSynchronizeCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 28: _t->agentInstanceSynchronizeCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 29: _t->agentInstanceSynchronizeCollectionTree((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->agentInstanceSynchronizeTags((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: { QString _r = _t->agentInstanceType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: { QStringList _r = _t->agentInstances();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 33: { QStringList _r = _t->agentMimeTypes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 34: { QString _r = _t->agentName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 35: { QStringList _r = _t->agentTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->createAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->removeAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->restartAgentInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->setAgentInstanceActivities((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 40: _t->setAgentInstanceActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 41: _t->setAgentInstanceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 42: _t->setAgentInstanceOnline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceAccountIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & )>(_a, &AgentManagerAdaptor::agentInstanceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , const QVariantMap & )>(_a, &AgentManagerAdaptor::agentInstanceAdvancedStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , bool )>(_a, &AgentManagerAdaptor::agentInstanceOnlineChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , uint , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceProgressChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & )>(_a, &AgentManagerAdaptor::agentInstanceRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , int , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceStatusChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & , const QString & )>(_a, &AgentManagerAdaptor::agentInstanceWarning, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & )>(_a, &AgentManagerAdaptor::agentTypeAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManagerAdaptor::*)(const QString & )>(_a, &AgentManagerAdaptor::agentTypeRemoved, 11))
            return;
    }
}

const QMetaObject *AgentManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AgentManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AgentManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AgentManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void AgentManagerAdaptor::agentInstanceAccountIdChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void AgentManagerAdaptor::agentInstanceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AgentManagerAdaptor::agentInstanceAdvancedStatusChanged(const QString & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void AgentManagerAdaptor::agentInstanceError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void AgentManagerAdaptor::agentInstanceNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void AgentManagerAdaptor::agentInstanceOnlineChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void AgentManagerAdaptor::agentInstanceProgressChanged(const QString & _t1, uint _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void AgentManagerAdaptor::agentInstanceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AgentManagerAdaptor::agentInstanceStatusChanged(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void AgentManagerAdaptor::agentInstanceWarning(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void AgentManagerAdaptor::agentTypeAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void AgentManagerAdaptor::agentTypeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
