/********************************************************************************
** Form generated from reading UI file 'tagwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGWIDGET_H
#define UI_TAGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "tagwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TagWidget
{
public:
    QHBoxLayout *horizontalLayout;
    Akonadi::TagView *tagView;
    QToolButton *editButton;

    void setupUi(QWidget *TagWidget)
    {
        if (TagWidget->objectName().isEmpty())
            TagWidget->setObjectName("TagWidget");
        TagWidget->resize(400, 46);
        horizontalLayout = new QHBoxLayout(TagWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        tagView = new Akonadi::TagView(TagWidget);
        tagView->setObjectName("tagView");
        tagView->setReadOnly(true);

        horizontalLayout->addWidget(tagView);

        editButton = new QToolButton(TagWidget);
        editButton->setObjectName("editButton");

        horizontalLayout->addWidget(editButton);


        retranslateUi(TagWidget);

        QMetaObject::connectSlotsByName(TagWidget);
    } // setupUi

    void retranslateUi(QWidget *TagWidget)
    {
        tagView->setPlaceholderText(tr2i18n("Click to add tags", nullptr));
        editButton->setText(tr2i18n("...", nullptr));
        (void)TagWidget;
    } // retranslateUi

};

namespace Ui {
    class TagWidget: public Ui_TagWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TAGWIDGET_H

