/****************************************************************************
** Meta object code from reading C++ file 'entitytreemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/models/entitytreemodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'entitytreemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::EntityTreeModel::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::EntityTreeModel",
        "collectionTreeFetched",
        "",
        "Akonadi::Collection::List",
        "collections",
        "collectionPopulated",
        "Akonadi::Collection::Id",
        "collectionId",
        "collectionFetched",
        "errorOccurred",
        "message",
        "monitoredCollectionStatisticsChanged",
        "Akonadi::CollectionStatistics",
        "monitoredMimeTypeChanged",
        "monitoredCollectionsChanged",
        "Akonadi::Collection",
        "monitoredItemsChanged",
        "Akonadi::Item",
        "monitoredResourcesChanged",
        "changeFetchState",
        "itemsFetched",
        "Akonadi::Item::List",
        "collectionsFetched",
        "monitoredCollectionAdded",
        "monitoredCollectionRemoved",
        "monitoredCollectionChanged",
        "monitoredCollectionMoved",
        "monitoredItemAdded",
        "monitoredItemRemoved",
        "monitoredItemChanged",
        "QSet<QByteArray>",
        "monitoredItemMoved",
        "monitoredItemLinked",
        "monitoredItemUnlinked",
        "Roles",
        "ItemIdRole",
        "ItemRole",
        "MimeTypeRole",
        "CollectionColorRole",
        "CollectionIdRole",
        "CollectionRole",
        "RemoteIdRole",
        "CollectionChildOrderRole",
        "ParentCollectionRole",
        "ColumnCountRole",
        "LoadedPartsRole",
        "AvailablePartsRole",
        "SessionRole",
        "CollectionRefRole",
        "CollectionDerefRole",
        "PendingCutRole",
        "EntityUrlRole",
        "UnreadCountRole",
        "FetchStateRole",
        "IsPopulatedRole",
        "OriginalCollectionNameRole",
        "DisplayNameRole",
        "UserRole",
        "TerminalUserRole",
        "EndRole",
        "FetchState",
        "IdleState",
        "FetchingState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionTreeFetched'
        QtMocHelpers::SignalData<void(const Akonadi::Collection::List &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'collectionPopulated'
        QtMocHelpers::SignalData<void(Akonadi::Collection::Id)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'collectionFetched'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'monitoredCollectionStatisticsChanged'
        QtMocHelpers::SlotData<void(Akonadi::Collection::Id, const Akonadi::CollectionStatistics &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Slot 'monitoredMimeTypeChanged'
        QtMocHelpers::SlotData<void(const QString &, bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'monitoredCollectionsChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'monitoredItemsChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'monitoredResourcesChanged'
        QtMocHelpers::SlotData<void(const QByteArray &, bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'changeFetchState'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'itemsFetched'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'collectionsFetched'
        QtMocHelpers::SlotData<void(Akonadi::Collection::List)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'monitoredCollectionAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredCollectionRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredCollectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredCollectionMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &, const Akonadi::Collection &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 }, { 0x80000000 | 15, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredItemAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredItemRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'monitoredItemChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 30, 2 },
        }}),
        // Slot 'monitoredItemMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &, const Akonadi::Collection &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 15, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredItemLinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'monitoredItemUnlinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 15, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(34, 34, QMC::EnumFlags{}).add({
            {   35, Roles::ItemIdRole },
            {   36, Roles::ItemRole },
            {   37, Roles::MimeTypeRole },
            {   38, Roles::CollectionColorRole },
            {   39, Roles::CollectionIdRole },
            {   40, Roles::CollectionRole },
            {   41, Roles::RemoteIdRole },
            {   42, Roles::CollectionChildOrderRole },
            {   43, Roles::ParentCollectionRole },
            {   44, Roles::ColumnCountRole },
            {   45, Roles::LoadedPartsRole },
            {   46, Roles::AvailablePartsRole },
            {   47, Roles::SessionRole },
            {   48, Roles::CollectionRefRole },
            {   49, Roles::CollectionDerefRole },
            {   50, Roles::PendingCutRole },
            {   51, Roles::EntityUrlRole },
            {   52, Roles::UnreadCountRole },
            {   53, Roles::FetchStateRole },
            {   54, Roles::IsPopulatedRole },
            {   55, Roles::OriginalCollectionNameRole },
            {   56, Roles::DisplayNameRole },
            {   57, Roles::UserRole },
            {   58, Roles::TerminalUserRole },
            {   59, Roles::EndRole },
        }),
        // enum 'FetchState'
        QtMocHelpers::EnumData<enum FetchState>(60, 60, QMC::EnumFlags{}).add({
            {   61, FetchState::IdleState },
            {   62, FetchState::FetchingState },
        }),
    };
    return QtMocHelpers::metaObjectData<EntityTreeModel, qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::EntityTreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>.metaTypes,
    nullptr
} };

void Akonadi::EntityTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EntityTreeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionTreeFetched((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::List>>(_a[1]))); break;
        case 1: _t->collectionPopulated((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::Id>>(_a[1]))); break;
        case 2: _t->collectionFetched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->d_func()->monitoredCollectionStatisticsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::Id>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionStatistics>>(_a[2]))); break;
        case 5: _t->d_func()->monitoredMimeTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->d_func()->monitoredCollectionsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->d_func()->monitoredItemsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->d_func()->monitoredResourcesChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->d_func()->changeFetchState((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 10: _t->d_func()->itemsFetched((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 11: _t->d_func()->collectionsFetched((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::List>>(_a[1]))); break;
        case 12: _t->d_func()->monitoredCollectionAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 13: _t->d_func()->monitoredCollectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 14: _t->d_func()->monitoredCollectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 15: _t->d_func()->monitoredCollectionMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 16: _t->d_func()->monitoredItemAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 17: _t->d_func()->monitoredItemRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 18: _t->d_func()->monitoredItemChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 19: _t->d_func()->monitoredItemMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 20: _t->d_func()->monitoredItemLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 21: _t->d_func()->monitoredItemUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Collection::List >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Collection::List >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EntityTreeModel::*)(const Akonadi::Collection::List & )>(_a, &EntityTreeModel::collectionTreeFetched, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EntityTreeModel::*)(Akonadi::Collection::Id )>(_a, &EntityTreeModel::collectionPopulated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EntityTreeModel::*)(int )>(_a, &EntityTreeModel::collectionFetched, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EntityTreeModel::*)(const QString & )>(_a, &EntityTreeModel::errorOccurred, 3))
            return;
    }
}

const QMetaObject *Akonadi::EntityTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::EntityTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi15EntityTreeModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Akonadi::EntityTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::EntityTreeModel::collectionTreeFetched(const Akonadi::Collection::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::EntityTreeModel::collectionPopulated(Akonadi::Collection::Id _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Akonadi::EntityTreeModel::collectionFetched(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi::EntityTreeModel::errorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
