/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Control.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "controladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__ControlAdaptor
 */

Akonadi__ControlAdaptor::Akonadi__ControlAdaptor(Akonadi::AgentBase *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__ControlAdaptor::~Akonadi__ControlAdaptor()
{
    // destructor
}

void Akonadi__ControlAdaptor::abort()
{
    // handle method call org.freedesktop.Akonadi.Agent.Control.abort
    parent()->abort();
}

void Akonadi__ControlAdaptor::cleanup()
{
    // handle method call org.freedesktop.Akonadi.Agent.Control.cleanup
    parent()->cleanup();
}

void Akonadi__ControlAdaptor::configure(qlonglong windowId)
{
    // handle method call org.freedesktop.Akonadi.Agent.Control.configure
    parent()->configure(windowId);
}

void Akonadi__ControlAdaptor::quit()
{
    // handle method call org.freedesktop.Akonadi.Agent.Control.quit
    parent()->quit();
}

void Akonadi__ControlAdaptor::reconfigure()
{
    // handle method call org.freedesktop.Akonadi.Agent.Control.reconfigure
    parent()->reconfigure();
}


#include "moc_controladaptor.cpp"
