/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Account.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ACCOUNTINTERFACE_H
#define ACCOUNTINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.Agent.Account
 */
class OrgFreedesktopAkonadiAgentAccountInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.Agent.Account"; }

public:
    OrgFreedesktopAkonadiAgentAccountInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiAgentAccountInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> accountId()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("accountId"), argumentList);
    }

    inline QDBusPendingReply<> setAccountId(const QString &accountId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(accountId);
        return asyncCallWithArgumentList(QStringLiteral("setAccountId"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void accountIdChanged(const QString &accountId);
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      namespace Agent {
        using Account = ::OrgFreedesktopAkonadiAgentAccountInterface;
      }
    }
  }
}

#endif
