/********************************************************************************
** Form generated from reading UI file 'subscriptiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SUBSCRIPTIONDIALOG_H
#define UI_SUBSCRIPTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SubscriptionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *searchLineEdit;
    QCheckBox *subscribedOnlyCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QTreeView *collectionView;
    QVBoxLayout *verticalLayout_2;
    QPushButton *subscribeButton;
    QPushButton *unsubscribeButton;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SubscriptionDialog)
    {
        if (SubscriptionDialog->objectName().isEmpty())
            SubscriptionDialog->setObjectName("SubscriptionDialog");
        SubscriptionDialog->resize(456, 443);
        verticalLayout = new QVBoxLayout(SubscriptionDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SubscriptionDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        searchLineEdit = new QLineEdit(SubscriptionDialog);
        searchLineEdit->setObjectName("searchLineEdit");
        searchLineEdit->setClearButtonEnabled(true);

        horizontalLayout->addWidget(searchLineEdit);

        subscribedOnlyCheckBox = new QCheckBox(SubscriptionDialog);
        subscribedOnlyCheckBox->setObjectName("subscribedOnlyCheckBox");

        horizontalLayout->addWidget(subscribedOnlyCheckBox);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        collectionView = new QTreeView(SubscriptionDialog);
        collectionView->setObjectName("collectionView");
        collectionView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        collectionView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        collectionView->header()->setVisible(false);

        horizontalLayout_2->addWidget(collectionView);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        subscribeButton = new QPushButton(SubscriptionDialog);
        subscribeButton->setObjectName("subscribeButton");

        verticalLayout_2->addWidget(subscribeButton);

        unsubscribeButton = new QPushButton(SubscriptionDialog);
        unsubscribeButton->setObjectName("unsubscribeButton");

        verticalLayout_2->addWidget(unsubscribeButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(SubscriptionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SubscriptionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SubscriptionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SubscriptionDialog);
    } // setupUi

    void retranslateUi(QDialog *SubscriptionDialog)
    {
        SubscriptionDialog->setWindowTitle(tr2i18n("Local Subscriptions", nullptr));
        label->setText(tr2i18n("Search:", nullptr));
        subscribedOnlyCheckBox->setText(tr2i18n("&Subscribed only", nullptr));
        subscribeButton->setText(tr2i18n("Su&bscribe", nullptr));
        unsubscribeButton->setText(tr2i18n("&Unsubscribe", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SubscriptionDialog: public Ui_SubscriptionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SUBSCRIPTIONDIALOG_H

