/****************************************************************************
** Meta object code from reading C++ file 'standardactionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/widgets/standardactionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'standardactionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::StandardActionManager::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::StandardActionManager",
        "selectionsChanged",
        "",
        "Akonadi::Collection::List",
        "selectedCollectionsList",
        "selectedFavoriteCollectionsList",
        "Akonadi::Item::List",
        "selectedItems",
        "actionStateUpdated",
        "slotCreateCollection",
        "slotCopyCollections",
        "slotCutCollections",
        "slotDeleteCollection",
        "slotMoveCollectionToTrash",
        "slotMoveItemToTrash",
        "slotRestoreCollectionFromTrash",
        "slotRestoreItemFromTrash",
        "slotTrashRestoreCollection",
        "slotTrashRestoreItem",
        "slotSynchronizeCollection",
        "slotSynchronizeCollectionRecursive",
        "slotSynchronizeFavoriteCollections",
        "slotCollectionProperties",
        "slotCopyItems",
        "slotCutItems",
        "slotPaste",
        "slotDeleteItems",
        "slotDeleteItemsDeferred",
        "slotLocalSubscription",
        "slotAddToFavorites",
        "slotRemoveFromFavorites",
        "slotRenameFavorite",
        "slotCopyCollectionTo",
        "slotMoveCollectionTo",
        "slotCopyItemTo",
        "slotMoveItemTo",
        "QAction*",
        "slotCreateResource",
        "slotDeleteResource",
        "slotResourceProperties",
        "slotSynchronizeResource",
        "slotToggleWorkOffline",
        "slotSynchronizeCollectionTree",
        "collectionCreationResult",
        "KJob*",
        "moveItemToTrashResult",
        "resourceCreationResult",
        "pasteResult"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionsChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Collection::List &, const Akonadi::Collection::List &, const Akonadi::Item::List &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'actionStateUpdated'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCreateCollection'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyCollections'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCutCollections'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteCollection'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveCollectionToTrash'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveItemToTrash'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRestoreCollectionFromTrash'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRestoreItemFromTrash'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTrashRestoreCollection'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTrashRestoreItem'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSynchronizeCollection'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSynchronizeCollectionRecursive'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSynchronizeFavoriteCollections'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCollectionProperties'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyItems'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCutItems'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteItems'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteItemsDeferred'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotLocalSubscription'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddToFavorites'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveFromFavorites'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameFavorite'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyCollectionTo'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveCollectionTo'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyItemTo'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveItemTo'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyCollectionTo'
        QtMocHelpers::SlotData<void(QAction *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotMoveCollectionTo'
        QtMocHelpers::SlotData<void(QAction *)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotCopyItemTo'
        QtMocHelpers::SlotData<void(QAction *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotMoveItemTo'
        QtMocHelpers::SlotData<void(QAction *)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotCreateResource'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteResource'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResourceProperties'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSynchronizeResource'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleWorkOffline'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSynchronizeCollectionTree'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'collectionCreationResult'
        QtMocHelpers::SlotData<void(KJob *)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Slot 'moveItemToTrashResult'
        QtMocHelpers::SlotData<void(KJob *)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Slot 'resourceCreationResult'
        QtMocHelpers::SlotData<void(KJob *)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
        // Slot 'pasteResult'
        QtMocHelpers::SlotData<void(KJob *)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StandardActionManager, qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::StandardActionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>.metaTypes,
    nullptr
} };

void Akonadi::StandardActionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StandardActionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::List>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[3]))); break;
        case 1: _t->actionStateUpdated(); break;
        case 2: _t->d->slotCreateCollection(); break;
        case 3: _t->d->slotCopyCollections(); break;
        case 4: _t->d->slotCutCollections(); break;
        case 5: _t->d->slotDeleteCollection(); break;
        case 6: _t->d->slotMoveCollectionToTrash(); break;
        case 7: _t->d->slotMoveItemToTrash(); break;
        case 8: _t->d->slotRestoreCollectionFromTrash(); break;
        case 9: _t->d->slotRestoreItemFromTrash(); break;
        case 10: _t->d->slotTrashRestoreCollection(); break;
        case 11: _t->d->slotTrashRestoreItem(); break;
        case 12: _t->d->slotSynchronizeCollection(); break;
        case 13: _t->d->slotSynchronizeCollectionRecursive(); break;
        case 14: _t->d->slotSynchronizeFavoriteCollections(); break;
        case 15: _t->d->slotCollectionProperties(); break;
        case 16: _t->d->slotCopyItems(); break;
        case 17: _t->d->slotCutItems(); break;
        case 18: _t->d->slotPaste(); break;
        case 19: _t->d->slotDeleteItems(); break;
        case 20: _t->d->slotDeleteItemsDeferred((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 21: _t->d->slotLocalSubscription(); break;
        case 22: _t->d->slotAddToFavorites(); break;
        case 23: _t->d->slotRemoveFromFavorites(); break;
        case 24: _t->d->slotRenameFavorite(); break;
        case 25: _t->d->slotCopyCollectionTo(); break;
        case 26: _t->d->slotMoveCollectionTo(); break;
        case 27: _t->d->slotCopyItemTo(); break;
        case 28: _t->d->slotMoveItemTo(); break;
        case 29: _t->d->slotCopyCollectionTo((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 30: _t->d->slotMoveCollectionTo((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 31: _t->d->slotCopyItemTo((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 32: _t->d->slotMoveItemTo((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 33: _t->d->slotCreateResource(); break;
        case 34: _t->d->slotDeleteResource(); break;
        case 35: _t->d->slotResourceProperties(); break;
        case 36: _t->d->slotSynchronizeResource(); break;
        case 37: _t->d->slotToggleWorkOffline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->d->slotSynchronizeCollectionTree(); break;
        case 39: _t->d->collectionCreationResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 40: _t->d->moveItemToTrashResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 41: _t->d->resourceCreationResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 42: _t->d->pasteResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Collection::List >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StandardActionManager::*)(const Akonadi::Collection::List & , const Akonadi::Collection::List & , const Akonadi::Item::List & )>(_a, &StandardActionManager::selectionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StandardActionManager::*)()>(_a, &StandardActionManager::actionStateUpdated, 1))
            return;
    }
}

const QMetaObject *Akonadi::StandardActionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::StandardActionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi21StandardActionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::StandardActionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::StandardActionManager::selectionsChanged(const Akonadi::Collection::List & _t1, const Akonadi::Collection::List & _t2, const Akonadi::Item::List & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Akonadi::StandardActionManager::actionStateUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
