/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef RESOURCEINTERFACE_H
#define RESOURCEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.Resource
 */
class OrgFreedesktopAkonadiResourceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.Resource"; }

public:
    OrgFreedesktopAkonadiResourceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiResourceInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QStringList> activities()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activities"), argumentList);
    }

    inline QDBusPendingReply<bool> activitiesEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activitiesEnabled"), argumentList);
    }

    inline QDBusPendingReply<QString> name()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("name"), argumentList);
    }

    inline QDBusPendingReply<> requestItemDelivery(const QList<qlonglong> &uids, const QByteArrayList &parts)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uids) << QVariant::fromValue(parts);
        return asyncCallWithArgumentList(QStringLiteral("requestItemDelivery"), argumentList);
    }

    inline QDBusPendingReply<> setActivities(const QStringList &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("setActivities"), argumentList);
    }

    inline QDBusPendingReply<> setActivitiesEnabled(bool en)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(en);
        return asyncCallWithArgumentList(QStringLiteral("setActivitiesEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setName(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("setName"), argumentList);
    }

    Q_NOREPLY inline void synchronize()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronize"), argumentList);
    }

    Q_NOREPLY inline void synchronizeCollection(qlonglong collectionId, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collectionId) << QVariant::fromValue(recursive);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronizeCollection"), argumentList);
    }

    Q_NOREPLY inline void synchronizeCollection(qlonglong collectionId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collectionId);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronizeCollection"), argumentList);
    }

    Q_NOREPLY inline void synchronizeCollectionAttributes(qlonglong collectionId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collectionId);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronizeCollectionAttributes"), argumentList);
    }

    Q_NOREPLY inline void synchronizeCollectionTree()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronizeCollectionTree"), argumentList);
    }

    Q_NOREPLY inline void synchronizeTags()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("synchronizeTags"), argumentList);
    }

    inline QDBusPendingReply<QStringList> taskList()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("taskList"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void attributesSynchronized(qlonglong collectionId);
    void collectionTreeSynchronized();
    void nameChanged(const QString &name);
    void synchronized();
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      using Resource = ::OrgFreedesktopAkonadiResourceInterface;
    }
  }
}

#endif
