/********************************************************************************
** Form generated from reading UI file 'collectiongeneralpropertiespage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLECTIONGENERALPROPERTIESPAGE_H
#define UI_COLLECTIONGENERALPROPERTIESPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kiconbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CollectionGeneralPropertiesPage
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *nameEdit;
    QCheckBox *customIconCheckbox;
    KIconButton *customIcon;
    QSpacerItem *spacerItem;
    QGroupBox *statsBox;
    QGridLayout *gridLayout1;
    QLabel *label_2;
    QLabel *countLabel;
    QLabel *label_3;
    QLabel *sizeLabel;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *CollectionGeneralPropertiesPage)
    {
        if (CollectionGeneralPropertiesPage->objectName().isEmpty())
            CollectionGeneralPropertiesPage->setObjectName("CollectionGeneralPropertiesPage");
        CollectionGeneralPropertiesPage->resize(400, 300);
        gridLayout = new QGridLayout(CollectionGeneralPropertiesPage);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(CollectionGeneralPropertiesPage);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        nameEdit = new QLineEdit(CollectionGeneralPropertiesPage);
        nameEdit->setObjectName("nameEdit");

        gridLayout->addWidget(nameEdit, 0, 1, 1, 3);

        customIconCheckbox = new QCheckBox(CollectionGeneralPropertiesPage);
        customIconCheckbox->setObjectName("customIconCheckbox");

        gridLayout->addWidget(customIconCheckbox, 1, 0, 1, 2);

        customIcon = new KIconButton(CollectionGeneralPropertiesPage);
        customIcon->setObjectName("customIcon");
        customIcon->setEnabled(false);
        customIcon->setIconSize(16);

        gridLayout->addWidget(customIcon, 1, 2, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 1, 3, 1, 1);

        statsBox = new QGroupBox(CollectionGeneralPropertiesPage);
        statsBox->setObjectName("statsBox");
        gridLayout1 = new QGridLayout(statsBox);
        gridLayout1->setObjectName("gridLayout1");
        label_2 = new QLabel(statsBox);
        label_2->setObjectName("label_2");

        gridLayout1->addWidget(label_2, 0, 0, 1, 1);

        countLabel = new QLabel(statsBox);
        countLabel->setObjectName("countLabel");

        gridLayout1->addWidget(countLabel, 0, 1, 1, 1);

        label_3 = new QLabel(statsBox);
        label_3->setObjectName("label_3");

        gridLayout1->addWidget(label_3, 1, 0, 1, 1);

        sizeLabel = new QLabel(statsBox);
        sizeLabel->setObjectName("sizeLabel");

        gridLayout1->addWidget(sizeLabel, 1, 1, 1, 1);


        gridLayout->addWidget(statsBox, 2, 0, 1, 4);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 3, 2, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(nameEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CollectionGeneralPropertiesPage);
        QObject::connect(customIconCheckbox, SIGNAL(toggled(bool)), customIcon, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CollectionGeneralPropertiesPage);
    } // setupUi

    void retranslateUi(QWidget *CollectionGeneralPropertiesPage)
    {
        label->setText(tr2i18n("&Name:", nullptr));
        customIconCheckbox->setText(tr2i18n("&Use custom icon:", nullptr));
        customIcon->setIcon(tr2i18n("folder", nullptr));
        statsBox->setTitle(tr2i18n("Statistics", nullptr));
        label_2->setText(tr2i18n("Content:", "object names"));
        countLabel->setText(tr2i18n("0 objects", nullptr));
        label_3->setText(tr2i18n("Size:", nullptr));
        sizeLabel->setText(tr2i18n("0 Byte", nullptr));
        (void)CollectionGeneralPropertiesPage;
    } // retranslateUi

};

namespace Ui {
    class CollectionGeneralPropertiesPage: public Ui_CollectionGeneralPropertiesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLLECTIONGENERALPROPERTIESPAGE_H

