
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_favoritecollectionsmodel_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"
#include "akonadi_statisticsproxymodel_wrapper.h"

// Extra includes
#include <kselectionproxymodel.h>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <collection.h>
#include <kjob.h>
#include <qabstractitemmodel.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_FavoriteCollectionsModel_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void FavoriteCollectionsModelWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

::QVariant FavoriteCollectionsModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::data(index, role);
    }
    return StatisticsProxyModelWrapper::sbk_o_data("FavoriteCollectionsModel", funcName, gil, pyOverride, index, role);
}

bool FavoriteCollectionsModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::dropMimeData(data, action, row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canDropMimeData("FavoriteCollectionsModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

::QFlags<Qt::ItemFlag> FavoriteCollectionsModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::flags(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_flags("FavoriteCollectionsModel", funcName, gil, pyOverride, index);
}

::QVariant FavoriteCollectionsModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::headerData(section, orientation, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_headerData("FavoriteCollectionsModel", funcName, gil, pyOverride, section, orientation, role);
}

::QStringList FavoriteCollectionsModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::mimeTypes();
    }
    return TrashFilterProxyModelWrapper::sbk_o_mimeTypes("FavoriteCollectionsModel", funcName, gil, pyOverride);
}

bool FavoriteCollectionsModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::FavoriteCollectionsModel::setData(index, value, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setData("FavoriteCollectionsModel", funcName, gil, pyOverride, index, value, role);
}

FavoriteCollectionsModelWrapper::~FavoriteCollectionsModelWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_FavoriteCollectionsModel_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Akonadi_FavoriteCollectionsModel_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("FavoriteCollectionsModel");
    return -1;
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_addCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::addCollection(const Akonadi::Collection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::addCollection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::addCollection(const Akonadi::Collection&)
            cppSelf->addCollection(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_collectionIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FavoriteCollectionsModel::collectionIds()const->QList<long long>
        QList<long long> cppResult = const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->collectionIds();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_longlong_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_data(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:data", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::data(const QModelIndex&,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // FavoriteCollectionsModel::data(const QModelIndex&,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = Qt::DisplayRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::data(const QModelIndex&,int=)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->::Akonadi::FavoriteCollectionsModel::data(*cppArg0, cppArg1)
                : const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_defaultFavoriteLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::defaultFavoriteLabel(const Akonadi::Collection&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::defaultFavoriteLabel(const Akonadi::Collection&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultFavoriteLabel", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::defaultFavoriteLabel(const Akonadi::Collection&)->QString
            QString cppResult = cppSelf->defaultFavoriteLabel(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_dropMimeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dropMimeData", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX]))), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[4])))) {
        overloadId = 0; // FavoriteCollectionsModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dropMimeData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::DropAction cppArg1{Qt::IgnoreAction};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QModelIndex cppArg4_local;
        ::QModelIndex *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4].isValue())
            pythonToCpp[4](pyArgs[4], &cppArg4_local);
        else
            pythonToCpp[4](pyArgs[4], &cppArg4);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::FavoriteCollectionsModel::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4)
                : cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_favoriteLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::favoriteLabel(const Akonadi::Collection&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::favoriteLabel(const Akonadi::Collection&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "favoriteLabel", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::favoriteLabel(const Akonadi::Collection&)->QString
            QString cppResult = cppSelf->favoriteLabel(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_flags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "flags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
            QFlags<Qt::ItemFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->::Akonadi::FavoriteCollectionsModel::flags(*cppArg0)
                : const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->flags(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX]))), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_headerData(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:headerData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::headerData(int,Qt::Orientation,int=)const->QVariant
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX]))), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // FavoriteCollectionsModel::headerData(int,Qt::Orientation,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "headerData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::DisplayRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::headerData(int,Qt::Orientation,int=)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->::Akonadi::FavoriteCollectionsModel::headerData(cppArg0, cppArg1, cppArg2)
                : const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->headerData(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_mimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FavoriteCollectionsModel::mimeTypes()const->QStringList
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->::Akonadi::FavoriteCollectionsModel::mimeTypes()
            : const_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppSelf)->mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_removeCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::removeCollection(const Akonadi::Collection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::removeCollection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::removeCollection(const Akonadi::Collection&)
            cppSelf->removeCollection(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_setCollections(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::setCollections(const QList<Akonadi::Collection>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Collection_IDX], (pyArg)))) {
        overloadId = 0; // FavoriteCollectionsModel::setCollections(const QList<Akonadi::Collection>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollections", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        ::QList<Akonadi::Collection> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::setCollections(const QList<Akonadi::Collection>&)
            cppSelf->setCollections(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_setData(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::setData(const QModelIndex&,const QVariant&,int=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // FavoriteCollectionsModel::setData(const QModelIndex&,const QVariant&,int=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::EditRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::setData(const QModelIndex&,const QVariant&,int=)->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::FavoriteCollectionsModel::setData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->setData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_FavoriteCollectionsModelFunc_setFavoriteLabel(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFavoriteLabel", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FavoriteCollectionsModel::setFavoriteLabel(const Akonadi::Collection&,const QString&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // FavoriteCollectionsModel::setFavoriteLabel(const Akonadi::Collection&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFavoriteLabel", SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // FavoriteCollectionsModel::setFavoriteLabel(const Akonadi::Collection&,const QString&)
            cppSelf->setFavoriteLabel(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_FavoriteCollectionsModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_FavoriteCollectionsModel_methods[] = {
    {"addCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_addCollection), METH_O, nullptr},
    {"collectionIds", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_collectionIds), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"defaultFavoriteLabel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_defaultFavoriteLabel), METH_O, nullptr},
    {"dropMimeData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_dropMimeData), METH_VARARGS, nullptr},
    {"favoriteLabel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_favoriteLabel), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_flags), METH_O, nullptr},
    {"headerData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_headerData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_mimeTypes), METH_NOARGS, nullptr},
    {"removeCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_removeCollection), METH_O, nullptr},
    {"setCollections", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_setCollections), METH_O, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_setData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFavoriteLabel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_FavoriteCollectionsModelFunc_setFavoriteLabel), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_FavoriteCollectionsModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::FavoriteCollectionsModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<FavoriteCollectionsModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_FavoriteCollectionsModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_FavoriteCollectionsModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_FavoriteCollectionsModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_FavoriteCollectionsModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_FavoriteCollectionsModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_FavoriteCollectionsModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_FavoriteCollectionsModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_FavoriteCollectionsModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_FavoriteCollectionsModel_spec = {
    "1:AkonadiCore.Akonadi.FavoriteCollectionsModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_FavoriteCollectionsModel_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void FavoriteCollectionsModel_PythonToCpp_FavoriteCollectionsModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_FavoriteCollectionsModel_PythonToCpp_FavoriteCollectionsModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_FavoriteCollectionsModel_TypeF()))
        return FavoriteCollectionsModel_PythonToCpp_FavoriteCollectionsModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *FavoriteCollectionsModel_PTR_CppToPython_FavoriteCollectionsModel(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_FavoriteCollectionsModel_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::FavoriteCollectionsModel *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_FavoriteCollectionsModel_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_FavoriteCollectionsModel_SignatureStrings[] = {
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.addCollection(self,collection:AkonadiCore.Akonadi.Collection)",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.collectionIds(self)->QList[long long]",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.defaultFavoriteLabel(self,col:AkonadiCore.Akonadi.Collection)->QString",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.dropMimeData(self,data:PySide6.QtCore.QMimeData,action:PySide6.QtCore.Qt.DropAction,row:int,column:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.favoriteLabel(self,col:AkonadiCore.Akonadi.Collection)->QString",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.flags(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.Qt.ItemFlag",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.headerData(self,section:int,orientation:PySide6.QtCore.Qt.Orientation,role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.mimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.removeCollection(self,collection:AkonadiCore.Akonadi.Collection)",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.setCollections(self,collections:QList[AkonadiCore.Akonadi.Collection])",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.setData(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],value:QVariant,role:int=Qt.EditRole)->bool",
    "AkonadiCore.Akonadi.FavoriteCollectionsModel.setFavoriteLabel(self,collection:AkonadiCore.Akonadi.Collection,label:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_FavoriteCollectionsModel_SignatureByteSize = 384;
static constexpr uint8_t Akonadi_FavoriteCollectionsModel_SignatureBytes[384] = {
    0x78, 0xda, 0xbd, 0x54, 0x4d, 0x6f, 0xc2, 0x30, 0x0c, 0xbd, 0xf3, 0x2b, 0x38, 0x0e, 0xa9, 0xeb,
    0x71, 0x87, 0x4a, 0x9b, 0x54, 0xc1, 0x90, 0x2a, 0x81, 0x46, 0xc7, 0xb6, 0x0b, 0xe2, 0x60, 0x88,
    0xcb, 0xa2, 0xa5, 0x49, 0x95, 0x04, 0xb6, 0xfe, 0xfb, 0x39, 0x6d, 0xa1, 0x1b, 0xb0, 0x8f, 0x48,
    0xc0, 0xa5, 0x4a, 0x63, 0xc7, 0xef, 0xe5, 0x3d, 0xc7, 0xf1, 0x9b, 0x92, 0xc0, 0x78, 0x5f, 0x69,
    0x0c, 0xe3, 0x7a, 0x1d, 0x0e, 0x61, 0xa3, 0x34, 0xb7, 0xd8, 0x57, 0x42, 0xe0, 0xd2, 0x72, 0x25,
    0xcd, 0x58, 0x31, 0x14, 0x21, 0x30, 0xd6, 0xee, 0x5d, 0x19, 0x14, 0x59, 0xb0, 0xdc, 0xfd, 0x47,
    0xf1, 0x91, 0x52, 0x6d, 0x7a, 0xaf, 0x13, 0xfb, 0x40, 0xb5, 0x75, 0x13, 0x66, 0x2a, 0xa8, 0xde,
    0xf5, 0x5d, 0x3a, 0xe2, 0xc6, 0xce, 0x84, 0x92, 0xab, 0xae, 0xfb, 0xcc, 0xfd, 0x4a, 0x32, 0xb0,
    0x50, 0x93, 0xe6, 0x92, 0xe1, 0x47, 0x64, 0xcb, 0x82, 0xcb, 0x55, 0xf8, 0x2c, 0x29, 0x65, 0x36,
    0x29, 0xa7, 0x9c, 0xe1, 0x4d, 0x98, 0xda, 0xaa, 0x58, 0x5a, 0x1d, 0x49, 0x5c, 0x5e, 0xd0, 0xdd,
    0x8f, 0x4d, 0x50, 0x1b, 0x22, 0x82, 0xd2, 0xb6, 0x59, 0xf3, 0x40, 0x2b, 0x81, 0x11, 0x97, 0xf6,
    0x36, 0xb5, 0xe1, 0x80, 0x9b, 0x42, 0x40, 0xf9, 0x48, 0x5b, 0x8e, 0xf6, 0x0b, 0x68, 0x0e, 0xd2,
    0x7a, 0xd2, 0xc5, 0x0c, 0xd6, 0xc2, 0x6e, 0xe3, 0x23, 0x58, 0xa0, 0xd8, 0x69, 0xfe, 0x97, 0xd8,
    0x04, 0x3a, 0xb5, 0x9a, 0xae, 0xe7, 0x89, 0xa9, 0x55, 0x31, 0xe6, 0x39, 0x0e, 0x76, 0x52, 0x39,
    0xd1, 0xa2, 0x03, 0x71, 0x9a, 0x94, 0x00, 0x6a, 0xe7, 0xf7, 0xe3, 0x24, 0x00, 0x15, 0x8a, 0xab,
    0x20, 0xe9, 0xf2, 0xee, 0x64, 0x71, 0xac, 0xd7, 0xb9, 0xac, 0x96, 0x05, 0x68, 0x12, 0xef, 0xc4,
    0x06, 0xd0, 0x9d, 0x17, 0x4a, 0x09, 0xbf, 0x0b, 0x67, 0x97, 0x54, 0x37, 0x13, 0xb0, 0x32, 0xe7,
    0xeb, 0x40, 0xa2, 0x75, 0x68, 0x44, 0x62, 0x31, 0x1f, 0x12, 0xae, 0x1f, 0xd3, 0x57, 0x04, 0x86,
    0xba, 0xed, 0x02, 0xd3, 0x3c, 0x71, 0x67, 0x1e, 0x9d, 0x20, 0x5c, 0xf8, 0xc1, 0xf8, 0x87, 0x36,
    0x7a, 0xf2, 0x17, 0x91, 0x53, 0xdb, 0x3d, 0x95, 0x05, 0xb6, 0xf3, 0xa0, 0x76, 0xc1, 0x4d, 0x05,
    0xbf, 0x4a, 0x1a, 0x73, 0xb5, 0xc1, 0x4b, 0xcd, 0x32, 0x83, 0xf6, 0xcb, 0xde, 0x3e, 0x96, 0x89,
    0xea, 0xb1, 0xf6, 0x3b, 0xe4, 0xdc, 0x1f, 0x73, 0x70, 0xde, 0x79, 0xb7, 0x01, 0xb1, 0xc6, 0x68,
    0xeb, 0xe4, 0x37, 0xb3, 0xef, 0x19, 0xb7, 0x8d, 0xd3, 0xfe, 0x4f, 0x92, 0x98, 0x1f, 0x9f, 0x79,
    0xff, 0xf3, 0x26, 0x10, 0xee, 0x50, 0xd4, 0xb4, 0x46, 0xaf, 0xf3, 0x09, 0x5c, 0xc3, 0x90, 0x28
};
#endif

PyTypeObject *init_Akonadi_FavoriteCollectionsModel(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_FavoriteCollectionsModel_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_FavoriteCollectionsModel_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "FavoriteCollectionsModel",
        "Akonadi::FavoriteCollectionsModel*",
        &Sbk_Akonadi_FavoriteCollectionsModel_spec,
        &Shiboken::callCppDestructor< Akonadi::FavoriteCollectionsModel >,
        Sbk_Akonadi_FavoriteCollectionsModel_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_FavoriteCollectionsModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_FavoriteCollectionsModel_SignatureBytes, Akonadi_FavoriteCollectionsModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_FavoriteCollectionsModel_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        FavoriteCollectionsModel_PythonToCpp_FavoriteCollectionsModel_PTR,
        is_FavoriteCollectionsModel_PythonToCpp_FavoriteCollectionsModel_PTR_Convertible,
        FavoriteCollectionsModel_PTR_CppToPython_FavoriteCollectionsModel);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::FavoriteCollectionsModel");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::FavoriteCollectionsModel*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::FavoriteCollectionsModel&");
    Shiboken::Conversions::registerConverterAlias(converter, "FavoriteCollectionsModel");
    Shiboken::Conversions::registerConverterAlias(converter, "FavoriteCollectionsModel*");
    Shiboken::Conversions::registerConverterAlias(converter, "FavoriteCollectionsModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::FavoriteCollectionsModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(FavoriteCollectionsModelWrapper).name());

    qRegisterMetaType< ::Akonadi::FavoriteCollectionsModel *>();

    return pyType;
}
