// This file is generated by kconfig_compiler_kf6 from knutresource.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

KnutSettings::KnutSettings( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mDataFileItem = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "DataFile" ), mDataFile );
  mDataFileItem->setLabel( QCoreApplication::translate("KnutSettings", "Path to the Knut data file.") );
  addItem( mDataFileItem, QStringLiteral( "DataFile" ) );
  mReadOnlyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ReadOnly" ), mReadOnly, false );
  mReadOnlyItem->setLabel( QCoreApplication::translate("KnutSettings", "Do not change the actual backend data.") );
  addItem( mReadOnlyItem, QStringLiteral( "ReadOnly" ) );
  mFileWatchingEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FileWatchingEnabled" ), mFileWatchingEnabled, true );
  mFileWatchingEnabledItem->setLabel( QCoreApplication::translate("KnutSettings", "FileWatchingEnabled") );
  addItem( mFileWatchingEnabledItem, QStringLiteral( "FileWatchingEnabled" ) );
}

KnutSettings::~KnutSettings()
{
}

