/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Account.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ACCOUNTADAPTOR_H
#define ACCOUNTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "accountbase_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Agent.Account
 */
class Akonadi__AccountAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Agent.Account")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Agent.Account\">\n"
"    <method name=\"setAccountId\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"accountId\"/>\n"
"    </method>\n"
"    <method name=\"accountId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <signal name=\"accountIdChanged\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"accountId\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    Akonadi__AccountAdaptor(Akonadi::AccountBasePrivate *parent);
    ~Akonadi__AccountAdaptor() override;

    inline Akonadi::AccountBasePrivate *parent() const
    { return static_cast<Akonadi::AccountBasePrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString accountId();
    void setAccountId(const QString &accountId);
Q_SIGNALS: // SIGNALS
    void accountIdChanged(const QString &accountId);
};

#endif
