// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akonadiserver_search_debug.h"


Q_LOGGING_CATEGORY(AKONADISERVER_SEARCH_LOG, "org.kde.pim.akonadiserver.search", QtInfoMsg)

