/****************************************************************************
** Meta object code from reading C++ file 'controladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "controladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'controladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi__ControlAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi__ControlAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Agent.Control",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.Agent.Control\">\n    "
        "<method name=\"quit\"/>\n    <method name=\"cleanup\"/>\n    <meth"
        "od name=\"configure\">\n      <arg direction=\"in\" type=\"x\" nam"
        "e=\"windowId\"/>\n      <annotation value=\"true\" name=\"org.free"
        "desktop.DBus.Method.NoReply\"/>\n    </method>\n    <signal name=\""
        "configurationDialogAccepted\"/>\n    <signal name=\"configurationD"
        "ialogRejected\"/>\n    <signal name=\"finished\"/>\n    <method na"
        "me=\"reconfigure\"/>\n    <method name=\"abort\"/>\n  </interface>"
        "\n",
        "configurationDialogAccepted",
        "",
        "configurationDialogRejected",
        "finished",
        "abort",
        "cleanup",
        "configure",
        "Q_NOREPLY",
        "windowId",
        "quit",
        "reconfigure"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configurationDialogAccepted'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationDialogRejected'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configure'
        QtMocHelpers::SlotData<void(qlonglong)>(11, 12, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Akonadi__ControlAdaptor, qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi__ControlAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>.metaTypes,
    nullptr
} };

void Akonadi__ControlAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Akonadi__ControlAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configurationDialogAccepted(); break;
        case 1: _t->configurationDialogRejected(); break;
        case 2: _t->finished(); break;
        case 3: _t->abort(); break;
        case 4: _t->cleanup(); break;
        case 5: _t->configure((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 6: _t->quit(); break;
        case 7: _t->reconfigure(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ControlAdaptor::*)()>(_a, &Akonadi__ControlAdaptor::configurationDialogAccepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ControlAdaptor::*)()>(_a, &Akonadi__ControlAdaptor::configurationDialogRejected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ControlAdaptor::*)()>(_a, &Akonadi__ControlAdaptor::finished, 2))
            return;
    }
}

const QMetaObject *Akonadi__ControlAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi__ControlAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23Akonadi__ControlAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Akonadi__ControlAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Akonadi__ControlAdaptor::configurationDialogAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Akonadi__ControlAdaptor::configurationDialogRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi__ControlAdaptor::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
