/****************************************************************************
** Meta object code from reading C++ file 'agentbase_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/agentbase/agentbase_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentbase_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::AgentBasePrivate::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::AgentBasePrivate",
        "D-Bus Interface",
        "org.kde.dfaure",
        "slotStatus",
        "",
        "status",
        "message",
        "slotPercent",
        "progress",
        "slotWarning",
        "slotError",
        "slotNetworkStatusChange",
        "isOnline",
        "slotResumedFromSuspend",
        "slotTemporaryOfflineTimeout",
        "changeProcessed",
        "dumpNotificationListToString",
        "dumpMemoryInfo",
        "dumpMemoryInfoToString",
        "itemAdded",
        "Akonadi::Item",
        "item",
        "Akonadi::Collection",
        "collection",
        "itemChanged",
        "QSet<QByteArray>",
        "partIdentifiers",
        "itemMoved",
        "source",
        "destination",
        "itemRemoved",
        "itemLinked",
        "itemUnlinked",
        "itemsFlagsChanged",
        "Akonadi::Item::List",
        "items",
        "addedFlags",
        "removedFlags",
        "itemsMoved",
        "itemsRemoved",
        "itemsLinked",
        "itemsUnlinked",
        "collectionAdded",
        "parent",
        "collectionChanged",
        "changedAttributes",
        "collectionMoved",
        "collectionRemoved",
        "collectionSubscribed",
        "collectionUnsubscribed",
        "tagAdded",
        "Akonadi::Tag",
        "tag",
        "tagChanged",
        "tagRemoved",
        "itemsTagsChanged",
        "QSet<Akonadi::Tag>",
        "addedTags",
        "removedTags"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotStatus'
        QtMocHelpers::SlotData<void(int, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'slotPercent'
        QtMocHelpers::SlotData<void(int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'slotWarning'
        QtMocHelpers::SlotData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'slotError'
        QtMocHelpers::SlotData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'slotNetworkStatusChange'
        QtMocHelpers::SlotData<void(bool)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'slotResumedFromSuspend'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTemporaryOfflineTimeout'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeProcessed'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dumpNotificationListToString'
        QtMocHelpers::SlotData<QString() const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'dumpMemoryInfo'
        QtMocHelpers::SlotData<void() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'dumpMemoryInfoToString'
        QtMocHelpers::SlotData<QString() const>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'itemAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'itemChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'itemMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &, const Akonadi::Collection &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 28 }, { 0x80000000 | 22, 29 },
        }}),
        // Slot 'itemRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'itemLinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'itemUnlinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'itemsFlagsChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QSet<QByteArray> &, const QSet<QByteArray> &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 25, 36 }, { 0x80000000 | 25, 37 },
        }}),
        // Slot 'itemsMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &, const Akonadi::Collection &)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 22, 28 }, { 0x80000000 | 22, 29 },
        }}),
        // Slot 'itemsRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'itemsLinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'itemsUnlinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'collectionAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 22, 43 },
        }}),
        // Slot 'collectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'collectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const QSet<QByteArray> &)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 25, 45 },
        }}),
        // Slot 'collectionMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &, const Akonadi::Collection &)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 22, 28 }, { 0x80000000 | 22, 29 },
        }}),
        // Slot 'collectionRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'collectionSubscribed'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 22, 43 },
        }}),
        // Slot 'collectionUnsubscribed'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'tagAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Tag &)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'tagChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Tag &)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'tagRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Tag &)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'itemsTagsChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QSet<Akonadi::Tag> &, const QSet<Akonadi::Tag> &)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { 0x80000000 | 56, 57 }, { 0x80000000 | 56, 58 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AgentBasePrivate, qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi::AgentBasePrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>.metaTypes,
    nullptr
} };

void Akonadi::AgentBasePrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentBasePrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->slotPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->slotWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->slotError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->slotNetworkStatusChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->slotResumedFromSuspend(); break;
        case 6: _t->slotTemporaryOfflineTimeout(); break;
        case 7: _t->changeProcessed(); break;
        case 8: { QString _r = _t->dumpNotificationListToString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->dumpMemoryInfo(); break;
        case 10: { QString _r = _t->dumpMemoryInfoToString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 12: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 13: _t->itemMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 14: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 15: _t->itemLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 16: _t->itemUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 17: _t->itemsFlagsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[3]))); break;
        case 18: _t->itemsMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 19: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 20: _t->itemsLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 21: _t->itemsUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 22: _t->collectionAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 23: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 24: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 25: _t->collectionMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 26: _t->collectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 27: _t->collectionSubscribed((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 28: _t->collectionUnsubscribed((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 29: _t->tagAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 30: _t->tagChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 31: _t->tagRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 32: _t->itemsTagsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<Akonadi::Tag> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Akonadi::AgentBasePrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::AgentBasePrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi16AgentBasePrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::AgentBasePrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}
QT_WARNING_POP
