
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_agenttype_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <QStringList>
#include <agenttype.h>
#include <qicon.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_AgentType_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_AgentType_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::AgentType >()))
        return -1;

    ::Akonadi::AgentType *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "AgentType", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: AgentType::AgentType()
    // 1: AgentType::AgentType(const Akonadi::AgentType&)
    if (numArgs == 0) {
        overloadId = 0; // AgentType()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), (pyArgs[0])))) {
        overloadId = 1; // AgentType::AgentType(const Akonadi::AgentType&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // AgentType()
        {

            // AgentType::AgentType()
            cptr = new ::Akonadi::AgentType();
            break;
        }
        case 1: // AgentType(const Akonadi::AgentType &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::AgentType cppArg0_local;
            ::Akonadi::AgentType *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // AgentType::AgentType(const Akonadi::AgentType&)
                cptr = new ::Akonadi::AgentType(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::AgentType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_capabilities(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::capabilities()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->capabilities();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_customProperties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::customProperties()const->QMap<QString,QVariant>
        QMap<QString,QVariant> cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->customProperties();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QMap_QString_QVariant_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::description()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::icon()const->QIcon
        QIcon cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->icon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_iconName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::iconName()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->iconName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::identifier()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->identifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_mimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::mimeTypes()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentTypeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentType::name()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentType *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentType__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_AgentType_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_AgentType_methods[] = {
    {"capabilities", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_capabilities), METH_NOARGS, nullptr},
    {"customProperties", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_customProperties), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_description), METH_NOARGS, nullptr},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_icon), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_iconName), METH_NOARGS, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_identifier), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_isValid), METH_NOARGS, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_mimeTypes), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentTypeFunc_name), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentType__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_Akonadi_AgentType_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), (pyArg)))) {
                // AgentType::operator==(const Akonadi::AgentType&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::AgentType cppArg0_local;
                ::Akonadi::AgentType *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Akonadi_AgentType_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_AgentType_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_AgentType_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_AgentType_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_AgentType_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Akonadi_AgentType_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_AgentType_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_AgentType_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_AgentType_spec = {
    "1:AkonadiCore.Akonadi.AgentType",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_AgentType_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void AgentType_PythonToCpp_AgentType_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_AgentType_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_AgentType_PythonToCpp_AgentType_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AgentType_TypeF()))
        return AgentType_PythonToCpp_AgentType_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *AgentType_PTR_CppToPython_AgentType(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_AgentType_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_AgentType_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *AgentType_COPY_CppToPython_AgentType(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::AgentType *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_AgentType_TypeF(), new ::Akonadi::AgentType(*source), true, true);
}

// Python to C++ copy conversion.
static void AgentType_PythonToCpp_AgentType_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::AgentType *>(cppOut) = *reinterpret_cast< ::Akonadi::AgentType *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_AgentType_PythonToCpp_AgentType_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AgentType_TypeF()))
        return AgentType_PythonToCpp_AgentType_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_AgentType_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.AgentType(self)",
    "0:AkonadiCore.Akonadi.AgentType(self,other:AkonadiCore.Akonadi.AgentType)",
    "AkonadiCore.Akonadi.AgentType.capabilities(self)->QStringList",
    "AkonadiCore.Akonadi.AgentType.customProperties(self)->QMap[QString, QVariant]",
    "AkonadiCore.Akonadi.AgentType.description(self)->QString",
    "AkonadiCore.Akonadi.AgentType.icon(self)->PySide6.QtGui.QIcon",
    "AkonadiCore.Akonadi.AgentType.iconName(self)->QString",
    "AkonadiCore.Akonadi.AgentType.identifier(self)->QString",
    "AkonadiCore.Akonadi.AgentType.isValid(self)->bool",
    "AkonadiCore.Akonadi.AgentType.mimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.AgentType.name(self)->QString",
    "AkonadiCore.Akonadi.AgentType.__copy__(self)->typing._Self",
    "AkonadiCore.Akonadi.AgentType.__eq__(self,other:AkonadiCore.Akonadi.AgentType)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_AgentType_SignatureByteSize = 217;
static constexpr uint8_t Akonadi_AgentType_SignatureBytes[217] = {
    0x78, 0xda, 0x9d, 0xd2, 0xc1, 0x0a, 0xc2, 0x30, 0x0c, 0x00, 0xd0, 0xbb, 0x5f, 0xe1, 0x51, 0x41,
    0x8b, 0x5e, 0x3c, 0x78, 0x10, 0xc4, 0x83, 0x08, 0x2a, 0x8e, 0x89, 0x17, 0x91, 0x52, 0xd7, 0x4c,
    0x83, 0x5b, 0x53, 0xdb, 0x78, 0xd8, 0xdf, 0x3b, 0x71, 0x22, 0x7a, 0xb0, 0x9b, 0xb7, 0x94, 0xe4,
    0x25, 0x0d, 0xed, 0x70, 0x3c, 0xbd, 0x90, 0x51, 0x1a, 0x67, 0xe4, 0x40, 0x54, 0xb1, 0x98, 0x9e,
    0xc0, 0xf0, 0xb6, 0xb0, 0xd0, 0xf1, 0x90, 0xa5, 0xdd, 0xd6, 0xa0, 0x46, 0x55, 0x8f, 0xf8, 0x0c,
    0xee, 0x77, 0x61, 0xb7, 0xf5, 0x33, 0x2d, 0x12, 0x65, 0xd5, 0x11, 0x33, 0x64, 0x04, 0xff, 0x1c,
    0xdd, 0x9f, 0x44, 0x31, 0x3b, 0x34, 0xa7, 0x25, 0x7a, 0x0e, 0xe9, 0x9b, 0x67, 0xca, 0x37, 0x8e,
    0x2c, 0xb8, 0x8f, 0x0e, 0x2b, 0x65, 0xf7, 0x55, 0x9b, 0x5e, 0x3b, 0xda, 0x29, 0x87, 0xca, 0xf0,
    0x21, 0xd0, 0x4d, 0x83, 0x4f, 0x1c, 0x5a, 0x46, 0x32, 0x5f, 0x57, 0x09, 0x40, 0x4c, 0xde, 0x62,
    0x53, 0xc4, 0xa8, 0x61, 0x24, 0x22, 0x9e, 0xdf, 0x50, 0x44, 0x8b, 0x32, 0x55, 0x43, 0xaf, 0x55,
    0x0e, 0x0d, 0x67, 0xea, 0x32, 0xc2, 0x14, 0xc1, 0x35, 0x74, 0x7e, 0xa7, 0x32, 0xd4, 0x2f, 0x74,
    0x24, 0xca, 0x02, 0x22, 0xc7, 0x1c, 0x1e, 0xc1, 0x1f, 0xef, 0x63, 0x1a, 0xaf, 0x25, 0x65, 0x42,
    0xb6, 0x90, 0xf2, 0xa5, 0xb8, 0xb0, 0x25, 0x12, 0x32, 0x2e, 0x8f, 0x41, 0x0a, 0xd7, 0x0a, 0xd6,
    0xfa, 0x99, 0xd5, 0xf2, 0x77, 0xec, 0x1e, 0x1c, 0x1b
};
#endif

PyTypeObject *init_Akonadi_AgentType(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_AgentType_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "AgentType",
        "Akonadi::AgentType",
        &Sbk_Akonadi_AgentType_spec,
        &Shiboken::callCppDestructor< ::Akonadi::AgentType >,
        Sbk_Akonadi_AgentType_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_AgentType_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_AgentType_SignatureBytes, Akonadi_AgentType_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_AgentType_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        AgentType_PythonToCpp_AgentType_PTR,
        is_AgentType_PythonToCpp_AgentType_PTR_Convertible,
        AgentType_PTR_CppToPython_AgentType,
        AgentType_COPY_CppToPython_AgentType);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentType");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentType*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentType&");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentType");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentType*");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentType&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::AgentType).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        AgentType_PythonToCpp_AgentType_COPY,
        is_AgentType_PythonToCpp_AgentType_COPY_Convertible);

    qRegisterMetaType< ::Akonadi::AgentType >("AgentType");
    qRegisterMetaType< ::Akonadi::AgentType >("Akonadi::AgentType");

    return pyType;
}
