
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_item_wrapper.h"

// Argument includes
#include <QList>
#include <QSet>
#include <QString>
#include <attribute.h>
#include <collection.h>
#include <item.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qurl.h>
#include <tag.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_Item_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_Item_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::Item >()))
        return -1;

    ::Akonadi::Item *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Item", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Item::Item()
    // 1: Item::Item(const Akonadi::Item&)
    // 2: Item::Item(const QString&)
    // 3: Item::Item(long long)
    if (numArgs == 0) {
        overloadId = 0; // Item()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArgs[0])))) {
        overloadId = 3; // Item::Item(long long)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 2; // Item::Item(const QString&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Item::Item(const Akonadi::Item&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Item()
        {

            // Item::Item()
            cptr = new ::Akonadi::Item();
            break;
        }
        case 1: // Item(const Akonadi::Item &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Item::Item(const Akonadi::Item&)
                cptr = new ::Akonadi::Item(*cppArg0);
            }
            break;
        }
        case 2: // Item(const QString &mimeType)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Item::Item(const QString&)
                cptr = new ::Akonadi::Item(cppArg0);
            }
            break;
        }
        case 3: // Item(long long id)
        {
            long long cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Item::Item(long long)
                cptr = new ::Akonadi::Item(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::Item >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_ItemFunc_addAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::addAttribute(Akonadi::Attribute*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]), (pyArg)))) {
        overloadId = 0; // Item::addAttribute(Akonadi::Attribute*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Attribute *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::addAttribute(Akonadi::Attribute*)
            cppSelf->addAttribute(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_apply(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::apply(const Akonadi::Item&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
        overloadId = 0; // Item::apply(const Akonadi::Item&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "apply", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::apply(const Akonadi::Item&)
            cppSelf->apply(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_attribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::attribute(const QByteArray&)->Akonadi::Attribute*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::attribute(const QByteArray&)->Akonadi::Attribute*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::attribute(const QByteArray&)->Akonadi::Attribute*
            Akonadi::Attribute * cppResult = cppSelf->attribute(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::attributes()const->QList<Akonadi::Attribute*>
        QList<Akonadi::Attribute*> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_AttributePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_availablePayloadMetaTypeIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::availablePayloadMetaTypeIds()const->QList<int>
        QList<int> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->availablePayloadMetaTypeIds();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_availablePayloadParts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::availablePayloadParts()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->availablePayloadParts();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_cachedPayloadParts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::cachedPayloadParts()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->cachedPayloadParts();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_clearAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::clearAttributes()
        cppSelf->clearAttributes();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_clearFlag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::clearFlag(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::clearFlag(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearFlag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::clearFlag(const QByteArray&)
            cppSelf->clearFlag(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_clearFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::clearFlags()
        cppSelf->clearFlags();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_clearPayload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::clearPayload()
        cppSelf->clearPayload();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_clearTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::clearTag(const Akonadi::Tag&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // Item::clearTag(const Akonadi::Tag&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "clearTag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Tag cppArg0_local;
        ::Akonadi::Tag *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::clearTag(const Akonadi::Tag&)
            cppSelf->clearTag(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_clearTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::clearTags()
        cppSelf->clearTags();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::flags()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_fromUrl([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static Item::fromUrl(const QUrl&)->Akonadi::Item
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // static Item::fromUrl(const QUrl&)->Akonadi::Item
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromUrl", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static Item::fromUrl(const QUrl&)->Akonadi::Item
            Akonadi::Item cppResult = ::Akonadi::Item::fromUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_gid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::gid()const->QString
        QString cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->gid();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_hasAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::hasAttribute(const QByteArray&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::hasAttribute(const QByteArray&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::hasAttribute(const QByteArray&)const->bool
            bool cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->hasAttribute(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_hasFlag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::hasFlag(const QByteArray&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::hasFlag(const QByteArray&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasFlag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::hasFlag(const QByteArray&)const->bool
            bool cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->hasFlag(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_hasPayload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::hasPayload()const->bool
        bool cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->hasPayload();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_hasTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::hasTag(const Akonadi::Tag&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // Item::hasTag(const Akonadi::Tag&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasTag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Tag cppArg0_local;
        ::Akonadi::Tag *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::hasTag(const Akonadi::Tag&)const->bool
            bool cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->hasTag(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::id()const->long long
        long long cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_loadedPayloadParts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::loadedPayloadParts()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->loadedPayloadParts();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::mimeType()const->QString
        QString cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_modificationTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::modificationTime()const->QDateTime
        QDateTime cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->modificationTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_parentCollection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::parentCollection()->Akonadi::Collection&
        Akonadi::Collection & cppResult = cppSelf->parentCollection();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_payloadData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::payloadData()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->payloadData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_payloadPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::payloadPath()const->QString
        QString cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->payloadPath();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_remoteId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::remoteId()const->QString
        QString cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->remoteId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_remoteRevision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::remoteRevision()const->QString
        QString cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->remoteRevision();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_removeAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::removeAttribute(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::removeAttribute(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::removeAttribute(const QByteArray&)
            cppSelf->removeAttribute(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_revision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::revision()const->int
        int cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->revision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_setCachedPayloadParts(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setCachedPayloadParts(const QSet<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // Item::setCachedPayloadParts(const QSet<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCachedPayloadParts", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setCachedPayloadParts(const QSet<QByteArray>&)
            cppSelf->setCachedPayloadParts(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setFlag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setFlag(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::setFlag(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setFlag(const QByteArray&)
            cppSelf->setFlag(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setFlags(const QSet<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // Item::setFlags(const QSet<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setFlags(const QSet<QByteArray>&)
            cppSelf->setFlags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setGid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setGid(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Item::setGid(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGid", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setGid(const QString&)
            cppSelf->setGid(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setId(long long)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 0; // Item::setId(long long)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setId(long long)
            cppSelf->setId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setMimeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setMimeType(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Item::setMimeType(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMimeType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setMimeType(const QString&)
            cppSelf->setMimeType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setModificationTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setModificationTime(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Item::setModificationTime(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModificationTime", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setModificationTime(const QDateTime&)
            cppSelf->setModificationTime(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setParentCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setParentCollection(const Akonadi::Collection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // Item::setParentCollection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParentCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setParentCollection(const Akonadi::Collection&)
            cppSelf->setParentCollection(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setPayloadFromData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setPayloadFromData(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Item::setPayloadFromData(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPayloadFromData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setPayloadFromData(const QByteArray&)
            cppSelf->setPayloadFromData(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setPayloadPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setPayloadPath(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Item::setPayloadPath(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPayloadPath", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setPayloadPath(const QString&)
            cppSelf->setPayloadPath(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setRemoteId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setRemoteId(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Item::setRemoteId(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setRemoteId(const QString&)
            cppSelf->setRemoteId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setRemoteRevision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setRemoteRevision(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Item::setRemoteRevision(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteRevision", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setRemoteRevision(const QString&)
            cppSelf->setRemoteRevision(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setRevision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setRevision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Item::setRevision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRevision", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setRevision(int)
            cppSelf->setRevision(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setSize(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // Item::setSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setSize(qint64)
            cppSelf->setSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setTag(const Akonadi::Tag&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // Item::setTag(const Akonadi::Tag&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTag", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Tag cppArg0_local;
        ::Akonadi::Tag *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setTag(const Akonadi::Tag&)
            cppSelf->setTag(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setTags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setTags(const QList<Akonadi::Tag>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Tag_IDX], (pyArg)))) {
        overloadId = 0; // Item::setTags(const QList<Akonadi::Tag>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QList<Akonadi::Tag> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setTags(const QList<Akonadi::Tag>&)
            cppSelf->setTags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_setVirtualReferences(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Item::setVirtualReferences(const QList<Akonadi::Collection>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Collection_IDX], (pyArg)))) {
        overloadId = 0; // Item::setVirtualReferences(const QList<Akonadi::Collection>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVirtualReferences", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        ::QList<Akonadi::Collection> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::setVirtualReferences(const QList<Akonadi::Collection>&)
            cppSelf->setVirtualReferences(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::size()const->qint64
        qint64 cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_storageCollectionId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::storageCollectionId()const->long long
        long long cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->storageCollectionId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_tags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::tags()const->QList<Akonadi::Tag>
        QList<Akonadi::Tag> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->tags();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Tag_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_url(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    if (PyArg_ParseTuple(args, "|O:url", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Item::url(Akonadi::Item::UrlType=)const->QUrl
    if (numArgs == 0) {
        overloadId = 0; // url(Akonadi::Item::UrlType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_UrlType_IDX]))), (pyArgs[0])))) {
        overloadId = 0; // Item::url(Akonadi::Item::UrlType=)const->QUrl
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "url", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_UrlType_IDX]))), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "url", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]);
            }
        }
        ::Akonadi::Item::UrlType cppArg0(Akonadi::Item::UrlType::UrlShort);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Item::url(Akonadi::Item::UrlType=)const->QUrl
            QUrl cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->url(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFunc_virtualReferences(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Item::virtualReferences()const->QList<Akonadi::Collection>
        QList<Akonadi::Collection> cppResult = const_cast<const ::Akonadi::Item *>(cppSelf)->virtualReferences();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Collection_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_Item__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_Item_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_Item_EnumFlagInfo[] = {
    "CreateOption:IntEnum",
    "UrlType:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_Item_methods[] = {
    {"addAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_addAttribute), METH_O, nullptr},
    {"apply", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_apply), METH_O, nullptr},
    {"attribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_attribute), METH_O, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_attributes), METH_NOARGS, nullptr},
    {"availablePayloadMetaTypeIds", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_availablePayloadMetaTypeIds), METH_NOARGS, nullptr},
    {"availablePayloadParts", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_availablePayloadParts), METH_NOARGS, nullptr},
    {"cachedPayloadParts", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_cachedPayloadParts), METH_NOARGS, nullptr},
    {"clearAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearAttributes), METH_NOARGS, nullptr},
    {"clearFlag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearFlag), METH_O, nullptr},
    {"clearFlags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearFlags), METH_NOARGS, nullptr},
    {"clearPayload", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearPayload), METH_NOARGS, nullptr},
    {"clearTag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearTag), METH_O, nullptr},
    {"clearTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_clearTags), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_flags), METH_NOARGS, nullptr},
    {"fromUrl", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_fromUrl), METH_O|METH_STATIC, nullptr},
    {"gid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_gid), METH_NOARGS, nullptr},
    {"hasAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_hasAttribute), METH_O, nullptr},
    {"hasFlag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_hasFlag), METH_O, nullptr},
    {"hasPayload", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_hasPayload), METH_NOARGS, nullptr},
    {"hasTag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_hasTag), METH_O, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_id), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_isValid), METH_NOARGS, nullptr},
    {"loadedPayloadParts", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_loadedPayloadParts), METH_NOARGS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_mimeType), METH_NOARGS, nullptr},
    {"modificationTime", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_modificationTime), METH_NOARGS, nullptr},
    {"parentCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_parentCollection), METH_NOARGS, nullptr},
    {"payloadData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_payloadData), METH_NOARGS, nullptr},
    {"payloadPath", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_payloadPath), METH_NOARGS, nullptr},
    {"remoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_remoteId), METH_NOARGS, nullptr},
    {"remoteRevision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_remoteRevision), METH_NOARGS, nullptr},
    {"removeAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_removeAttribute), METH_O, nullptr},
    {"revision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_revision), METH_NOARGS, nullptr},
    {"setCachedPayloadParts", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setCachedPayloadParts), METH_O, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setFlag), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setFlags), METH_O, nullptr},
    {"setGid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setGid), METH_O, nullptr},
    {"setId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setId), METH_O, nullptr},
    {"setMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setMimeType), METH_O, nullptr},
    {"setModificationTime", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setModificationTime), METH_O, nullptr},
    {"setParentCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setParentCollection), METH_O, nullptr},
    {"setPayloadFromData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setPayloadFromData), METH_O, nullptr},
    {"setPayloadPath", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setPayloadPath), METH_O, nullptr},
    {"setRemoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setRemoteId), METH_O, nullptr},
    {"setRemoteRevision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setRemoteRevision), METH_O, nullptr},
    {"setRevision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setRevision), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setSize), METH_O, nullptr},
    {"setTag", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setTag), METH_O, nullptr},
    {"setTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setTags), METH_O, nullptr},
    {"setVirtualReferences", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_setVirtualReferences), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_size), METH_NOARGS, nullptr},
    {"storageCollectionId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_storageCollectionId), METH_NOARGS, nullptr},
    {"tags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_tags), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_url), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"virtualReferences", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFunc_virtualReferences), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_Item__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_Akonadi_Item_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
                // Item::operator!=(const Akonadi::Item&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Item cppArg0_local;
                ::Akonadi::Item *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
                // Item::operator<(const Akonadi::Item&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Item cppArg0_local;
                ::Akonadi::Item *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
                // Item::operator==(const Akonadi::Item&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Item cppArg0_local;
                ::Akonadi::Item *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_Akonadi_Item_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(self)));
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_Akonadi_Item_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_Item_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_Item_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_Akonadi_Item_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_Item_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_Item_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Akonadi_Item_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_Item_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_Item_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_Item_spec = {
    "1:AkonadiCore.Akonadi.Item",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_Item_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_Item_CreateOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Item::CreateOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Item::CreateOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Item_CreateOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_CreateOption_IDX])))
        return Enum_PythonToCpp_Akonadi_Item_CreateOption;
    return {};
}

static PyObject *Akonadi_Item_CreateOption_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Item::CreateOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Item::CreateOption *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_Item_UrlType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Item::UrlType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Item::UrlType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Item_UrlType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_UrlType_IDX])))
        return Enum_PythonToCpp_Akonadi_Item_UrlType;
    return {};
}

static PyObject *Akonadi_Item_UrlType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Item::UrlType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Item::UrlType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Item_PythonToCpp_Item_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_Item_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Item_PythonToCpp_Item_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_Item_TypeF()))
        return Item_PythonToCpp_Item_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Item_PTR_CppToPython_Item(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_Item_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_Item_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Item_COPY_CppToPython_Item(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::Item *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_Item_TypeF(), new ::Akonadi::Item(*source), true, true);
}

// Python to C++ copy conversion.
static void Item_PythonToCpp_Item_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::Item *>(cppOut) = *reinterpret_cast< ::Akonadi::Item *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Item_PythonToCpp_Item_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_Item_TypeF()))
        return Item_PythonToCpp_Item_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_Item_SignatureStrings[] = {
    "3:AkonadiCore.Akonadi.Item(self)",
    "2:AkonadiCore.Akonadi.Item(self,other:AkonadiCore.Akonadi.Item)",
    "1:AkonadiCore.Akonadi.Item(self,mimeType:QString)",
    "0:AkonadiCore.Akonadi.Item(self,id:long long)",
    "AkonadiCore.Akonadi.Item.addAttribute(self,attribute:AkonadiCore.Akonadi.Attribute)",
    "AkonadiCore.Akonadi.Item.apply(self,other:AkonadiCore.Akonadi.Item)",
    "AkonadiCore.Akonadi.Item.attribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->AkonadiCore.Akonadi.Attribute",
    "AkonadiCore.Akonadi.Item.attributes(self)->QList[AkonadiCore.Akonadi.Attribute]",
    "AkonadiCore.Akonadi.Item.availablePayloadMetaTypeIds(self)->QList[int]",
    "AkonadiCore.Akonadi.Item.availablePayloadParts(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Item.cachedPayloadParts(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Item.clearAttributes(self)",
    "AkonadiCore.Akonadi.Item.clearFlag(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.Item.clearFlags(self)",
    "AkonadiCore.Akonadi.Item.clearPayload(self)",
    "AkonadiCore.Akonadi.Item.clearTag(self,tag:AkonadiCore.Akonadi.Tag)",
    "AkonadiCore.Akonadi.Item.clearTags(self)",
    "AkonadiCore.Akonadi.Item.flags(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Item.fromUrl(url:typing.Union[PySide6.QtCore.QUrl, QString])->AkonadiCore.Akonadi.Item",
    "AkonadiCore.Akonadi.Item.gid(self)->QString",
    "AkonadiCore.Akonadi.Item.hasAttribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "AkonadiCore.Akonadi.Item.hasFlag(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "AkonadiCore.Akonadi.Item.hasPayload(self)->bool",
    "AkonadiCore.Akonadi.Item.hasTag(self,tag:AkonadiCore.Akonadi.Tag)->bool",
    "AkonadiCore.Akonadi.Item.id(self)->long long",
    "AkonadiCore.Akonadi.Item.isValid(self)->bool",
    "AkonadiCore.Akonadi.Item.loadedPayloadParts(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Item.mimeType(self)->QString",
    "AkonadiCore.Akonadi.Item.modificationTime(self)->PySide6.QtCore.QDateTime",
    "AkonadiCore.Akonadi.Item.parentCollection(self)->AkonadiCore.Akonadi.Collection",
    "AkonadiCore.Akonadi.Item.payloadData(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.Item.payloadPath(self)->QString",
    "AkonadiCore.Akonadi.Item.remoteId(self)->QString",
    "AkonadiCore.Akonadi.Item.remoteRevision(self)->QString",
    "AkonadiCore.Akonadi.Item.removeAttribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.Item.revision(self)->int",
    "AkonadiCore.Akonadi.Item.setCachedPayloadParts(self,cachedParts:QSet[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.Item.setFlag(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.Item.setFlags(self,flags:QSet[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.Item.setGid(self,gid:QString)",
    "AkonadiCore.Akonadi.Item.setId(self,identifier:long long)",
    "AkonadiCore.Akonadi.Item.setMimeType(self,mimeType:QString)",
    "AkonadiCore.Akonadi.Item.setModificationTime(self,datetime:PySide6.QtCore.QDateTime)",
    "AkonadiCore.Akonadi.Item.setParentCollection(self,parent:AkonadiCore.Akonadi.Collection)",
    "AkonadiCore.Akonadi.Item.setPayloadFromData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.Item.setPayloadPath(self,filePath:QString)",
    "AkonadiCore.Akonadi.Item.setRemoteId(self,id:QString)",
    "AkonadiCore.Akonadi.Item.setRemoteRevision(self,revision:QString)",
    "AkonadiCore.Akonadi.Item.setRevision(self,revision:int)",
    "AkonadiCore.Akonadi.Item.setSize(self,size:qint64)",
    "AkonadiCore.Akonadi.Item.setTag(self,tag:AkonadiCore.Akonadi.Tag)",
    "AkonadiCore.Akonadi.Item.setTags(self,list:QList[AkonadiCore.Akonadi.Tag])",
    "AkonadiCore.Akonadi.Item.setVirtualReferences(self,collections:QList[AkonadiCore.Akonadi.Collection])",
    "AkonadiCore.Akonadi.Item.size(self)->qint64",
    "AkonadiCore.Akonadi.Item.storageCollectionId(self)->long long",
    "AkonadiCore.Akonadi.Item.tags(self)->QList[AkonadiCore.Akonadi.Tag]",
    "AkonadiCore.Akonadi.Item.url(self,type:AkonadiCore.Akonadi.Item.UrlType=Akonadi.Item.UrlType.UrlShort)->PySide6.QtCore.QUrl",
    "AkonadiCore.Akonadi.Item.virtualReferences(self)->QList[AkonadiCore.Akonadi.Collection]",
    "AkonadiCore.Akonadi.Item.__copy__(self)->typing._Self",
    "AkonadiCore.Akonadi.Item.__ne__(self,other:AkonadiCore.Akonadi.Item)->bool",
    "AkonadiCore.Akonadi.Item.__lt__(self,other:AkonadiCore.Akonadi.Item)->bool",
    "AkonadiCore.Akonadi.Item.__eq__(self,other:AkonadiCore.Akonadi.Item)->bool",
    "AkonadiCore.Akonadi.Item.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_Item_SignatureByteSize = 740;
static constexpr uint8_t Akonadi_Item_SignatureBytes[740] = {
    0x78, 0xda, 0xb5, 0x57, 0x4d, 0x6f, 0xda, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x72, 0x8c, 0x2b, 0x07,
    0xf5, 0x4b, 0x39, 0x58, 0x4a, 0x24, 0x9a, 0x2a, 0x55, 0xa4, 0x46, 0xe2, 0x23, 0xc9, 0x25, 0x8a,
    0xac, 0xc1, 0x1e, 0xf0, 0xaa, 0x6b, 0x2f, 0x59, 0x4f, 0x90, 0xdc, 0x5f, 0xdf, 0x31, 0xd8, 0x18,
    0xa8, 0x77, 0xbd, 0x29, 0xee, 0x05, 0x30, 0xcc, 0x7b, 0x33, 0x3b, 0x33, 0x6f, 0x76, 0xf8, 0x12,
    0x8c, 0x7e, 0xa9, 0x0c, 0x62, 0x71, 0xa3, 0x34, 0x0e, 0xab, 0xcf, 0xc3, 0x3b, 0xc2, 0xf4, 0x3c,
    0x47, 0xb9, 0xf0, 0x06, 0x9f, 0xed, 0x06, 0xbe, 0xa2, 0x04, 0xb5, 0xd1, 0xc6, 0x1b, 0x7c, 0xea,
    0xc0, 0xa7, 0x22, 0xc5, 0x87, 0x62, 0x85, 0xc1, 0x64, 0x46, 0x5a, 0x64, 0x4b, 0x6f, 0xf0, 0xb1,
    0x03, 0x21, 0xe2, 0x40, 0xaa, 0x6c, 0x79, 0x56, 0xbe, 0x78, 0x03, 0x93, 0xed, 0x10, 0xe2, 0x78,
    0x44, 0x4c, 0x39, 0x7f, 0x23, 0xdc, 0x02, 0xa1, 0x7e, 0x6c, 0x75, 0xb0, 0x33, 0xb6, 0x71, 0xae,
    0x56, 0xb2, 0x70, 0x3b, 0xb7, 0x99, 0xe3, 0x30, 0xa8, 0x0c, 0x52, 0x0c, 0xa8, 0x58, 0xf1, 0xd1,
    0x87, 0x8f, 0x99, 0x50, 0xd9, 0xf3, 0xb8, 0x98, 0x89, 0x18, 0x2f, 0x87, 0x13, 0xda, 0x80, 0x27,
    0xdf, 0x0a, 0xc2, 0x91, 0xd6, 0x50, 0xf8, 0x67, 0x51, 0x02, 0xfa, 0xc3, 0x8b, 0x77, 0x71, 0x6d,
    0x3d, 0x80, 0x83, 0xef, 0x7c, 0x5b, 0xdd, 0x8b, 0xeb, 0xc9, 0x4f, 0x91, 0xd3, 0xb3, 0x95, 0xee,
    0xc5, 0xc2, 0xb7, 0x06, 0x21, 0x61, 0x2e, 0x71, 0x0c, 0x85, 0x54, 0x10, 0xdf, 0x23, 0x41, 0x59,
    0xcc, 0xbb, 0xf8, 0xc8, 0x81, 0xc8, 0xe8, 0x1d, 0x34, 0x63, 0xd0, 0xd4, 0x10, 0xcc, 0x90, 0xcc,
    0x39, 0xb1, 0xb0, 0x46, 0x10, 0x25, 0x18, 0xf7, 0x4b, 0x29, 0x11, 0xf4, 0xe8, 0x28, 0x89, 0x1d,
    0xe6, 0xb7, 0x12, 0x96, 0xff, 0x5e, 0x6a, 0x07, 0x72, 0xb7, 0x30, 0xaa, 0x3c, 0x38, 0xd9, 0x3e,
    0xd4, 0x11, 0x13, 0x2c, 0x5b, 0x5b, 0x9c, 0x0d, 0x1c, 0x38, 0x3a, 0x03, 0x5b, 0x34, 0xd1, 0x9f,
    0x50, 0x94, 0x85, 0x56, 0xe9, 0xa3, 0x96, 0xe7, 0x6f, 0x5a, 0xda, 0xb3, 0xcb, 0x46, 0xfe, 0x59,
    0x35, 0x66, 0x4c, 0x22, 0x2a, 0x19, 0xcd, 0xae, 0x96, 0x22, 0x6e, 0xc2, 0xdd, 0xf0, 0x98, 0x6d,
    0x13, 0xc8, 0x47, 0x7d, 0x48, 0x7d, 0xae, 0x94, 0xb4, 0x7a, 0x39, 0xad, 0xc1, 0x1c, 0x1c, 0x1c,
    0xb4, 0x8e, 0x83, 0xbd, 0x53, 0xfb, 0x74, 0xf1, 0x34, 0x99, 0xde, 0x0d, 0x7b, 0x8b, 0x71, 0xfe,
    0x04, 0x52, 0x38, 0x46, 0x58, 0x9e, 0xa5, 0xe7, 0xb9, 0x50, 0x5f, 0x62, 0xce, 0xcd, 0x91, 0xaa,
    0x58, 0x2c, 0x44, 0x04, 0xc4, 0x45, 0x7a, 0x60, 0x70, 0x0d, 0x3c, 0x76, 0xfe, 0x1d, 0x08, 0xcb,
    0xdf, 0xcd, 0x4c, 0x2b, 0xd0, 0x98, 0xb1, 0xb5, 0x94, 0x18, 0x95, 0x6c, 0x35, 0x53, 0x1b, 0xa0,
    0xb1, 0xb2, 0xf1, 0x6d, 0xf2, 0xc2, 0x8e, 0xc1, 0x14, 0xd4, 0x2e, 0x23, 0x9d, 0x2c, 0x63, 0xa0,
    0xc4, 0x39, 0x27, 0x1a, 0x53, 0x45, 0x7c, 0x75, 0xbc, 0x13, 0x30, 0xc5, 0xb5, 0xc8, 0xf7, 0x0e,
    0xee, 0x04, 0x5b, 0x63, 0x0f, 0xda, 0xb4, 0xb9, 0x38, 0x8c, 0x89, 0xaf, 0x3f, 0xb3, 0x71, 0x8e,
    0x74, 0xd3, 0x7e, 0x55, 0xf9, 0xf5, 0x15, 0xc6, 0x5f, 0x04, 0x1d, 0xcd, 0xe9, 0x59, 0x1d, 0xfc,
    0xaf, 0x4b, 0xa8, 0xa2, 0xae, 0xc2, 0xdd, 0xcc, 0xf3, 0xd3, 0x02, 0xfd, 0x51, 0xa9, 0xd8, 0xe7,
    0x51, 0xdb, 0xac, 0x84, 0x36, 0x44, 0xd5, 0x30, 0xbc, 0x16, 0xb2, 0x0e, 0x58, 0x54, 0xbc, 0x95,
    0xb9, 0xac, 0x87, 0x8c, 0xbc, 0xdf, 0x57, 0x6d, 0xcb, 0x22, 0x6a, 0xc5, 0xb6, 0x09, 0xd8, 0x8f,
    0x59, 0xae, 0xc4, 0x4f, 0x81, 0x49, 0xc7, 0x76, 0xd2, 0x71, 0x9b, 0x96, 0xfd, 0xad, 0xc2, 0x03,
    0xbb, 0xa0, 0xbb, 0x88, 0x37, 0x9d, 0x75, 0xcb, 0x37, 0xe5, 0x4e, 0xd8, 0x65, 0xb0, 0xd0, 0x6b,
    0x27, 0x8c, 0x8f, 0x44, 0xef, 0x2f, 0x44, 0xb9, 0xd2, 0x51, 0xe2, 0x96, 0xd2, 0xe9, 0xbe, 0xfe,
    0x7d, 0xd7, 0xf2, 0x4f, 0xff, 0x1e, 0x02, 0x7e, 0x2d, 0x3f, 0x57, 0x86, 0x56, 0x2c, 0x6b, 0xd6,
    0x8e, 0x9b, 0x89, 0xdf, 0x55, 0xd9, 0x73, 0xfe, 0x14, 0xbc, 0x32, 0xe0, 0xf2, 0xab, 0x1d, 0x72,
    0xe2, 0x62, 0xb5, 0x65, 0xa8, 0xc4, 0x26, 0x79, 0xaf, 0x0e, 0xcc, 0xeb, 0x3b, 0x1b, 0x76, 0x94,
    0xeb, 0x49, 0x68, 0x7a, 0x03, 0x39, 0xc5, 0x05, 0x72, 0x83, 0x45, 0x58, 0xcf, 0x9c, 0x5d, 0x4f,
    0xe5, 0x16, 0xfa, 0xa6, 0xf3, 0xac, 0x5e, 0xea, 0x14, 0xf1, 0x0c, 0xdc, 0xe6, 0xc7, 0x62, 0x4b,
    0x4a, 0xc3, 0x12, 0x1b, 0xe2, 0xbb, 0xf7, 0x6c, 0x00, 0xb4, 0xbf, 0x49, 0x5a, 0x93, 0x62, 0xe6,
    0xe0, 0x05, 0xb2, 0xaa, 0x4e, 0x39, 0x06, 0x8c, 0x66, 0xbc, 0x46, 0x96, 0x73, 0xe2, 0xaa, 0xed,
    0xcb, 0xf2, 0x7d, 0x96, 0x28, 0x4d, 0x2d, 0xd7, 0x26, 0xff, 0x64, 0xf6, 0xbd, 0x6e, 0x2d, 0x86,
    0xf5, 0x30, 0x7b, 0x25, 0x30, 0xf3, 0x86, 0x61, 0xa4, 0x56, 0x45, 0x18, 0xd6, 0x74, 0x95, 0xde,
    0xc3, 0x19, 0x3f, 0xda, 0x50, 0x19, 0x56, 0x98, 0xae, 0x3f, 0xba, 0x5d, 0xdb, 0x56, 0x18, 0x4a,
    0xea, 0x8d, 0x0a, 0x5f, 0x7b, 0xa3, 0xe2, 0x3d, 0x35, 0x69, 0xd2, 0x52, 0x5e, 0xd0, 0x7f, 0x00,
    0x04, 0x32, 0x29, 0x7d
};
#endif

PyTypeObject *init_Akonadi_Item(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_Item_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Item",
        "Akonadi::Item",
        &Sbk_Akonadi_Item_spec,
        &Shiboken::callCppDestructor< ::Akonadi::Item >,
        Sbk_Akonadi_Item_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_Item_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_Item_SignatureBytes, Akonadi_Item_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_Item_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Item_PythonToCpp_Item_PTR,
        is_Item_PythonToCpp_Item_PTR_Convertible,
        Item_PTR_CppToPython_Item,
        Item_COPY_CppToPython_Item);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Item");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Item*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Item&");
    Shiboken::Conversions::registerConverterAlias(converter, "Item");
    Shiboken::Conversions::registerConverterAlias(converter, "Item*");
    Shiboken::Conversions::registerConverterAlias(converter, "Item&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::Item).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Item_PythonToCpp_Item_COPY,
        is_Item_PythonToCpp_Item_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_Item_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'CreateOption'.
    const char *CreateOption_Initializer[] = {
        "AddIfMissing",
        "DontCreate",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CreateOption_InitializerValues[] = {
        uint8_t(Akonadi::Item::CreateOption::AddIfMissing), //  0x00  0
        uint8_t(Akonadi::Item::CreateOption::DontCreate)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Item.CreateOption",
        CreateOption_Initializer, CreateOption_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_CreateOption_IDX].type = EType;
    // Register converter for enum 'Akonadi::Item::CreateOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Item_CreateOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Item_CreateOption,
            is_Enum_PythonToCpp_Akonadi_Item_CreateOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Item::CreateOption");
        Shiboken::Conversions::registerConverterAlias(converter, "Item::CreateOption");
        Shiboken::Conversions::registerConverterAlias(converter, "CreateOption");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CreateOption' enum.

    // Initialization of enum 'UrlType'.
    const char *UrlType_Initializer[] = {
        "UrlShort",
        "UrlWithMimeType",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UrlType_InitializerValues[] = {
        uint8_t(Akonadi::Item::UrlType::UrlShort),       //  0x00  0
        uint8_t(Akonadi::Item::UrlType::UrlWithMimeType) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Item.UrlType",
        UrlType_Initializer, UrlType_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_UrlType_IDX].type = EType;
    // Register converter for enum 'Akonadi::Item::UrlType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Item_UrlType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Item_UrlType,
            is_Enum_PythonToCpp_Akonadi_Item_UrlType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Item::UrlType");
        Shiboken::Conversions::registerConverterAlias(converter, "Item::UrlType");
        Shiboken::Conversions::registerConverterAlias(converter, "UrlType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UrlType' enum.

    qRegisterMetaType< ::Akonadi::Item >("Item");
    qRegisterMetaType< ::Akonadi::Item >("Akonadi::Item");
    qRegisterMetaType< ::Akonadi::Item::CreateOption >("Item::CreateOption");
    qRegisterMetaType< ::Akonadi::Item::CreateOption >("Akonadi::Item::CreateOption");
    qRegisterMetaType< ::Akonadi::Item::UrlType >("Item::UrlType");
    qRegisterMetaType< ::Akonadi::Item::UrlType >("Akonadi::Item::UrlType");

    return pyType;
}

PyTypeObject *init_Akonadi_ItemStaticFields(PyObject *module)
{
    auto *obContainerType = PyObject_GetAttrString(module, "Akonadi");
    auto *obType = PyObject_GetAttrString(obContainerType, "Item");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "FullPayload",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), Akonadi::Item::FullPayload));
    return type;
}
