/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.Transport.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "transportadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__TransportAdaptor
 */

Akonadi__TransportAdaptor::Akonadi__TransportAdaptor(Akonadi::TransportResourceBasePrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__TransportAdaptor::~Akonadi__TransportAdaptor()
{
    // destructor
}

void Akonadi__TransportAdaptor::send(qlonglong itemId)
{
    // handle method call org.freedesktop.Akonadi.Resource.Transport.send
    parent()->send(itemId);
}


#include "moc_transportadaptor.cpp"
