/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.TracerNotification.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TRACERNOTIFICATIONADAPTOR_H
#define TRACERNOTIFICATIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbustracer.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.TracerNotification
 */
class TracerNotificationAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.TracerNotification")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.TracerNotification\">\n"
"    <signal name=\"connectionStarted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"connectionEnded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"connectionDataInput\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"connectionDataOutput\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"identifier\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"signalEmitted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"signalName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"warningEmitted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"componentName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"    <signal name=\"errorEmitted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"componentName\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    TracerNotificationAdaptor(Akonadi::Server::DBusTracer *parent);
    ~TracerNotificationAdaptor() override;

    inline Akonadi::Server::DBusTracer *parent() const
    { return static_cast<Akonadi::Server::DBusTracer *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void connectionDataInput(const QString &identifier, const QString &msg);
    void connectionDataOutput(const QString &identifier, const QString &msg);
    void connectionEnded(const QString &identifier, const QString &msg);
    void connectionStarted(const QString &identifier, const QString &msg);
    void errorEmitted(const QString &componentName, const QString &msg);
    void signalEmitted(const QString &signalName, const QString &msg);
    void warningEmitted(const QString &componentName, const QString &msg);
};

#endif
