
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collection_wrapper.h"

// Argument includes
#include <QList>
#include <QSet>
#include <QString>
#include <QStringList>
#include <attribute.h>
#include <cachepolicy.h>
#include <collection.h>
#include <collectionstatistics.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_Collection_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_Collection_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::Collection >()))
        return -1;

    ::Akonadi::Collection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Collection", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Collection::Collection()
    // 1: Collection::Collection(const Akonadi::Collection&)
    // 2: Collection::Collection(long long)
    if (numArgs == 0) {
        overloadId = 0; // Collection()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArgs[0])))) {
        overloadId = 2; // Collection::Collection(long long)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Collection::Collection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Collection()
        {

            // Collection::Collection()
            cptr = new ::Akonadi::Collection();
            break;
        }
        case 1: // Collection(const Akonadi::Collection &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::Collection cppArg0_local;
            ::Akonadi::Collection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Collection::Collection(const Akonadi::Collection&)
                cptr = new ::Akonadi::Collection(*cppArg0);
            }
            break;
        }
        case 2: // Collection(long long id)
        {
            long long cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Collection::Collection(long long)
                cptr = new ::Akonadi::Collection(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::Collection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_CollectionFunc_addAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::addAttribute(Akonadi::Attribute*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::addAttribute(Akonadi::Attribute*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Attribute *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::addAttribute(Akonadi::Attribute*)
            cppSelf->addAttribute(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_attribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::attribute(const QByteArray&)->Akonadi::Attribute*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::attribute(const QByteArray&)->Akonadi::Attribute*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::attribute(const QByteArray&)->Akonadi::Attribute*
            Akonadi::Attribute * cppResult = cppSelf->attribute(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::attributes()const->QList<Akonadi::Attribute*>
        QList<Akonadi::Attribute*> cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_AttributePTR_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_cachePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::cachePolicy()const->Akonadi::CachePolicy
        Akonadi::CachePolicy cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->cachePolicy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CachePolicy_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_clearAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::clearAttributes()
        cppSelf->clearAttributes();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_contentMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::contentMimeTypes()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->contentMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_displayName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::displayName()const->QString
        QString cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->displayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_enabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::enabled()const->bool
        bool cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->enabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_fromUrl([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static Collection::fromUrl(const QUrl&)->Akonadi::Collection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // static Collection::fromUrl(const QUrl&)->Akonadi::Collection
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromUrl", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static Collection::fromUrl(const QUrl&)->Akonadi::Collection
            Akonadi::Collection cppResult = ::Akonadi::Collection::fromUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_hasAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::hasAttribute(const QByteArray&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::hasAttribute(const QByteArray&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::hasAttribute(const QByteArray&)const->bool
            bool cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->hasAttribute(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::id()const->long long
        long long cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_isVirtual(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::isVirtual()const->bool
        bool cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->isVirtual();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_keepLocalChanges(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::keepLocalChanges()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->keepLocalChanges();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_localListPreference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::localListPreference(Akonadi::Collection::ListPurpose)const->Akonadi::Collection::ListPreference
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX]))), (pyArg)))) {
        overloadId = 0; // Collection::localListPreference(Akonadi::Collection::ListPurpose)const->Akonadi::Collection::ListPreference
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "localListPreference", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::Akonadi::Collection::ListPurpose cppArg0{Akonadi::Collection::ListSync};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::localListPreference(Akonadi::Collection::ListPurpose)const->Akonadi::Collection::ListPreference
            Akonadi::Collection::ListPreference cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->localListPreference(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPreference_IDX]))), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_mimeType([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Collection::mimeType()->QString
        QString cppResult = ::Akonadi::Collection::mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::name()const->QString
        QString cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_parentCollection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::parentCollection()->Akonadi::Collection&
        Akonadi::Collection & cppResult = cppSelf->parentCollection();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_remoteId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::remoteId()const->QString
        QString cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->remoteId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_remoteRevision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::remoteRevision()const->QString
        QString cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->remoteRevision();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_removeAttribute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::removeAttribute(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::removeAttribute(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::removeAttribute(const QByteArray&)
            cppSelf->removeAttribute(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_resource(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::resource()const->QString
        QString cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->resource();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_rights(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::rights()const->QFlags<Akonadi::Collection::Right>
        QFlags<Akonadi::Collection::Right> cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->rights();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_Collection_Right_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_root([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Collection::root()->Akonadi::Collection
        Akonadi::Collection cppResult = ::Akonadi::Collection::root();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_setCachePolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setCachePolicy(const Akonadi::CachePolicy&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CachePolicy_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::setCachePolicy(const Akonadi::CachePolicy&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCachePolicy", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::CachePolicy cppArg0_local;
        ::Akonadi::CachePolicy *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setCachePolicy(const Akonadi::CachePolicy&)
            cppSelf->setCachePolicy(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setContentMimeTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setContentMimeTypes(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setContentMimeTypes(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentMimeTypes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setContentMimeTypes(const QStringList&)
            cppSelf->setContentMimeTypes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Collection::setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEnabled", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setEnabled(bool)
            cppSelf->setEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setId(long long)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 0; // Collection::setId(long long)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setId(long long)
            cppSelf->setId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setKeepLocalChanges(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setKeepLocalChanges(const QSet<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setKeepLocalChanges(const QSet<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeepLocalChanges", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setKeepLocalChanges(const QSet<QByteArray>&)
            cppSelf->setKeepLocalChanges(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setLocalListPreference(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLocalListPreference", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Collection::setLocalListPreference(Akonadi::Collection::ListPurpose,Akonadi::Collection::ListPreference)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPreference_IDX]))), (pyArgs[1])))) {
        overloadId = 0; // Collection::setLocalListPreference(Akonadi::Collection::ListPurpose,Akonadi::Collection::ListPreference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLocalListPreference", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::Akonadi::Collection::ListPurpose cppArg0{Akonadi::Collection::ListSync};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Akonadi::Collection::ListPreference cppArg1{Akonadi::Collection::ListEnabled};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setLocalListPreference(Akonadi::Collection::ListPurpose,Akonadi::Collection::ListPreference)
            cppSelf->setLocalListPreference(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setName(const QString&)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setParentCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setParentCollection(const Akonadi::Collection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::setParentCollection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParentCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setParentCollection(const Akonadi::Collection&)
            cppSelf->setParentCollection(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setRemoteId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setRemoteId(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setRemoteId(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setRemoteId(const QString&)
            cppSelf->setRemoteId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setRemoteRevision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setRemoteRevision(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setRemoteRevision(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRemoteRevision", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setRemoteRevision(const QString&)
            cppSelf->setRemoteRevision(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setResource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setResource(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Collection::setResource(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResource", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setResource(const QString&)
            cppSelf->setResource(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setRights(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setRights(QFlags<Akonadi::Collection::Right>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_Collection_Right_IDX]))), (pyArg)))) {
        overloadId = 0; // Collection::setRights(QFlags<Akonadi::Collection::Right>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRights", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::QFlags<Akonadi::Collection::Right> cppArg0 = QFlags<Akonadi::Collection::Right>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setRights(QFlags<Akonadi::Collection::Right>)
            cppSelf->setRights(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setShouldList(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setShouldList", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Collection::setShouldList(Akonadi::Collection::ListPurpose,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // Collection::setShouldList(Akonadi::Collection::ListPurpose,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setShouldList", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::Akonadi::Collection::ListPurpose cppArg0{Akonadi::Collection::ListSync};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setShouldList(Akonadi::Collection::ListPurpose,bool)
            cppSelf->setShouldList(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setStatistics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setStatistics(const Akonadi::CollectionStatistics&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), (pyArg)))) {
        overloadId = 0; // Collection::setStatistics(const Akonadi::CollectionStatistics&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatistics", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::CollectionStatistics cppArg0_local;
        ::Akonadi::CollectionStatistics *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setStatistics(const Akonadi::CollectionStatistics&)
            cppSelf->setStatistics(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_setVirtual(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::setVirtual(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Collection::setVirtual(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVirtual", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::setVirtual(bool)
            cppSelf->setVirtual(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFunc_shouldList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Collection::shouldList(Akonadi::Collection::ListPurpose)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX]))), (pyArg)))) {
        overloadId = 0; // Collection::shouldList(Akonadi::Collection::ListPurpose)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "shouldList", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        ::Akonadi::Collection::ListPurpose cppArg0{Akonadi::Collection::ListSync};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::shouldList(Akonadi::Collection::ListPurpose)const->bool
            bool cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->shouldList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_statistics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Collection::statistics()const->Akonadi::CollectionStatistics
        Akonadi::CollectionStatistics cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->statistics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_url(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    if (PyArg_ParseTuple(args, "|O:url", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Collection::url(Akonadi::Collection::UrlType=)const->QUrl
    if (numArgs == 0) {
        overloadId = 0; // url(Akonadi::Collection::UrlType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_UrlType_IDX]))), (pyArgs[0])))) {
        overloadId = 0; // Collection::url(Akonadi::Collection::UrlType=)const->QUrl
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "url", SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"type", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_UrlType_IDX]))), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "url", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]);
            }
        }
        ::Akonadi::Collection::UrlType cppArg0(Akonadi::Collection::UrlType::UrlShort);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Collection::url(Akonadi::Collection::UrlType=)const->QUrl
            QUrl cppResult = const_cast<const ::Akonadi::Collection *>(cppSelf)->url(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFunc_virtualMimeType([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Collection::virtualMimeType()->QString
        QString cppResult = ::Akonadi::Collection::virtualMimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_Collection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_Collection_PropertyStrings[] = {
    "cachePolicy:",
    "contentMimeTypes::",
    "displayName:",
    "enabled::",
    "id::",
    "isValid:",
    "isVirtual::setVirtual",
    "name::",
    "remoteIdd:remoteId:setRemoteId",
    "remoteRevision::",
    "resource::",
    "rights::",
    "statistics:",
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_Collection_EnumFlagInfo[] = {
    "CreateOption:IntEnum",
    "ListPreference:IntEnum",
    "ListPurpose:IntEnum",
    "Right:IntFlag:Rights",
    "UrlType:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_Collection_methods[] = {
    {"addAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_addAttribute), METH_O, nullptr},
    {"attribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_attribute), METH_O, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_attributes), METH_NOARGS, nullptr},
    {"cachePolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_cachePolicy), METH_NOARGS, nullptr},
    {"clearAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_clearAttributes), METH_NOARGS, nullptr},
    {"contentMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_contentMimeTypes), METH_NOARGS, nullptr},
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_displayName), METH_NOARGS, nullptr},
    {"enabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_enabled), METH_NOARGS, nullptr},
    {"fromUrl", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_fromUrl), METH_O|METH_STATIC, nullptr},
    {"hasAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_hasAttribute), METH_O, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_id), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_isValid), METH_NOARGS, nullptr},
    {"isVirtual", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_isVirtual), METH_NOARGS, nullptr},
    {"keepLocalChanges", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_keepLocalChanges), METH_NOARGS, nullptr},
    {"localListPreference", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_localListPreference), METH_O, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_mimeType), METH_NOARGS|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_name), METH_NOARGS, nullptr},
    {"parentCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_parentCollection), METH_NOARGS, nullptr},
    {"remoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_remoteId), METH_NOARGS, nullptr},
    {"remoteRevision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_remoteRevision), METH_NOARGS, nullptr},
    {"removeAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_removeAttribute), METH_O, nullptr},
    {"resource", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_resource), METH_NOARGS, nullptr},
    {"rights", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_rights), METH_NOARGS, nullptr},
    {"root", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_root), METH_NOARGS|METH_STATIC, nullptr},
    {"setCachePolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setCachePolicy), METH_O, nullptr},
    {"setContentMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setContentMimeTypes), METH_O, nullptr},
    {"setEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setEnabled), METH_O, nullptr},
    {"setId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setId), METH_O, nullptr},
    {"setKeepLocalChanges", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setKeepLocalChanges), METH_O, nullptr},
    {"setLocalListPreference", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setLocalListPreference), METH_VARARGS, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setName), METH_O, nullptr},
    {"setParentCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setParentCollection), METH_O, nullptr},
    {"setRemoteId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setRemoteId), METH_O, nullptr},
    {"setRemoteRevision", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setRemoteRevision), METH_O, nullptr},
    {"setResource", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setResource), METH_O, nullptr},
    {"setRights", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setRights), METH_O, nullptr},
    {"setShouldList", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setShouldList), METH_VARARGS, nullptr},
    {"setStatistics", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setStatistics), METH_O, nullptr},
    {"setVirtual", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_setVirtual), METH_O, nullptr},
    {"shouldList", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_shouldList), METH_O, nullptr},
    {"statistics", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_statistics), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_url), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"virtualMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFunc_virtualMimeType), METH_NOARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_Collection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_Akonadi_Collection_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
                // Collection::operator!=(const Akonadi::Collection&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Collection cppArg0_local;
                ::Akonadi::Collection *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
                // Collection::operator<(const Akonadi::Collection&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Collection cppArg0_local;
                ::Akonadi::Collection *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
                // Collection::operator==(const Akonadi::Collection&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::Collection cppArg0_local;
                ::Akonadi::Collection *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Akonadi_Collection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_Collection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_Akonadi_Collection__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(self)));
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C


// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_Collection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_Akonadi_Collection__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_Collection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_Collection_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Akonadi_Collection_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_Collection_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_Collection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_Collection_spec = {
    "1:AkonadiCore.Akonadi.Collection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_Collection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_Collection_Right(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Collection::Right>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Collection::Right *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Collection_Right_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_Right_IDX])))
        return Enum_PythonToCpp_Akonadi_Collection_Right;
    return {};
}

static PyObject *Akonadi_Collection_Right_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Collection::Right>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Collection::Right *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Flag_PythonToCpp_Akonadi_Collection_Right(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::Akonadi::Collection::Right>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::Akonadi::Collection::Right> *>(cppOut) = value;

}

static PyObject *Akonadi_Collection_Right_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::Akonadi::Collection::Right> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_Right_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_Akonadi_Collection_CreateOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Collection::CreateOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Collection::CreateOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Collection_CreateOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_CreateOption_IDX])))
        return Enum_PythonToCpp_Akonadi_Collection_CreateOption;
    return {};
}

static PyObject *Akonadi_Collection_CreateOption_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Collection::CreateOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Collection::CreateOption *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_Collection_UrlType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Collection::UrlType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Collection::UrlType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Collection_UrlType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_UrlType_IDX])))
        return Enum_PythonToCpp_Akonadi_Collection_UrlType;
    return {};
}

static PyObject *Akonadi_Collection_UrlType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Collection::UrlType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Collection::UrlType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_Collection_ListPreference(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Collection::ListPreference>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Collection::ListPreference *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Collection_ListPreference_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPreference_IDX])))
        return Enum_PythonToCpp_Akonadi_Collection_ListPreference;
    return {};
}

static PyObject *Akonadi_Collection_ListPreference_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Collection::ListPreference>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Collection::ListPreference *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_Collection_ListPurpose(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::Collection::ListPurpose>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::Collection::ListPurpose *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_Collection_ListPurpose_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX])))
        return Enum_PythonToCpp_Akonadi_Collection_ListPurpose;
    return {};
}

static PyObject *Akonadi_Collection_ListPurpose_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::Collection::ListPurpose>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::Collection::ListPurpose *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Collection_PythonToCpp_Collection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_Collection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Collection_PythonToCpp_Collection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_Collection_TypeF()))
        return Collection_PythonToCpp_Collection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Collection_PTR_CppToPython_Collection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_Collection_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_Collection_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Collection_COPY_CppToPython_Collection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::Collection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_Collection_TypeF(), new ::Akonadi::Collection(*source), true, true);
}

// Python to C++ copy conversion.
static void Collection_PythonToCpp_Collection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::Collection *>(cppOut) = *reinterpret_cast< ::Akonadi::Collection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Collection_PythonToCpp_Collection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_Collection_TypeF()))
        return Collection_PythonToCpp_Collection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_Collection_SignatureStrings[] = {
    "2:AkonadiCore.Akonadi.Collection(self,*:KeywordOnly=None,id:long long=None,remoteIdd:QString=None,isValid:bool=None,remoteRevision:QString=None,enabled:bool=None,isVirtual:bool=None,name:QString=None,displayName:QString=None,rights:AkonadiCore.Akonadi.Collection.Right=None,contentMimeTypes:QStringList=None,resource:QString=None,statistics:Akonadi.CollectionStatistics=None,cachePolicy:Akonadi.CachePolicy=None)",
    "1:AkonadiCore.Akonadi.Collection(self,other:AkonadiCore.Akonadi.Collection,*:KeywordOnly=None,id:long long=None,remoteIdd:QString=None,isValid:bool=None,remoteRevision:QString=None,enabled:bool=None,isVirtual:bool=None,name:QString=None,displayName:QString=None,rights:AkonadiCore.Akonadi.Collection.Right=None,contentMimeTypes:QStringList=None,resource:QString=None,statistics:Akonadi.CollectionStatistics=None,cachePolicy:Akonadi.CachePolicy=None)",
    "0:AkonadiCore.Akonadi.Collection(self,id:long long,*:KeywordOnly=None,id:long long=None,remoteIdd:QString=None,isValid:bool=None,remoteRevision:QString=None,enabled:bool=None,isVirtual:bool=None,name:QString=None,displayName:QString=None,rights:AkonadiCore.Akonadi.Collection.Right=None,contentMimeTypes:QStringList=None,resource:QString=None,statistics:Akonadi.CollectionStatistics=None,cachePolicy:Akonadi.CachePolicy=None)",
    "AkonadiCore.Akonadi.Collection.addAttribute(self,attribute:AkonadiCore.Akonadi.Attribute)",
    "AkonadiCore.Akonadi.Collection.attribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->AkonadiCore.Akonadi.Attribute",
    "AkonadiCore.Akonadi.Collection.attributes(self)->QList[AkonadiCore.Akonadi.Attribute]",
    "AkonadiCore.Akonadi.Collection.cachePolicy(self)->AkonadiCore.Akonadi.CachePolicy",
    "AkonadiCore.Akonadi.Collection.clearAttributes(self)",
    "AkonadiCore.Akonadi.Collection.contentMimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.Collection.displayName(self)->QString",
    "AkonadiCore.Akonadi.Collection.enabled(self)->bool",
    "AkonadiCore.Akonadi.Collection.fromUrl(url:typing.Union[PySide6.QtCore.QUrl, QString])->AkonadiCore.Akonadi.Collection",
    "AkonadiCore.Akonadi.Collection.hasAttribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "AkonadiCore.Akonadi.Collection.id(self)->long long",
    "AkonadiCore.Akonadi.Collection.isValid(self)->bool",
    "AkonadiCore.Akonadi.Collection.isVirtual(self)->bool",
    "AkonadiCore.Akonadi.Collection.keepLocalChanges(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.Collection.localListPreference(self,purpose:AkonadiCore.Akonadi.Collection.ListPurpose)->AkonadiCore.Akonadi.Collection.ListPreference",
    "AkonadiCore.Akonadi.Collection.mimeType()->QString",
    "AkonadiCore.Akonadi.Collection.name(self)->QString",
    "AkonadiCore.Akonadi.Collection.parentCollection(self)->AkonadiCore.Akonadi.Collection",
    "AkonadiCore.Akonadi.Collection.remoteId(self)->QString",
    "AkonadiCore.Akonadi.Collection.remoteRevision(self)->QString",
    "AkonadiCore.Akonadi.Collection.removeAttribute(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.Collection.resource(self)->QString",
    "AkonadiCore.Akonadi.Collection.rights(self)->AkonadiCore.Akonadi.Collection.Right",
    "AkonadiCore.Akonadi.Collection.root()->AkonadiCore.Akonadi.Collection",
    "AkonadiCore.Akonadi.Collection.setCachePolicy(self,policy:AkonadiCore.Akonadi.CachePolicy)",
    "AkonadiCore.Akonadi.Collection.setContentMimeTypes(self,types:QStringList)",
    "AkonadiCore.Akonadi.Collection.setEnabled(self,enabled:bool)",
    "AkonadiCore.Akonadi.Collection.setId(self,identifier:long long)",
    "AkonadiCore.Akonadi.Collection.setKeepLocalChanges(self,parts:QSet[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.Collection.setLocalListPreference(self,purpose:AkonadiCore.Akonadi.Collection.ListPurpose,preference:AkonadiCore.Akonadi.Collection.ListPreference)",
    "AkonadiCore.Akonadi.Collection.setName(self,name:QString)",
    "AkonadiCore.Akonadi.Collection.setParentCollection(self,parent:AkonadiCore.Akonadi.Collection)",
    "AkonadiCore.Akonadi.Collection.setRemoteId(self,id:QString)",
    "AkonadiCore.Akonadi.Collection.setRemoteRevision(self,revision:QString)",
    "AkonadiCore.Akonadi.Collection.setResource(self,identifier:QString)",
    "AkonadiCore.Akonadi.Collection.setRights(self,rights:AkonadiCore.Akonadi.Collection.Right)",
    "AkonadiCore.Akonadi.Collection.setShouldList(self,purpose:AkonadiCore.Akonadi.Collection.ListPurpose,shouldList:bool)",
    "AkonadiCore.Akonadi.Collection.setStatistics(self,statistics:AkonadiCore.Akonadi.CollectionStatistics)",
    "AkonadiCore.Akonadi.Collection.setVirtual(self,isVirtual:bool)",
    "AkonadiCore.Akonadi.Collection.shouldList(self,purpose:AkonadiCore.Akonadi.Collection.ListPurpose)->bool",
    "AkonadiCore.Akonadi.Collection.statistics(self)->AkonadiCore.Akonadi.CollectionStatistics",
    "AkonadiCore.Akonadi.Collection.url(self,type:AkonadiCore.Akonadi.Collection.UrlType=Akonadi.Collection.UrlType.UrlShort)->PySide6.QtCore.QUrl",
    "AkonadiCore.Akonadi.Collection.virtualMimeType()->QString",
    "AkonadiCore.Akonadi.Collection.__copy__(self)->typing._Self",
    "AkonadiCore.Akonadi.Collection.__ne__(self,other:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.Collection.__lt__(self,other:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.Collection.__eq__(self,other:AkonadiCore.Akonadi.Collection)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_Collection_SignatureByteSize = 764;
static constexpr uint8_t Akonadi_Collection_SignatureBytes[764] = {
    0x78, 0xda, 0xed, 0x58, 0x4b, 0x6f, 0xdb, 0x30, 0x0c, 0xbe, 0xef, 0x57, 0xe4, 0x98, 0x14, 0x5e,
    0xb0, 0xed, 0xb0, 0x43, 0x80, 0x0e, 0xc8, 0x82, 0x1d, 0x86, 0xa6, 0x5d, 0x1e, 0x6b, 0x2f, 0x45,
    0x61, 0x28, 0x36, 0x13, 0x0b, 0x55, 0x24, 0x4f, 0x52, 0x32, 0xf8, 0xdf, 0x4f, 0x8e, 0x5f, 0xb2,
    0xf3, 0xa0, 0x9c, 0x64, 0xe8, 0xa5, 0x97, 0xb6, 0xb1, 0xf9, 0x7d, 0xa4, 0x48, 0xea, 0x23, 0xd3,
    0x2f, 0x83, 0xe1, 0xab, 0xe0, 0x24, 0xa4, 0x23, 0x21, 0xa1, 0x9f, 0xff, 0xdd, 0x1f, 0x09, 0xc6,
    0x20, 0xd0, 0x54, 0xf0, 0xae, 0x02, 0xb6, 0xf4, 0x6e, 0x06, 0x77, 0x90, 0xfc, 0x15, 0x32, 0xfc,
    0xc5, 0x59, 0x72, 0xfb, 0x20, 0x38, 0x78, 0x34, 0x1c, 0x30, 0xc1, 0x57, 0x9d, 0xf4, 0x47, 0xf6,
    0x44, 0xc2, 0x5a, 0x68, 0xf8, 0x19, 0x86, 0x83, 0xe9, 0x5c, 0x4b, 0x5a, 0x3c, 0xa6, 0xea, 0x89,
    0x30, 0x63, 0xbd, 0x10, 0x82, 0xd9, 0x86, 0x33, 0xd8, 0x52, 0x65, 0x3c, 0xd4, 0xad, 0x81, 0x93,
    0x05, 0x03, 0xdb, 0xda, 0xe0, 0xa9, 0xd4, 0x1b, 0xc2, 0xac, 0x67, 0x9c, 0xac, 0xa1, 0x8e, 0x0b,
    0xa9, 0x8a, 0x19, 0x49, 0x1e, 0xf6, 0x5e, 0x48, 0xba, 0x8a, 0xb4, 0x42, 0x4e, 0xd9, 0x9f, 0xa5,
    0x56, 0x19, 0x20, 0x10, 0x5c, 0x03, 0xd7, 0xf7, 0x74, 0x0d, 0xbf, 0x93, 0x18, 0x54, 0x41, 0x37,
    0xa6, 0x4a, 0x17, 0xf1, 0x2b, 0xb1, 0x91, 0x41, 0xc3, 0x91, 0xd2, 0x44, 0x1b, 0x13, 0x1a, 0x94,
    0xce, 0x2c, 0x07, 0xf3, 0xf2, 0x65, 0xee, 0x84, 0x04, 0x11, 0x4c, 0x04, 0xa3, 0x41, 0x52, 0x59,
    0x57, 0xcf, 0x76, 0x46, 0xbd, 0x0f, 0x9f, 0x9d, 0x8a, 0x23, 0x74, 0x04, 0x12, 0xb1, 0x7c, 0xaf,
    0xe0, 0xdb, 0x54, 0xf0, 0x93, 0x53, 0x05, 0xed, 0x4a, 0xbc, 0x57, 0xea, 0x6d, 0x2a, 0x85, 0x04,
    0x4d, 0xc2, 0x70, 0xa8, 0x4d, 0x04, 0x8b, 0x8d, 0x86, 0xac, 0x68, 0xa4, 0xf8, 0x78, 0xf0, 0xbc,
    0xa5, 0x31, 0xce, 0x5c, 0xa7, 0xdd, 0xa5, 0x5b, 0x27, 0xb1, 0x39, 0x6b, 0xff, 0x91, 0x1b, 0x83,
    0xe7, 0x49, 0x32, 0xa7, 0x21, 0x7c, 0xed, 0x4f, 0xf5, 0x8e, 0x62, 0xfa, 0x3d, 0xd1, 0x30, 0x94,
    0x92, 0x24, 0x5e, 0x27, 0x88, 0x88, 0xbc, 0x79, 0xe9, 0x7d, 0xfc, 0x76, 0x32, 0x04, 0xe7, 0x08,
    0xd4, 0x2e, 0x04, 0x43, 0x37, 0x4d, 0x0b, 0xf0, 0x7c, 0x92, 0xf4, 0x05, 0x63, 0xb5, 0xd2, 0x5e,
    0xd0, 0x1e, 0x44, 0x54, 0x66, 0x28, 0x23, 0x03, 0x22, 0x87, 0x8d, 0x60, 0x51, 0x50, 0xa3, 0xc5,
    0xca, 0x23, 0x56, 0x9d, 0x86, 0x51, 0x58, 0xfd, 0xde, 0x40, 0x63, 0xc8, 0xfc, 0x86, 0x15, 0xa8,
    0xf4, 0x52, 0x61, 0x90, 0xa5, 0x14, 0xeb, 0x47, 0xc9, 0xba, 0x1b, 0xc9, 0x4e, 0xb7, 0x81, 0x31,
    0xf2, 0x3a, 0x79, 0x1c, 0xc7, 0x5a, 0xa0, 0xe2, 0xc5, 0xdc, 0x46, 0x44, 0x0d, 0xaf, 0xd1, 0x88,
    0x2e, 0x47, 0xa4, 0x65, 0x42, 0x4a, 0x55, 0x43, 0x21, 0x99, 0xb0, 0xb5, 0x49, 0x64, 0xa9, 0x65,
    0x6d, 0x40, 0xaf, 0x00, 0xf1, 0x58, 0x04, 0x84, 0x8d, 0x22, 0xc2, 0x57, 0x76, 0xb7, 0x80, 0x3e,
    0x7e, 0x7e, 0xf4, 0x2e, 0xb0, 0x94, 0x32, 0x6d, 0xb5, 0x89, 0x84, 0x25, 0x48, 0xe0, 0x41, 0x9e,
    0xe4, 0x78, 0x23, 0x63, 0xa1, 0x00, 0x93, 0xcc, 0x1d, 0x34, 0x33, 0x45, 0x2b, 0xdd, 0xaf, 0xfb,
    0xc1, 0x42, 0x5b, 0xe7, 0x17, 0xa3, 0xeb, 0xde, 0xd5, 0xbc, 0xfd, 0x45, 0x88, 0x89, 0x09, 0x46,
    0x37, 0xe6, 0xde, 0xc5, 0x4d, 0x5b, 0x4c, 0xc1, 0x96, 0xc1, 0xd4, 0x67, 0xe2, 0x19, 0xe0, 0x2d,
    0x5c, 0xe1, 0xae, 0xe0, 0x8e, 0xb2, 0xc9, 0xd7, 0x36, 0xbe, 0xdd, 0x0c, 0x76, 0xcb, 0x6f, 0x36,
    0x8a, 0x51, 0x46, 0x21, 0x74, 0xf7, 0xe2, 0x5a, 0x29, 0xd0, 0xa3, 0xc6, 0x44, 0xf0, 0xe2, 0xda,
    0x50, 0x3e, 0x36, 0x16, 0x7a, 0x2e, 0xd4, 0x87, 0x54, 0xde, 0xd3, 0xcd, 0x9d, 0xc2, 0x85, 0xea,
    0x87, 0xa5, 0xd9, 0xb5, 0x15, 0xc9, 0x05, 0x9c, 0xf7, 0xa2, 0xd9, 0xd8, 0x4c, 0x34, 0x74, 0x49,
    0xcd, 0x62, 0x5e, 0x6a, 0x9c, 0x0b, 0xfe, 0xee, 0x90, 0xfe, 0x78, 0xe6, 0xf6, 0xe8, 0xf4, 0x1c,
    0x27, 0x35, 0xc8, 0x85, 0x7e, 0x7c, 0x3d, 0x1d, 0xf2, 0xe2, 0x92, 0x62, 0xd0, 0x4a, 0x90, 0x5c,
    0xe2, 0x2c, 0x47, 0x6d, 0x6d, 0xfb, 0x74, 0x41, 0x4e, 0x0e, 0x09, 0x8d, 0x97, 0xc9, 0x0f, 0x12,
    0xa7, 0x0b, 0xfd, 0xcc, 0x56, 0x9c, 0x74, 0x2f, 0x6f, 0x11, 0xda, 0x6c, 0x5f, 0x76, 0xcc, 0x7a,
    0x5b, 0x5f, 0xcc, 0xdd, 0x78, 0x2c, 0x61, 0xb0, 0x3b, 0xad, 0x0d, 0x47, 0xa5, 0x12, 0x6d, 0xb6,
    0x76, 0x17, 0xea, 0x79, 0x24, 0x36, 0x2c, 0x4c, 0x6b, 0x7e, 0x76, 0x6b, 0xa9, 0x92, 0xc2, 0xf9,
    0xe2, 0x55, 0x4b, 0x7f, 0xe6, 0x75, 0xff, 0x1b, 0xc2, 0x11, 0x70, 0x05, 0x74, 0x71, 0x63, 0xaf,
    0x14, 0x8d, 0x6f, 0x4b, 0x38, 0xfc, 0xe2, 0xc4, 0x38, 0x2e, 0x31, 0xaa, 0x9e, 0x0b, 0x54, 0xba,
    0xab, 0x14, 0x60, 0xcc, 0x66, 0x29, 0xad, 0x94, 0x15, 0x0b, 0xdc, 0x2c, 0xa8, 0xa9, 0x16, 0xdf,
    0x1e, 0x7f, 0x95, 0xfe, 0x36, 0xed, 0x22, 0xb5, 0x09, 0xf1, 0xc0, 0x7a, 0x8b, 0x45, 0xb3, 0xcd,
    0xb2, 0x7f, 0xdf, 0x7e, 0x83, 0xf1, 0xfd, 0x40, 0xc4, 0x89, 0xef, 0x17, 0xf9, 0xc9, 0x47, 0xb7,
    0x3f, 0x37, 0x1f, 0x71, 0x2c, 0x87, 0x1c, 0xe9, 0xf4, 0xaf, 0x17, 0xc7, 0xa2, 0xf9, 0x3e, 0xd3,
    0xff, 0x85, 0x16, 0xfe, 0x9c, 0x43, 0xfb, 0x0f, 0x36, 0x01, 0x75, 0x33
};
#endif

PyTypeObject *init_Akonadi_Collection(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_Collection_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Collection",
        "Akonadi::Collection",
        &Sbk_Akonadi_Collection_spec,
        &Shiboken::callCppDestructor< ::Akonadi::Collection >,
        Sbk_Akonadi_Collection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_Collection_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_Collection_SignatureBytes, Akonadi_Collection_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_Collection_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Collection_PythonToCpp_Collection_PTR,
        is_Collection_PythonToCpp_Collection_PTR_Convertible,
        Collection_PTR_CppToPython_Collection,
        Collection_COPY_CppToPython_Collection);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection&");
    Shiboken::Conversions::registerConverterAlias(converter, "Collection");
    Shiboken::Conversions::registerConverterAlias(converter, "Collection*");
    Shiboken::Conversions::registerConverterAlias(converter, "Collection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::Collection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Collection_PythonToCpp_Collection_COPY,
        is_Collection_PythonToCpp_Collection_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_Collection_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Right'.
    const char *Right_Initializer[] = {
        "ReadOnly",
        "CanChangeItem",
        "CanCreateItem",
        "CanDeleteItem",
        "CanChangeCollection",
        "CanCreateCollection",
        "CanDeleteCollection",
        "CanLinkItem",
        "CanUnlinkItem",
        "AllRights",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Right_InitializerValues[] = {
        uint8_t(Akonadi::Collection::Right::ReadOnly),            //  0x00  0
        uint8_t(Akonadi::Collection::Right::CanChangeItem),       //  0x01  1
        uint8_t(Akonadi::Collection::Right::CanCreateItem),       //  0x02  2
        uint8_t(Akonadi::Collection::Right::CanDeleteItem),       //  0x04  4
        uint8_t(Akonadi::Collection::Right::CanChangeCollection), //  0x08  8
        uint8_t(Akonadi::Collection::Right::CanCreateCollection), //  0x10  16
        uint8_t(Akonadi::Collection::Right::CanDeleteCollection), //  0x20  32
        uint8_t(Akonadi::Collection::Right::CanLinkItem),         //  0x40  64
        uint8_t(Akonadi::Collection::Right::CanUnlinkItem),       //  0x80  128
        uint8_t(Akonadi::Collection::Right::AllRights)            //  0x3f  63
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Collection.Right",
        Right_Initializer, Right_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_Right_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkAkonadiCoreTypeStructs[SBK_QFlags_Akonadi_Collection_Right_IDX].type =
        EType;
    // Register converter for enum 'Akonadi::Collection::Right'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_Right_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Collection_Right,
            is_Enum_PythonToCpp_Akonadi_Collection_Right_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection::Right");
        Shiboken::Conversions::registerConverterAlias(converter, "Collection::Right");
        Shiboken::Conversions::registerConverterAlias(converter, "Right");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_Right_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_Akonadi_Collection_Right,
            is_Enum_PythonToCpp_Akonadi_Collection_Right_Convertible);
        // Register converter for flag 'QFlags<Akonadi::Collection::Right>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<Akonadi::Collection::Right>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "Akonadi::Collection::Rights");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Right' enum/flags.

    // Initialization of enum 'CreateOption'.
    const char *CreateOption_Initializer[] = {
        "AddIfMissing",
        "DontCreate",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CreateOption_InitializerValues[] = {
        uint8_t(Akonadi::Collection::CreateOption::AddIfMissing), //  0x00  0
        uint8_t(Akonadi::Collection::CreateOption::DontCreate)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Collection.CreateOption",
        CreateOption_Initializer, CreateOption_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_CreateOption_IDX].type = EType;
    // Register converter for enum 'Akonadi::Collection::CreateOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_CreateOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Collection_CreateOption,
            is_Enum_PythonToCpp_Akonadi_Collection_CreateOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection::CreateOption");
        Shiboken::Conversions::registerConverterAlias(converter, "Collection::CreateOption");
        Shiboken::Conversions::registerConverterAlias(converter, "CreateOption");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CreateOption' enum.

    // Initialization of enum 'UrlType'.
    const char *UrlType_Initializer[] = {
        "UrlShort",
        "UrlWithName",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UrlType_InitializerValues[] = {
        uint8_t(Akonadi::Collection::UrlType::UrlShort),   //  0x00  0
        uint8_t(Akonadi::Collection::UrlType::UrlWithName) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Collection.UrlType",
        UrlType_Initializer, UrlType_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_UrlType_IDX].type = EType;
    // Register converter for enum 'Akonadi::Collection::UrlType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_UrlType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Collection_UrlType,
            is_Enum_PythonToCpp_Akonadi_Collection_UrlType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection::UrlType");
        Shiboken::Conversions::registerConverterAlias(converter, "Collection::UrlType");
        Shiboken::Conversions::registerConverterAlias(converter, "UrlType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UrlType' enum.

    // Initialization of enum 'ListPreference'.
    const char *ListPreference_Initializer[] = {
        "ListEnabled",
        "ListDisabled",
        "ListDefault",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ListPreference_InitializerValues[] = {
        uint8_t(Akonadi::Collection::ListPreference::ListEnabled),  //  0x00  0
        uint8_t(Akonadi::Collection::ListPreference::ListDisabled), //  0x01  1
        uint8_t(Akonadi::Collection::ListPreference::ListDefault)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Collection.ListPreference",
        ListPreference_Initializer, ListPreference_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPreference_IDX].type = EType;
    // Register converter for enum 'Akonadi::Collection::ListPreference'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_ListPreference_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Collection_ListPreference,
            is_Enum_PythonToCpp_Akonadi_Collection_ListPreference_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection::ListPreference");
        Shiboken::Conversions::registerConverterAlias(converter, "Collection::ListPreference");
        Shiboken::Conversions::registerConverterAlias(converter, "ListPreference");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ListPreference' enum.

    // Initialization of enum 'ListPurpose'.
    const char *ListPurpose_Initializer[] = {
        "ListSync",
        "ListDisplay",
        "ListIndex",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ListPurpose_InitializerValues[] = {
        uint8_t(Akonadi::Collection::ListPurpose::ListSync),    //  0x00  0
        uint8_t(Akonadi::Collection::ListPurpose::ListDisplay), //  0x01  1
        uint8_t(Akonadi::Collection::ListPurpose::ListIndex)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.Collection.ListPurpose",
        ListPurpose_Initializer, ListPurpose_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_ListPurpose_IDX].type = EType;
    // Register converter for enum 'Akonadi::Collection::ListPurpose'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_Collection_ListPurpose_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_Collection_ListPurpose,
            is_Enum_PythonToCpp_Akonadi_Collection_ListPurpose_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::Collection::ListPurpose");
        Shiboken::Conversions::registerConverterAlias(converter, "Collection::ListPurpose");
        Shiboken::Conversions::registerConverterAlias(converter, "ListPurpose");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ListPurpose' enum.

    qRegisterMetaType< ::Akonadi::Collection >("Collection");
    qRegisterMetaType< ::Akonadi::Collection >("Akonadi::Collection");
    qRegisterMetaType< ::Akonadi::Collection::Right >("Collection::Right");
    qRegisterMetaType< ::Akonadi::Collection::Right >("Akonadi::Collection::Right");
    qRegisterMetaType< ::Akonadi::Collection::CreateOption >("Collection::CreateOption");
    qRegisterMetaType< ::Akonadi::Collection::CreateOption >("Akonadi::Collection::CreateOption");
    qRegisterMetaType< ::Akonadi::Collection::UrlType >("Collection::UrlType");
    qRegisterMetaType< ::Akonadi::Collection::UrlType >("Akonadi::Collection::UrlType");
    qRegisterMetaType< ::Akonadi::Collection::ListPreference >("Collection::ListPreference");
    qRegisterMetaType< ::Akonadi::Collection::ListPreference >("Akonadi::Collection::ListPreference");
    qRegisterMetaType< ::Akonadi::Collection::ListPurpose >("Collection::ListPurpose");
    qRegisterMetaType< ::Akonadi::Collection::ListPurpose >("Akonadi::Collection::ListPurpose");

    return pyType;
}
