/********************************************************************************
** Form generated from reading UI file 'tagselectiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGSELECTIONDIALOG_H
#define UI_TAGSELECTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "tageditwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TagSelectionDialog
{
public:
    QVBoxLayout *verticalLayout;
    Akonadi::TagEditWidget *tagWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TagSelectionDialog)
    {
        if (TagSelectionDialog->objectName().isEmpty())
            TagSelectionDialog->setObjectName("TagSelectionDialog");
        TagSelectionDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(TagSelectionDialog);
        verticalLayout->setObjectName("verticalLayout");
        tagWidget = new Akonadi::TagEditWidget(TagSelectionDialog);
        tagWidget->setObjectName("tagWidget");

        verticalLayout->addWidget(tagWidget);

        buttonBox = new QDialogButtonBox(TagSelectionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TagSelectionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TagSelectionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TagSelectionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TagSelectionDialog);
    } // setupUi

    void retranslateUi(QDialog *TagSelectionDialog)
    {
        TagSelectionDialog->setWindowTitle(tr2i18n("Select Tags", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TagSelectionDialog: public Ui_TagSelectionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TAGSELECTIONDIALOG_H

