
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_recursivecollectionfilterproxymodel_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void RecursiveCollectionFilterProxyModelWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

RecursiveCollectionFilterProxyModelWrapper::RecursiveCollectionFilterProxyModelWrapper(::QObject * parent) : Akonadi::RecursiveCollectionFilterProxyModel(parent)
{
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::buddy(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

bool RecursiveCollectionFilterProxyModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::canDropMimeData(data, action, row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canDropMimeData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::canFetchMore(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, parent);
}

void RecursiveCollectionFilterProxyModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, event);
}

bool RecursiveCollectionFilterProxyModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::clearItemData(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

int RecursiveCollectionFilterProxyModelWrapper::columnCount(const ::QModelIndex & index) const
{
    static const char *funcName = "columnCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::RecursiveCollectionFilterProxyModel::columnCount(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_columnCount("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

void RecursiveCollectionFilterProxyModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, signal);
}

void RecursiveCollectionFilterProxyModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, event);
}

::QVariant RecursiveCollectionFilterProxyModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::data(index, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_data("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index, role);
}

void RecursiveCollectionFilterProxyModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, signal);
}

bool RecursiveCollectionFilterProxyModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::dropMimeData(data, action, row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canDropMimeData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, event);
}

bool RecursiveCollectionFilterProxyModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, watched, event);
}

void RecursiveCollectionFilterProxyModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::fetchMore(parent);
    }
    TrashFilterProxyModelWrapper::sbk_o_fetchMore("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::filterAcceptsColumn(int source_column, const ::QModelIndex & source_parent) const
{
    static const char *funcName = "filterAcceptsColumn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::filterAcceptsColumn(source_column, source_parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_filterAcceptsColumn("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, source_column, source_parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::filterAcceptsRow(int sourceRow, const ::QModelIndex & sourceParent) const
{
    static const char *funcName = "filterAcceptsRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::RecursiveCollectionFilterProxyModel::filterAcceptsRow(sourceRow, sourceParent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_filterAcceptsColumn("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceRow, sourceParent);
}

::QFlags<Qt::ItemFlag> RecursiveCollectionFilterProxyModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::flags(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_flags("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

bool RecursiveCollectionFilterProxyModelWrapper::hasChildren(const ::QModelIndex & parent) const
{
    static const char *funcName = "hasChildren";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::hasChildren(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, parent);
}

::QVariant RecursiveCollectionFilterProxyModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::headerData(section, orientation, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_headerData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::index(row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_index("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, row, column, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::insertColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::insertColumns(column, count, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_insertColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, column, count, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::insertRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::insertRows(row, count, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_insertColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, row, count, parent);
}

::QMap<int,QVariant> RecursiveCollectionFilterProxyModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::itemData(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_itemData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

bool RecursiveCollectionFilterProxyModelWrapper::lessThan(const ::QModelIndex & source_left, const ::QModelIndex & source_right) const
{
    static const char *funcName = "lessThan";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::lessThan(source_left, source_right);
    }
    return TrashFilterProxyModelWrapper::sbk_o_lessThan("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, source_left, source_right);
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::mapFromSource(const ::QModelIndex & sourceIndex) const
{
    static const char *funcName = "mapFromSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapFromSource(sourceIndex);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceIndex);
}

::QItemSelection RecursiveCollectionFilterProxyModelWrapper::mapSelectionFromSource(const ::QItemSelection & sourceSelection) const
{
    static const char *funcName = "mapSelectionFromSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapSelectionFromSource(sourceSelection);
    }
    return TrashFilterProxyModelWrapper::sbk_o_mapSelectionFromSource("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceSelection);
}

::QItemSelection RecursiveCollectionFilterProxyModelWrapper::mapSelectionToSource(const ::QItemSelection & proxySelection) const
{
    static const char *funcName = "mapSelectionToSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapSelectionToSource(proxySelection);
    }
    return TrashFilterProxyModelWrapper::sbk_o_mapSelectionFromSource("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, proxySelection);
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::mapToSource(const ::QModelIndex & proxyIndex) const
{
    static const char *funcName = "mapToSource";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mapToSource(proxyIndex);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, proxyIndex);
}

::QList<QModelIndex> RecursiveCollectionFilterProxyModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::match(start, role, value, hits, flags);
    }
    return TrashFilterProxyModelWrapper::sbk_o_match("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * RecursiveCollectionFilterProxyModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mimeData(indexes);
    }
    return TrashFilterProxyModelWrapper::sbk_o_mimeData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, indexes);
}

::QStringList RecursiveCollectionFilterProxyModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::mimeTypes();
    }
    return TrashFilterProxyModelWrapper::sbk_o_mimeTypes("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

bool RecursiveCollectionFilterProxyModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return TrashFilterProxyModelWrapper::sbk_o_moveColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool RecursiveCollectionFilterProxyModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return TrashFilterProxyModelWrapper::sbk_o_moveColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void RecursiveCollectionFilterProxyModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    TrashFilterProxyModelWrapper::sbk_o_multiData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index, roleDataSpan);
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::parent(const ::QModelIndex & child) const
{
    static const char *funcName = "parent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::parent(child);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, child);
}

bool RecursiveCollectionFilterProxyModelWrapper::removeColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::removeColumns(column, count, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_insertColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, column, count, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::removeRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::removeRows(row, count, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_insertColumns("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, row, count, parent);
}

void RecursiveCollectionFilterProxyModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

void RecursiveCollectionFilterProxyModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::revert();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

::QHash<int,QByteArray> RecursiveCollectionFilterProxyModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::roleNames();
    }
    return TrashFilterProxyModelWrapper::sbk_o_roleNames("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

int RecursiveCollectionFilterProxyModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::rowCount(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_columnCount("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, parent);
}

bool RecursiveCollectionFilterProxyModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setData(index, value, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index, value, role);
}

bool RecursiveCollectionFilterProxyModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setHeaderData(section, orientation, value, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setHeaderData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool RecursiveCollectionFilterProxyModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::setItemData(index, roles);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setItemData("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index, roles);
}

void RecursiveCollectionFilterProxyModelWrapper::setSourceModel(::QAbstractItemModel * sourceModel)
{
    static const char *funcName = "setSourceModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::setSourceModel(sourceModel);
    }
    TrashFilterProxyModelWrapper::sbk_o_setSourceModel("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, sourceModel);
}

::QModelIndex RecursiveCollectionFilterProxyModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::sibling(row, column, idx);
    }
    return TrashFilterProxyModelWrapper::sbk_o_index("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, row, column, idx);
}

void RecursiveCollectionFilterProxyModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::sort(column, order);
    }
    TrashFilterProxyModelWrapper::sbk_o_sort("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, column, order);
}

::QSize RecursiveCollectionFilterProxyModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[47], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::span(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_span("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, index);
}

bool RecursiveCollectionFilterProxyModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[48], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::submit();
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> RecursiveCollectionFilterProxyModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[49], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractProxyModel::supportedDragActions();
    }
    return TrashFilterProxyModelWrapper::sbk_o_supportedDragActions("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> RecursiveCollectionFilterProxyModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[50], nameCache));
    if (pyOverride.isNull()) {
        return this->::QSortFilterProxyModel::supportedDropActions();
    }
    return TrashFilterProxyModelWrapper::sbk_o_supportedDragActions("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride);
}

void RecursiveCollectionFilterProxyModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), gil, funcName, m_PyMethodCache[51], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("RecursiveCollectionFilterProxyModel", funcName, gil, pyOverride, event);
}

const QMetaObject *RecursiveCollectionFilterProxyModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::RecursiveCollectionFilterProxyModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int RecursiveCollectionFilterProxyModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::RecursiveCollectionFilterProxyModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *RecursiveCollectionFilterProxyModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< RecursiveCollectionFilterProxyModelWrapper *>(this));
    }
    return Akonadi::RecursiveCollectionFilterProxyModel::qt_metacast(_clname);
}

RecursiveCollectionFilterProxyModelWrapper::~RecursiveCollectionFilterProxyModelWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_RecursiveCollectionFilterProxyModel_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::RecursiveCollectionFilterProxyModel >()))
        return -1;

    RecursiveCollectionFilterProxyModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:RecursiveCollectionFilterProxyModel", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::RecursiveCollectionFilterProxyModel(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::RecursiveCollectionFilterProxyModel(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::RecursiveCollectionFilterProxyModel(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) RecursiveCollectionFilterProxyModelWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new RecursiveCollectionFilterProxyModelWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::RecursiveCollectionFilterProxyModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_addContentMimeTypeInclusionFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilter(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilter(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addContentMimeTypeInclusionFilter", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilter(const QString&)
            cppSelf->addContentMimeTypeInclusionFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_addContentMimeTypeInclusionFilters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilters(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilters(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addContentMimeTypeInclusionFilters", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::addContentMimeTypeInclusionFilters(const QStringList&)
            cppSelf->addContentMimeTypeInclusionFilters(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_clearFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecursiveCollectionFilterProxyModel::clearFilters()
        cppSelf->clearFilters();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_columnCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QAbstractItemModel::columnCount(const QModelIndex&)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // QAbstractItemModel::columnCount(const QModelIndex&)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "columnCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::columnCount(const QModelIndex&)const->int
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::RecursiveCollectionFilterProxyModel *>(cppSelf)->::Akonadi::RecursiveCollectionFilterProxyModel::columnCount(*cppArg0)
                : const_cast<const ::Akonadi::RecursiveCollectionFilterProxyModel *>(cppSelf)->columnCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_contentMimeTypeInclusionFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecursiveCollectionFilterProxyModel::contentMimeTypeInclusionFilters()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::RecursiveCollectionFilterProxyModel *>(cppSelf)->contentMimeTypeInclusionFilters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_filterAcceptsRow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "filterAcceptsRow", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSortFilterProxyModel::filterAcceptsRow(int,const QModelIndex&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[1])))) {
        overloadId = 0; // QSortFilterProxyModel::filterAcceptsRow(int,const QModelIndex&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "filterAcceptsRow", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QModelIndex cppArg1_local;
        ::QModelIndex *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QSortFilterProxyModel::filterAcceptsRow(int,const QModelIndex&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::RecursiveCollectionFilterProxyModel *>(cppSelf)->::Akonadi::RecursiveCollectionFilterProxyModel::filterAcceptsRow(cppArg0, *cppArg1)
                : const_cast<const ::Akonadi::RecursiveCollectionFilterProxyModel *>(cppSelf)->filterAcceptsRow(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setContentMimeTypeInclusionFilters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::setContentMimeTypeInclusionFilters(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::setContentMimeTypeInclusionFilters(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentMimeTypeInclusionFilters", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::setContentMimeTypeInclusionFilters(const QStringList&)
            cppSelf->setContentMimeTypeInclusionFilters(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setExcludeUnifiedMailBox(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::setExcludeUnifiedMailBox(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::setExcludeUnifiedMailBox(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExcludeUnifiedMailBox", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::setExcludeUnifiedMailBox(bool)
            cppSelf->setExcludeUnifiedMailBox(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setIncludeCheckedOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::setIncludeCheckedOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::setIncludeCheckedOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludeCheckedOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::setIncludeCheckedOnly(bool)
            cppSelf->setIncludeCheckedOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setSearchPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecursiveCollectionFilterProxyModel::setSearchPattern(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // RecursiveCollectionFilterProxyModel::setSearchPattern(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSearchPattern", SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecursiveCollectionFilterProxyModel::setSearchPattern(const QString&)
            cppSelf->setSearchPattern(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_RecursiveCollectionFilterProxyModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_RecursiveCollectionFilterProxyModel_methods[] = {
    {"addContentMimeTypeInclusionFilter", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_addContentMimeTypeInclusionFilter), METH_O, nullptr},
    {"addContentMimeTypeInclusionFilters", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_addContentMimeTypeInclusionFilters), METH_O, nullptr},
    {"clearFilters", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_clearFilters), METH_NOARGS, nullptr},
    {"columnCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_columnCount), METH_O, nullptr},
    {"contentMimeTypeInclusionFilters", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_contentMimeTypeInclusionFilters), METH_NOARGS, nullptr},
    {"filterAcceptsRow", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_filterAcceptsRow), METH_VARARGS, nullptr},
    {"setContentMimeTypeInclusionFilters", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setContentMimeTypeInclusionFilters), METH_O, nullptr},
    {"setExcludeUnifiedMailBox", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setExcludeUnifiedMailBox), METH_O, nullptr},
    {"setIncludeCheckedOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setIncludeCheckedOnly), METH_O, nullptr},
    {"setSearchPattern", reinterpret_cast<PyCFunction>(Sbk_Akonadi_RecursiveCollectionFilterProxyModelFunc_setSearchPattern), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_RecursiveCollectionFilterProxyModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<RecursiveCollectionFilterProxyModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_RecursiveCollectionFilterProxyModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_RecursiveCollectionFilterProxyModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_RecursiveCollectionFilterProxyModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_RecursiveCollectionFilterProxyModel_spec = {
    "1:AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_RecursiveCollectionFilterProxyModel_slots
};

} //extern "C"

static void *Sbk_Akonadi_RecursiveCollectionFilterProxyModel_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::RecursiveCollectionFilterProxyModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void RecursiveCollectionFilterProxyModel_PythonToCpp_RecursiveCollectionFilterProxyModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_RecursiveCollectionFilterProxyModel_PythonToCpp_RecursiveCollectionFilterProxyModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF()))
        return RecursiveCollectionFilterProxyModel_PythonToCpp_RecursiveCollectionFilterProxyModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *RecursiveCollectionFilterProxyModel_PTR_CppToPython_RecursiveCollectionFilterProxyModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::RecursiveCollectionFilterProxyModel *>(const_cast<void *>(cppIn)), Sbk_Akonadi_RecursiveCollectionFilterProxyModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_RecursiveCollectionFilterProxyModel_SignatureStrings[] = {
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.addContentMimeTypeInclusionFilter(self,mimeType:QString)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.addContentMimeTypeInclusionFilters(self,mimeTypes:QStringList)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.clearFilters(self)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.columnCount(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->int",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.contentMimeTypeInclusionFilters(self)->QStringList",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.filterAcceptsRow(self,sourceRow:int,sourceParent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.setContentMimeTypeInclusionFilters(self,mimeTypes:QStringList)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.setExcludeUnifiedMailBox(self,exclude:bool)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.setIncludeCheckedOnly(self,checked:bool)",
    "AkonadiCore.Akonadi.RecursiveCollectionFilterProxyModel.setSearchPattern(self,pattern:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_RecursiveCollectionFilterProxyModel_SignatureByteSize = 321;
static constexpr uint8_t Akonadi_RecursiveCollectionFilterProxyModel_SignatureBytes[321] = {
    0x78, 0xda, 0xc5, 0x94, 0xc1, 0x4e, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0x3c, 0x05, 0x47, 0x26, 0x8d,
    0x1e, 0x39, 0x54, 0x02, 0xa9, 0x54, 0x20, 0x4d, 0x62, 0x5a, 0xb7, 0xc2, 0x09, 0x71, 0xe8, 0x12,
    0x8f, 0x85, 0x65, 0x76, 0x95, 0xb8, 0xd0, 0xbe, 0x3d, 0x6e, 0xb3, 0x8d, 0xb1, 0x0b, 0x52, 0x0b,
    0xe2, 0x56, 0xc7, 0x76, 0xbe, 0xdf, 0x7f, 0xd2, 0x24, 0x1b, 0xc2, 0x42, 0x9b, 0x94, 0x1c, 0x44,
    0x49, 0xf8, 0x8e, 0x16, 0xa0, 0x2a, 0xe7, 0xcd, 0x3b, 0xa4, 0x64, 0x2d, 0x28, 0x36, 0x84, 0xf7,
    0xc6, 0x32, 0xb8, 0xcc, 0x51, 0xdd, 0x4c, 0x49, 0x83, 0xbd, 0xf0, 0x60, 0x57, 0xe3, 0xb2, 0x70,
    0x80, 0x1c, 0x67, 0x4d, 0x6e, 0x34, 0x5c, 0x45, 0x73, 0xee, 0xb6, 0x99, 0xcf, 0x96, 0x6f, 0xd2,
    0x75, 0x8d, 0x95, 0xb5, 0x25, 0xbb, 0xd1, 0x59, 0xd2, 0x8f, 0x11, 0x15, 0x5a, 0xa7, 0x84, 0x2c,
    0x88, 0xa9, 0xd9, 0xc2, 0x63, 0x53, 0xc2, 0x04, 0x95, 0xad, 0xfc, 0xa1, 0x36, 0xa8, 0xd8, 0xee,
    0x92, 0xf1, 0x3c, 0x67, 0x67, 0xf0, 0xf5, 0x0f, 0x81, 0xfe, 0x3b, 0xd1, 0xef, 0x91, 0x0f, 0xc6,
    0x73, 0x7f, 0xac, 0xb2, 0x50, 0xb8, 0x63, 0xc0, 0x80, 0xad, 0xc8, 0x56, 0x5b, 0x4c, 0xa9, 0x42,
    0x0e, 0x52, 0x0d, 0x6a, 0xa8, 0x63, 0x6e, 0x4a, 0x51, 0x19, 0x3d, 0xa1, 0xf4, 0x3c, 0x9f, 0x1e,
    0x57, 0xd7, 0x39, 0x69, 0xeb, 0xc6, 0xe7, 0xa7, 0xb9, 0x4c, 0x24, 0xc9, 0x6c, 0xad, 0x23, 0x87,
    0xaa, 0x97, 0xd1, 0xe5, 0x8d, 0x41, 0x1e, 0xa0, 0xf1, 0x67, 0x8b, 0x05, 0x71, 0x64, 0x6d, 0x6f,
    0xd4, 0xaa, 0x5b, 0x48, 0x94, 0x82, 0x92, 0xfd, 0x82, 0x3e, 0x82, 0x27, 0x9e, 0x2a, 0xa7, 0x40,
    0xc2, 0x58, 0xc6, 0xd8, 0x45, 0x59, 0xb8, 0xca, 0xbf, 0x6e, 0xd4, 0x92, 0xc8, 0xf6, 0x96, 0xef,
    0x81, 0xff, 0xe3, 0x3e, 0x0a, 0xf6, 0xae, 0x16, 0x8e, 0x06, 0xf1, 0x61, 0x65, 0x40, 0x4f, 0x0b,
    0x63, 0x6f, 0xa9, 0x0e, 0x30, 0x08, 0xa9, 0xb8, 0x9d, 0x6c, 0x10, 0xa3, 0x9b, 0x45, 0x43, 0xba,
    0x06, 0xb5, 0x01, 0x3d, 0x43, 0xdb, 0x04, 0x80, 0x0a, 0x0b, 0xc3, 0x01, 0xb9, 0xfc, 0x56, 0x6a,
    0x9d, 0x15, 0x2c, 0x19, 0xdc, 0xbf, 0x58, 0x5d, 0xf0, 0xf5, 0x54, 0x7c, 0x02, 0xb3, 0x2c, 0xe8,
    0x6b
};
#endif

PyTypeObject *init_Akonadi_RecursiveCollectionFilterProxyModel(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_RecursiveCollectionFilterProxyModel_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSortFilterProxyModel_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_RecursiveCollectionFilterProxyModel_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "RecursiveCollectionFilterProxyModel",
        "Akonadi::RecursiveCollectionFilterProxyModel*",
        &Sbk_Akonadi_RecursiveCollectionFilterProxyModel_spec,
        &Shiboken::callCppDestructor< Akonadi::RecursiveCollectionFilterProxyModel >,
        Sbk_Akonadi_RecursiveCollectionFilterProxyModel_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_RecursiveCollectionFilterProxyModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_RecursiveCollectionFilterProxyModel_SignatureBytes, Akonadi_RecursiveCollectionFilterProxyModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_RecursiveCollectionFilterProxyModel_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        RecursiveCollectionFilterProxyModel_PythonToCpp_RecursiveCollectionFilterProxyModel_PTR,
        is_RecursiveCollectionFilterProxyModel_PythonToCpp_RecursiveCollectionFilterProxyModel_PTR_Convertible,
        RecursiveCollectionFilterProxyModel_PTR_CppToPython_RecursiveCollectionFilterProxyModel);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::RecursiveCollectionFilterProxyModel");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::RecursiveCollectionFilterProxyModel*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::RecursiveCollectionFilterProxyModel&");
    Shiboken::Conversions::registerConverterAlias(converter, "RecursiveCollectionFilterProxyModel");
    Shiboken::Conversions::registerConverterAlias(converter, "RecursiveCollectionFilterProxyModel*");
    Shiboken::Conversions::registerConverterAlias(converter, "RecursiveCollectionFilterProxyModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::RecursiveCollectionFilterProxyModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(RecursiveCollectionFilterProxyModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_RecursiveCollectionFilterProxyModel_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::RecursiveCollectionFilterProxyModel::staticMetaObject, sizeof(RecursiveCollectionFilterProxyModelWrapper));

    return pyType;
}
