
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_mimetypechecker_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <collection.h>
#include <item.h>
#include <mimetypechecker.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_MimeTypeChecker_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_MimeTypeChecker_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::MimeTypeChecker >()))
        return -1;

    ::Akonadi::MimeTypeChecker *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "MimeTypeChecker", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: MimeTypeChecker::MimeTypeChecker()
    // 1: MimeTypeChecker::MimeTypeChecker(const Akonadi::MimeTypeChecker&)
    if (numArgs == 0) {
        overloadId = 0; // MimeTypeChecker()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), (pyArgs[0])))) {
        overloadId = 1; // MimeTypeChecker::MimeTypeChecker(const Akonadi::MimeTypeChecker&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // MimeTypeChecker()
        {

            // MimeTypeChecker::MimeTypeChecker()
            cptr = new ::Akonadi::MimeTypeChecker();
            break;
        }
        case 1: // MimeTypeChecker(const Akonadi::MimeTypeChecker &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::MimeTypeChecker cppArg0_local;
            ::Akonadi::MimeTypeChecker *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // MimeTypeChecker::MimeTypeChecker(const Akonadi::MimeTypeChecker&)
                cptr = new ::Akonadi::MimeTypeChecker(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::MimeTypeChecker >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_addWantedMimeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: MimeTypeChecker::addWantedMimeType(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // MimeTypeChecker::addWantedMimeType(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addWantedMimeType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // MimeTypeChecker::addWantedMimeType(const QString&)
            cppSelf->addWantedMimeType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_containsWantedMimeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: MimeTypeChecker::containsWantedMimeType(const QStringList&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // MimeTypeChecker::containsWantedMimeType(const QStringList&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "containsWantedMimeType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // MimeTypeChecker::containsWantedMimeType(const QStringList&)const->bool
            bool cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->containsWantedMimeType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_hasWantedMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // MimeTypeChecker::hasWantedMimeTypes()const->bool
        bool cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->hasWantedMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_isWantedCollection([[maybe_unused]] PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] ::Akonadi::MimeTypeChecker *cppSelf = nullptr;
    if (self)
        cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isWantedCollection", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: MimeTypeChecker::isWantedCollection(const Akonadi::Collection&)const->bool
    // 1: static MimeTypeChecker::isWantedCollection(const Akonadi::Collection&,const QString&)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // isWantedCollection(Akonadi::Collection)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // static MimeTypeChecker::isWantedCollection(const Akonadi::Collection&,const QString&)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isWantedCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isWantedCollection(const Akonadi::Collection &collection) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Collection cppArg0_local;
            ::Akonadi::Collection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // MimeTypeChecker::isWantedCollection(const Akonadi::Collection&)const->bool
                bool cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->isWantedCollection(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isWantedCollection(const Akonadi::Collection &collection, const QString &wantedMimeType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Collection cppArg0_local;
            ::Akonadi::Collection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static MimeTypeChecker::isWantedCollection(const Akonadi::Collection&,const QString&)->bool
                bool cppResult = ::Akonadi::MimeTypeChecker::isWantedCollection(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_isWantedItem([[maybe_unused]] PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] ::Akonadi::MimeTypeChecker *cppSelf = nullptr;
    if (self)
        cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isWantedItem", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: MimeTypeChecker::isWantedItem(const Akonadi::Item&)const->bool
    // 1: static MimeTypeChecker::isWantedItem(const Akonadi::Item&,const QString&)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // isWantedItem(Akonadi::Item)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // static MimeTypeChecker::isWantedItem(const Akonadi::Item&,const QString&)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isWantedItem", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isWantedItem(const Akonadi::Item &item) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // MimeTypeChecker::isWantedItem(const Akonadi::Item&)const->bool
                bool cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->isWantedItem(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isWantedItem(const Akonadi::Item &item, const QString &wantedMimeType)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static MimeTypeChecker::isWantedItem(const Akonadi::Item&,const QString&)->bool
                bool cppResult = ::Akonadi::MimeTypeChecker::isWantedItem(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_isWantedMimeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: MimeTypeChecker::isWantedMimeType(const QString&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // MimeTypeChecker::isWantedMimeType(const QString&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isWantedMimeType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // MimeTypeChecker::isWantedMimeType(const QString&)const->bool
            bool cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->isWantedMimeType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_removeWantedMimeType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: MimeTypeChecker::removeWantedMimeType(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // MimeTypeChecker::removeWantedMimeType(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeWantedMimeType", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // MimeTypeChecker::removeWantedMimeType(const QString&)
            cppSelf->removeWantedMimeType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_setWantedMimeTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: MimeTypeChecker::setWantedMimeTypes(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // MimeTypeChecker::setWantedMimeTypes(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWantedMimeTypes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // MimeTypeChecker::setWantedMimeTypes(const QStringList&)
            cppSelf->setWantedMimeTypes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_MimeTypeCheckerFunc_wantedMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // MimeTypeChecker::wantedMimeTypes()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::MimeTypeChecker *>(cppSelf)->wantedMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_MimeTypeChecker__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection = {"isWantedCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_isWantedCollection), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem = {"isWantedItem", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_isWantedItem), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_Akonadi_MimeTypeChecker_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_MimeTypeChecker_methods[] = {
    {"addWantedMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_addWantedMimeType), METH_O, nullptr},
    {"containsWantedMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_containsWantedMimeType), METH_O, nullptr},
    {"hasWantedMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_hasWantedMimeTypes), METH_NOARGS, nullptr},
    {"isWantedCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_isWantedCollection), METH_VARARGS|METH_STATIC, nullptr},
    {"isWantedItem", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_isWantedItem), METH_VARARGS|METH_STATIC, nullptr},
    {"isWantedMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_isWantedMimeType), METH_O, nullptr},
    {"removeWantedMimeType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_removeWantedMimeType), METH_O, nullptr},
    {"setWantedMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_setWantedMimeTypes), METH_O, nullptr},
    {"wantedMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeCheckerFunc_wantedMimeTypes), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_MimeTypeChecker__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_Akonadi_MimeTypeChecker_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PyType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection = {
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection.ml_name,
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection.ml_meth,
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection.ml_flags & (~METH_STATIC),
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection.ml_doc,
    };
    if (PyUnicode_CompareWithASCIIString(name, "isWantedCollection") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_Akonadi_MimeTypeCheckerMethod_isWantedCollection, self, 0);
    static PyMethodDef non_static_Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem = {
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem.ml_name,
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem.ml_meth,
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem.ml_flags & (~METH_STATIC),
        Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem.ml_doc,
    };
    if (PyUnicode_CompareWithASCIIString(name, "isWantedItem") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_Akonadi_MimeTypeCheckerMethod_isWantedItem, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_Akonadi_MimeTypeChecker_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_MimeTypeChecker_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_MimeTypeChecker_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_Akonadi_MimeTypeChecker_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_MimeTypeChecker_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_MimeTypeChecker_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_MimeTypeChecker_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_MimeTypeChecker_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_MimeTypeChecker_spec = {
    "1:AkonadiCore.Akonadi.MimeTypeChecker",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_MimeTypeChecker_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void MimeTypeChecker_PythonToCpp_MimeTypeChecker_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_MimeTypeChecker_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_MimeTypeChecker_PythonToCpp_MimeTypeChecker_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_MimeTypeChecker_TypeF()))
        return MimeTypeChecker_PythonToCpp_MimeTypeChecker_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *MimeTypeChecker_PTR_CppToPython_MimeTypeChecker(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_MimeTypeChecker_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_MimeTypeChecker_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *MimeTypeChecker_COPY_CppToPython_MimeTypeChecker(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::MimeTypeChecker *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_MimeTypeChecker_TypeF(), new ::Akonadi::MimeTypeChecker(*source), true, true);
}

// Python to C++ copy conversion.
static void MimeTypeChecker_PythonToCpp_MimeTypeChecker_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::MimeTypeChecker *>(cppOut) = *reinterpret_cast< ::Akonadi::MimeTypeChecker *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_MimeTypeChecker_PythonToCpp_MimeTypeChecker_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_MimeTypeChecker_TypeF()))
        return MimeTypeChecker_PythonToCpp_MimeTypeChecker_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_MimeTypeChecker_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.MimeTypeChecker(self)",
    "0:AkonadiCore.Akonadi.MimeTypeChecker(self,other:AkonadiCore.Akonadi.MimeTypeChecker)",
    "AkonadiCore.Akonadi.MimeTypeChecker.addWantedMimeType(self,mimeType:QString)",
    "AkonadiCore.Akonadi.MimeTypeChecker.containsWantedMimeType(self,mimeTypes:QStringList)->bool",
    "AkonadiCore.Akonadi.MimeTypeChecker.hasWantedMimeTypes(self)->bool",
    "1:AkonadiCore.Akonadi.MimeTypeChecker.isWantedCollection(self,collection:AkonadiCore.Akonadi.Collection)->bool",
    "0:AkonadiCore.Akonadi.MimeTypeChecker.isWantedCollection(collection:AkonadiCore.Akonadi.Collection,wantedMimeType:QString)->bool",
    "1:AkonadiCore.Akonadi.MimeTypeChecker.isWantedItem(self,item:AkonadiCore.Akonadi.Item)->bool",
    "0:AkonadiCore.Akonadi.MimeTypeChecker.isWantedItem(item:AkonadiCore.Akonadi.Item,wantedMimeType:QString)->bool",
    "AkonadiCore.Akonadi.MimeTypeChecker.isWantedMimeType(self,mimeType:QString)->bool",
    "AkonadiCore.Akonadi.MimeTypeChecker.removeWantedMimeType(self,mimeType:QString)",
    "AkonadiCore.Akonadi.MimeTypeChecker.setWantedMimeTypes(self,mimeTypes:QStringList)",
    "AkonadiCore.Akonadi.MimeTypeChecker.wantedMimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.MimeTypeChecker.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_MimeTypeChecker_SignatureByteSize = 237;
static constexpr uint8_t Akonadi_MimeTypeChecker_SignatureBytes[237] = {
    0x78, 0xda, 0xad, 0x92, 0xcd, 0x0a, 0xc2, 0x30, 0x10, 0x84, 0xef, 0x7d, 0x12, 0x0b, 0x1a, 0xf4,
    0xea, 0x41, 0x90, 0x9e, 0x04, 0x3d, 0x88, 0x82, 0xc7, 0x10, 0xd3, 0xd5, 0x06, 0xdb, 0x6c, 0x49,
    0x16, 0xa5, 0x6f, 0x6f, 0xb5, 0xad, 0x7f, 0x54, 0x5d, 0x8b, 0xb7, 0x2c, 0x9d, 0xfd, 0x26, 0x93,
    0xce, 0x68, 0x3c, 0x3d, 0xa0, 0x55, 0xb1, 0x89, 0xd0, 0x81, 0xa8, 0xcf, 0x62, 0x61, 0x32, 0x58,
    0x17, 0x39, 0x44, 0x09, 0xe8, 0x03, 0xb8, 0x9e, 0x87, 0x74, 0x17, 0x06, 0x43, 0xb6, 0xb6, 0x8f,
    0x94, 0x80, 0xe3, 0xc8, 0xc3, 0x80, 0x21, 0x12, 0x2a, 0x8e, 0x37, 0xca, 0x12, 0xc4, 0xcd, 0x87,
    0xca, 0x25, 0xab, 0xa7, 0xf1, 0x72, 0x45, 0xce, 0xd8, 0x3d, 0x0f, 0xa6, 0xd1, 0x92, 0x32, 0xd6,
    0x7f, 0x22, 0xfa, 0x06, 0x39, 0x37, 0x9e, 0xc2, 0xc1, 0x64, 0x8b, 0x98, 0xb2, 0xe0, 0x89, 0x7a,
    0xe1, 0xfa, 0xea, 0xf1, 0x6a, 0xc4, 0x88, 0xf3, 0x26, 0xc2, 0xd4, 0x8c, 0x08, 0xd3, 0x14, 0x34,
    0x19, 0xb4, 0xd5, 0xed, 0xf4, 0x6d, 0x6e, 0xc5, 0xdc, 0xe5, 0x8d, 0xdd, 0xb0, 0xab, 0x1d, 0xdb,
    0xa9, 0x7f, 0x7a, 0x4a, 0x7b, 0xfb, 0x13, 0x9d, 0xf2, 0xce, 0x08, 0xb2, 0x2a, 0xa9, 0x29, 0x4f,
    0xad, 0xab, 0x17, 0x49, 0xb7, 0x74, 0x57, 0xf8, 0x47, 0xee, 0x97, 0x2c, 0xbf, 0x98, 0x7d, 0xe9,
    0xe9, 0x0f, 0x44, 0x07, 0x19, 0x1e, 0xe1, 0x7f, 0xed, 0xf7, 0x40, 0x6d, 0x05, 0x7d, 0xd3, 0x7c,
    0x16, 0xf2, 0xd4, 0x5e, 0xf8, 0x07, 0x0e, 0x0b, 0x23, 0xa5, 0xc6, 0xbc, 0x90, 0xb2, 0xd9, 0xa7,
    0x22, 0x2f, 0xd7, 0x85, 0x5c, 0x95, 0x63, 0x70, 0x06, 0x5a, 0x52, 0xb8, 0x87
};
#endif

PyTypeObject *init_Akonadi_MimeTypeChecker(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_MimeTypeChecker_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_MimeTypeChecker_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "MimeTypeChecker",
        "Akonadi::MimeTypeChecker",
        &Sbk_Akonadi_MimeTypeChecker_spec,
        &Shiboken::callCppDestructor< ::Akonadi::MimeTypeChecker >,
        Sbk_Akonadi_MimeTypeChecker_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_MimeTypeChecker_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_MimeTypeChecker_SignatureBytes, Akonadi_MimeTypeChecker_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_MimeTypeChecker_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        MimeTypeChecker_PythonToCpp_MimeTypeChecker_PTR,
        is_MimeTypeChecker_PythonToCpp_MimeTypeChecker_PTR_Convertible,
        MimeTypeChecker_PTR_CppToPython_MimeTypeChecker,
        MimeTypeChecker_COPY_CppToPython_MimeTypeChecker);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::MimeTypeChecker");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::MimeTypeChecker*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::MimeTypeChecker&");
    Shiboken::Conversions::registerConverterAlias(converter, "MimeTypeChecker");
    Shiboken::Conversions::registerConverterAlias(converter, "MimeTypeChecker*");
    Shiboken::Conversions::registerConverterAlias(converter, "MimeTypeChecker&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::MimeTypeChecker).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        MimeTypeChecker_PythonToCpp_MimeTypeChecker_COPY,
        is_MimeTypeChecker_PythonToCpp_MimeTypeChecker_COPY_Convertible);

    qRegisterMetaType< ::Akonadi::MimeTypeChecker >("MimeTypeChecker");
    qRegisterMetaType< ::Akonadi::MimeTypeChecker >("Akonadi::MimeTypeChecker");

    return pyType;
}
