
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collectionutils_wrapper.h"

// Argument includes
#include <QString>
#include <collection.h>
#include <item.h>
#include <qabstractitemmodel.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;


// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Akonadi_CollectionUtils_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNamespace("CollectionUtils");
    return -1;
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_defaultIconName([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::defaultIconName(const Akonadi::Collection&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::defaultIconName(const Akonadi::Collection&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "defaultIconName", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::defaultIconName(const Akonadi::Collection&)->QString
            QString cppResult = ::Akonadi::CollectionUtils::defaultIconName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_displayIconName([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::displayIconName(const Akonadi::Collection&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::displayIconName(const Akonadi::Collection&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "displayIconName", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::displayIconName(const Akonadi::Collection&)->QString
            QString cppResult = ::Akonadi::CollectionUtils::displayIconName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_fromIndex([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::fromIndex(const QModelIndex&)->Akonadi::Collection
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::fromIndex(const QModelIndex&)->Akonadi::Collection
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromIndex", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::fromIndex(const QModelIndex&)->Akonadi::Collection
            Akonadi::Collection cppResult = ::Akonadi::CollectionUtils::fromIndex(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_hasValidHierarchicalRID([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Collection&)->bool
    // 1: static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Item&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
        overloadId = 1; // static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Item&)->bool
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasValidHierarchicalRID", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // hasValidHierarchicalRID(const Akonadi::Collection &col)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::Akonadi::Collection cppArg0_local;
            ::Akonadi::Collection *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Collection&)->bool
                bool cppResult = ::Akonadi::CollectionUtils::hasValidHierarchicalRID(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // hasValidHierarchicalRID(const Akonadi::Item &item)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // static CollectionUtils::hasValidHierarchicalRID(const Akonadi::Item&)->bool
                bool cppResult = ::Akonadi::CollectionUtils::hasValidHierarchicalRID(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isFolder([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isFolder(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isFolder(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isFolder", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isFolder(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isFolder(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isReadOnly([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isReadOnly(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isReadOnly(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isReadOnly", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isReadOnly(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isReadOnly(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isResource([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isResource(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isResource(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isResource", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isResource(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isResource(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isRoot([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isRoot(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isRoot(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isRoot", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isRoot(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isRoot(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isStructural([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isStructural(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isStructural(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isStructural", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isStructural(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isStructural(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isUnifiedMailbox([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isUnifiedMailbox(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isUnifiedMailbox(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isUnifiedMailbox", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isUnifiedMailbox(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isUnifiedMailbox(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionUtilsFunc_isVirtualParent([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static CollectionUtils::isVirtualParent(const Akonadi::Collection&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // static CollectionUtils::isVirtualParent(const Akonadi::Collection&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isVirtualParent", SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CollectionUtils::isVirtualParent(const Akonadi::Collection&)->bool
            bool cppResult = ::Akonadi::CollectionUtils::isVirtualParent(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_CollectionUtils_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CollectionUtils_methods[] = {
    {"defaultIconName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_defaultIconName), METH_O|METH_STATIC, nullptr},
    {"displayIconName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_displayIconName), METH_O|METH_STATIC, nullptr},
    {"fromIndex", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_fromIndex), METH_O|METH_STATIC, nullptr},
    {"hasValidHierarchicalRID", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_hasValidHierarchicalRID), METH_O|METH_STATIC, nullptr},
    {"isFolder", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isFolder), METH_O|METH_STATIC, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isReadOnly), METH_O|METH_STATIC, nullptr},
    {"isResource", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isResource), METH_O|METH_STATIC, nullptr},
    {"isRoot", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isRoot), METH_O|METH_STATIC, nullptr},
    {"isStructural", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isStructural), METH_O|METH_STATIC, nullptr},
    {"isUnifiedMailbox", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isUnifiedMailbox), METH_O|METH_STATIC, nullptr},
    {"isVirtualParent", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionUtilsFunc_isVirtualParent), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_CollectionUtils_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CollectionUtils_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CollectionUtils_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionUtils_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CollectionUtils_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CollectionUtils_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionUtils_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CollectionUtils_spec = {
    "1:AkonadiCore.Akonadi.CollectionUtils",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CollectionUtils_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *AkonadiCoreAkonadi_CollectionUtils_SignatureStrings[] = {
    "AkonadiCore.Akonadi.CollectionUtils.defaultIconName(col:AkonadiCore.Akonadi.Collection)->QString",
    "AkonadiCore.Akonadi.CollectionUtils.displayIconName(col:AkonadiCore.Akonadi.Collection)->QString",
    "AkonadiCore.Akonadi.CollectionUtils.fromIndex(index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->AkonadiCore.Akonadi.Collection",
    "1:AkonadiCore.Akonadi.CollectionUtils.hasValidHierarchicalRID(col:AkonadiCore.Akonadi.Collection)->bool",
    "0:AkonadiCore.Akonadi.CollectionUtils.hasValidHierarchicalRID(item:AkonadiCore.Akonadi.Item)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isFolder(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isReadOnly(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isResource(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isRoot(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isStructural(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isUnifiedMailbox(collection:AkonadiCore.Akonadi.Collection)->bool",
    "AkonadiCore.Akonadi.CollectionUtils.isVirtualParent(collection:AkonadiCore.Akonadi.Collection)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t AkonadiCoreAkonadi_CollectionUtils_SignatureByteSize = 264;
static constexpr uint8_t AkonadiCoreAkonadi_CollectionUtils_SignatureBytes[264] = {
    0x78, 0xda, 0xb5, 0x93, 0x41, 0x4b, 0x03, 0x31, 0x10, 0x85, 0xef, 0xfd, 0x15, 0x1e, 0x2b, 0xe8,
    0xa2, 0x17, 0x0f, 0x7b, 0x10, 0x96, 0x8a, 0xb8, 0x87, 0xea, 0x6e, 0x4b, 0x7b, 0x11, 0x0f, 0xd3,
    0x64, 0xd6, 0x0e, 0xce, 0x66, 0x4a, 0x32, 0x0b, 0xdd, 0x7f, 0x6f, 0x5a, 0x15, 0x41, 0xa4, 0x44,
    0x24, 0x97, 0x10, 0x98, 0x37, 0xef, 0x7b, 0x09, 0xbc, 0xea, 0x4d, 0x1c, 0x58, 0x9a, 0x89, 0xc7,
    0xa2, 0xfa, 0xb8, 0x17, 0x33, 0x61, 0x46, 0xa3, 0x24, 0x6e, 0xa5, 0xc4, 0xa1, 0xb0, 0xd8, 0xc1,
    0xc0, 0x5a, 0x1b, 0x71, 0x8f, 0xd0, 0xe3, 0xd4, 0x08, 0x97, 0xd5, 0xc9, 0xbd, 0xf3, 0xcb, 0xdb,
    0x76, 0xa9, 0x9e, 0xdc, 0xeb, 0xa4, 0x4a, 0x01, 0x50, 0xd8, 0x31, 0x8c, 0xf9, 0x00, 0x9d, 0x97,
    0xbe, 0x76, 0x16, 0xf7, 0x53, 0x3a, 0x9c, 0xa5, 0x8e, 0xbb, 0xb8, 0x5a, 0xac, 0x5c, 0x54, 0x3c,
    0x37, 0xe3, 0x92, 0x2c, 0xde, 0x14, 0xad, 0x1e, 0x3d, 0xda, 0xb9, 0x58, 0xe4, 0xa3, 0xfa, 0xe2,
    0xec, 0xe7, 0xac, 0x41, 0x1f, 0x28, 0x28, 0x3a, 0xfd, 0x56, 0xbd, 0xc4, 0x30, 0xa7, 0x43, 0x4c,
    0xae, 0xcb, 0x94, 0x94, 0x5b, 0x08, 0x6b, 0x60, 0xb2, 0x0f, 0x84, 0x1e, 0xbc, 0xd9, 0x92, 0x01,
    0x5e, 0xd4, 0x77, 0x69, 0xdf, 0xb1, 0x11, 0xe1, 0xc9, 0xd5, 0xbf, 0x38, 0xa4, 0xd8, 0xff, 0x6a,
    0x50, 0xc7, 0xc1, 0x17, 0x22, 0x05, 0x40, 0xe1, 0x5e, 0xd8, 0xa2, 0x3f, 0x24, 0xff, 0x1c, 0x24,
    0x3e, 0x20, 0xcd, 0x7d, 0x81, 0x60, 0x9f, 0x1c, 0x8f, 0xf9, 0xfc, 0x83, 0x0c, 0xde, 0x60, 0x36,
    0x7f, 0x11, 0xcd, 0xe5, 0x1d, 0x5b, 0x31, 0x18, 0x1d, 0x3c, 0x70, 0x2e, 0x42, 0x6c, 0x4d, 0x47,
    0x68, 0xe7, 0x40, 0xbc, 0x91, 0x7d, 0x2e, 0xca, 0x9a, 0xbc, 0x0e, 0xc0, 0x0d, 0xf8, 0x58, 0xb6,
    0xbf, 0x43, 0xde, 0x01, 0xd2, 0xe0, 0xcd, 0x1f
};
#endif

PyTypeObject *init_AkonadiCoreAkonadi_CollectionUtils(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_AkonadiCoreAkonadi_CollectionUtils_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_CollectionUtils_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CollectionUtils",
        "Akonadi::CollectionUtils",
        &Sbk_Akonadi_CollectionUtils_spec,
        nullptr,
        Sbk_Akonadi_CollectionUtils_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, AkonadiCoreAkonadi_CollectionUtils_SignatureStrings);
#else
    InitSignatureBytes(pyType, AkonadiCoreAkonadi_CollectionUtils_SignatureBytes, AkonadiCoreAkonadi_CollectionUtils_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CollectionUtils_PropertyStrings);
    typeStruct.type = pyType;



    return pyType;
}
