/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Search.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef AGENTSEARCHINTERFACE_H
#define AGENTSEARCHINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.Agent.Search
 */
class OrgFreedesktopAkonadiAgentSearchInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.Agent.Search"; }

public:
    OrgFreedesktopAkonadiAgentSearchInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiAgentSearchInterface();

public Q_SLOTS: // METHODS
    Q_NOREPLY inline void addSearch(const QString &query, const QString &queryLanguage, qlonglong destination)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(query) << QVariant::fromValue(queryLanguage) << QVariant::fromValue(destination);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("addSearch"), argumentList);
    }

    Q_NOREPLY inline void removeSearch(qlonglong destination)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(destination);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("removeSearch"), argumentList);
    }

    Q_NOREPLY inline void search(const QByteArray &searchId, const QString &query, qlonglong collection)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(searchId) << QVariant::fromValue(query) << QVariant::fromValue(collection);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("search"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      namespace Agent {
        using Search = ::OrgFreedesktopAkonadiAgentSearchInterface;
      }
    }
  }
}

#endif
