/****************************************************************************
** Meta object code from reading C++ file 'agentinstance.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/agentinstance.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentinstance.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi13AgentInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::AgentInstance::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi13AgentInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::AgentInstance",
        "isValid",
        "identifier",
        "name",
        "status",
        "Akonadi::AgentInstance::Status",
        "statusMessage",
        "progress",
        "isOnline",
        "Status",
        "Idle",
        "Running",
        "Broken",
        "NotConfigured"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'identifier'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<Akonadi::AgentInstance::Status>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'statusMessage'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'progress'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'isOnline'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(9, 9, QMC::EnumFlags{}).add({
            {   10, Status::Idle },
            {   11, Status::Running },
            {   12, Status::Broken },
            {   13, Status::NotConfigured },
        }),
    };
    return QtMocHelpers::metaObjectData<AgentInstance, qt_meta_tag_ZN7Akonadi13AgentInstanceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::AgentInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi13AgentInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi13AgentInstanceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi13AgentInstanceE_t>.metaTypes,
    nullptr
} };

void Akonadi::AgentInstance::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<AgentInstance *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->identifier(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<Akonadi::AgentInstance::Status*>(_v) = _t->status(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->statusMessage(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->progress(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isOnline(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setIsOnline(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
