/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Status.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef STATUSADAPTOR_H
#define STATUSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "agentbase.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Agent.Status
 */
class Akonadi__StatusAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Agent.Status")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Agent.Status\">\n"
"    <signal name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"status\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"percent\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"percent\"/>\n"
"    </signal>\n"
"    <signal name=\"warning\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"error\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"    <signal name=\"onlineChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"state\"/>\n"
"    </signal>\n"
"    <signal name=\"advancedStatus\">\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"status\"/>\n"
"    </signal>\n"
"    <method name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"statusMessage\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"progress\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"isOnline\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setOnline\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"state\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Akonadi__StatusAdaptor(Akonadi::AgentBase *parent);
    ~Akonadi__StatusAdaptor() override;

    inline Akonadi::AgentBase *parent() const
    { return static_cast<Akonadi::AgentBase *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool isOnline();
    int progress();
    Q_NOREPLY void setOnline(bool state);
    int status();
    QString statusMessage();
Q_SIGNALS: // SIGNALS
    void advancedStatus(const QVariantMap &status);
    void error(const QString &message);
    void onlineChanged(bool state);
    void percent(int percent);
    void status(int status, const QString &message);
    void warning(const QString &message);
};

#endif
