
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_tagattribute_wrapper.h"

// Wrappers providing overrides
#include "akonadi_exception_wrapper.h"
#include "akonadi_attribute_wrapper.h"

// Argument includes
#include <QString>
#include <qbytearray.h>
#include <qcolor.h>
#include <tagattribute.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_TagAttribute_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void TagAttributeWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

TagAttributeWrapper::TagAttributeWrapper()
{
}

::Akonadi::TagAttribute * TagAttributeWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_TagAttribute_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::TagAttribute::clone();
    }
    return sbk_o_clone("TagAttribute", funcName, gil, pyOverride);
}

::Akonadi::TagAttribute * TagAttributeWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< Akonadi::TagAttribute >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::Akonadi::TagAttribute *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void TagAttributeWrapper::deserialize(const ::QByteArray & data)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_TagAttribute_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::TagAttribute::deserialize(data);
    }
    AttributeWrapper::sbk_o_deserialize("TagAttribute", funcName, gil, pyOverride, data);
}

::QByteArray TagAttributeWrapper::serialized() const
{
    static const char *funcName = "serialized";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_TagAttribute_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::TagAttribute::serialized();
    }
    return ExceptionWrapper::sbk_o_type("TagAttribute", funcName, gil, pyOverride);
}

::QByteArray TagAttributeWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_TagAttribute_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::TagAttribute::type();
    }
    return ExceptionWrapper::sbk_o_type("TagAttribute", funcName, gil, pyOverride);
}

TagAttributeWrapper::~TagAttributeWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_TagAttribute_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_TagAttribute_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::TagAttribute >()))
        return -1;

    TagAttributeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // TagAttribute::TagAttribute()
        cptr = new TagAttributeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::TagAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_backgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::backgroundColor()const->QColor
        QColor cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->backgroundColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::clone()const->Akonadi::TagAttribute*
        Akonadi::TagAttribute * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->::Akonadi::TagAttribute::clone()
            : const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attribute::deserialize(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Attribute::deserialize(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Attribute::deserialize(const QByteArray&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::TagAttribute::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_displayName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::displayName()const->QString
        QString cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->displayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::font()const->QString
        QString cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_iconName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::iconName()const->QString
        QString cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->iconName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_inToolbar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::inToolbar()const->bool
        bool cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->inToolbar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_priority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::priority()const->int
        int cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->priority();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_serialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::serialized()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->::Akonadi::TagAttribute::serialized()
            : const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->serialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setBackgroundColor(const QColor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // TagAttribute::setBackgroundColor(const QColor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundColor", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setBackgroundColor(const QColor&)
            cppSelf->setBackgroundColor(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setDisplayName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setDisplayName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // TagAttribute::setDisplayName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDisplayName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setDisplayName(const QString&)
            cppSelf->setDisplayName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setFont(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // TagAttribute::setFont(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setFont(const QString&)
            cppSelf->setFont(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setIconName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setIconName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // TagAttribute::setIconName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIconName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setIconName(const QString&)
            cppSelf->setIconName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setInToolbar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setInToolbar(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // TagAttribute::setInToolbar(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInToolbar", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setInToolbar(bool)
            cppSelf->setInToolbar(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setPriority(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // TagAttribute::setPriority(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPriority", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setPriority(int)
            cppSelf->setPriority(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setShortcut(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setShortcut(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // TagAttribute::setShortcut(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShortcut", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setShortcut(const QString&)
            cppSelf->setShortcut(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_setTextColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: TagAttribute::setTextColor(const QColor&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // TagAttribute::setTextColor(const QColor&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextColor", SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // TagAttribute::setTextColor(const QColor&)
            cppSelf->setTextColor(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_shortcut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::shortcut()const->QString
        QString cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->shortcut();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_textColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // TagAttribute::textColor()const->QColor
        QColor cppResult = const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->textColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_TagAttributeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::type()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->::Akonadi::TagAttribute::type()
            : const_cast<const ::Akonadi::TagAttribute *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_TagAttribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_TagAttribute_methods[] = {
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_backgroundColor), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_clone), METH_NOARGS, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_deserialize), METH_O, nullptr},
    {"displayName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_displayName), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_font), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_iconName), METH_NOARGS, nullptr},
    {"inToolbar", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_inToolbar), METH_NOARGS, nullptr},
    {"priority", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_priority), METH_NOARGS, nullptr},
    {"serialized", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_serialized), METH_NOARGS, nullptr},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setBackgroundColor), METH_O, nullptr},
    {"setDisplayName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setDisplayName), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setFont), METH_O, nullptr},
    {"setIconName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setIconName), METH_O, nullptr},
    {"setInToolbar", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setInToolbar), METH_O, nullptr},
    {"setPriority", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setPriority), METH_O, nullptr},
    {"setShortcut", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setShortcut), METH_O, nullptr},
    {"setTextColor", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_setTextColor), METH_O, nullptr},
    {"shortcut", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_shortcut), METH_NOARGS, nullptr},
    {"textColor", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_textColor), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_TagAttributeFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_TagAttribute_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::TagAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<TagAttributeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_TagAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_TagAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_TagAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_TagAttribute_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_TagAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_TagAttribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_TagAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_TagAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_TagAttribute_spec = {
    "1:AkonadiCore.Akonadi.TagAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_TagAttribute_slots
};

} //extern "C"

static void *Sbk_Akonadi_TagAttribute_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::Akonadi::Attribute >())
        return dynamic_cast< ::Akonadi::TagAttribute *>(reinterpret_cast< ::Akonadi::Attribute *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void TagAttribute_PythonToCpp_TagAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_TagAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_TagAttribute_PythonToCpp_TagAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_TagAttribute_TypeF()))
        return TagAttribute_PythonToCpp_TagAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *TagAttribute_PTR_CppToPython_TagAttribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_TagAttribute_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::TagAttribute *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_TagAttribute_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_TagAttribute_SignatureStrings[] = {
    "AkonadiCore.Akonadi.TagAttribute(self)",
    "AkonadiCore.Akonadi.TagAttribute.backgroundColor(self)->PySide6.QtGui.QColor",
    "AkonadiCore.Akonadi.TagAttribute.clone(self)->AkonadiCore.Akonadi.TagAttribute",
    "AkonadiCore.Akonadi.TagAttribute.deserialize(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.TagAttribute.displayName(self)->QString",
    "AkonadiCore.Akonadi.TagAttribute.font(self)->QString",
    "AkonadiCore.Akonadi.TagAttribute.iconName(self)->QString",
    "AkonadiCore.Akonadi.TagAttribute.inToolbar(self)->bool",
    "AkonadiCore.Akonadi.TagAttribute.priority(self)->int",
    "AkonadiCore.Akonadi.TagAttribute.serialized(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.TagAttribute.setBackgroundColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "AkonadiCore.Akonadi.TagAttribute.setDisplayName(self,name:QString)",
    "AkonadiCore.Akonadi.TagAttribute.setFont(self,fontKey:QString)",
    "AkonadiCore.Akonadi.TagAttribute.setIconName(self,name:QString)",
    "AkonadiCore.Akonadi.TagAttribute.setInToolbar(self,inToolbar:bool)",
    "AkonadiCore.Akonadi.TagAttribute.setPriority(self,priority:int)",
    "AkonadiCore.Akonadi.TagAttribute.setShortcut(self,shortcut:QString)",
    "AkonadiCore.Akonadi.TagAttribute.setTextColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "AkonadiCore.Akonadi.TagAttribute.shortcut(self)->QString",
    "AkonadiCore.Akonadi.TagAttribute.textColor(self)->PySide6.QtGui.QColor",
    "AkonadiCore.Akonadi.TagAttribute.type(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_TagAttribute_SignatureByteSize = 364;
static constexpr uint8_t Akonadi_TagAttribute_SignatureBytes[364] = {
    0x78, 0xda, 0xd5, 0x94, 0xc1, 0x4b, 0xc3, 0x30, 0x14, 0xc6, 0xef, 0xfe, 0x15, 0x3d, 0xaa, 0xc4,
    0x82, 0x20, 0x3b, 0xf4, 0x20, 0x74, 0x13, 0xc7, 0x50, 0x64, 0x75, 0xd3, 0x8b, 0x78, 0x48, 0x9b,
    0xac, 0x7b, 0x2c, 0xbe, 0x8c, 0xf4, 0x15, 0x8c, 0x7f, 0xbd, 0xd9, 0xba, 0x76, 0xdd, 0x54, 0xd2,
    0xee, 0xe6, 0x2d, 0x21, 0xef, 0xfb, 0xf2, 0xf2, 0xe5, 0x97, 0xc4, 0x2b, 0x8d, 0x5c, 0xc0, 0x48,
    0x1b, 0x19, 0xc6, 0xd5, 0x38, 0x9c, 0xf3, 0x3c, 0x26, 0x32, 0x90, 0x96, 0x24, 0xcf, 0x0b, 0xa9,
    0x16, 0x17, 0x67, 0xb1, 0xa7, 0x2c, 0x4c, 0x79, 0xb6, 0xca, 0x8d, 0x2e, 0x51, 0x8c, 0xb4, 0xd2,
    0xa6, 0x92, 0x5d, 0xdd, 0x4e, 0xed, 0x0c, 0x84, 0x1c, 0x84, 0x09, 0x8d, 0x4b, 0x08, 0x93, 0xed,
    0x9a, 0xdf, 0x2c, 0x53, 0x1a, 0x65, 0x6d, 0xe1, 0xab, 0xf6, 0xdb, 0x09, 0x59, 0x48, 0x03, 0x5c,
    0xc1, 0x57, 0x65, 0xca, 0x04, 0x27, 0x1e, 0x91, 0x5d, 0x03, 0xe6, 0xe1, 0x0b, 0x82, 0xc6, 0xb7,
    0x7d, 0x9f, 0x5b, 0x9b, 0x64, 0x68, 0x49, 0xc6, 0xc6, 0x70, 0xcb, 0x82, 0x6c, 0xc9, 0xcd, 0xe5,
    0x7b, 0x87, 0x08, 0x04, 0x14, 0x6b, 0xc5, 0xed, 0x13, 0xff, 0x68, 0x7a, 0x4f, 0x66, 0x6e, 0x11,
    0x73, 0xbf, 0x76, 0xa1, 0x91, 0x7a, 0x8b, 0x20, 0xd3, 0x78, 0xd2, 0x6e, 0x80, 0x73, 0xad, 0x55,
    0xca, 0x9b, 0x6b, 0x4a, 0xdd, 0xd4, 0x2f, 0x5b, 0x1b, 0xd0, 0x06, 0xc8, 0xd6, 0x2a, 0x40, 0xf2,
    0x8b, 0x9a, 0xe8, 0xc5, 0x4f, 0x26, 0x8e, 0xb2, 0xee, 0x62, 0x46, 0xc3, 0x5f, 0x40, 0x63, 0xd9,
    0x66, 0xf8, 0xd7, 0x8d, 0xee, 0xc9, 0x63, 0x41, 0xf2, 0xc8, 0x09, 0xf0, 0xba, 0x0a, 0x8a, 0x05,
    0x47, 0x45, 0xcf, 0x79, 0xca, 0x07, 0x37, 0xae, 0xea, 0x95, 0xbb, 0xa6, 0x91, 0xda, 0x05, 0x55,
    0xaf, 0x14, 0x8e, 0x95, 0x4e, 0xb9, 0xaa, 0xed, 0x6a, 0xa3, 0x12, 0x0b, 0xc8, 0x51, 0x8a, 0xc0,
    0x65, 0xd2, 0x85, 0x15, 0x77, 0x90, 0xbb, 0x23, 0x5c, 0x18, 0xba, 0x51, 0xb4, 0x73, 0xec, 0x66,
    0x71, 0x5f, 0x53, 0xc3, 0x36, 0xfc, 0x3c, 0x48, 0xdb, 0x4f, 0x3e, 0x69, 0xf3, 0x73, 0xc2, 0xf6,
    0x93, 0x03, 0x8c, 0x58, 0x43, 0x55, 0xb4, 0xc1, 0xa9, 0x9b, 0xc5, 0xb4, 0x8d, 0x14, 0xab, 0x01,
    0x8b, 0x5c, 0x8a, 0xdd, 0xf4, 0xb3, 0xa5, 0x36, 0x94, 0x95, 0xbb, 0x14, 0x8a, 0xdd, 0xac, 0xdf,
    0x31, 0xe6, 0xf2, 0x93, 0xfe, 0x35, 0x4b, 0xed, 0x0c, 0xfa, 0x7c, 0x03, 0x74, 0x70, 0xf0, 0x93,
    0x7f, 0x6b, 0x17, 0x95, 0xf4, 0xbf, 0xed, 0x6f, 0x59, 0x61, 0x55, 0xe9
};
#endif

PyTypeObject *init_Akonadi_TagAttribute(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagAttribute_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_TagAttribute_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "TagAttribute",
        "Akonadi::TagAttribute*",
        &Sbk_Akonadi_TagAttribute_spec,
        &Shiboken::callCppDestructor< Akonadi::TagAttribute >,
        Sbk_Akonadi_TagAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_TagAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_TagAttribute_SignatureBytes, Akonadi_TagAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_TagAttribute_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        TagAttribute_PythonToCpp_TagAttribute_PTR,
        is_TagAttribute_PythonToCpp_TagAttribute_PTR_Convertible,
        TagAttribute_PTR_CppToPython_TagAttribute);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagAttribute");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::TagAttribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "TagAttribute");
    Shiboken::Conversions::registerConverterAlias(converter, "TagAttribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "TagAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::TagAttribute).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(TagAttributeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_TagAttribute_typeDiscovery);

    qRegisterMetaType< ::Akonadi::TagAttribute *>();

    return pyType;
}
