
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collectionidentificationattribute_wrapper.h"

// Wrappers providing overrides
#include "akonadi_exception_wrapper.h"
#include "akonadi_attribute_wrapper.h"

// Argument includes
#include <attribute.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void CollectionIdentificationAttributeWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

CollectionIdentificationAttributeWrapper::CollectionIdentificationAttributeWrapper(const ::QByteArray & identifier, const ::QByteArray & folderNamespace, const ::QByteArray & name, const ::QByteArray & organizationUnit, const ::QByteArray & mail) : Akonadi::CollectionIdentificationAttribute(identifier, folderNamespace, name, organizationUnit, mail)
{
}

::Akonadi::Attribute * CollectionIdentificationAttributeWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionIdentificationAttribute::clone();
    }
    return AttributeWrapper::sbk_o_clone("CollectionIdentificationAttribute", funcName, gil, pyOverride);
}

void CollectionIdentificationAttributeWrapper::deserialize(const ::QByteArray & data)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionIdentificationAttribute::deserialize(data);
    }
    AttributeWrapper::sbk_o_deserialize("CollectionIdentificationAttribute", funcName, gil, pyOverride, data);
}

::QByteArray CollectionIdentificationAttributeWrapper::serialized() const
{
    static const char *funcName = "serialized";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionIdentificationAttribute::serialized();
    }
    return ExceptionWrapper::sbk_o_type("CollectionIdentificationAttribute", funcName, gil, pyOverride);
}

::QByteArray CollectionIdentificationAttributeWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CollectionIdentificationAttribute::type();
    }
    return ExceptionWrapper::sbk_o_type("CollectionIdentificationAttribute", funcName, gil, pyOverride);
}

CollectionIdentificationAttributeWrapper::~CollectionIdentificationAttributeWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_CollectionIdentificationAttribute_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::CollectionIdentificationAttribute >()))
        return -1;

    CollectionIdentificationAttributeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:CollectionIdentificationAttribute", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::CollectionIdentificationAttribute(const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=)
    if (numArgs == 0) {
        overloadId = 0; // CollectionIdentificationAttribute(QByteArray,QByteArray,QByteArray,QByteArray,QByteArray)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // CollectionIdentificationAttribute(QByteArray,QByteArray,QByteArray,QByteArray,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // CollectionIdentificationAttribute(QByteArray,QByteArray,QByteArray,QByteArray,QByteArray)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // CollectionIdentificationAttribute(QByteArray,QByteArray,QByteArray,QByteArray,QByteArray)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // CollectionIdentificationAttribute(QByteArray,QByteArray,QByteArray,QByteArray,QByteArray)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[4])))) {
                        overloadId = 0; // CollectionIdentificationAttribute::CollectionIdentificationAttribute(const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[5] = {{"identifier", 0}, {"folderNamespace", 1}, {"name", 2}, {"organizationUnit", 3}, {"mail", 4}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 5, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))))
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))))
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))))
                || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[3])))))
                || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[4])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);
            }
        }
    }

    // PyMI support
    Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QByteArray cppArg0_local = QByteArray();
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QByteArray cppArg1_local = QByteArray();
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return -1;
        ::QByteArray cppArg2_local = QByteArray();
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return -1;
        ::QByteArray cppArg3_local = QByteArray();
        ::QByteArray *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3]) {
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);
            }
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return -1;
        ::QByteArray cppArg4_local = QByteArray();
        ::QByteArray *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4]) {
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::CollectionIdentificationAttribute(const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=,const QByteArray&=)
            cptr = new CollectionIdentificationAttributeWrapper(*cppArg0, *cppArg1, *cppArg2, *cppArg3, *cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::CollectionIdentificationAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::clone()const->Akonadi::Attribute*
        Akonadi::Attribute * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->::Akonadi::CollectionIdentificationAttribute::clone()
            : const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_collectionNamespace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionIdentificationAttribute::collectionNamespace()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->collectionNamespace();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attribute::deserialize(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Attribute::deserialize(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Attribute::deserialize(const QByteArray&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::CollectionIdentificationAttribute::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionIdentificationAttribute::identifier()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->identifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_mail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionIdentificationAttribute::mail()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->mail();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionIdentificationAttribute::name()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_ou(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionIdentificationAttribute::ou()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->ou();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_serialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::serialized()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->::Akonadi::CollectionIdentificationAttribute::serialized()
            : const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->serialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_setCollectionNamespace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::setCollectionNamespace(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionIdentificationAttribute::setCollectionNamespace(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionNamespace", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::setCollectionNamespace(const QByteArray&)
            cppSelf->setCollectionNamespace(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_setIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::setIdentifier(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionIdentificationAttribute::setIdentifier(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIdentifier", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::setIdentifier(const QByteArray&)
            cppSelf->setIdentifier(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_setMail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::setMail(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionIdentificationAttribute::setMail(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMail", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::setMail(const QByteArray&)
            cppSelf->setMail(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::setName(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionIdentificationAttribute::setName(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::setName(const QByteArray&)
            cppSelf->setName(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_setOu(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionIdentificationAttribute::setOu(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionIdentificationAttribute::setOu(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOu", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionIdentificationAttribute::setOu(const QByteArray&)
            cppSelf->setOu(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionIdentificationAttributeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::type()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->::Akonadi::CollectionIdentificationAttribute::type()
            : const_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_CollectionIdentificationAttribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CollectionIdentificationAttribute_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_clone), METH_NOARGS, nullptr},
    {"collectionNamespace", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_collectionNamespace), METH_NOARGS, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_deserialize), METH_O, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_identifier), METH_NOARGS, nullptr},
    {"mail", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_mail), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_name), METH_NOARGS, nullptr},
    {"ou", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_ou), METH_NOARGS, nullptr},
    {"serialized", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_serialized), METH_NOARGS, nullptr},
    {"setCollectionNamespace", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_setCollectionNamespace), METH_O, nullptr},
    {"setIdentifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_setIdentifier), METH_O, nullptr},
    {"setMail", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_setMail), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_setName), METH_O, nullptr},
    {"setOu", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_setOu), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionIdentificationAttributeFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_CollectionIdentificationAttribute_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::CollectionIdentificationAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<CollectionIdentificationAttributeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_CollectionIdentificationAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CollectionIdentificationAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CollectionIdentificationAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionIdentificationAttribute_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionIdentificationAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CollectionIdentificationAttribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CollectionIdentificationAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionIdentificationAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CollectionIdentificationAttribute_spec = {
    "1:AkonadiCore.Akonadi.CollectionIdentificationAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CollectionIdentificationAttribute_slots
};

} //extern "C"

static void *Sbk_Akonadi_CollectionIdentificationAttribute_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::Akonadi::Attribute >())
        return dynamic_cast< ::Akonadi::CollectionIdentificationAttribute *>(reinterpret_cast< ::Akonadi::Attribute *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CollectionIdentificationAttribute_PythonToCpp_CollectionIdentificationAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CollectionIdentificationAttribute_PythonToCpp_CollectionIdentificationAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF()))
        return CollectionIdentificationAttribute_PythonToCpp_CollectionIdentificationAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CollectionIdentificationAttribute_PTR_CppToPython_CollectionIdentificationAttribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_CollectionIdentificationAttribute_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::CollectionIdentificationAttribute *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_CollectionIdentificationAttribute_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_CollectionIdentificationAttribute_SignatureStrings[] = {
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute(self,identifier:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),folderNamespace:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),name:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),organizationUnit:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),mail:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.clone(self)->AkonadiCore.Akonadi.Attribute",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.collectionNamespace(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.deserialize(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.identifier(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.mail(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.name(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.ou(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.serialized(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.setCollectionNamespace(self,ns:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.setIdentifier(self,identifier:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.setMail(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.setName(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.setOu(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.CollectionIdentificationAttribute.type(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_CollectionIdentificationAttribute_SignatureByteSize = 278;
static constexpr uint8_t Akonadi_CollectionIdentificationAttribute_SignatureBytes[278] = {
    0x78, 0xda, 0xc5, 0x94, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfc, 0x0a, 0x8e, 0x2b, 0x0a,
    0x95, 0xb8, 0x70, 0x40, 0x02, 0xa9, 0xf4, 0xb4, 0x03, 0x83, 0x09, 0x71, 0x42, 0x68, 0x32, 0x89,
    0x5b, 0x2c, 0xb2, 0x64, 0x72, 0xdd, 0x43, 0xf7, 0xeb, 0x49, 0xb7, 0xb5, 0x13, 0x12, 0x93, 0xa0,
    0x55, 0xca, 0x2d, 0x1f, 0xd6, 0xf3, 0xc6, 0xf6, 0xeb, 0x64, 0x9f, 0xde, 0x81, 0xa1, 0xdc, 0x33,
    0xa6, 0xd9, 0x7e, 0x9d, 0xe6, 0xde, 0x5a, 0xd4, 0x42, 0xde, 0xcd, 0x0d, 0x3a, 0xa1, 0x82, 0x34,
    0xb4, 0xbb, 0x4c, 0x84, 0xe9, 0xbd, 0x16, 0x9c, 0x55, 0x68, 0x0b, 0x45, 0x87, 0x4b, 0xe4, 0x1b,
    0x69, 0x36, 0xe4, 0xca, 0xf4, 0xc5, 0x85, 0xa8, 0xd7, 0xa7, 0xe6, 0x39, 0x5c, 0x5d, 0xa7, 0x4b,
    0xd9, 0x51, 0x97, 0xf7, 0x8d, 0x60, 0xc6, 0x0c, 0x8d, 0x3a, 0xd7, 0x1f, 0xc0, 0x17, 0x6f, 0xb7,
    0xc7, 0xa3, 0x59, 0xa2, 0x0a, 0x6f, 0x0d, 0xf2, 0x02, 0xd6, 0x58, 0x6d, 0x40, 0xe3, 0x28, 0x96,
    0x0b, 0x94, 0x51, 0x00, 0xcf, 0x25, 0x38, 0xda, 0xee, 0xd2, 0x0d, 0x00, 0x19, 0x05, 0x5b, 0x03,
    0xd9, 0x31, 0x80, 0xe4, 0x2c, 0x1b, 0xd2, 0x9d, 0x54, 0x5b, 0xef, 0xf6, 0x3d, 0x4a, 0x2e, 0xef,
    0x7e, 0x42, 0xf4, 0xa1, 0x43, 0x05, 0xfa, 0x88, 0xbe, 0x6d, 0x9d, 0xdc, 0xc9, 0x0c, 0x07, 0x4a,
    0x19, 0xac, 0x90, 0x09, 0x2c, 0x6d, 0x0f, 0xae, 0x33, 0x20, 0xf0, 0xc7, 0xa2, 0x0e, 0xad, 0xe3,
    0xd1, 0xe0, 0xb1, 0xb2, 0x6b, 0x1d, 0x12, 0x8b, 0xdd, 0xce, 0x42, 0x2c, 0xb6, 0xaf, 0x63, 0x91,
    0xfb, 0x6e, 0x9b, 0x78, 0x0a, 0x92, 0x9f, 0xf0, 0xaf, 0x72, 0xd5, 0x44, 0xd6, 0x0a, 0x8f, 0x98,
    0x7f, 0x77, 0xd7, 0xf0, 0xef, 0x74, 0xc4, 0x1b, 0x1e, 0x3a, 0xff, 0x29, 0xe0, 0x72, 0xb5, 0xba,
    0x9a, 0x4e, 0x79, 0xd1, 0xb9, 0x73, 0x72, 0xe5, 0xc7, 0xfa, 0x1f, 0x74, 0x83, 0xca, 0x2f, 0x86,
    0xf1, 0x0b, 0x5f, 0x40, 0xcb, 0xbc
};
#endif

PyTypeObject *init_Akonadi_CollectionIdentificationAttribute(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionIdentificationAttribute_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_CollectionIdentificationAttribute_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CollectionIdentificationAttribute",
        "Akonadi::CollectionIdentificationAttribute*",
        &Sbk_Akonadi_CollectionIdentificationAttribute_spec,
        &Shiboken::callCppDestructor< Akonadi::CollectionIdentificationAttribute >,
        Sbk_Akonadi_CollectionIdentificationAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_CollectionIdentificationAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_CollectionIdentificationAttribute_SignatureBytes, Akonadi_CollectionIdentificationAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CollectionIdentificationAttribute_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CollectionIdentificationAttribute_PythonToCpp_CollectionIdentificationAttribute_PTR,
        is_CollectionIdentificationAttribute_PythonToCpp_CollectionIdentificationAttribute_PTR_Convertible,
        CollectionIdentificationAttribute_PTR_CppToPython_CollectionIdentificationAttribute);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionIdentificationAttribute");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionIdentificationAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionIdentificationAttribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionIdentificationAttribute");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionIdentificationAttribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionIdentificationAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::CollectionIdentificationAttribute).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(CollectionIdentificationAttributeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_CollectionIdentificationAttribute_typeDiscovery);

    qRegisterMetaType< ::Akonadi::CollectionIdentificationAttribute *>();

    return pyType;
}
