/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.AgentManagerInternal.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "agentmanagerinternaladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class AgentManagerInternalAdaptor
 */

AgentManagerInternalAdaptor::AgentManagerInternalAdaptor(AgentManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

AgentManagerInternalAdaptor::~AgentManagerInternalAdaptor()
{
    // destructor
}

void AgentManagerInternalAdaptor::addSearch(const QString &query, const QString &queryLanguage, qlonglong destination)
{
    // handle method call org.freedesktop.Akonadi.AgentManagerInternal.addSearch
    parent()->addSearch(query, queryLanguage, destination);
}

void AgentManagerInternalAdaptor::removeSearch(qlonglong destination)
{
    // handle method call org.freedesktop.Akonadi.AgentManagerInternal.removeSearch
    parent()->removeSearch(destination);
}


#include "moc_agentmanagerinternaladaptor.cpp"
