/****************************************************************************
** Meta object code from reading C++ file 'resourceinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "resourceinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourceinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiResourceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiResourceInterface",
        "attributesSynchronized",
        "",
        "collectionId",
        "collectionTreeSynchronized",
        "nameChanged",
        "name",
        "synchronized",
        "activities",
        "QDBusPendingReply<QStringList>",
        "activitiesEnabled",
        "QDBusPendingReply<bool>",
        "QDBusPendingReply<QString>",
        "requestItemDelivery",
        "QDBusPendingReply<>",
        "QList<qlonglong>",
        "uids",
        "QByteArrayList",
        "parts",
        "setActivities",
        "setActivitiesEnabled",
        "en",
        "setName",
        "synchronize",
        "Q_NOREPLY",
        "synchronizeCollection",
        "recursive",
        "synchronizeCollectionAttributes",
        "synchronizeCollectionTree",
        "synchronizeTags",
        "taskList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'attributesSynchronized'
        QtMocHelpers::SignalData<void(qlonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Signal 'collectionTreeSynchronized'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'synchronized'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'activitiesEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'name'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(6, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'requestItemDelivery'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<qlonglong> &, const QByteArrayList &)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setActivities'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(19, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Slot 'setActivitiesEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(20, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'synchronize'
        QtMocHelpers::SlotData<void()>(23, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeCollection'
        QtMocHelpers::SlotData<void(qlonglong, bool)>(25, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'synchronizeCollection'
        QtMocHelpers::SlotData<void(qlonglong)>(25, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'synchronizeCollectionAttributes'
        QtMocHelpers::SlotData<void(qlonglong)>(27, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'synchronizeCollectionTree'
        QtMocHelpers::SlotData<void()>(28, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeTags'
        QtMocHelpers::SlotData<void()>(29, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'taskList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(30, 2, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiResourceInterface, qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiResourceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiResourceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiResourceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->attributesSynchronized((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: _t->collectionTreeSynchronized(); break;
        case 2: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->synchronized(); break;
        case 4: { QDBusPendingReply<QStringList> _r = _t->activities();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->activitiesEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QString> _r = _t->name();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->requestItemDelivery((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->setActivities((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->setActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->synchronize(); break;
        case 12: _t->synchronizeCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->synchronizeCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 14: _t->synchronizeCollectionAttributes((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 15: _t->synchronizeCollectionTree(); break;
        case 16: _t->synchronizeTags(); break;
        case 17: { QDBusPendingReply<QStringList> _r = _t->taskList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiResourceInterface::*)(qlonglong )>(_a, &OrgFreedesktopAkonadiResourceInterface::attributesSynchronized, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiResourceInterface::*)()>(_a, &OrgFreedesktopAkonadiResourceInterface::collectionTreeSynchronized, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiResourceInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiResourceInterface::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiResourceInterface::*)()>(_a, &OrgFreedesktopAkonadiResourceInterface::synchronized, 3))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiResourceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiResourceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopAkonadiResourceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiResourceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiResourceInterface::attributesSynchronized(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgFreedesktopAkonadiResourceInterface::collectionTreeSynchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgFreedesktopAkonadiResourceInterface::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgFreedesktopAkonadiResourceInterface::synchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
