
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_notificationsubscriber_wrapper.h"

// Argument includes
#include <QSet>
#include <QString>
#include <collectionfetchscope.h>
#include <itemfetchscope.h>
#include <monitor.h>
#include <notificationsubscriber.h>
#include <qbytearray.h>
#include <tagfetchscope.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_NotificationSubscriber_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_NotificationSubscriber_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::NotificationSubscriber >()))
        return -1;

    ::Akonadi::NotificationSubscriber *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "NotificationSubscriber", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: NotificationSubscriber::NotificationSubscriber()
    // 1: NotificationSubscriber::NotificationSubscriber(const Akonadi::NotificationSubscriber&)
    if (numArgs == 0) {
        overloadId = 0; // NotificationSubscriber()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), (pyArgs[0])))) {
        overloadId = 1; // NotificationSubscriber::NotificationSubscriber(const Akonadi::NotificationSubscriber&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // NotificationSubscriber()
        {

            // NotificationSubscriber::NotificationSubscriber()
            cptr = new ::Akonadi::NotificationSubscriber();
            break;
        }
        case 1: // NotificationSubscriber(const Akonadi::NotificationSubscriber &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::NotificationSubscriber cppArg0_local;
            ::Akonadi::NotificationSubscriber *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // NotificationSubscriber::NotificationSubscriber(const Akonadi::NotificationSubscriber&)
                cptr = new ::Akonadi::NotificationSubscriber(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::NotificationSubscriber >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_collectionFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::collectionFetchScope()const->Akonadi::CollectionFetchScope
        Akonadi::CollectionFetchScope cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->collectionFetchScope();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_ignoredSessions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::ignoredSessions()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->ignoredSessions();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_isAllMonitored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::isAllMonitored()const->bool
        bool cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->isAllMonitored();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_isExclusive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::isExclusive()const->bool
        bool cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->isExclusive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_itemFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::itemFetchScope()const->Akonadi::ItemFetchScope
        Akonadi::ItemFetchScope cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->itemFetchScope();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredCollections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredCollections()const->QSet<qint64>
        QSet<qint64> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredCollections();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredItems()const->QSet<qint64>
        QSet<qint64> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredMimeTypes()const->QSet<QString>
        QSet<QString> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredResources()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredResources();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredTags()const->QSet<qint64>
        QSet<qint64> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredTags();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_monitoredTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::monitoredTypes()const->QSet<Akonadi::Monitor::Type>
        QSet<Akonadi::Monitor::Type> cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->monitoredTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_Akonadi_Monitor_Type_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_sessionId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::sessionId()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->sessionId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setCollectionFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::CollectionFetchScope cppArg0_local;
        ::Akonadi::CollectionFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setCollectionFetchScope(const Akonadi::CollectionFetchScope&)
            cppSelf->setCollectionFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setIgnoredSessions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setIgnoredSessions(const QSet<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setIgnoredSessions(const QSet<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIgnoredSessions", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setIgnoredSessions(const QSet<QByteArray>&)
            cppSelf->setIgnoredSessions(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setIsAllMonitored(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setIsAllMonitored(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setIsAllMonitored(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIsAllMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setIsAllMonitored(bool)
            cppSelf->setIsAllMonitored(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setIsExclusive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setIsExclusive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setIsExclusive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIsExclusive", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setIsExclusive(bool)
            cppSelf->setIsExclusive(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setItemFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setItemFetchScope(const Akonadi::ItemFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setItemFetchScope(const Akonadi::ItemFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::ItemFetchScope cppArg0_local;
        ::Akonadi::ItemFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setItemFetchScope(const Akonadi::ItemFetchScope&)
            cppSelf->setItemFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredCollections(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredCollections(const QSet<qint64>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredCollections(const QSet<qint64>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredCollections", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<qint64> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredCollections(const QSet<qint64>&)
            cppSelf->setMonitoredCollections(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredItems(const QSet<qint64>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredItems(const QSet<qint64>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredItems", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<qint64> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredItems(const QSet<qint64>&)
            cppSelf->setMonitoredItems(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredMimeTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredMimeTypes(const QSet<QString>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QString_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredMimeTypes(const QSet<QString>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredMimeTypes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<QString> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredMimeTypes(const QSet<QString>&)
            cppSelf->setMonitoredMimeTypes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredResources(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredResources(const QSet<QByteArray>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredResources(const QSet<QByteArray>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredResources", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredResources(const QSet<QByteArray>&)
            cppSelf->setMonitoredResources(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredTags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredTags(const QSet<qint64>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_qint64_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredTags(const QSet<qint64>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredTags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<qint64> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredTags(const QSet<qint64>&)
            cppSelf->setMonitoredTags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setMonitoredTypes(const QSet<Akonadi::Monitor::Type>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_Akonadi_Monitor_Type_IDX], (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setMonitoredTypes(const QSet<Akonadi::Monitor::Type>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMonitoredTypes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        ::QSet<Akonadi::Monitor::Type> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setMonitoredTypes(const QSet<Akonadi::Monitor::Type>&)
            cppSelf->setMonitoredTypes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setSessionId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setSessionId(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setSessionId(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSessionId", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setSessionId(const QByteArray&)
            cppSelf->setSessionId(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setSubscriber(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setSubscriber(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setSubscriber(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubscriber", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setSubscriber(const QByteArray&)
            cppSelf->setSubscriber(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_setTagFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: NotificationSubscriber::setTagFetchScope(const Akonadi::TagFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // NotificationSubscriber::setTagFetchScope(const Akonadi::TagFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTagFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::TagFetchScope cppArg0_local;
        ::Akonadi::TagFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // NotificationSubscriber::setTagFetchScope(const Akonadi::TagFetchScope&)
            cppSelf->setTagFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_subscriber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::subscriber()const->QByteArray
        QByteArray cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->subscriber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriberFunc_tagFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // NotificationSubscriber::tagFetchScope()const->Akonadi::TagFetchScope
        Akonadi::TagFetchScope cppResult = const_cast<const ::Akonadi::NotificationSubscriber *>(cppSelf)->tagFetchScope();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_NotificationSubscriber__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_NotificationSubscriber_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_NotificationSubscriber_methods[] = {
    {"collectionFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_collectionFetchScope), METH_NOARGS, nullptr},
    {"ignoredSessions", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_ignoredSessions), METH_NOARGS, nullptr},
    {"isAllMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_isAllMonitored), METH_NOARGS, nullptr},
    {"isExclusive", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_isExclusive), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_isValid), METH_NOARGS, nullptr},
    {"itemFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_itemFetchScope), METH_NOARGS, nullptr},
    {"monitoredCollections", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredCollections), METH_NOARGS, nullptr},
    {"monitoredItems", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredItems), METH_NOARGS, nullptr},
    {"monitoredMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredMimeTypes), METH_NOARGS, nullptr},
    {"monitoredResources", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredResources), METH_NOARGS, nullptr},
    {"monitoredTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredTags), METH_NOARGS, nullptr},
    {"monitoredTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_monitoredTypes), METH_NOARGS, nullptr},
    {"sessionId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_sessionId), METH_NOARGS, nullptr},
    {"setCollectionFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setCollectionFetchScope), METH_O, nullptr},
    {"setIgnoredSessions", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setIgnoredSessions), METH_O, nullptr},
    {"setIsAllMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setIsAllMonitored), METH_O, nullptr},
    {"setIsExclusive", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setIsExclusive), METH_O, nullptr},
    {"setItemFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setItemFetchScope), METH_O, nullptr},
    {"setMonitoredCollections", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredCollections), METH_O, nullptr},
    {"setMonitoredItems", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredItems), METH_O, nullptr},
    {"setMonitoredMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredMimeTypes), METH_O, nullptr},
    {"setMonitoredResources", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredResources), METH_O, nullptr},
    {"setMonitoredTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredTags), METH_O, nullptr},
    {"setMonitoredTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setMonitoredTypes), METH_O, nullptr},
    {"setSessionId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setSessionId), METH_O, nullptr},
    {"setSubscriber", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setSubscriber), METH_O, nullptr},
    {"setTagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_setTagFetchScope), METH_O, nullptr},
    {"subscriber", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_subscriber), METH_NOARGS, nullptr},
    {"tagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriberFunc_tagFetchScope), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_NotificationSubscriber__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_NotificationSubscriber_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_NotificationSubscriber_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_NotificationSubscriber_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_NotificationSubscriber_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_NotificationSubscriber_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_NotificationSubscriber_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_NotificationSubscriber_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_NotificationSubscriber_spec = {
    "1:AkonadiCore.Akonadi.NotificationSubscriber",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_NotificationSubscriber_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void NotificationSubscriber_PythonToCpp_NotificationSubscriber_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_NotificationSubscriber_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_NotificationSubscriber_PythonToCpp_NotificationSubscriber_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_NotificationSubscriber_TypeF()))
        return NotificationSubscriber_PythonToCpp_NotificationSubscriber_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *NotificationSubscriber_PTR_CppToPython_NotificationSubscriber(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_NotificationSubscriber_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_NotificationSubscriber_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *NotificationSubscriber_COPY_CppToPython_NotificationSubscriber(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::NotificationSubscriber *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_NotificationSubscriber_TypeF(), new ::Akonadi::NotificationSubscriber(*source), true, true);
}

// Python to C++ copy conversion.
static void NotificationSubscriber_PythonToCpp_NotificationSubscriber_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::NotificationSubscriber *>(cppOut) = *reinterpret_cast< ::Akonadi::NotificationSubscriber *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_NotificationSubscriber_PythonToCpp_NotificationSubscriber_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_NotificationSubscriber_TypeF()))
        return NotificationSubscriber_PythonToCpp_NotificationSubscriber_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_NotificationSubscriber_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.NotificationSubscriber(self)",
    "0:AkonadiCore.Akonadi.NotificationSubscriber(self,other:AkonadiCore.Akonadi.NotificationSubscriber)",
    "AkonadiCore.Akonadi.NotificationSubscriber.collectionFetchScope(self)->AkonadiCore.Akonadi.CollectionFetchScope",
    "AkonadiCore.Akonadi.NotificationSubscriber.ignoredSessions(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.NotificationSubscriber.isAllMonitored(self)->bool",
    "AkonadiCore.Akonadi.NotificationSubscriber.isExclusive(self)->bool",
    "AkonadiCore.Akonadi.NotificationSubscriber.isValid(self)->bool",
    "AkonadiCore.Akonadi.NotificationSubscriber.itemFetchScope(self)->AkonadiCore.Akonadi.ItemFetchScope",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredCollections(self)->QSet[qint64]",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredItems(self)->QSet[qint64]",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredMimeTypes(self)->QSet[QString]",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredResources(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredTags(self)->QSet[qint64]",
    "AkonadiCore.Akonadi.NotificationSubscriber.monitoredTypes(self)->QSet[AkonadiCore.Akonadi.Monitor.Type]",
    "AkonadiCore.Akonadi.NotificationSubscriber.sessionId(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.NotificationSubscriber.setCollectionFetchScope(self,collectionFetchScope:AkonadiCore.Akonadi.CollectionFetchScope)",
    "AkonadiCore.Akonadi.NotificationSubscriber.setIgnoredSessions(self,ignoredSessions:QSet[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setIsAllMonitored(self,isAllMonitored:bool)",
    "AkonadiCore.Akonadi.NotificationSubscriber.setIsExclusive(self,isExclusive:bool)",
    "AkonadiCore.Akonadi.NotificationSubscriber.setItemFetchScope(self,itemFetchScope:AkonadiCore.Akonadi.ItemFetchScope)",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredCollections(self,collections:QSet[qint64])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredItems(self,items:QSet[qint64])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredMimeTypes(self,mimeTypes:QSet[QString])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredResources(self,resources:QSet[PySide6.QtCore.QByteArray])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredTags(self,tags:QSet[qint64])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setMonitoredTypes(self,type:QSet[AkonadiCore.Akonadi.Monitor.Type])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setSessionId(self,sessionId:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setSubscriber(self,subscriber:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCore.Akonadi.NotificationSubscriber.setTagFetchScope(self,tagFetchScope:AkonadiCore.Akonadi.TagFetchScope)",
    "AkonadiCore.Akonadi.NotificationSubscriber.subscriber(self)->PySide6.QtCore.QByteArray",
    "AkonadiCore.Akonadi.NotificationSubscriber.tagFetchScope(self)->AkonadiCore.Akonadi.TagFetchScope",
    "AkonadiCore.Akonadi.NotificationSubscriber.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_NotificationSubscriber_SignatureByteSize = 459;
static constexpr uint8_t Akonadi_NotificationSubscriber_SignatureBytes[459] = {
    0x78, 0xda, 0xb5, 0x96, 0xcf, 0x4f, 0xc2, 0x30, 0x14, 0xc7, 0xef, 0xfc, 0x15, 0x1e, 0xc5, 0xd4,
    0x45, 0x13, 0xc3, 0x61, 0x07, 0x13, 0x24, 0x9a, 0x70, 0x98, 0x71, 0x16, 0xbd, 0x18, 0xb2, 0x8c,
    0xf2, 0x80, 0xc6, 0x6e, 0xc5, 0xb6, 0x18, 0xf7, 0xdf, 0xdb, 0xc1, 0x06, 0xeb, 0x7e, 0x84, 0x75,
    0x19, 0xb7, 0x76, 0x6b, 0xbf, 0xdf, 0xb7, 0xf7, 0x5e, 0x3f, 0xeb, 0xbd, 0x3b, 0xfe, 0xe6, 0x71,
    0xb8, 0xa4, 0x13, 0x2e, 0xc0, 0xc9, 0xc6, 0xce, 0x2b, 0x57, 0x74, 0x45, 0x49, 0xa8, 0x28, 0x8f,
    0xf1, 0x6e, 0x21, 0x89, 0xa0, 0x0b, 0x10, 0xd7, 0x12, 0xd8, 0x6a, 0x38, 0xb8, 0xb3, 0xdd, 0x82,
    0xb8, 0xda, 0x80, 0xb0, 0xd8, 0x35, 0x1c, 0xb4, 0x5f, 0xeb, 0x10, 0xce, 0x18, 0x90, 0xf4, 0xe1,
    0x0b, 0x28, 0xb2, 0xc1, 0x84, 0x6f, 0xe1, 0x10, 0xe9, 0xed, 0x63, 0x9d, 0xcc, 0xa4, 0x66, 0xbd,
    0x8d, 0x1f, 0x5d, 0xc7, 0x7a, 0xd5, 0x12, 0x83, 0x94, 0xfa, 0x85, 0xcc, 0xad, 0x7c, 0x0c, 0xea,
    0xeb, 0x2d, 0xc1, 0x74, 0x09, 0x23, 0xc7, 0x57, 0x7b, 0x25, 0xff, 0x29, 0x51, 0x30, 0x16, 0x22,
    0x4c, 0xe6, 0x56, 0x0e, 0x72, 0xcc, 0x98, 0xc7, 0x63, 0xaa, 0x52, 0xa3, 0xdc, 0x60, 0xc1, 0x39,
    0xb3, 0x53, 0x79, 0xfe, 0x23, 0x6c, 0x27, 0xe9, 0x2f, 0x74, 0x97, 0xf8, 0x0c, 0x19, 0xed, 0x1e,
    0x81, 0x82, 0xa8, 0x5d, 0x4d, 0xa6, 0xc6, 0x4a, 0x1b, 0x8f, 0x28, 0x4f, 0xd3, 0xa9, 0xac, 0x66,
    0x49, 0x7e, 0x68, 0xac, 0x46, 0x0f, 0xf3, 0x4e, 0x9a, 0x69, 0x58, 0xfd, 0xa9, 0x79, 0x34, 0x82,
    0x59, 0xb2, 0x05, 0x53, 0xd1, 0xc7, 0x4a, 0xd0, 0x78, 0xdd, 0x4d, 0xf2, 0x1d, 0x24, 0xdf, 0x09,
    0x02, 0x97, 0xe8, 0xc2, 0xa3, 0xc9, 0x2c, 0x5c, 0xf7, 0x97, 0x84, 0x6a, 0x02, 0xea, 0x54, 0xb2,
    0xe6, 0x77, 0xd2, 0xd5, 0x56, 0x3e, 0xf2, 0x70, 0x2a, 0xa7, 0xc7, 0x9e, 0x6d, 0xcc, 0x85, 0x9d,
    0xaa, 0x9a, 0x34, 0x51, 0x06, 0xd5, 0xf1, 0xc7, 0x6d, 0x0b, 0x9e, 0xa1, 0x65, 0x18, 0xd3, 0x1a,
    0xf8, 0xa0, 0x12, 0x91, 0xdc, 0x33, 0x4d, 0x60, 0xed, 0x59, 0xc5, 0x11, 0x32, 0x11, 0xe5, 0xa6,
    0x64, 0xb0, 0x97, 0x35, 0xf9, 0x84, 0x0a, 0xc0, 0xea, 0x26, 0x58, 0xc5, 0x0d, 0x32, 0x11, 0xe4,
    0x9e, 0x67, 0x8f, 0xad, 0xa9, 0xd7, 0xc4, 0x9f, 0x42, 0x5f, 0x64, 0x15, 0xc9, 0x8e, 0x4d, 0x67,
    0x87, 0x13, 0x8d, 0xf6, 0x9f, 0xd5, 0x93, 0xaa, 0x49, 0x25, 0x14, 0xe5, 0x53, 0xd7, 0xa0, 0x53,
    0x67, 0x79, 0x93, 0x50, 0x48, 0xe4, 0xd3, 0xbe, 0x9b, 0xd4, 0xab, 0xd0, 0x0a, 0x29, 0x3d, 0xea,
    0x27, 0x47, 0x85, 0xfc, 0x28, 0x3d, 0x74, 0xdb, 0x71, 0xcb, 0xd6, 0x0e, 0x1b, 0xec, 0x42, 0x47,
    0x94, 0xb9, 0xda, 0x53, 0xd7, 0xc0, 0xf9, 0x88, 0xf5, 0xb4, 0x39, 0x65, 0xe8, 0x8a, 0x6c, 0x42,
    0x71, 0x63, 0x6f, 0x5b, 0xba, 0xac, 0xc9, 0xe3, 0xfc, 0xc2, 0xc6, 0xba, 0x52, 0xe5, 0xe3, 0xaa,
    0x8a, 0x8f, 0x6a, 0x4f, 0xab, 0xb1, 0xc9, 0xce, 0xb1, 0x74, 0x8f, 0xed, 0xe9, 0xdf, 0xa0, 0x2a,
    0x5f, 0xd1, 0x70, 0xc7, 0x31, 0x22, 0xb7, 0x71, 0x08, 0x02, 0xbd, 0x23, 0x09, 0x82, 0x5c, 0x3c,
    0xab, 0x4a, 0x80, 0xf5, 0x74, 0xf0, 0x0f, 0x6f, 0x77, 0x69, 0x50
};
#endif

PyTypeObject *init_Akonadi_NotificationSubscriber(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_NotificationSubscriber_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_NotificationSubscriber_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "NotificationSubscriber",
        "Akonadi::NotificationSubscriber",
        &Sbk_Akonadi_NotificationSubscriber_spec,
        &Shiboken::callCppDestructor< ::Akonadi::NotificationSubscriber >,
        Sbk_Akonadi_NotificationSubscriber_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_NotificationSubscriber_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_NotificationSubscriber_SignatureBytes, Akonadi_NotificationSubscriber_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_NotificationSubscriber_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        NotificationSubscriber_PythonToCpp_NotificationSubscriber_PTR,
        is_NotificationSubscriber_PythonToCpp_NotificationSubscriber_PTR_Convertible,
        NotificationSubscriber_PTR_CppToPython_NotificationSubscriber,
        NotificationSubscriber_COPY_CppToPython_NotificationSubscriber);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::NotificationSubscriber");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::NotificationSubscriber*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::NotificationSubscriber&");
    Shiboken::Conversions::registerConverterAlias(converter, "NotificationSubscriber");
    Shiboken::Conversions::registerConverterAlias(converter, "NotificationSubscriber*");
    Shiboken::Conversions::registerConverterAlias(converter, "NotificationSubscriber&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::NotificationSubscriber).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        NotificationSubscriber_PythonToCpp_NotificationSubscriber_COPY,
        is_NotificationSubscriber_PythonToCpp_NotificationSubscriber_COPY_Convertible);

    qRegisterMetaType< ::Akonadi::NotificationSubscriber >("NotificationSubscriber");
    qRegisterMetaType< ::Akonadi::NotificationSubscriber >("Akonadi::NotificationSubscriber");

    return pyType;
}
