/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/quick/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CollectionForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionForeign::qt_create_metaobjectdata<qt_meta_tag_ZN17CollectionForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionForeign",
        "QML.Foreign",
        "Akonadi:: Collection",
        "QML.Element",
        "collection"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CollectionForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CollectionForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CollectionForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17CollectionDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionDerived::qt_create_metaobjectdata<qt_meta_tag_ZN17CollectionDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CollectionDerived, qt_meta_tag_ZN17CollectionDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CollectionDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<Akonadi::Collection>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CollectionDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11ItemForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemForeign::qt_create_metaobjectdata<qt_meta_tag_ZN11ItemForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemForeign",
        "QML.Foreign",
        "Akonadi:: Item",
        "QML.Element",
        "item"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ItemForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ItemForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ItemForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ItemForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ItemForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11ItemDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemDerived::qt_create_metaobjectdata<qt_meta_tag_ZN11ItemDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemDerived, qt_meta_tag_ZN11ItemDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<Akonadi::Item>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ItemDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ItemDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ItemDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22EntityTreeModelForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto EntityTreeModelForeign::qt_create_metaobjectdata<qt_meta_tag_ZN22EntityTreeModelForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EntityTreeModelForeign",
        "QML.Element",
        "EntityTreeModel",
        "QML.Foreign",
        "Akonadi::EntityTreeModel",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Only enums"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<EntityTreeModelForeign, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EntityTreeModelForeign::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EntityTreeModelForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EntityTreeModelForeignE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22EntityTreeModelForeignE_t>.metaTypes,
    nullptr
} };

void EntityTreeModelForeign::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EntityTreeModelForeign *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EntityTreeModelForeign::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EntityTreeModelForeign::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EntityTreeModelForeignE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EntityTreeModelForeign::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN20AgentInstanceForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentInstanceForeign::qt_create_metaobjectdata<qt_meta_tag_ZN20AgentInstanceForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentInstanceForeign",
        "QML.Element",
        "agentInstance",
        "QML.Foreign",
        "Akonadi::AgentInstance"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AgentInstanceForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AgentInstanceForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AgentInstanceForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AgentInstanceForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AgentInstanceForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18SpecialCollectionsE_t {};
} // unnamed namespace

template <> constexpr inline auto SpecialCollections::qt_create_metaobjectdata<qt_meta_tag_ZN18SpecialCollectionsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpecialCollections",
        "QML.Element",
        "QML.Foreign",
        "Akonadi::SpecialCollections",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Abstract class"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<SpecialCollections, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SpecialCollections::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SpecialCollectionsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SpecialCollectionsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SpecialCollectionsE_t>.metaTypes,
    nullptr
} };

void SpecialCollections::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpecialCollections *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SpecialCollections::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpecialCollections::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SpecialCollectionsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SpecialCollections::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentFilterProxyModelForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentFilterProxyModelForeign",
        "QML.Element",
        "AgentFilterProxyModel",
        "QML.Foreign",
        "Akonadi::AgentFilterProxyModel",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "C++ only"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<AgentFilterProxyModelForeign, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AgentFilterProxyModelForeign::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t>.metaTypes,
    nullptr
} };

void AgentFilterProxyModelForeign::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentFilterProxyModelForeign *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *AgentFilterProxyModelForeign::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AgentFilterProxyModelForeign::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28AgentFilterProxyModelForeignE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AgentFilterProxyModelForeign::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN24CollectionDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN24CollectionDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionDerivedForeign",
        "QML.Element",
        "Collection",
        "QML.Foreign",
        "CollectionDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN24CollectionDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN24CollectionDerivedForeignE =
    CollectionDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN24CollectionDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN24CollectionDerivedForeignE =
    qt_staticMetaObjectContent_ZN24CollectionDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN24CollectionDerivedForeignE =
    qt_staticMetaObjectContent_ZN24CollectionDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject CollectionDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN24CollectionDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN24CollectionDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN24CollectionDerivedForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18ItemDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18ItemDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemDerivedForeign",
        "QML.Element",
        "Item",
        "QML.Foreign",
        "ItemDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN18ItemDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN18ItemDerivedForeignE =
    ItemDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18ItemDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN18ItemDerivedForeignE =
    qt_staticMetaObjectContent_ZN18ItemDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN18ItemDerivedForeignE =
    qt_staticMetaObjectContent_ZN18ItemDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject ItemDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN18ItemDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN18ItemDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN18ItemDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
