/********************************************************************************
** Form generated from reading UI file 'collectionmaintenancepage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLECTIONMAINTENANCEPAGE_H
#define UI_COLLECTIONMAINTENANCEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CollectionMaintenancePage
{
public:
    QFormLayout *verticalLayout;
    QLabel *label;
    QLabel *folderTypeLbl;
    QLabel *folderSizeLbl;
    QLabel *label_3;
    QLabel *label_5;
    QLabel *itemsCountLbl;
    QLabel *label_7;
    QLabel *unreadItemsCountLbl;
    QLabel *indexingLabel;
    QCheckBox *enableIndexingChkBox;
    QLabel *indexedCountLbl;
    QPushButton *reindexButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CollectionMaintenancePage)
    {
        if (CollectionMaintenancePage->objectName().isEmpty())
            CollectionMaintenancePage->setObjectName("CollectionMaintenancePage");
        CollectionMaintenancePage->resize(468, 371);
        verticalLayout = new QFormLayout(CollectionMaintenancePage);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(CollectionMaintenancePage);
        label->setObjectName("label");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        folderTypeLbl = new QLabel(CollectionMaintenancePage);
        folderTypeLbl->setObjectName("folderTypeLbl");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, folderTypeLbl);

        folderSizeLbl = new QLabel(CollectionMaintenancePage);
        folderSizeLbl->setObjectName("folderSizeLbl");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, folderSizeLbl);

        label_3 = new QLabel(CollectionMaintenancePage);
        label_3->setObjectName("label_3");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        label_5 = new QLabel(CollectionMaintenancePage);
        label_5->setObjectName("label_5");

        verticalLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        itemsCountLbl = new QLabel(CollectionMaintenancePage);
        itemsCountLbl->setObjectName("itemsCountLbl");

        verticalLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, itemsCountLbl);

        label_7 = new QLabel(CollectionMaintenancePage);
        label_7->setObjectName("label_7");

        verticalLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        unreadItemsCountLbl = new QLabel(CollectionMaintenancePage);
        unreadItemsCountLbl->setObjectName("unreadItemsCountLbl");

        verticalLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, unreadItemsCountLbl);

        indexingLabel = new QLabel(CollectionMaintenancePage);
        indexingLabel->setObjectName("indexingLabel");

        verticalLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, indexingLabel);

        enableIndexingChkBox = new QCheckBox(CollectionMaintenancePage);
        enableIndexingChkBox->setObjectName("enableIndexingChkBox");

        verticalLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, enableIndexingChkBox);

        indexedCountLbl = new QLabel(CollectionMaintenancePage);
        indexedCountLbl->setObjectName("indexedCountLbl");

        verticalLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, indexedCountLbl);

        reindexButton = new QPushButton(CollectionMaintenancePage);
        reindexButton->setObjectName("reindexButton");

        verticalLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, reindexButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->setItem(7, QFormLayout::ItemRole::LabelRole, verticalSpacer);


        retranslateUi(CollectionMaintenancePage);

        QMetaObject::connectSlotsByName(CollectionMaintenancePage);
    } // setupUi

    void retranslateUi(QWidget *CollectionMaintenancePage)
    {
        label->setText(tr2i18n("Folder type:", nullptr));
        folderTypeLbl->setText(tr2i18n("unknown", nullptr));
        folderSizeLbl->setText(tr2i18n("unknown", nullptr));
        label_3->setText(tr2i18n("File size:", nullptr));
        label_5->setText(tr2i18n("Total items:", nullptr));
        itemsCountLbl->setText(tr2i18n("unknown", nullptr));
        label_7->setText(tr2i18n("Unread items:", nullptr));
        unreadItemsCountLbl->setText(tr2i18n("unknown", nullptr));
        indexingLabel->setText(tr2i18n("Indexing:", nullptr));
        enableIndexingChkBox->setText(tr2i18n("Enable fulltext indexing", nullptr));
        indexedCountLbl->setText(tr2i18n("Retrieving indexed items count...", nullptr));
        reindexButton->setText(tr2i18n("Reindex folder", nullptr));
        (void)CollectionMaintenancePage;
    } // retranslateUi

};

namespace Ui {
    class CollectionMaintenancePage: public Ui_CollectionMaintenancePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLLECTIONMAINTENANCEPAGE_H

