/****************************************************************************
** Meta object code from reading C++ file 'storagedebuggeradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "storagedebuggeradaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagedebuggeradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22StorageDebuggerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto StorageDebuggerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorageDebuggerAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.StorageDebugger",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.StorageDebugger\">\n  "
        "  <method name=\"enableSQLDebugging\">\n      <arg direction=\"in\""
        " type=\"b\" name=\"enable\"/>\n    </method>\n    <method name=\"i"
        "sSQLDebuggingEnabled\">\n      <arg direction=\"out\" type=\"b\"/>"
        "\n    </method>\n    <signal name=\"connectionOpened\">\n      <ar"
        "g direction=\"out\" type=\"x\" name=\"id\"/>\n      <arg direction"
        "=\"out\" type=\"s\" name=\"name\"/>\n      <arg direction=\"out\" "
        "type=\"x\" name=\"timestamp\"/>\n    </signal>\n    <signal name=\""
        "connectionChanged\">\n      <arg direction=\"out\" type=\"x\" name"
        "=\"id\"/>\n      <arg direction=\"out\" type=\"s\" name=\"name\"/>"
        "\n    </signal>\n    <signal name=\"connectionClosed\">\n      <ar"
        "g direction=\"out\" type=\"x\" name=\"id\"/>\n      <arg direction"
        "=\"out\" type=\"x\" name=\"timestamp\"/>\n    </signal>\n    <sign"
        "al name=\"transactionStarted\">\n      <arg direction=\"out\" type"
        "=\"x\" name=\"connectionId\"/>\n      <arg direction=\"out\" type="
        "\"s\" name=\"name\"/>\n      <arg direction=\"out\" type=\"x\" nam"
        "e=\"timestamp\"/>\n      <arg direction=\"out\" type=\"u\" name=\""
        "duration\"/>\n      <arg direction=\"out\" type=\"s\" name=\"error"
        "\"/>\n    </signal>\n    <signal name=\"transactionFinished\">\n  "
        "    <arg direction=\"out\" type=\"x\" name=\"connectionId\"/>\n   "
        "   <arg direction=\"out\" type=\"b\" name=\"commit\"/>\n      <arg"
        " direction=\"out\" type=\"x\" name=\"timestamp\"/>\n      <arg dir"
        "ection=\"out\" type=\"u\" name=\"duration\"/>\n      <arg directio"
        "n=\"out\" type=\"s\" name=\"error\"/>\n    </signal>\n    <method "
        "name=\"connections\">\n      <arg direction=\"out\" type=\"a(xsxsx"
        ")\"/>\n      <annotation value=\"QList&lt;DbConnection&gt;\" name="
        "\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <si"
        "gnal name=\"queryExecuted\">\n      <arg direction=\"out\" type=\""
        "d\" name=\"sequence\"/>\n      <arg direction=\"out\" type=\"x\" n"
        "ame=\"connectionId\"/>\n      <arg type=\"x\" name=\"timestamp\"/>"
        "\n      <arg direction=\"out\" type=\"u\" name=\"duration\"/>\n   "
        "   <arg direction=\"out\" type=\"s\" name=\"query\"/>\n      <anno"
        "tation value=\"const QMap&lt;QString,QVariant&gt; &amp;\" name=\"o"
        "rg.qtproject.QtDBus.QtTypeName.Out5\"/>\n      <annotation value=\""
        "const QMap&lt;QString,QVariant&gt; &amp;\" name=\"org.qtproject.Qt"
        "DBus.QtTypeName.In5\"/>\n      <arg direction=\"out\" type=\"a{sv}"
        "\" name=\"values\"/>\n      <arg direction=\"out\" type=\"i\" name"
        "=\"resultsCount\"/>\n      <annotation value=\"const QList&lt;QLis"
        "t&lt;QVariant&gt; &gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeN"
        "ame.Out7\"/>\n      <annotation value=\"const QList&lt;QList&lt;QV"
        "ariant&gt; &gt; &amp;\" name=\"org.qtproject.QtDBus.QtTypeName.In7"
        "\"/>\n      <arg direction=\"out\" type=\"aav\" name=\"result\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"error\"/>\n    </si"
        "gnal>\n  </interface>\n",
        "connectionChanged",
        "",
        "id",
        "name",
        "connectionClosed",
        "timestamp",
        "connectionOpened",
        "queryExecuted",
        "sequence",
        "connectionId",
        "duration",
        "query",
        "QMap<QString,QVariant>",
        "values",
        "resultsCount",
        "QList<QList<QVariant>>",
        "result",
        "error",
        "transactionFinished",
        "commit",
        "transactionStarted",
        "connections",
        "QList<DbConnection>",
        "enableSQLDebugging",
        "enable",
        "isSQLDebuggingEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void(qlonglong, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'connectionClosed'
        QtMocHelpers::SignalData<void(qlonglong, qlonglong)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 }, { QMetaType::LongLong, 10 },
        }}),
        // Signal 'connectionOpened'
        QtMocHelpers::SignalData<void(qlonglong, const QString &, qlonglong)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 }, { QMetaType::QString, 8 }, { QMetaType::LongLong, 10 },
        }}),
        // Signal 'queryExecuted'
        QtMocHelpers::SignalData<void(double, qlonglong, qlonglong, uint, const QString &, const QMap<QString,QVariant> &, int, const QList<QList<QVariant> > &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 13 }, { QMetaType::LongLong, 14 }, { QMetaType::LongLong, 10 }, { QMetaType::UInt, 15 },
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 },
            { QMetaType::QString, 22 },
        }}),
        // Signal 'transactionFinished'
        QtMocHelpers::SignalData<void(qlonglong, bool, qlonglong, uint, const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 14 }, { QMetaType::Bool, 24 }, { QMetaType::LongLong, 10 }, { QMetaType::UInt, 15 },
            { QMetaType::QString, 22 },
        }}),
        // Signal 'transactionStarted'
        QtMocHelpers::SignalData<void(qlonglong, const QString &, qlonglong, uint, const QString &)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 14 }, { QMetaType::QString, 8 }, { QMetaType::LongLong, 10 }, { QMetaType::UInt, 15 },
            { QMetaType::QString, 22 },
        }}),
        // Slot 'connections'
        QtMocHelpers::SlotData<QList<DbConnection>()>(26, 6, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'enableSQLDebugging'
        QtMocHelpers::SlotData<void(bool)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'isSQLDebuggingEnabled'
        QtMocHelpers::SlotData<bool()>(30, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<StorageDebuggerAdaptor, qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject StorageDebuggerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>.metaTypes,
    nullptr
} };

void StorageDebuggerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageDebuggerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->connectionClosed((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 2: _t->connectionOpened((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 3: _t->queryExecuted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QVariant>>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QList<QList<QVariant>>>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9]))); break;
        case 4: _t->transactionFinished((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 5: _t->transactionStarted((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 6: { QList<DbConnection> _r = _t->connections();
            if (_a[0]) *reinterpret_cast<QList<DbConnection>*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->enableSQLDebugging((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: { bool _r = _t->isSQLDebuggingEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(qlonglong , const QString & )>(_a, &StorageDebuggerAdaptor::connectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(qlonglong , qlonglong )>(_a, &StorageDebuggerAdaptor::connectionClosed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(qlonglong , const QString & , qlonglong )>(_a, &StorageDebuggerAdaptor::connectionOpened, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(double , qlonglong , qlonglong , uint , const QString & , const QMap<QString,QVariant> & , int , const QList<QList<QVariant> > & , const QString & )>(_a, &StorageDebuggerAdaptor::queryExecuted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(qlonglong , bool , qlonglong , uint , const QString & )>(_a, &StorageDebuggerAdaptor::transactionFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebuggerAdaptor::*)(qlonglong , const QString & , qlonglong , uint , const QString & )>(_a, &StorageDebuggerAdaptor::transactionStarted, 5))
            return;
    }
}

const QMetaObject *StorageDebuggerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorageDebuggerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22StorageDebuggerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int StorageDebuggerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void StorageDebuggerAdaptor::connectionChanged(qlonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void StorageDebuggerAdaptor::connectionClosed(qlonglong _t1, qlonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void StorageDebuggerAdaptor::connectionOpened(qlonglong _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void StorageDebuggerAdaptor::queryExecuted(double _t1, qlonglong _t2, qlonglong _t3, uint _t4, const QString & _t5, const QMap<QString,QVariant> & _t6, int _t7, const QList<QList<QVariant> > & _t8, const QString & _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}

// SIGNAL 4
void StorageDebuggerAdaptor::transactionFinished(qlonglong _t1, bool _t2, qlonglong _t3, uint _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 5
void StorageDebuggerAdaptor::transactionStarted(qlonglong _t1, const QString & _t2, qlonglong _t3, uint _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5);
}
QT_WARNING_POP
