
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_accountactivitiesabstract_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"
#include "akonadi_specialcollectionsdiscoveryjob_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_AccountActivitiesAbstract_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void AccountActivitiesAbstractWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

AccountActivitiesAbstractWrapper::AccountActivitiesAbstractWrapper(::QObject * parent) : Akonadi::AccountActivitiesAbstract(parent)
{
}

void AccountActivitiesAbstractWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("AccountActivitiesAbstract", funcName, gil, pyOverride, event);
}

void AccountActivitiesAbstractWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("AccountActivitiesAbstract", funcName, gil, pyOverride, signal);
}

::QString AccountActivitiesAbstractWrapper::currentActivity() const
{
    static const char *funcName = "currentActivity";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.currentActivity");
        return ::QString();
    }
    return SpecialCollectionsDiscoveryJobWrapper::sbk_o_errorString("AccountActivitiesAbstract", funcName, gil, pyOverride);
}

void AccountActivitiesAbstractWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("AccountActivitiesAbstract", funcName, gil, pyOverride, event);
}

void AccountActivitiesAbstractWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("AccountActivitiesAbstract", funcName, gil, pyOverride, signal);
}

bool AccountActivitiesAbstractWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("AccountActivitiesAbstract", funcName, gil, pyOverride, event);
}

bool AccountActivitiesAbstractWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("AccountActivitiesAbstract", funcName, gil, pyOverride, watched, event);
}

bool AccountActivitiesAbstractWrapper::filterAcceptsRow(const ::QStringList & activities) const
{
    static const char *funcName = "filterAcceptsRow";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.filterAcceptsRow");
        return false;
    }
    return sbk_o_filterAcceptsRow("AccountActivitiesAbstract", funcName, gil, pyOverride, activities);
}

bool AccountActivitiesAbstractWrapper::sbk_o_filterAcceptsRow([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QStringList & activities)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &activities)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &activities)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool AccountActivitiesAbstractWrapper::hasActivitySupport() const
{
    static const char *funcName = "hasActivitySupport";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.hasActivitySupport");
        return false;
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("AccountActivitiesAbstract", funcName, gil, pyOverride);
}

void AccountActivitiesAbstractWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("AccountActivitiesAbstract", funcName, gil, pyOverride, event);
}

const QMetaObject *AccountActivitiesAbstractWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::AccountActivitiesAbstract::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int AccountActivitiesAbstractWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::AccountActivitiesAbstract::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *AccountActivitiesAbstractWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< AccountActivitiesAbstractWrapper *>(this));
    }
    return Akonadi::AccountActivitiesAbstract::qt_metacast(_clname);
}

AccountActivitiesAbstractWrapper::~AccountActivitiesAbstractWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_AccountActivitiesAbstract_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_AccountActivitiesAbstract_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("Akonadi::AccountActivitiesAbstract");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::AccountActivitiesAbstract >()))
        return -1;

    AccountActivitiesAbstractWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:AccountActivitiesAbstract", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: AccountActivitiesAbstract::AccountActivitiesAbstract(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // AccountActivitiesAbstract(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // AccountActivitiesAbstract::AccountActivitiesAbstract(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AccountActivitiesAbstract::AccountActivitiesAbstract(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) AccountActivitiesAbstractWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new AccountActivitiesAbstractWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::AccountActivitiesAbstract >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_AccountActivitiesAbstractFunc_currentActivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AccountActivitiesAbstract *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AccountActivitiesAbstract::currentActivity()const->QString
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.currentActivity");
            return {};
        }
        QString cppResult = const_cast<const ::Akonadi::AccountActivitiesAbstract *>(cppSelf)->currentActivity();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AccountActivitiesAbstractFunc_filterAcceptsRow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AccountActivitiesAbstract *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AccountActivitiesAbstract::filterAcceptsRow(const QStringList&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // AccountActivitiesAbstract::filterAcceptsRow(const QStringList&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "filterAcceptsRow", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AccountActivitiesAbstract::filterAcceptsRow(const QStringList&)const->bool
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.filterAcceptsRow");
                return {};
            }
            bool cppResult = const_cast<const ::Akonadi::AccountActivitiesAbstract *>(cppSelf)->filterAcceptsRow(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AccountActivitiesAbstractFunc_hasActivitySupport(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AccountActivitiesAbstract *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AccountActivitiesAbstract::hasActivitySupport()const->bool
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("AccountActivitiesAbstract.hasActivitySupport");
            return {};
        }
        bool cppResult = const_cast<const ::Akonadi::AccountActivitiesAbstract *>(cppSelf)->hasActivitySupport();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_AccountActivitiesAbstract_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_AccountActivitiesAbstract_methods[] = {
    {"currentActivity", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AccountActivitiesAbstractFunc_currentActivity), METH_NOARGS, nullptr},
    {"filterAcceptsRow", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AccountActivitiesAbstractFunc_filterAcceptsRow), METH_O, nullptr},
    {"hasActivitySupport", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AccountActivitiesAbstractFunc_hasActivitySupport), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_AccountActivitiesAbstract_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::AccountActivitiesAbstract *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<AccountActivitiesAbstractWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_AccountActivitiesAbstract_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_AccountActivitiesAbstract_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_AccountActivitiesAbstract_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_AccountActivitiesAbstract_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_AccountActivitiesAbstract_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_AccountActivitiesAbstract_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_AccountActivitiesAbstract_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_AccountActivitiesAbstract_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_AccountActivitiesAbstract_spec = {
    "1:AkonadiCore.Akonadi.AccountActivitiesAbstract",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_AccountActivitiesAbstract_slots
};

} //extern "C"

static void *Sbk_Akonadi_AccountActivitiesAbstract_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::AccountActivitiesAbstract *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void AccountActivitiesAbstract_PythonToCpp_AccountActivitiesAbstract_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_AccountActivitiesAbstract_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_AccountActivitiesAbstract_PythonToCpp_AccountActivitiesAbstract_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AccountActivitiesAbstract_TypeF()))
        return AccountActivitiesAbstract_PythonToCpp_AccountActivitiesAbstract_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *AccountActivitiesAbstract_PTR_CppToPython_AccountActivitiesAbstract(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::AccountActivitiesAbstract *>(const_cast<void *>(cppIn)), Sbk_Akonadi_AccountActivitiesAbstract_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_AccountActivitiesAbstract_SignatureStrings[] = {
    "AkonadiCore.Akonadi.AccountActivitiesAbstract(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.AccountActivitiesAbstract.currentActivity(self)->QString",
    "AkonadiCore.Akonadi.AccountActivitiesAbstract.filterAcceptsRow(self,activities:QStringList)->bool",
    "AkonadiCore.Akonadi.AccountActivitiesAbstract.hasActivitySupport(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_AccountActivitiesAbstract_SignatureByteSize = 157;
static constexpr uint8_t Akonadi_AccountActivitiesAbstract_SignatureBytes[157] = {
    0x78, 0xda, 0x95, 0x8e, 0xcd, 0x0a, 0xc2, 0x30, 0x10, 0x84, 0xef, 0x3e, 0x89, 0x82, 0xe6, 0xe8,
    0xa1, 0xa0, 0x10, 0xbc, 0x0a, 0x5a, 0xfb, 0x04, 0x69, 0xba, 0xd5, 0xd5, 0x90, 0x84, 0xcd, 0x44,
    0xe9, 0xdb, 0x5b, 0xfb, 0xe3, 0xbd, 0xb7, 0x85, 0xd9, 0xf9, 0xbe, 0xd1, 0xaf, 0xe0, 0x4d, 0xc3,
    0xa7, 0x20, 0xa4, 0xf4, 0x78, 0x2b, 0x6d, 0x6d, 0xc8, 0x1e, 0xda, 0x82, 0xdf, 0x0c, 0xa6, 0xa4,
    0xeb, 0x04, 0x31, 0x16, 0xeb, 0x44, 0xae, 0xdd, 0x46, 0x23, 0xe4, 0x51, 0x5c, 0xbb, 0x8a, 0x1b,
    0xda, 0xab, 0x12, 0x43, 0xb9, 0xbc, 0xd4, 0x4f, 0xb2, 0x38, 0xf8, 0xec, 0x5c, 0x84, 0x6c, 0x56,
    0x7a, 0x09, 0x59, 0xd9, 0x2c, 0x3f, 0xea, 0x94, 0x74, 0x83, 0x69, 0xb3, 0x3b, 0x96, 0x15, 0x84,
    0xfd, 0x7d, 0x21, 0xac, 0x65, 0x07, 0x92, 0x3e, 0xa7, 0x88, 0x74, 0x0b, 0x9f, 0x71, 0xb7, 0xf9,
    0x3f, 0x16, 0x13, 0xf6, 0xcc, 0x09, 0xbd, 0xa4, 0x0e, 0xc1, 0x2d, 0x34, 0x3c, 0x4c, 0x9a, 0xa7,
    0x56, 0x39, 0xc6, 0x20, 0x98, 0x17, 0x0f, 0xb0, 0x2f, 0x64, 0x2c, 0x81, 0x0e
};
#endif

PyTypeObject *init_Akonadi_AccountActivitiesAbstract(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_AccountActivitiesAbstract_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_AccountActivitiesAbstract_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "AccountActivitiesAbstract",
        "Akonadi::AccountActivitiesAbstract*",
        &Sbk_Akonadi_AccountActivitiesAbstract_spec,
        &Shiboken::callCppDestructor< Akonadi::AccountActivitiesAbstract >,
        Sbk_Akonadi_AccountActivitiesAbstract_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_AccountActivitiesAbstract_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_AccountActivitiesAbstract_SignatureBytes, Akonadi_AccountActivitiesAbstract_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_AccountActivitiesAbstract_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        AccountActivitiesAbstract_PythonToCpp_AccountActivitiesAbstract_PTR,
        is_AccountActivitiesAbstract_PythonToCpp_AccountActivitiesAbstract_PTR_Convertible,
        AccountActivitiesAbstract_PTR_CppToPython_AccountActivitiesAbstract);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AccountActivitiesAbstract");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AccountActivitiesAbstract*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AccountActivitiesAbstract&");
    Shiboken::Conversions::registerConverterAlias(converter, "AccountActivitiesAbstract");
    Shiboken::Conversions::registerConverterAlias(converter, "AccountActivitiesAbstract*");
    Shiboken::Conversions::registerConverterAlias(converter, "AccountActivitiesAbstract&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::AccountActivitiesAbstract).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(AccountActivitiesAbstractWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_AccountActivitiesAbstract_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Akonadi::AccountActivitiesAbstract::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::AccountActivitiesAbstract::staticMetaObject, sizeof(AccountActivitiesAbstractWrapper));

    return pyType;
}
