/****************************************************************************
** Meta object code from reading C++ file 'monitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/monitor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi7MonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Monitor::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi7MonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Monitor",
        "itemChanged",
        "",
        "Akonadi::Item",
        "item",
        "QSet<QByteArray>",
        "partIdentifiers",
        "itemsFlagsChanged",
        "Akonadi::Item::List",
        "items",
        "addedFlags",
        "removedFlags",
        "itemsTagsChanged",
        "QSet<Akonadi::Tag>",
        "addedTags",
        "removedTags",
        "itemMoved",
        "Akonadi::Collection",
        "collectionSource",
        "collectionDestination",
        "itemsMoved",
        "itemAdded",
        "collection",
        "itemRemoved",
        "itemsRemoved",
        "itemLinked",
        "itemsLinked",
        "itemUnlinked",
        "itemsUnlinked",
        "collectionAdded",
        "parent",
        "collectionChanged",
        "attributeNames",
        "collectionMoved",
        "source",
        "destination",
        "collectionRemoved",
        "collectionSubscribed",
        "collectionUnsubscribed",
        "collectionStatisticsChanged",
        "Akonadi::Collection::Id",
        "id",
        "Akonadi::CollectionStatistics",
        "statistics",
        "tagAdded",
        "Akonadi::Tag",
        "tag",
        "tagChanged",
        "tagRemoved",
        "notificationSubscriberAdded",
        "Akonadi::NotificationSubscriber",
        "subscriber",
        "notificationSubscriberChanged",
        "notificationSubscriberRemoved",
        "debugNotification",
        "Akonadi::ChangeNotification",
        "notification",
        "collectionMonitored",
        "monitored",
        "itemMonitored",
        "resourceMonitored",
        "identifier",
        "mimeTypeMonitored",
        "mimeType",
        "allMonitored",
        "tagMonitored",
        "typeMonitored",
        "Akonadi::Monitor::Type",
        "type",
        "monitorReady",
        "handleCommands"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'itemsFlagsChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &, const QSet<QByteArray> &, const QSet<QByteArray> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 5, 10 }, { 0x80000000 | 5, 11 },
        }}),
        // Signal 'itemsTagsChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &, const QSet<Akonadi::Tag> &, const QSet<Akonadi::Tag> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Signal 'itemMoved'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &, const Akonadi::Collection &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 19 },
        }}),
        // Signal 'itemsMoved'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &, const Akonadi::Collection &, const Akonadi::Collection &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 17, 19 },
        }}),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 22 },
        }}),
        // Signal 'itemRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'itemsRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'itemLinked'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 22 },
        }}),
        // Signal 'itemsLinked'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 17, 22 },
        }}),
        // Signal 'itemUnlinked'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 22 },
        }}),
        // Signal 'itemsUnlinked'
        QtMocHelpers::SignalData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 17, 22 },
        }}),
        // Signal 'collectionAdded'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 }, { 0x80000000 | 17, 30 },
        }}),
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 },
        }}),
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &, const QSet<QByteArray> &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 }, { 0x80000000 | 5, 32 },
        }}),
        // Signal 'collectionMoved'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &, const Akonadi::Collection &, const Akonadi::Collection &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 }, { 0x80000000 | 17, 34 }, { 0x80000000 | 17, 35 },
        }}),
        // Signal 'collectionRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 },
        }}),
        // Signal 'collectionSubscribed'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 }, { 0x80000000 | 17, 30 },
        }}),
        // Signal 'collectionUnsubscribed'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 },
        }}),
        // Signal 'collectionStatisticsChanged'
        QtMocHelpers::SignalData<void(Akonadi::Collection::Id, const Akonadi::CollectionStatistics &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Signal 'tagAdded'
        QtMocHelpers::SignalData<void(const Akonadi::Tag &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'tagChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Tag &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'tagRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::Tag &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Signal 'notificationSubscriberAdded'
        QtMocHelpers::SignalData<void(const Akonadi::NotificationSubscriber &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Signal 'notificationSubscriberChanged'
        QtMocHelpers::SignalData<void(const Akonadi::NotificationSubscriber &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Signal 'notificationSubscriberRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::NotificationSubscriber &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Signal 'debugNotification'
        QtMocHelpers::SignalData<void(const Akonadi::ChangeNotification &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Signal 'collectionMonitored'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &, bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 22 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'itemMonitored'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'resourceMonitored'
        QtMocHelpers::SignalData<void(const QByteArray &, bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 61 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'mimeTypeMonitored'
        QtMocHelpers::SignalData<void(const QString &, bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 63 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'allMonitored'
        QtMocHelpers::SignalData<void(bool)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Signal 'tagMonitored'
        QtMocHelpers::SignalData<void(const Akonadi::Tag &, bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'typeMonitored'
        QtMocHelpers::SignalData<void(const Akonadi::Monitor::Type, bool)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 67, 68 }, { QMetaType::Bool, 58 },
        }}),
        // Signal 'monitorReady'
        QtMocHelpers::SignalData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleCommands'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Monitor, qt_meta_tag_ZN7Akonadi7MonitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Monitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi7MonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi7MonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi7MonitorE_t>.metaTypes,
    nullptr
} };

void Akonadi::Monitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Monitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 1: _t->itemsFlagsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[3]))); break;
        case 2: _t->itemsTagsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[3]))); break;
        case 3: _t->itemMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 4: _t->itemsMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 5: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 6: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 7: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 8: _t->itemLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 9: _t->itemsLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 10: _t->itemUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 11: _t->itemsUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 12: _t->collectionAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 13: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 14: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 15: _t->collectionMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 16: _t->collectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 17: _t->collectionSubscribed((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 18: _t->collectionUnsubscribed((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 19: _t->collectionStatisticsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection::Id>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionStatistics>>(_a[2]))); break;
        case 20: _t->tagAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 21: _t->tagChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 22: _t->tagRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1]))); break;
        case 23: _t->notificationSubscriberAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::NotificationSubscriber>>(_a[1]))); break;
        case 24: _t->notificationSubscriberChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::NotificationSubscriber>>(_a[1]))); break;
        case 25: _t->notificationSubscriberRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::NotificationSubscriber>>(_a[1]))); break;
        case 26: _t->debugNotification((*reinterpret_cast<std::add_pointer_t<Akonadi::ChangeNotification>>(_a[1]))); break;
        case 27: _t->collectionMonitored((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->itemMonitored((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: _t->resourceMonitored((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 30: _t->mimeTypeMonitored((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->allMonitored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->tagMonitored((*reinterpret_cast<std::add_pointer_t<Akonadi::Tag>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: _t->typeMonitored((*reinterpret_cast<std::add_pointer_t<Akonadi::Monitor::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 34: _t->monitorReady(); break;
        case 35: _t->d_ptr->handleCommands(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<Akonadi::Tag> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Tag >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , const QSet<QByteArray> & )>(_a, &Monitor::itemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & , const QSet<QByteArray> & , const QSet<QByteArray> & )>(_a, &Monitor::itemsFlagsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & , const QSet<Akonadi::Tag> & , const QSet<Akonadi::Tag> & )>(_a, &Monitor::itemsTagsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , const Akonadi::Collection & , const Akonadi::Collection & )>(_a, &Monitor::itemMoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & , const Akonadi::Collection & , const Akonadi::Collection & )>(_a, &Monitor::itemsMoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &Monitor::itemAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & )>(_a, &Monitor::itemRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & )>(_a, &Monitor::itemsRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &Monitor::itemLinked, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & , const Akonadi::Collection & )>(_a, &Monitor::itemsLinked, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &Monitor::itemUnlinked, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item::List & , const Akonadi::Collection & )>(_a, &Monitor::itemsUnlinked, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & , const Akonadi::Collection & )>(_a, &Monitor::collectionAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & )>(_a, &Monitor::collectionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & , const QSet<QByteArray> & )>(_a, &Monitor::collectionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & , const Akonadi::Collection & , const Akonadi::Collection & )>(_a, &Monitor::collectionMoved, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & )>(_a, &Monitor::collectionRemoved, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & , const Akonadi::Collection & )>(_a, &Monitor::collectionSubscribed, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & )>(_a, &Monitor::collectionUnsubscribed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(Akonadi::Collection::Id , const Akonadi::CollectionStatistics & )>(_a, &Monitor::collectionStatisticsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Tag & )>(_a, &Monitor::tagAdded, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Tag & )>(_a, &Monitor::tagChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Tag & )>(_a, &Monitor::tagRemoved, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::NotificationSubscriber & )>(_a, &Monitor::notificationSubscriberAdded, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::NotificationSubscriber & )>(_a, &Monitor::notificationSubscriberChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::NotificationSubscriber & )>(_a, &Monitor::notificationSubscriberRemoved, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::ChangeNotification & )>(_a, &Monitor::debugNotification, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Collection & , bool )>(_a, &Monitor::collectionMonitored, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Item & , bool )>(_a, &Monitor::itemMonitored, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const QByteArray & , bool )>(_a, &Monitor::resourceMonitored, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const QString & , bool )>(_a, &Monitor::mimeTypeMonitored, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(bool )>(_a, &Monitor::allMonitored, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Tag & , bool )>(_a, &Monitor::tagMonitored, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)(const Akonadi::Monitor::Type , bool )>(_a, &Monitor::typeMonitored, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Monitor::*)()>(_a, &Monitor::monitorReady, 34))
            return;
    }
}

const QMetaObject *Akonadi::Monitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Monitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi7MonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::Monitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Monitor::itemChanged(const Akonadi::Item & _t1, const QSet<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Akonadi::Monitor::itemsFlagsChanged(const Akonadi::Item::List & _t1, const QSet<QByteArray> & _t2, const QSet<QByteArray> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Akonadi::Monitor::itemsTagsChanged(const Akonadi::Item::List & _t1, const QSet<Akonadi::Tag> & _t2, const QSet<Akonadi::Tag> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void Akonadi::Monitor::itemMoved(const Akonadi::Item & _t1, const Akonadi::Collection & _t2, const Akonadi::Collection & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Akonadi::Monitor::itemsMoved(const Akonadi::Item::List & _t1, const Akonadi::Collection & _t2, const Akonadi::Collection & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void Akonadi::Monitor::itemAdded(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Akonadi::Monitor::itemRemoved(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Akonadi::Monitor::itemsRemoved(const Akonadi::Item::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Akonadi::Monitor::itemLinked(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Akonadi::Monitor::itemsLinked(const Akonadi::Item::List & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Akonadi::Monitor::itemUnlinked(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void Akonadi::Monitor::itemsUnlinked(const Akonadi::Item::List & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void Akonadi::Monitor::collectionAdded(const Akonadi::Collection & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Akonadi::Monitor::collectionChanged(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Akonadi::Monitor::collectionChanged(const Akonadi::Collection & _t1, const QSet<QByteArray> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void Akonadi::Monitor::collectionMoved(const Akonadi::Collection & _t1, const Akonadi::Collection & _t2, const Akonadi::Collection & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void Akonadi::Monitor::collectionRemoved(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Akonadi::Monitor::collectionSubscribed(const Akonadi::Collection & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void Akonadi::Monitor::collectionUnsubscribed(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Akonadi::Monitor::collectionStatisticsChanged(Akonadi::Collection::Id _t1, const Akonadi::CollectionStatistics & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Akonadi::Monitor::tagAdded(const Akonadi::Tag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Akonadi::Monitor::tagChanged(const Akonadi::Tag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Akonadi::Monitor::tagRemoved(const Akonadi::Tag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Akonadi::Monitor::notificationSubscriberAdded(const Akonadi::NotificationSubscriber & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void Akonadi::Monitor::notificationSubscriberChanged(const Akonadi::NotificationSubscriber & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void Akonadi::Monitor::notificationSubscriberRemoved(const Akonadi::NotificationSubscriber & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void Akonadi::Monitor::debugNotification(const Akonadi::ChangeNotification & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void Akonadi::Monitor::collectionMonitored(const Akonadi::Collection & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2);
}

// SIGNAL 28
void Akonadi::Monitor::itemMonitored(const Akonadi::Item & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2);
}

// SIGNAL 29
void Akonadi::Monitor::resourceMonitored(const QByteArray & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2);
}

// SIGNAL 30
void Akonadi::Monitor::mimeTypeMonitored(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void Akonadi::Monitor::allMonitored(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void Akonadi::Monitor::tagMonitored(const Akonadi::Tag & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1, _t2);
}

// SIGNAL 33
void Akonadi::Monitor::typeMonitored(const Akonadi::Monitor::Type _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1, _t2);
}

// SIGNAL 34
void Akonadi::Monitor::monitorReady()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}
QT_WARNING_POP
