/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Preprocessor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PREPROCESSORADAPTOR_H
#define PREPROCESSORADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "preprocessorbase_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Preprocessor
 */
class Akonadi__PreprocessorAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Preprocessor")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Preprocessor\">\n"
"    <signal name=\"itemProcessed\">\n"
"      <arg direction=\"out\" type=\"x\" name=\"id\"/>\n"
"    </signal>\n"
"    <method name=\"beginProcessItem\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"collectionId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"mimeType\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Akonadi__PreprocessorAdaptor(Akonadi::PreprocessorBasePrivate *parent);
    ~Akonadi__PreprocessorAdaptor() override;

    inline Akonadi::PreprocessorBasePrivate *parent() const
    { return static_cast<Akonadi::PreprocessorBasePrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void beginProcessItem(qlonglong id, qlonglong collectionId, const QString &mimeType);
Q_SIGNALS: // SIGNALS
    void itemProcessed(qlonglong id);
};

#endif
