/****************************************************************************
** Meta object code from reading C++ file 'storagedebugger.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/server/storage/storagedebugger.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagedebugger.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Server::StorageDebugger::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Server::StorageDebugger",
        "connectionOpened",
        "",
        "id",
        "timestamp",
        "name",
        "connectionChanged",
        "connectionClosed",
        "transactionStarted",
        "connectionId",
        "duration",
        "error",
        "transactionFinished",
        "commit",
        "queryExecuted",
        "sequence",
        "query",
        "QVariantList",
        "values",
        "resultsCount",
        "QList<QList<QVariant>>",
        "result",
        "connections",
        "QList<DbConnection>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionOpened'
        QtMocHelpers::SignalData<void(qint64, qint64, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::LongLong, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void(qint64, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'connectionClosed'
        QtMocHelpers::SignalData<void(qint64, qint64)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::LongLong, 4 },
        }}),
        // Signal 'transactionStarted'
        QtMocHelpers::SignalData<void(qint64, const QString &, qint64, uint, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 }, { QMetaType::QString, 5 }, { QMetaType::LongLong, 4 }, { QMetaType::UInt, 10 },
            { QMetaType::QString, 11 },
        }}),
        // Signal 'transactionFinished'
        QtMocHelpers::SignalData<void(qint64, bool, qint64, uint, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 }, { QMetaType::Bool, 13 }, { QMetaType::LongLong, 4 }, { QMetaType::UInt, 10 },
            { QMetaType::QString, 11 },
        }}),
        // Signal 'queryExecuted'
        QtMocHelpers::SignalData<void(double, qint64, qint64, uint, const QString &, const QVariantList &, int, const QList<QList<QVariant>> &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 }, { QMetaType::LongLong, 9 }, { QMetaType::LongLong, 4 }, { QMetaType::UInt, 10 },
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 },
            { QMetaType::QString, 11 },
        }}),
        // Method 'connections'
        QtMocHelpers::MethodData<QList<DbConnection>() const>(22, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 23),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorageDebugger, qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Server::StorageDebugger::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>.metaTypes,
    nullptr
} };

void Akonadi::Server::StorageDebugger::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageDebugger *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionOpened((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->connectionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->connectionClosed((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 3: _t->transactionStarted((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 4: _t->transactionFinished((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 5: _t->queryExecuted((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QList<QList<QVariant>>>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9]))); break;
        case 6: { QList<DbConnection> _r = _t->connections();
            if (_a[0]) *reinterpret_cast<QList<DbConnection>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(qint64 , qint64 , const QString & )>(_a, &StorageDebugger::connectionOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(qint64 , const QString & )>(_a, &StorageDebugger::connectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(qint64 , qint64 )>(_a, &StorageDebugger::connectionClosed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(qint64 , const QString & , qint64 , uint , const QString & )>(_a, &StorageDebugger::transactionStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(qint64 , bool , qint64 , uint , const QString & )>(_a, &StorageDebugger::transactionFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageDebugger::*)(double , qint64 , qint64 , uint , const QString & , const QVariantList & , int , const QList<QList<QVariant>> & , const QString & )>(_a, &StorageDebugger::queryExecuted, 5))
            return;
    }
}

const QMetaObject *Akonadi::Server::StorageDebugger::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Server::StorageDebugger::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server15StorageDebuggerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::Server::StorageDebugger::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Server::StorageDebugger::connectionOpened(qint64 _t1, qint64 _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void Akonadi::Server::StorageDebugger::connectionChanged(qint64 _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Akonadi::Server::StorageDebugger::connectionClosed(qint64 _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Akonadi::Server::StorageDebugger::transactionStarted(qint64 _t1, const QString & _t2, qint64 _t3, uint _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 4
void Akonadi::Server::StorageDebugger::transactionFinished(qint64 _t1, bool _t2, qint64 _t3, uint _t4, const QString & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 5
void Akonadi::Server::StorageDebugger::queryExecuted(double _t1, qint64 _t2, qint64 _t3, uint _t4, const QString & _t5, const QVariantList & _t6, int _t7, const QList<QList<QVariant>> & _t8, const QString & _t9)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8, _t9);
}
QT_WARNING_POP
