/****************************************************************************
** Meta object code from reading C++ file 'resourcebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/agentbase/resourcebase.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi12ResourceBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::ResourceBase::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::ResourceBase",
        "nameChanged",
        "",
        "name",
        "synchronized",
        "attributesSynchronized",
        "collectionId",
        "collectionTreeSynchronized",
        "retrieveNextItemSyncBatch",
        "remainingBatchSize",
        "retrieveCollections",
        "retrieveTags",
        "retrieveCollectionAttributes",
        "Akonadi::Collection",
        "collection",
        "retrieveItems",
        "setItemSyncBatchSize",
        "batchSize",
        "setScheduleAttributeSyncBeforeItemSync",
        "retrieveItem",
        "Akonadi::Item",
        "item",
        "QSet<QByteArray>",
        "parts",
        "Akonadi::Item::List",
        "items",
        "abortActivity",
        "slotAbortRequested",
        "slotDeliveryDone",
        "KJob*",
        "slotCollectionSyncDone",
        "slotDeleteResourceCollection",
        "slotDeleteResourceCollectionDone",
        "slotCollectionDeletionDone",
        "slotInvalidateCache",
        "slotLocalListDone",
        "slotSynchronizeCollection",
        "slotCollectionListDone",
        "slotSynchronizeCollectionAttributes",
        "slotCollectionListForAttributesDone",
        "slotCollectionAttributesSyncDone",
        "slotItemSyncDone",
        "slotPercent",
        "slotDelayedEmitProgress",
        "slotPrepareItemRetrieval",
        "slotPrepareItemRetrievalResult",
        "slotPrepareItemsRetrieval",
        "QList<Akonadi::Item>",
        "slotPrepareItemsRetrievalResult",
        "changeCommittedResult",
        "slotSessionReconnected",
        "slotRecursiveMoveReplay",
        "RecursiveMover*",
        "slotRecursiveMoveReplayResult",
        "slotTagSyncDone",
        "slotSynchronizeTags",
        "slotItemRetrievalCollectionFetchDone",
        "slotAttributeRetrievalCollectionFetchDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'synchronized'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attributesSynchronized'
        QtMocHelpers::SignalData<void(qlonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 },
        }}),
        // Signal 'collectionTreeSynchronized'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'retrieveNextItemSyncBatch'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveTags'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveCollectionAttributes'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setItemSyncBatchSize'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setScheduleAttributeSyncBeforeItemSync'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'retrieveItem'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &, const QSet<QByteArray> &)>(19, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<bool(const Akonadi::Item::List &, const QSet<QByteArray> &)>(15, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'abortActivity'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotAbortRequested'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeliveryDone'
        QtMocHelpers::SlotData<void(KJob *)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotCollectionSyncDone'
        QtMocHelpers::SlotData<void(KJob *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotDeleteResourceCollection'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteResourceCollectionDone'
        QtMocHelpers::SlotData<void(KJob *)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotCollectionDeletionDone'
        QtMocHelpers::SlotData<void(KJob *)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotInvalidateCache'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotLocalListDone'
        QtMocHelpers::SlotData<void(KJob *)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotSynchronizeCollection'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotCollectionListDone'
        QtMocHelpers::SlotData<void(KJob *)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotSynchronizeCollectionAttributes'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotCollectionListForAttributesDone'
        QtMocHelpers::SlotData<void(KJob *)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotCollectionAttributesSyncDone'
        QtMocHelpers::SlotData<void(KJob *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotItemSyncDone'
        QtMocHelpers::SlotData<void(KJob *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotPercent'
        QtMocHelpers::SlotData<void(KJob *, quint64)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Slot 'slotDelayedEmitProgress'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrepareItemRetrieval'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 25 },
        }}),
        // Slot 'slotPrepareItemRetrievalResult'
        QtMocHelpers::SlotData<void(KJob *)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotPrepareItemsRetrieval'
        QtMocHelpers::SlotData<void(const QList<Akonadi::Item> &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 25 },
        }}),
        // Slot 'slotPrepareItemsRetrievalResult'
        QtMocHelpers::SlotData<void(KJob *)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'changeCommittedResult'
        QtMocHelpers::SlotData<void(KJob *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotSessionReconnected'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRecursiveMoveReplay'
        QtMocHelpers::SlotData<void(RecursiveMover *)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 2 },
        }}),
        // Slot 'slotRecursiveMoveReplayResult'
        QtMocHelpers::SlotData<void(KJob *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotTagSyncDone'
        QtMocHelpers::SlotData<void(KJob *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotSynchronizeTags'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemRetrievalCollectionFetchDone'
        QtMocHelpers::SlotData<void(KJob *)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
        // Slot 'slotAttributeRetrievalCollectionFetchDone'
        QtMocHelpers::SlotData<void(KJob *)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourceBase, qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::ResourceBase::staticMetaObject = { {
    QMetaObject::SuperData::link<AgentBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>.metaTypes,
    nullptr
} };

void Akonadi::ResourceBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourceBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->synchronized(); break;
        case 2: _t->attributesSynchronized((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 3: _t->collectionTreeSynchronized(); break;
        case 4: _t->retrieveNextItemSyncBatch((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->retrieveCollections(); break;
        case 6: _t->retrieveTags(); break;
        case 7: _t->retrieveCollectionAttributes((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 8: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 9: _t->setItemSyncBatchSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setScheduleAttributeSyncBeforeItemSync((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: { bool _r = _t->retrieveItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->abortActivity(); break;
        case 14: _t->d_func()->slotAbortRequested(); break;
        case 15: _t->d_func()->slotDeliveryDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 16: _t->d_func()->slotCollectionSyncDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 17: _t->d_func()->slotDeleteResourceCollection(); break;
        case 18: _t->d_func()->slotDeleteResourceCollectionDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 19: _t->d_func()->slotCollectionDeletionDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 20: _t->d_func()->slotInvalidateCache((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 21: _t->d_func()->slotLocalListDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 22: _t->d_func()->slotSynchronizeCollection((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 23: _t->d_func()->slotCollectionListDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 24: _t->d_func()->slotSynchronizeCollectionAttributes((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 25: _t->d_func()->slotCollectionListForAttributesDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 26: _t->d_func()->slotCollectionAttributesSyncDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 27: _t->d_func()->slotItemSyncDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 28: _t->d_func()->slotPercent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[2]))); break;
        case 29: _t->d_func()->slotDelayedEmitProgress(); break;
        case 30: _t->d_func()->slotPrepareItemRetrieval((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 31: _t->d_func()->slotPrepareItemRetrievalResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 32: _t->d_func()->slotPrepareItemsRetrieval((*reinterpret_cast<std::add_pointer_t<QList<Akonadi::Item>>>(_a[1]))); break;
        case 33: _t->d_func()->slotPrepareItemsRetrievalResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 34: _t->d_func()->changeCommittedResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 35: _t->d_func()->slotSessionReconnected(); break;
        case 36: _t->d_func()->slotRecursiveMoveReplay((*reinterpret_cast<std::add_pointer_t<RecursiveMover*>>(_a[1]))); break;
        case 37: _t->d_func()->slotRecursiveMoveReplayResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 38: _t->d_func()->slotTagSyncDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 39: _t->d_func()->slotSynchronizeTags(); break;
        case 40: _t->d_func()->slotItemRetrievalCollectionFetchDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 41: _t->d_func()->slotAttributeRetrievalCollectionFetchDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Akonadi::Item> >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourceBase::*)(const QString & )>(_a, &ResourceBase::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceBase::*)()>(_a, &ResourceBase::synchronized, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceBase::*)(qlonglong )>(_a, &ResourceBase::attributesSynchronized, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceBase::*)()>(_a, &ResourceBase::collectionTreeSynchronized, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceBase::*)(int )>(_a, &ResourceBase::retrieveNextItemSyncBatch, 4))
            return;
    }
}

const QMetaObject *Akonadi::ResourceBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::ResourceBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi12ResourceBaseE_t>.strings))
        return static_cast<void*>(this);
    return AgentBase::qt_metacast(_clname);
}

int Akonadi::ResourceBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AgentBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::ResourceBase::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::ResourceBase::synchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi::ResourceBase::attributesSynchronized(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi::ResourceBase::collectionTreeSynchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Akonadi::ResourceBase::retrieveNextItemSyncBatch(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
