/****************************************************************************
** Meta object code from reading C++ file 'collection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/collection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi10CollectionE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Collection::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi10CollectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Collection",
        "id",
        "Id",
        "remoteIdd",
        "isValid",
        "remoteRevision",
        "enabled",
        "isVirtual",
        "name",
        "displayName",
        "rights",
        "Rights",
        "contentMimeTypes",
        "resource",
        "statistics",
        "CollectionStatistics",
        "cachePolicy",
        "CachePolicy",
        "Right",
        "ReadOnly",
        "CanChangeItem",
        "CanCreateItem",
        "CanDeleteItem",
        "CanChangeCollection",
        "CanCreateCollection",
        "CanDeleteCollection",
        "CanLinkItem",
        "CanUnlinkItem",
        "AllRights"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<Id>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'remoteIdd'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'remoteRevision'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isVirtual'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'rights'
        QtMocHelpers::PropertyData<Rights>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'contentMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(12, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'resource'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'statistics'
        QtMocHelpers::PropertyData<CollectionStatistics>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'cachePolicy'
        QtMocHelpers::PropertyData<CachePolicy>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Right'
        QtMocHelpers::EnumData<enum Right>(18, 18, QMC::EnumFlags{}).add({
            {   19, Right::ReadOnly },
            {   20, Right::CanChangeItem },
            {   21, Right::CanCreateItem },
            {   22, Right::CanDeleteItem },
            {   23, Right::CanChangeCollection },
            {   24, Right::CanCreateCollection },
            {   25, Right::CanDeleteCollection },
            {   26, Right::CanLinkItem },
            {   27, Right::CanUnlinkItem },
            {   28, Right::AllRights },
        }),
    };
    return QtMocHelpers::metaObjectData<Collection, qt_meta_tag_ZN7Akonadi10CollectionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Collection::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi10CollectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi10CollectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi10CollectionE_t>.metaTypes,
    nullptr
} };

void Akonadi::Collection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Collection *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Id*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->remoteId(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->remoteRevision(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isVirtual(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 8: *reinterpret_cast<Rights*>(_v) = _t->rights(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->contentMimeTypes(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->resource(); break;
        case 11: *reinterpret_cast<CollectionStatistics*>(_v) = _t->statistics(); break;
        case 12: *reinterpret_cast<CachePolicy*>(_v) = _t->cachePolicy(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<Id*>(_v)); break;
        case 1: _t->setRemoteId(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setRemoteRevision(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setVirtual(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setRights(*reinterpret_cast<Rights*>(_v)); break;
        case 9: _t->setContentMimeTypes(*reinterpret_cast<QStringList*>(_v)); break;
        case 10: _t->setResource(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
