
/*
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */


#ifndef AkonadiSchema_H
#define AkonadiSchema_H

#include "src/server/storage/schema.h"

namespace Akonadi {
namespace Server {

class AkonadiSchema : public Schema
{
  public:
    QList<TableDescription> tables() override;
    QList<RelationDescription> relations() override;
};

} // namespace Server
} // namespace Akonadi

#endif
