/*
    SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "agentconfigurationfactorybase.h"

using namespace Akonadi;

AgentConfigurationFactoryBase::AgentConfigurationFactoryBase(QObject *parent)
    : QObject(parent)
{
}

#include "moc_agentconfigurationfactorybase.cpp"
