/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Knut.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(KnutSettings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

QString SettingsAdaptor::dataFile()
{
    // handle method call org.kde.Akonadi.Knut.Settings.dataFile
    return parent()->dataFile();
}

bool SettingsAdaptor::fileWatchingEnabled()
{
    // handle method call org.kde.Akonadi.Knut.Settings.fileWatchingEnabled
    return parent()->fileWatchingEnabled();
}

bool SettingsAdaptor::readOnly()
{
    // handle method call org.kde.Akonadi.Knut.Settings.readOnly
    return parent()->readOnly();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Knut.Settings.save
    parent()->save();
}

void SettingsAdaptor::setDataFile(const QString &in0)
{
    // handle method call org.kde.Akonadi.Knut.Settings.setDataFile
    parent()->setDataFile(in0);
}

void SettingsAdaptor::setFileWatchingEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Knut.Settings.setFileWatchingEnabled
    parent()->setFileWatchingEnabled(in0);
}

void SettingsAdaptor::setReadOnly(bool in0)
{
    // handle method call org.kde.Akonadi.Knut.Settings.setReadOnly
    parent()->setReadOnly(in0);
}


#include "moc_settingsadaptor.cpp"
