/********************************************************************************
** Form generated from reading UI file 'tagmanagementdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGMANAGEMENTDIALOG_H
#define UI_TAGMANAGEMENTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "tageditwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TagManagementDialog
{
public:
    QVBoxLayout *verticalLayout;
    Akonadi::TagEditWidget *tagEditWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TagManagementDialog)
    {
        if (TagManagementDialog->objectName().isEmpty())
            TagManagementDialog->setObjectName("TagManagementDialog");
        TagManagementDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(TagManagementDialog);
        verticalLayout->setObjectName("verticalLayout");
        tagEditWidget = new Akonadi::TagEditWidget(TagManagementDialog);
        tagEditWidget->setObjectName("tagEditWidget");

        verticalLayout->addWidget(tagEditWidget);

        buttonBox = new QDialogButtonBox(TagManagementDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TagManagementDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TagManagementDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TagManagementDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TagManagementDialog);
    } // setupUi

    void retranslateUi(QDialog *TagManagementDialog)
    {
        TagManagementDialog->setWindowTitle(tr2i18n("Manage Tags", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TagManagementDialog: public Ui_TagManagementDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TAGMANAGEMENTDIALOG_H

