/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "resourceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__ResourceAdaptor
 */

Akonadi__ResourceAdaptor::Akonadi__ResourceAdaptor(Akonadi::ResourceBase *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__ResourceAdaptor::~Akonadi__ResourceAdaptor()
{
    // destructor
}

QStringList Akonadi__ResourceAdaptor::activities()
{
    // handle method call org.freedesktop.Akonadi.Resource.activities
    return parent()->activities();
}

bool Akonadi__ResourceAdaptor::activitiesEnabled()
{
    // handle method call org.freedesktop.Akonadi.Resource.activitiesEnabled
    return parent()->activitiesEnabled();
}

QString Akonadi__ResourceAdaptor::name()
{
    // handle method call org.freedesktop.Akonadi.Resource.name
    return parent()->name();
}

void Akonadi__ResourceAdaptor::requestItemDelivery(const QList<qlonglong> &uids, const QByteArrayList &parts)
{
    // handle method call org.freedesktop.Akonadi.Resource.requestItemDelivery
    parent()->requestItemDelivery(uids, parts);
}

void Akonadi__ResourceAdaptor::setActivities(const QStringList &name)
{
    // handle method call org.freedesktop.Akonadi.Resource.setActivities
    parent()->setActivities(name);
}

void Akonadi__ResourceAdaptor::setActivitiesEnabled(bool en)
{
    // handle method call org.freedesktop.Akonadi.Resource.setActivitiesEnabled
    parent()->setActivitiesEnabled(en);
}

void Akonadi__ResourceAdaptor::setName(const QString &name)
{
    // handle method call org.freedesktop.Akonadi.Resource.setName
    parent()->setName(name);
}

void Akonadi__ResourceAdaptor::synchronize()
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronize
    parent()->synchronize();
}

void Akonadi__ResourceAdaptor::synchronizeCollection(qlonglong collectionId, bool recursive)
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronizeCollection
    parent()->synchronizeCollection(collectionId, recursive);
}

void Akonadi__ResourceAdaptor::synchronizeCollection(qlonglong collectionId)
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronizeCollection
    parent()->synchronizeCollection(collectionId);
}

void Akonadi__ResourceAdaptor::synchronizeCollectionAttributes(qlonglong collectionId)
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronizeCollectionAttributes
    parent()->synchronizeCollectionAttributes(collectionId);
}

void Akonadi__ResourceAdaptor::synchronizeCollectionTree()
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronizeCollectionTree
    parent()->synchronizeCollectionTree();
}

void Akonadi__ResourceAdaptor::synchronizeTags()
{
    // handle method call org.freedesktop.Akonadi.Resource.synchronizeTags
    parent()->synchronizeTags();
}

QStringList Akonadi__ResourceAdaptor::taskList()
{
    // handle method call org.freedesktop.Akonadi.Resource.taskList
    return parent()->taskList();
}


#include "moc_resourceadaptor.cpp"
