// This file is generated by kconfig_compiler_kf6 from resourcebase.kcfg.
// All changes you do to this file will be lost.
#ifndef AKONADI_RESOURCEBASESETTINGS_H
#define AKONADI_RESOURCEBASESETTINGS_H

#include "akonadiagentbase_export.h"

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Akonadi {

class AKONADIAGENTBASE_EXPORT ResourceBaseSettings : public KConfigSkeleton
{
  public:

    static ResourceBaseSettings *self();
    ~ResourceBaseSettings() override;

    /**
      Set MinimumCheckInterval
    */
    static
    void setMinimumCheckInterval( int v )
    {
      if (!self()->isMinimumCheckIntervalImmutable())
        self()->mMinimumCheckInterval = v;
    }

    /**
      Get MinimumCheckInterval
    */
    static
    int minimumCheckInterval()
    {
      return self()->mMinimumCheckInterval;
    }

    /**
      Is MinimumCheckInterval Immutable
    */
    static
    bool isMinimumCheckIntervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MinimumCheckInterval" ) );
    }

    /**
      Get Item object corresponding to MinimumCheckInterval()
    */
    ItemInt *minimumCheckIntervalItem()
    {
      return mMinimumCheckIntervalItem;
    }

  protected:
    ResourceBaseSettings();
    friend class ResourceBaseSettingsHelper;


    // ConfigurationDialogRestrictions
    int mMinimumCheckInterval;

  private:
    ItemInt *mMinimumCheckIntervalItem;
};

}

#endif

