/****************************************************************************
** Meta object code from reading C++ file 'connection_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/core/connection_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'connection_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi10ConnectionE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Connection::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi10ConnectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Connection",
        "connected",
        "",
        "reconnected",
        "commandReceived",
        "tag",
        "Akonadi::Protocol::CommandPtr",
        "command",
        "socketDisconnected",
        "socketError",
        "message",
        "doReconnect",
        "doForceReconnect",
        "doCloseConnection",
        "doSendCommand",
        "reconnect",
        "ConnectionType",
        "CommandConnection",
        "NotificationConnection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reconnected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'commandReceived'
        QtMocHelpers::SignalData<void(qint64, const Akonadi::Protocol::CommandPtr &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'socketDisconnected'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'socketError'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'doReconnect'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doForceReconnect'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doCloseConnection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doSendCommand'
        QtMocHelpers::SlotData<void(qint64, const Akonadi::Protocol::CommandPtr &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Method 'reconnect'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ConnectionType'
        QtMocHelpers::EnumData<enum ConnectionType>(16, 16, QMC::EnumFlags{}).add({
            {   17, ConnectionType::CommandConnection },
            {   18, ConnectionType::NotificationConnection },
        }),
    };
    return QtMocHelpers::metaObjectData<Connection, qt_meta_tag_ZN7Akonadi10ConnectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Connection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi10ConnectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi10ConnectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi10ConnectionE_t>.metaTypes,
    nullptr
} };

void Akonadi::Connection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Connection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connected(); break;
        case 1: _t->reconnected(); break;
        case 2: _t->commandReceived((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Protocol::CommandPtr>>(_a[2]))); break;
        case 3: _t->socketDisconnected(); break;
        case 4: _t->socketError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->doReconnect(); break;
        case 6: _t->doForceReconnect(); break;
        case 7: _t->doCloseConnection(); break;
        case 8: _t->doSendCommand((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Protocol::CommandPtr>>(_a[2]))); break;
        case 9: _t->reconnect(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Protocol::CommandPtr >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Protocol::CommandPtr >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Connection::*)()>(_a, &Connection::connected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Connection::*)()>(_a, &Connection::reconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Connection::*)(qint64 , const Akonadi::Protocol::CommandPtr & )>(_a, &Connection::commandReceived, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Connection::*)()>(_a, &Connection::socketDisconnected, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Connection::*)(const QString & )>(_a, &Connection::socketError, 4))
            return;
    }
}

const QMetaObject *Akonadi::Connection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Connection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi10ConnectionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akonadi::Connection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Connection::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Akonadi::Connection::reconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi::Connection::commandReceived(qint64 _t1, const Akonadi::Protocol::CommandPtr & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Akonadi::Connection::socketDisconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Akonadi::Connection::socketError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
