
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collectionfetchscope_wrapper.h"

// Argument includes
#include <QSet>
#include <QString>
#include <QStringList>
#include <collectionfetchscope.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_CollectionFetchScope_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_CollectionFetchScope_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::CollectionFetchScope >()))
        return -1;

    ::Akonadi::CollectionFetchScope *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "CollectionFetchScope", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CollectionFetchScope::CollectionFetchScope()
    // 1: CollectionFetchScope::CollectionFetchScope(const Akonadi::CollectionFetchScope&)
    if (numArgs == 0) {
        overloadId = 0; // CollectionFetchScope()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), (pyArgs[0])))) {
        overloadId = 1; // CollectionFetchScope::CollectionFetchScope(const Akonadi::CollectionFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // CollectionFetchScope()
        {

            // CollectionFetchScope::CollectionFetchScope()
            cptr = new ::Akonadi::CollectionFetchScope();
            break;
        }
        case 1: // CollectionFetchScope(const Akonadi::CollectionFetchScope &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::CollectionFetchScope cppArg0_local;
            ::Akonadi::CollectionFetchScope *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // CollectionFetchScope::CollectionFetchScope(const Akonadi::CollectionFetchScope&)
                cptr = new ::Akonadi::CollectionFetchScope(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::CollectionFetchScope >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_ancestorFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::ancestorFetchScope()->Akonadi::CollectionFetchScope&
        Akonadi::CollectionFetchScope & cppResult = cppSelf->ancestorFetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_ancestorRetrieval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::ancestorRetrieval()const->Akonadi::CollectionFetchScope::AncestorRetrieval
        Akonadi::CollectionFetchScope::AncestorRetrieval cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->ancestorRetrieval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::attributes()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_contentMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::contentMimeTypes()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->contentMimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_fetchAttribute(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fetchAttribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CollectionFetchScope::fetchAttribute(const QByteArray&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fetchAttribute(QByteArray,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // CollectionFetchScope::fetchAttribute(const QByteArray&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::fetchAttribute(const QByteArray&,bool=)
            cppSelf->fetchAttribute(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_fetchIdOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::fetchIdOnly()const->bool
        bool cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->fetchIdOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_ignoreRetrievalErrors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::ignoreRetrievalErrors()const->bool
        bool cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->ignoreRetrievalErrors();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_includeStatistics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::includeStatistics()const->bool
        bool cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->includeStatistics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::isEmpty()const->bool
        bool cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_listFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::listFilter()const->Akonadi::CollectionFetchScope::ListFilter
        Akonadi::CollectionFetchScope::ListFilter cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->listFilter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_resource(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionFetchScope::resource()const->QString
        QString cppResult = const_cast<const ::Akonadi::CollectionFetchScope *>(cppSelf)->resource();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setAncestorFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setAncestorFetchScope(const Akonadi::CollectionFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setAncestorFetchScope(const Akonadi::CollectionFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAncestorFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::CollectionFetchScope cppArg0_local;
        ::Akonadi::CollectionFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setAncestorFetchScope(const Akonadi::CollectionFetchScope&)
            cppSelf->setAncestorFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setAncestorRetrieval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setAncestorRetrieval(Akonadi::CollectionFetchScope::AncestorRetrieval)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX]))), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setAncestorRetrieval(Akonadi::CollectionFetchScope::AncestorRetrieval)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAncestorRetrieval", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        ::Akonadi::CollectionFetchScope::AncestorRetrieval cppArg0{Akonadi::CollectionFetchScope::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setAncestorRetrieval(Akonadi::CollectionFetchScope::AncestorRetrieval)
            cppSelf->setAncestorRetrieval(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setContentMimeTypes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setContentMimeTypes(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setContentMimeTypes(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContentMimeTypes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setContentMimeTypes(const QStringList&)
            cppSelf->setContentMimeTypes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setFetchIdOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setFetchIdOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setFetchIdOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchIdOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setFetchIdOnly(bool)
            cppSelf->setFetchIdOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setIgnoreRetrievalErrors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setIgnoreRetrievalErrors(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setIgnoreRetrievalErrors(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIgnoreRetrievalErrors", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setIgnoreRetrievalErrors(bool)
            cppSelf->setIgnoreRetrievalErrors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setIncludeStatistics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setIncludeStatistics(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setIncludeStatistics(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludeStatistics", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setIncludeStatistics(bool)
            cppSelf->setIncludeStatistics(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setListFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX]))), (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setListFilter", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        ::Akonadi::CollectionFetchScope::ListFilter cppArg0{Akonadi::CollectionFetchScope::NoFilter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
            cppSelf->setListFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScopeFunc_setResource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionFetchScope::setResource(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // CollectionFetchScope::setResource(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResource", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionFetchScope::setResource(const QString&)
            cppSelf->setResource(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionFetchScope__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_CollectionFetchScope_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_CollectionFetchScope_EnumFlagInfo[] = {
    "AncestorRetrieval:IntEnum",
    "ListFilter:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CollectionFetchScope_methods[] = {
    {"ancestorFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_ancestorFetchScope), METH_NOARGS, nullptr},
    {"ancestorRetrieval", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_ancestorRetrieval), METH_NOARGS, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_attributes), METH_NOARGS, nullptr},
    {"contentMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_contentMimeTypes), METH_NOARGS, nullptr},
    {"fetchAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_fetchAttribute), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchIdOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_fetchIdOnly), METH_NOARGS, nullptr},
    {"ignoreRetrievalErrors", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_ignoreRetrievalErrors), METH_NOARGS, nullptr},
    {"includeStatistics", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_includeStatistics), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_isEmpty), METH_NOARGS, nullptr},
    {"listFilter", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_listFilter), METH_NOARGS, nullptr},
    {"resource", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_resource), METH_NOARGS, nullptr},
    {"setAncestorFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setAncestorFetchScope), METH_O, nullptr},
    {"setAncestorRetrieval", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setAncestorRetrieval), METH_O, nullptr},
    {"setContentMimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setContentMimeTypes), METH_O, nullptr},
    {"setFetchIdOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setFetchIdOnly), METH_O, nullptr},
    {"setIgnoreRetrievalErrors", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setIgnoreRetrievalErrors), METH_O, nullptr},
    {"setIncludeStatistics", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setIncludeStatistics), METH_O, nullptr},
    {"setListFilter", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setListFilter), METH_O, nullptr},
    {"setResource", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScopeFunc_setResource), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionFetchScope__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_CollectionFetchScope_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CollectionFetchScope_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CollectionFetchScope_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionFetchScope_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CollectionFetchScope_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CollectionFetchScope_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionFetchScope_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CollectionFetchScope_spec = {
    "1:AkonadiCore.Akonadi.CollectionFetchScope",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CollectionFetchScope_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_CollectionFetchScope_AncestorRetrieval(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::CollectionFetchScope::AncestorRetrieval>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::CollectionFetchScope::AncestorRetrieval *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_CollectionFetchScope_AncestorRetrieval_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX])))
        return Enum_PythonToCpp_Akonadi_CollectionFetchScope_AncestorRetrieval;
    return {};
}

static PyObject *Akonadi_CollectionFetchScope_AncestorRetrieval_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::CollectionFetchScope::AncestorRetrieval>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::CollectionFetchScope::AncestorRetrieval *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_CollectionFetchScope_ListFilter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::CollectionFetchScope::ListFilter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::CollectionFetchScope::ListFilter *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_CollectionFetchScope_ListFilter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX])))
        return Enum_PythonToCpp_Akonadi_CollectionFetchScope_ListFilter;
    return {};
}

static PyObject *Akonadi_CollectionFetchScope_ListFilter_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::CollectionFetchScope::ListFilter>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::CollectionFetchScope::ListFilter *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CollectionFetchScope_PythonToCpp_CollectionFetchScope_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_CollectionFetchScope_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CollectionFetchScope_PythonToCpp_CollectionFetchScope_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionFetchScope_TypeF()))
        return CollectionFetchScope_PythonToCpp_CollectionFetchScope_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CollectionFetchScope_PTR_CppToPython_CollectionFetchScope(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_CollectionFetchScope_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_CollectionFetchScope_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *CollectionFetchScope_COPY_CppToPython_CollectionFetchScope(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::CollectionFetchScope *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_CollectionFetchScope_TypeF(), new ::Akonadi::CollectionFetchScope(*source), true, true);
}

// Python to C++ copy conversion.
static void CollectionFetchScope_PythonToCpp_CollectionFetchScope_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::CollectionFetchScope *>(cppOut) = *reinterpret_cast< ::Akonadi::CollectionFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_CollectionFetchScope_PythonToCpp_CollectionFetchScope_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionFetchScope_TypeF()))
        return CollectionFetchScope_PythonToCpp_CollectionFetchScope_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_CollectionFetchScope_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.CollectionFetchScope(self)",
    "0:AkonadiCore.Akonadi.CollectionFetchScope(self,other:AkonadiCore.Akonadi.CollectionFetchScope)",
    "AkonadiCore.Akonadi.CollectionFetchScope.ancestorFetchScope(self)->AkonadiCore.Akonadi.CollectionFetchScope",
    "AkonadiCore.Akonadi.CollectionFetchScope.ancestorRetrieval(self)->AkonadiCore.Akonadi.CollectionFetchScope.AncestorRetrieval",
    "AkonadiCore.Akonadi.CollectionFetchScope.attributes(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.CollectionFetchScope.contentMimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.CollectionFetchScope.fetchAttribute(self,type:typing.Union[PySide6.QtCore.QByteArray, char*],fetch:bool=true)",
    "AkonadiCore.Akonadi.CollectionFetchScope.fetchIdOnly(self)->bool",
    "AkonadiCore.Akonadi.CollectionFetchScope.ignoreRetrievalErrors(self)->bool",
    "AkonadiCore.Akonadi.CollectionFetchScope.includeStatistics(self)->bool",
    "AkonadiCore.Akonadi.CollectionFetchScope.isEmpty(self)->bool",
    "AkonadiCore.Akonadi.CollectionFetchScope.listFilter(self)->AkonadiCore.Akonadi.CollectionFetchScope.ListFilter",
    "AkonadiCore.Akonadi.CollectionFetchScope.resource(self)->QString",
    "AkonadiCore.Akonadi.CollectionFetchScope.setAncestorFetchScope(self,scope:AkonadiCore.Akonadi.CollectionFetchScope)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setAncestorRetrieval(self,ancestorDepth:AkonadiCore.Akonadi.CollectionFetchScope.AncestorRetrieval)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setContentMimeTypes(self,mimeTypes:QStringList)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setFetchIdOnly(self,fetchIdOnly:bool)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setIgnoreRetrievalErrors(self,enabled:bool)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setIncludeStatistics(self,include:bool)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setListFilter(self,arg__1:AkonadiCore.Akonadi.CollectionFetchScope.ListFilter)",
    "AkonadiCore.Akonadi.CollectionFetchScope.setResource(self,resource:QString)",
    "AkonadiCore.Akonadi.CollectionFetchScope.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_CollectionFetchScope_SignatureByteSize = 384;
static constexpr uint8_t Akonadi_CollectionFetchScope_SignatureBytes[384] = {
    0x78, 0xda, 0xb5, 0x94, 0x41, 0x6b, 0xc2, 0x30, 0x14, 0xc7, 0xef, 0x7e, 0x8a, 0x1d, 0xe7, 0xc8,
    0xca, 0xbc, 0xec, 0x50, 0xd8, 0xa0, 0x3a, 0x05, 0xc1, 0xb1, 0x69, 0xb7, 0xd3, 0x90, 0x12, 0xd3,
    0xa7, 0x0d, 0x8b, 0x49, 0x49, 0x5e, 0x07, 0xfd, 0xf6, 0x8b, 0x9d, 0x91, 0x5a, 0x14, 0x92, 0xc2,
    0x2e, 0x6d, 0x02, 0x79, 0xbf, 0xff, 0x4b, 0x93, 0x5f, 0x47, 0x71, 0xf2, 0xad, 0x24, 0xcd, 0xf9,
    0x44, 0x69, 0x88, 0x8e, 0xe3, 0x68, 0xa2, 0x84, 0x00, 0x86, 0x5c, 0xc9, 0x19, 0x20, 0x2b, 0x52,
    0xa6, 0x4a, 0xb8, 0x35, 0x20, 0xb6, 0xc3, 0xc1, 0x43, 0x58, 0x01, 0x51, 0x58, 0x80, 0xf6, 0xae,
    0x19, 0x0e, 0x7c, 0x57, 0x46, 0x54, 0x32, 0x30, 0xa8, 0x74, 0xb7, 0xc3, 0xfb, 0x67, 0x5f, 0x44,
    0x78, 0xd6, 0x0a, 0x50, 0x73, 0xf8, 0xa1, 0x22, 0x34, 0x2a, 0x4a, 0xba, 0x84, 0x80, 0x70, 0xb4,
    0x25, 0x9b, 0x0a, 0xc1, 0xb8, 0xd4, 0x65, 0x0a, 0xf8, 0xf5, 0x5e, 0xa7, 0x3c, 0x87, 0xc7, 0x68,
    0x89, 0x0d, 0x62, 0x39, 0xae, 0x11, 0x12, 0xad, 0x69, 0xbd, 0xf6, 0x47, 0x33, 0x25, 0x11, 0x24,
    0xbe, 0xf2, 0x3d, 0x7c, 0xd4, 0x65, 0x3b, 0xc0, 0x46, 0xca, 0xdd, 0x82, 0x1b, 0xf4, 0x87, 0x6d,
    0x0f, 0xc3, 0xc4, 0x35, 0xfb, 0x77, 0xfa, 0x68, 0xa9, 0xb1, 0x7d, 0x58, 0x58, 0xf4, 0x29, 0xed,
    0xfa, 0xeb, 0x6d, 0x93, 0x1b, 0x56, 0x50, 0x7d, 0xb7, 0x26, 0x0d, 0x27, 0xde, 0x28, 0x25, 0x9e,
    0x50, 0x57, 0x21, 0x57, 0xa2, 0xa9, 0x9c, 0xe7, 0x6f, 0x52, 0xd4, 0x6e, 0x27, 0x07, 0x8c, 0x3f,
    0x80, 0xef, 0xa4, 0x5d, 0x73, 0x3a, 0xa3, 0xa9, 0xd6, 0x4a, 0x9b, 0x9e, 0x28, 0xc9, 0x44, 0x95,
    0x43, 0x8a, 0x14, 0xed, 0x57, 0xe4, 0xac, 0x2f, 0xc6, 0x4c, 0xf7, 0x25, 0xf6, 0xdc, 0x8e, 0xb0,
    0xc9, 0x33, 0x2e, 0x10, 0x74, 0xf0, 0x7d, 0x5d, 0x9c, 0x4a, 0xfd, 0xe3, 0x34, 0x18, 0x55, 0x69,
    0x06, 0x9d, 0x5b, 0xe4, 0x0f, 0x30, 0x80, 0xc9, 0x65, 0xab, 0x89, 0x39, 0x0c, 0xff, 0xe3, 0x37,
    0xd2, 0xca, 0x3c, 0xb7, 0x9b, 0x38, 0xe9, 0x5f, 0xa0, 0xc4, 0x22, 0xee, 0x6f, 0x7a, 0x58, 0x33,
    0x93, 0x4b, 0x4a, 0x92, 0xbd, 0x9b, 0xc6, 0x2d, 0x35, 0xc3, 0xc0, 0xb3, 0x8e, 0x1c, 0xa4, 0x65,
    0x4b, 0x63, 0x5b, 0x18, 0x6e, 0x7e, 0x55, 0x15, 0x02, 0x92, 0x6e, 0x04, 0xe4, 0x7d, 0xa0, 0x17,
    0xa5, 0x21, 0x47, 0x97, 0x7a, 0x00, 0x17, 0xe7, 0x06, 0x10, 0xaa, 0x77, 0x59, 0x36, 0x8a, 0x7b,
    0x68, 0x10, 0x96, 0xbb, 0x6a, 0xab, 0x40, 0x9c, 0x18, 0xee, 0xf0, 0x02, 0x58, 0x59, 0x66, 0x5f,
    0x75, 0x96, 0x39, 0xa7, 0x8e, 0xff, 0xd2, 0x2c, 0xb5, 0xd3, 0xc1, 0x2f, 0xda, 0x98, 0xe4, 0xcb
};
#endif

PyTypeObject *init_Akonadi_CollectionFetchScope(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_CollectionFetchScope_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CollectionFetchScope",
        "Akonadi::CollectionFetchScope",
        &Sbk_Akonadi_CollectionFetchScope_spec,
        &Shiboken::callCppDestructor< ::Akonadi::CollectionFetchScope >,
        Sbk_Akonadi_CollectionFetchScope_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_CollectionFetchScope_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_CollectionFetchScope_SignatureBytes, Akonadi_CollectionFetchScope_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CollectionFetchScope_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CollectionFetchScope_PythonToCpp_CollectionFetchScope_PTR,
        is_CollectionFetchScope_PythonToCpp_CollectionFetchScope_PTR_Convertible,
        CollectionFetchScope_PTR_CppToPython_CollectionFetchScope,
        CollectionFetchScope_COPY_CppToPython_CollectionFetchScope);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionFetchScope");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionFetchScope*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionFetchScope&");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchScope");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchScope*");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchScope&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::CollectionFetchScope).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        CollectionFetchScope_PythonToCpp_CollectionFetchScope_COPY,
        is_CollectionFetchScope_PythonToCpp_CollectionFetchScope_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_CollectionFetchScope_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'AncestorRetrieval'.
    const char *AncestorRetrieval_Initializer[] = {
        "None_",
        "Parent",
        "All",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AncestorRetrieval_InitializerValues[] = {
        uint8_t(Akonadi::CollectionFetchScope::AncestorRetrieval::None),   //  0x00  0
        uint8_t(Akonadi::CollectionFetchScope::AncestorRetrieval::Parent), //  0x01  1
        uint8_t(Akonadi::CollectionFetchScope::AncestorRetrieval::All)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.CollectionFetchScope.AncestorRetrieval",
        AncestorRetrieval_Initializer, AncestorRetrieval_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_AncestorRetrieval_IDX].type = EType;
    // Register converter for enum 'Akonadi::CollectionFetchScope::AncestorRetrieval'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_CollectionFetchScope_AncestorRetrieval_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_CollectionFetchScope_AncestorRetrieval,
            is_Enum_PythonToCpp_Akonadi_CollectionFetchScope_AncestorRetrieval_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionFetchScope::AncestorRetrieval");
        Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchScope::AncestorRetrieval");
        Shiboken::Conversions::registerConverterAlias(converter, "AncestorRetrieval");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AncestorRetrieval' enum.

    // Initialization of enum 'ListFilter'.
    const char *ListFilter_Initializer[] = {
        "NoFilter",
        "Display",
        "Sync",
        "Index",
        "Enabled",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ListFilter_InitializerValues[] = {
        uint8_t(Akonadi::CollectionFetchScope::ListFilter::NoFilter), //  0x00  0
        uint8_t(Akonadi::CollectionFetchScope::ListFilter::Display),  //  0x01  1
        uint8_t(Akonadi::CollectionFetchScope::ListFilter::Sync),     //  0x02  2
        uint8_t(Akonadi::CollectionFetchScope::ListFilter::Index),    //  0x03  3
        uint8_t(Akonadi::CollectionFetchScope::ListFilter::Enabled)   //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.CollectionFetchScope.ListFilter",
        ListFilter_Initializer, ListFilter_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX].type = EType;
    // Register converter for enum 'Akonadi::CollectionFetchScope::ListFilter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_CollectionFetchScope_ListFilter_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_CollectionFetchScope_ListFilter,
            is_Enum_PythonToCpp_Akonadi_CollectionFetchScope_ListFilter_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionFetchScope::ListFilter");
        Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchScope::ListFilter");
        Shiboken::Conversions::registerConverterAlias(converter, "ListFilter");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ListFilter' enum.

    qRegisterMetaType< ::Akonadi::CollectionFetchScope >("CollectionFetchScope");
    qRegisterMetaType< ::Akonadi::CollectionFetchScope >("Akonadi::CollectionFetchScope");
    qRegisterMetaType< ::Akonadi::CollectionFetchScope::AncestorRetrieval >("CollectionFetchScope::AncestorRetrieval");
    qRegisterMetaType< ::Akonadi::CollectionFetchScope::AncestorRetrieval >("Akonadi::CollectionFetchScope::AncestorRetrieval");
    qRegisterMetaType< ::Akonadi::CollectionFetchScope::ListFilter >("CollectionFetchScope::ListFilter");
    qRegisterMetaType< ::Akonadi::CollectionFetchScope::ListFilter >("Akonadi::CollectionFetchScope::ListFilter");

    return pyType;
}
