
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_servermanager_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <QString>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <servermanager.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ServerManager_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void ServerManagerWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

void ServerManagerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("ServerManager", funcName, gil, pyOverride, event);
}

void ServerManagerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("ServerManager", funcName, gil, pyOverride, signal);
}

void ServerManagerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("ServerManager", funcName, gil, pyOverride, event);
}

void ServerManagerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("ServerManager", funcName, gil, pyOverride, signal);
}

bool ServerManagerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("ServerManager", funcName, gil, pyOverride, event);
}

bool ServerManagerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("ServerManager", funcName, gil, pyOverride, watched, event);
}

void ServerManagerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ServerManager_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("ServerManager", funcName, gil, pyOverride, event);
}

const QMetaObject *ServerManagerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::ServerManager::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int ServerManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::ServerManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *ServerManagerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< ServerManagerWrapper *>(this));
    }
    return Akonadi::ServerManager::qt_metacast(_clname);
}

ServerManagerWrapper::~ServerManagerWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_ServerManager_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Akonadi_ServerManager_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("ServerManager");
    return -1;
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_addNamespace([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static ServerManager::addNamespace(const QString&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static ServerManager::addNamespace(const QString&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addNamespace", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static ServerManager::addNamespace(const QString&)->QString
            QString cppResult = ::Akonadi::ServerManager::addNamespace(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_agentConfigFilePath([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static ServerManager::agentConfigFilePath(const QString&)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static ServerManager::agentConfigFilePath(const QString&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "agentConfigFilePath", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static ServerManager::agentConfigFilePath(const QString&)->QString
            QString cppResult = ::Akonadi::ServerManager::agentConfigFilePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_agentServiceName([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "agentServiceName", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static ServerManager::agentServiceName(Akonadi::ServerManager::ServiceAgentType,const QString&)->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceAgentType_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // static ServerManager::agentServiceName(Akonadi::ServerManager::ServiceAgentType,const QString&)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "agentServiceName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]);

    // Call function/method
    {
        ::Akonadi::ServerManager::ServiceAgentType cppArg0{Akonadi::ServerManager::Agent};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static ServerManager::agentServiceName(Akonadi::ServerManager::ServiceAgentType,const QString&)->QString
            QString cppResult = ::Akonadi::ServerManager::agentServiceName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_brokenReason([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::brokenReason()->QString
        QString cppResult = ::Akonadi::ServerManager::brokenReason();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_generation([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::generation()->uint
        uint cppResult = ::Akonadi::ServerManager::generation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_hasInstanceIdentifier([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::hasInstanceIdentifier()->bool
        bool cppResult = ::Akonadi::ServerManager::hasInstanceIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_instanceIdentifier([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::instanceIdentifier()->QString
        QString cppResult = ::Akonadi::ServerManager::instanceIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_isRunning([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::isRunning()->bool
        bool cppResult = ::Akonadi::ServerManager::isRunning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_self([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::self()->Akonadi::ServerManager*
        Akonadi::ServerManager * cppResult = ::Akonadi::ServerManager::self();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_serverConfigFilePath([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static ServerManager::serverConfigFilePath(Akonadi::ServerManager::OpenMode)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_OpenMode_IDX]))), (pyArg)))) {
        overloadId = 0; // static ServerManager::serverConfigFilePath(Akonadi::ServerManager::OpenMode)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serverConfigFilePath", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]);

    // Call function/method
    {
        ::Akonadi::ServerManager::OpenMode cppArg0{Akonadi::ServerManager::ReadOnly};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static ServerManager::serverConfigFilePath(Akonadi::ServerManager::OpenMode)->QString
            QString cppResult = ::Akonadi::ServerManager::serverConfigFilePath(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_serviceName([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static ServerManager::serviceName(Akonadi::ServerManager::ServiceType)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceType_IDX]))), (pyArg)))) {
        overloadId = 0; // static ServerManager::serviceName(Akonadi::ServerManager::ServiceType)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serviceName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]);

    // Call function/method
    {
        ::Akonadi::ServerManager::ServiceType cppArg0{Akonadi::ServerManager::Server};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static ServerManager::serviceName(Akonadi::ServerManager::ServiceType)->QString
            QString cppResult = ::Akonadi::ServerManager::serviceName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_start([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::start()->bool
        bool cppResult = ::Akonadi::ServerManager::start();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_state([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::state()->Akonadi::ServerManager::State
        Akonadi::ServerManager::State cppResult = ::Akonadi::ServerManager::state();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_State_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ServerManagerFunc_stop([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static ServerManager::stop()->bool
        bool cppResult = ::Akonadi::ServerManager::stop();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_ServerManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_ServerManager_EnumFlagInfo[] = {
    "OpenMode:IntEnum",
    "ServiceAgentType:IntEnum",
    "ServiceType:IntEnum",
    "State:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ServerManager_methods[] = {
    {"addNamespace", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_addNamespace), METH_O|METH_STATIC, nullptr},
    {"agentConfigFilePath", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_agentConfigFilePath), METH_O|METH_STATIC, nullptr},
    {"agentServiceName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_agentServiceName), METH_VARARGS|METH_STATIC, nullptr},
    {"brokenReason", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_brokenReason), METH_NOARGS|METH_STATIC, nullptr},
    {"generation", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_generation), METH_NOARGS|METH_STATIC, nullptr},
    {"hasInstanceIdentifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_hasInstanceIdentifier), METH_NOARGS|METH_STATIC, nullptr},
    {"instanceIdentifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_instanceIdentifier), METH_NOARGS|METH_STATIC, nullptr},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_isRunning), METH_NOARGS|METH_STATIC, nullptr},
    {"self", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_self), METH_NOARGS|METH_STATIC, nullptr},
    {"serverConfigFilePath", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_serverConfigFilePath), METH_O|METH_STATIC, nullptr},
    {"serviceName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_serviceName), METH_O|METH_STATIC, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_start), METH_NOARGS|METH_STATIC, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_state), METH_NOARGS|METH_STATIC, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ServerManagerFunc_stop), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_ServerManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::ServerManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<ServerManagerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_ServerManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ServerManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ServerManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_ServerManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ServerManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ServerManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ServerManager_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ServerManager_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ServerManager_spec = {
    "1:AkonadiCore.Akonadi.ServerManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ServerManager_slots
};

} //extern "C"

static void *Sbk_Akonadi_ServerManager_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::ServerManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_ServerManager_State(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ServerManager::State>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ServerManager::State *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ServerManager_State_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_State_IDX])))
        return Enum_PythonToCpp_Akonadi_ServerManager_State;
    return {};
}

static PyObject *Akonadi_ServerManager_State_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ServerManager::State>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ServerManager::State *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_ServerManager_ServiceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ServerManager::ServiceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ServerManager::ServiceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ServerManager_ServiceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceType_IDX])))
        return Enum_PythonToCpp_Akonadi_ServerManager_ServiceType;
    return {};
}

static PyObject *Akonadi_ServerManager_ServiceType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ServerManager::ServiceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ServerManager::ServiceType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_ServerManager_ServiceAgentType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ServerManager::ServiceAgentType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ServerManager::ServiceAgentType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ServerManager_ServiceAgentType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceAgentType_IDX])))
        return Enum_PythonToCpp_Akonadi_ServerManager_ServiceAgentType;
    return {};
}

static PyObject *Akonadi_ServerManager_ServiceAgentType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ServerManager::ServiceAgentType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ServerManager::ServiceAgentType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_ServerManager_OpenMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ServerManager::OpenMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ServerManager::OpenMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ServerManager_OpenMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_OpenMode_IDX])))
        return Enum_PythonToCpp_Akonadi_ServerManager_OpenMode;
    return {};
}

static PyObject *Akonadi_ServerManager_OpenMode_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ServerManager::OpenMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ServerManager::OpenMode *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ServerManager_PythonToCpp_ServerManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ServerManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ServerManager_PythonToCpp_ServerManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ServerManager_TypeF()))
        return ServerManager_PythonToCpp_ServerManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ServerManager_PTR_CppToPython_ServerManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::ServerManager *>(const_cast<void *>(cppIn)), Sbk_Akonadi_ServerManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ServerManager_SignatureStrings[] = {
    "AkonadiCore.Akonadi.ServerManager.addNamespace(string:QString)->QString",
    "AkonadiCore.Akonadi.ServerManager.agentConfigFilePath(identifier:QString)->QString",
    "AkonadiCore.Akonadi.ServerManager.agentServiceName(agentType:AkonadiCore.Akonadi.ServerManager.ServiceAgentType,identifier:QString)->QString",
    "AkonadiCore.Akonadi.ServerManager.brokenReason()->QString",
    "AkonadiCore.Akonadi.ServerManager.generation()->uint",
    "AkonadiCore.Akonadi.ServerManager.hasInstanceIdentifier()->bool",
    "AkonadiCore.Akonadi.ServerManager.instanceIdentifier()->QString",
    "AkonadiCore.Akonadi.ServerManager.isRunning()->bool",
    "AkonadiCore.Akonadi.ServerManager.self()->AkonadiCore.Akonadi.ServerManager",
    "AkonadiCore.Akonadi.ServerManager.serverConfigFilePath(openMode:AkonadiCore.Akonadi.ServerManager.OpenMode)->QString",
    "AkonadiCore.Akonadi.ServerManager.serviceName(serviceType:AkonadiCore.Akonadi.ServerManager.ServiceType)->QString",
    "AkonadiCore.Akonadi.ServerManager.start()->bool",
    "AkonadiCore.Akonadi.ServerManager.state()->AkonadiCore.Akonadi.ServerManager.State",
    "AkonadiCore.Akonadi.ServerManager.stop()->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ServerManager_SignatureByteSize = 241;
static constexpr uint8_t Akonadi_ServerManager_SignatureBytes[241] = {
    0x78, 0xda, 0xa5, 0x92, 0xdd, 0x6a, 0xc3, 0x30, 0x0c, 0x85, 0xef, 0xf7, 0x24, 0x19, 0x6c, 0x79,
    0x80, 0x5e, 0x0c, 0x42, 0x61, 0xd0, 0x8b, 0xee, 0xa7, 0xd9, 0x0b, 0xa8, 0xf1, 0x49, 0x2a, 0x9a,
    0x4a, 0xc1, 0x56, 0x0b, 0x7d, 0xfb, 0xc5, 0x6d, 0x56, 0xc6, 0x18, 0xc4, 0xde, 0xae, 0x2c, 0x8b,
    0xf3, 0x49, 0xc7, 0xb2, 0xaa, 0xbd, 0x0a, 0x39, 0x5e, 0xaa, 0x47, 0x59, 0x5d, 0xe3, 0xb2, 0x86,
    0x3f, 0xc1, 0xaf, 0x49, 0xa8, 0x83, 0x2f, 0xc9, 0xb9, 0x17, 0x3a, 0x20, 0x0c, 0xd4, 0xa0, 0x08,
    0xe6, 0x59, 0xba, 0xc5, 0x7b, 0x7d, 0x39, 0xef, 0x1f, 0x9f, 0xa6, 0xe8, 0xae, 0x9a, 0xaf, 0xd3,
    0x41, 0x6c, 0xa9, 0xd2, 0x72, 0xf7, 0xcc, 0x3d, 0xde, 0xc8, 0x76, 0x05, 0xbb, 0x31, 0xc7, 0x2d,
    0xc3, 0xff, 0xbd, 0x64, 0x4c, 0x71, 0x83, 0xe8, 0xb1, 0xb8, 0x24, 0x3e, 0xce, 0x03, 0x16, 0xf3,
    0xf0, 0xc4, 0x55, 0x5f, 0xc8, 0xc3, 0x3f, 0xcd, 0x6c, 0xbd, 0xee, 0x21, 0x1b, 0x50, 0x50, 0x29,
    0xb2, 0xc8, 0xd1, 0x01, 0x3c, 0x19, 0x5f, 0xb9, 0x23, 0x8b, 0x25, 0x40, 0x3b, 0x0a, 0x2b, 0x09,
    0x46, 0xd2, 0x60, 0x75, 0x33, 0x1e, 0xf9, 0xad, 0x6a, 0x9f, 0xc0, 0xf3, 0xaf, 0x70, 0xba, 0x69,
    0x0e, 0x9b, 0xa3, 0xc8, 0xa8, 0xcd, 0xe8, 0x19, 0xd0, 0xb7, 0x51, 0x3e, 0xab, 0x4c, 0xaa, 0x15,
    0x6f, 0x3f, 0xf6, 0x49, 0x07, 0xc8, 0x5a, 0x5d, 0xca, 0xf7, 0xbf, 0x4e, 0xd2, 0xac, 0x47, 0x87,
    0x6f, 0xbb, 0x36, 0xc5, 0x79, 0xdb, 0x16, 0xd5, 0x79, 0x1d, 0x8d, 0xbc, 0xe5, 0x8c, 0xd8, 0xc8,
    0x90, 0x34, 0xe3, 0xb2, 0x8e, 0xd2, 0xa4, 0x92, 0x3a, 0xdc, 0x1c, 0x7c, 0x02, 0x06, 0x96, 0x8b,
    0x5e
};
#endif

PyTypeObject *init_Akonadi_ServerManager(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_ServerManager_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ServerManager",
        "Akonadi::ServerManager*",
        &Sbk_Akonadi_ServerManager_spec,
        &Shiboken::callCppDestructor< Akonadi::ServerManager >,
        Sbk_Akonadi_ServerManager_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ServerManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ServerManager_SignatureBytes, Akonadi_ServerManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ServerManager_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ServerManager_PythonToCpp_ServerManager_PTR,
        is_ServerManager_PythonToCpp_ServerManager_PTR_Convertible,
        ServerManager_PTR_CppToPython_ServerManager);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager&");
    Shiboken::Conversions::registerConverterAlias(converter, "ServerManager");
    Shiboken::Conversions::registerConverterAlias(converter, "ServerManager*");
    Shiboken::Conversions::registerConverterAlias(converter, "ServerManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ServerManager).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(ServerManagerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_ServerManager_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_ServerManager_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'State'.
    const char *State_Initializer[] = {
        "NotRunning",
        "Starting",
        "Running",
        "Stopping",
        "Broken",
        "Upgrading",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t State_InitializerValues[] = {
        uint8_t(Akonadi::ServerManager::State::NotRunning), //  0x00  0
        uint8_t(Akonadi::ServerManager::State::Starting),   //  0x01  1
        uint8_t(Akonadi::ServerManager::State::Running),    //  0x02  2
        uint8_t(Akonadi::ServerManager::State::Stopping),   //  0x03  3
        uint8_t(Akonadi::ServerManager::State::Broken),     //  0x04  4
        uint8_t(Akonadi::ServerManager::State::Upgrading)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ServerManager.State",
        State_Initializer, State_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_State_IDX].type = EType;
    // Register converter for enum 'Akonadi::ServerManager::State'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ServerManager_State_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ServerManager_State,
            is_Enum_PythonToCpp_Akonadi_ServerManager_State_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager::State");
        Shiboken::Conversions::registerConverterAlias(converter, "ServerManager::State");
        Shiboken::Conversions::registerConverterAlias(converter, "State");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'State' enum.

    // Initialization of enum 'ServiceType'.
    const char *ServiceType_Initializer[] = {
        "Server",
        "Control",
        "ControlLock",
        "UpgradeIndicator",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceType_InitializerValues[] = {
        uint8_t(Akonadi::ServerManager::ServiceType::Server),          //  0x00  0
        uint8_t(Akonadi::ServerManager::ServiceType::Control),         //  0x01  1
        uint8_t(Akonadi::ServerManager::ServiceType::ControlLock),     //  0x02  2
        uint8_t(Akonadi::ServerManager::ServiceType::UpgradeIndicator) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ServerManager.ServiceType",
        ServiceType_Initializer, ServiceType_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceType_IDX].type = EType;
    // Register converter for enum 'Akonadi::ServerManager::ServiceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ServerManager_ServiceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ServerManager_ServiceType,
            is_Enum_PythonToCpp_Akonadi_ServerManager_ServiceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager::ServiceType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServerManager::ServiceType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceType' enum.

    // Initialization of enum 'ServiceAgentType'.
    const char *ServiceAgentType_Initializer[] = {
        "Agent",
        "Resource",
        "Preprocessor",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ServiceAgentType_InitializerValues[] = {
        uint8_t(Akonadi::ServerManager::ServiceAgentType::Agent),       //  0x00  0
        uint8_t(Akonadi::ServerManager::ServiceAgentType::Resource),    //  0x01  1
        uint8_t(Akonadi::ServerManager::ServiceAgentType::Preprocessor) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ServerManager.ServiceAgentType",
        ServiceAgentType_Initializer, ServiceAgentType_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_ServiceAgentType_IDX].type = EType;
    // Register converter for enum 'Akonadi::ServerManager::ServiceAgentType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ServerManager_ServiceAgentType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ServerManager_ServiceAgentType,
            is_Enum_PythonToCpp_Akonadi_ServerManager_ServiceAgentType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager::ServiceAgentType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServerManager::ServiceAgentType");
        Shiboken::Conversions::registerConverterAlias(converter, "ServiceAgentType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ServiceAgentType' enum.

    // Initialization of enum 'OpenMode'.
    const char *OpenMode_Initializer[] = {
        "ReadOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OpenMode_InitializerValues[] = {
        uint8_t(Akonadi::ServerManager::OpenMode::ReadOnly), //  0x00  0
        uint8_t(Akonadi::ServerManager::OpenMode::ReadWrite) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ServerManager.OpenMode",
        OpenMode_Initializer, OpenMode_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ServerManager_OpenMode_IDX].type = EType;
    // Register converter for enum 'Akonadi::ServerManager::OpenMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ServerManager_OpenMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ServerManager_OpenMode,
            is_Enum_PythonToCpp_Akonadi_ServerManager_OpenMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ServerManager::OpenMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ServerManager::OpenMode");
        Shiboken::Conversions::registerConverterAlias(converter, "OpenMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'OpenMode' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::ServerManager::staticMetaObject);
    qRegisterMetaType< ::Akonadi::ServerManager::State >("ServerManager::State");
    qRegisterMetaType< ::Akonadi::ServerManager::State >("Akonadi::ServerManager::State");
    qRegisterMetaType< ::Akonadi::ServerManager::ServiceType >("ServerManager::ServiceType");
    qRegisterMetaType< ::Akonadi::ServerManager::ServiceType >("Akonadi::ServerManager::ServiceType");
    qRegisterMetaType< ::Akonadi::ServerManager::ServiceAgentType >("ServerManager::ServiceAgentType");
    qRegisterMetaType< ::Akonadi::ServerManager::ServiceAgentType >("Akonadi::ServerManager::ServiceAgentType");
    qRegisterMetaType< ::Akonadi::ServerManager::OpenMode >("ServerManager::OpenMode");
    qRegisterMetaType< ::Akonadi::ServerManager::OpenMode >("Akonadi::ServerManager::OpenMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::ServerManager::staticMetaObject, sizeof(ServerManagerWrapper));

    return pyType;
}
