
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_collectionstatistics_wrapper.h"

// Argument includes
#include <collectionstatistics.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_CollectionStatistics_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_CollectionStatistics_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::CollectionStatistics >()))
        return -1;

    ::Akonadi::CollectionStatistics *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "CollectionStatistics", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CollectionStatistics::CollectionStatistics()
    // 1: CollectionStatistics::CollectionStatistics(const Akonadi::CollectionStatistics&)
    if (numArgs == 0) {
        overloadId = 0; // CollectionStatistics()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), (pyArgs[0])))) {
        overloadId = 1; // CollectionStatistics::CollectionStatistics(const Akonadi::CollectionStatistics&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // CollectionStatistics()
        {

            // CollectionStatistics::CollectionStatistics()
            cptr = new ::Akonadi::CollectionStatistics();
            break;
        }
        case 1: // CollectionStatistics(const Akonadi::CollectionStatistics &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::CollectionStatistics cppArg0_local;
            ::Akonadi::CollectionStatistics *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // CollectionStatistics::CollectionStatistics(const Akonadi::CollectionStatistics&)
                cptr = new ::Akonadi::CollectionStatistics(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::CollectionStatistics >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionStatistics::count()const->qint64
        qint64 cppResult = const_cast<const ::Akonadi::CollectionStatistics *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_setCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionStatistics::setCount(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // CollectionStatistics::setCount(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionStatistics::setCount(qint64)
            cppSelf->setCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionStatistics::setSize(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // CollectionStatistics::setSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionStatistics::setSize(qint64)
            cppSelf->setSize(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_setUnreadCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CollectionStatistics::setUnreadCount(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // CollectionStatistics::setUnreadCount(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnreadCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CollectionStatistics::setUnreadCount(qint64)
            cppSelf->setUnreadCount(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionStatistics::size()const->qint64
        qint64 cppResult = const_cast<const ::Akonadi::CollectionStatistics *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionStatisticsFunc_unreadCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CollectionStatistics::unreadCount()const->qint64
        qint64 cppResult = const_cast<const ::Akonadi::CollectionStatistics *>(cppSelf)->unreadCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CollectionStatistics__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_CollectionStatistics_PropertyStrings[] = {
    "count:",
    "size:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CollectionStatistics_methods[] = {
    {"count", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_count), METH_NOARGS, nullptr},
    {"setCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_setCount), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_setSize), METH_O, nullptr},
    {"setUnreadCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_setUnreadCount), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_size), METH_NOARGS, nullptr},
    {"unreadCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatisticsFunc_unreadCount), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CollectionStatistics__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_CollectionStatistics_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CollectionStatistics_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_Akonadi_CollectionStatistics__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(self)));
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C


// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CollectionStatistics_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionStatistics__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CollectionStatistics_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CollectionStatistics_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CollectionStatistics_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CollectionStatistics_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CollectionStatistics_spec = {
    "1:AkonadiCore.Akonadi.CollectionStatistics",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CollectionStatistics_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CollectionStatistics_PythonToCpp_CollectionStatistics_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_CollectionStatistics_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CollectionStatistics_PythonToCpp_CollectionStatistics_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionStatistics_TypeF()))
        return CollectionStatistics_PythonToCpp_CollectionStatistics_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CollectionStatistics_PTR_CppToPython_CollectionStatistics(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_CollectionStatistics_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_CollectionStatistics_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *CollectionStatistics_COPY_CppToPython_CollectionStatistics(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::CollectionStatistics *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_CollectionStatistics_TypeF(), new ::Akonadi::CollectionStatistics(*source), true, true);
}

// Python to C++ copy conversion.
static void CollectionStatistics_PythonToCpp_CollectionStatistics_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::CollectionStatistics *>(cppOut) = *reinterpret_cast< ::Akonadi::CollectionStatistics *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_CollectionStatistics_PythonToCpp_CollectionStatistics_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CollectionStatistics_TypeF()))
        return CollectionStatistics_PythonToCpp_CollectionStatistics_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_CollectionStatistics_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.CollectionStatistics(self,*:KeywordOnly=None,count:int=None,size:int=None)",
    "0:AkonadiCore.Akonadi.CollectionStatistics(self,other:AkonadiCore.Akonadi.CollectionStatistics,*:KeywordOnly=None,count:int=None,size:int=None)",
    "AkonadiCore.Akonadi.CollectionStatistics.count(self)->qint64",
    "AkonadiCore.Akonadi.CollectionStatistics.setCount(self,count:qint64)",
    "AkonadiCore.Akonadi.CollectionStatistics.setSize(self,size:qint64)",
    "AkonadiCore.Akonadi.CollectionStatistics.setUnreadCount(self,count:qint64)",
    "AkonadiCore.Akonadi.CollectionStatistics.size(self)->qint64",
    "AkonadiCore.Akonadi.CollectionStatistics.unreadCount(self)->qint64",
    "AkonadiCore.Akonadi.CollectionStatistics.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_CollectionStatistics_SignatureByteSize = 179;
static constexpr uint8_t Akonadi_CollectionStatistics_SignatureBytes[179] = {
    0x78, 0xda, 0xad, 0x90, 0x3d, 0x0b, 0xc2, 0x30, 0x10, 0x86, 0xf7, 0xfe, 0x12, 0x2b, 0x35, 0x28,
    0x88, 0x43, 0x41, 0x41, 0x32, 0x0a, 0x3a, 0x14, 0xe7, 0x50, 0xd2, 0x53, 0x83, 0xe1, 0xae, 0x26,
    0x57, 0x24, 0xfe, 0x7a, 0x4b, 0xbf, 0x06, 0xa7, 0xb6, 0xb8, 0xdd, 0x3b, 0xbc, 0xcf, 0x3d, 0x77,
    0x9b, 0xf4, 0xf8, 0x24, 0xcc, 0x0b, 0x23, 0xc9, 0x81, 0xe8, 0x66, 0x21, 0xc9, 0x5a, 0xd0, 0x6c,
    0x08, 0x33, 0xce, 0xd9, 0x78, 0x36, 0xda, 0x2f, 0x3c, 0xd8, 0x5b, 0xb2, 0x4c, 0x4f, 0x10, 0xde,
    0xe4, 0x8a, 0x0b, 0xda, 0xb0, 0x3f, 0x13, 0x42, 0xa2, 0xa9, 0x42, 0x4e, 0x0d, 0x72, 0x1b, 0xbd,
    0xf9, 0xc0, 0x90, 0xe2, 0x68, 0x3d, 0x71, 0x01, 0xf1, 0x03, 0xdc, 0xe8, 0xce, 0x74, 0x9f, 0xb1,
    0x64, 0xd1, 0x60, 0x1a, 0xa7, 0x78, 0x75, 0x78, 0xd5, 0x80, 0xdd, 0x76, 0x7c, 0xd9, 0x03, 0xcb,
    0xa1, 0xdf, 0x19, 0xb5, 0x8c, 0x78, 0x12, 0x24, 0xab, 0xe5, 0x5b, 0x46, 0x73, 0xc6, 0x1c, 0xc4,
    0x15, 0x1d, 0xe4, 0xc5, 0x1f, 0x6c, 0x7a, 0x95, 0x19, 0xef, 0xa8, 0x7e, 0x1c, 0x66, 0x20, 0x94,
    0xd2, 0x54, 0x06, 0xa5, 0xfa, 0x3e, 0x87, 0xd2, 0xe0, 0x5d, 0xa8, 0xac, 0x8e, 0xd1, 0x17, 0xf3,
    0x8f, 0x07, 0xdc
};
#endif

PyTypeObject *init_Akonadi_CollectionStatistics(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionStatistics_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_CollectionStatistics_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CollectionStatistics",
        "Akonadi::CollectionStatistics",
        &Sbk_Akonadi_CollectionStatistics_spec,
        &Shiboken::callCppDestructor< ::Akonadi::CollectionStatistics >,
        Sbk_Akonadi_CollectionStatistics_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_CollectionStatistics_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_CollectionStatistics_SignatureBytes, Akonadi_CollectionStatistics_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CollectionStatistics_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CollectionStatistics_PythonToCpp_CollectionStatistics_PTR,
        is_CollectionStatistics_PythonToCpp_CollectionStatistics_PTR_Convertible,
        CollectionStatistics_PTR_CppToPython_CollectionStatistics,
        CollectionStatistics_COPY_CppToPython_CollectionStatistics);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionStatistics");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionStatistics*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CollectionStatistics&");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionStatistics");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionStatistics*");
    Shiboken::Conversions::registerConverterAlias(converter, "CollectionStatistics&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::CollectionStatistics).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        CollectionStatistics_PythonToCpp_CollectionStatistics_COPY,
        is_CollectionStatistics_PythonToCpp_CollectionStatistics_COPY_Convertible);

    qRegisterMetaType< ::Akonadi::CollectionStatistics >("CollectionStatistics");
    qRegisterMetaType< ::Akonadi::CollectionStatistics >("Akonadi::CollectionStatistics");

    return pyType;
}
