/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.PreprocessorManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "preprocessormanageradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PreprocessorManagerAdaptor
 */

PreprocessorManagerAdaptor::PreprocessorManagerAdaptor(Akonadi::Server::PreprocessorManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PreprocessorManagerAdaptor::~PreprocessorManagerAdaptor()
{
    // destructor
}

void PreprocessorManagerAdaptor::registerInstance(const QString &id)
{
    // handle method call org.freedesktop.Akonadi.PreprocessorManager.registerInstance
    parent()->registerInstance(id);
}

void PreprocessorManagerAdaptor::unregisterInstance(const QString &id)
{
    // handle method call org.freedesktop.Akonadi.PreprocessorManager.unregisterInstance
    parent()->unregisterInstance(id);
}


#include "moc_preprocessormanageradaptor.cpp"
