/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<agentconfiguration.h>)
#  include <agentconfiguration.h>
#endif
#if __has_include(<collectioncomboboxmodel.h>)
#  include <collectioncomboboxmodel.h>
#endif
#if __has_include(<collectioneditorcontroller.h>)
#  include <collectioneditorcontroller.h>
#endif
#if __has_include(<collectionpickermodel.h>)
#  include <collectionpickermodel.h>
#endif
#if __has_include(<etmtreeviewstatesaver.h>)
#  include <etmtreeviewstatesaver.h>
#endif
#if __has_include(<mimetypes.h>)
#  include <mimetypes.h>
#endif
#if __has_include(<tagmanager.h>)
#  include <tagmanager.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_akonadi()
{
    qmlRegisterModule("org.kde.akonadi", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AgentConfiguration>("org.kde.akonadi", 254);
    qmlRegisterEnum<AgentConfiguration::AgentStatuses>("AgentConfiguration::AgentStatuses");
    qmlRegisterTypesAndRevisions<AgentFilterProxyModelForeign>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<AgentInstanceForeign>("org.kde.akonadi", 254);
    QMetaType::fromType<AgentInstanceForeign *>().id();
    qmlRegisterEnum<Akonadi::AgentInstance::Status>("Akonadi::AgentInstance::Status");
    QMetaType::fromType<Akonadi::Collection>().id();
    qmlRegisterEnum<Akonadi::Collection::Right>("Akonadi::Collection::Right");
    qmlRegisterTypesAndRevisions<Akonadi::Quick::CollectionComboBoxModel>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<Akonadi::Quick::CollectionPickerModel>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<Akonadi::Quick::MimeTypes>("org.kde.akonadi", 254);
    QMetaType::fromType<CollectionDerived>().id();
    qmlRegisterNamespaceAndRevisions(&CollectionDerived::staticMetaObject, "org.kde.akonadi", 254, nullptr, &CollectionDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<CollectionEditorController>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<CollectionForeign>("org.kde.akonadi", 254);
    QMetaType::fromType<CollectionForeign *>().id();
    qmlRegisterTypesAndRevisions<ETMTreeViewStateSaver>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<EntityTreeModelForeign>("org.kde.akonadi", 254);
    qmlRegisterEnum<Akonadi::EntityTreeModel::Roles>("Akonadi::EntityTreeModel::Roles");
    qmlRegisterEnum<Akonadi::EntityTreeModel::FetchState>("Akonadi::EntityTreeModel::FetchState");
    QMetaType::fromType<ItemDerived>().id();
    qmlRegisterNamespaceAndRevisions(&ItemDerived::staticMetaObject, "org.kde.akonadi", 254, nullptr, &ItemDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<ItemForeign>("org.kde.akonadi", 254);
    QMetaType::fromType<ItemForeign *>().id();
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<SpecialCollections>("org.kde.akonadi", 254);
    qmlRegisterTypesAndRevisions<TagManager>("org.kde.akonadi", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.akonadi", 254, 254);
}

static const QQmlModuleRegistration orgkdeakonadiRegistration("org.kde.akonadi", qml_register_types_org_kde_akonadi);
