/********************************************************************************
** Form generated from reading UI file 'manageaccountwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGEACCOUNTWIDGET_H
#define UI_MANAGEACCOUNTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/AgentInstanceWidget"

QT_BEGIN_NAMESPACE

class Ui_ManageAccountWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *vlay;
    QCheckBox *accountOnCurrentActivity;
    QLabel *label;
    QLineEdit *mFilterAccount;
    QHBoxLayout *hlay;
    Akonadi::AgentInstanceWidget *mAccountList;
    QVBoxLayout *btn_vlay;
    QPushButton *mAddAccountButton;
    QPushButton *mModifyAccountButton;
    QPushButton *mRemoveAccountButton;
    QFrame *line;
    QPushButton *mRestartAccountButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ManageAccountWidget)
    {
        if (ManageAccountWidget->objectName().isEmpty())
            ManageAccountWidget->setObjectName("ManageAccountWidget");
        ManageAccountWidget->resize(692, 578);
        verticalLayout_3 = new QVBoxLayout(ManageAccountWidget);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        vlay = new QVBoxLayout();
        vlay->setSpacing(6);
        vlay->setObjectName("vlay");
        accountOnCurrentActivity = new QCheckBox(ManageAccountWidget);
        accountOnCurrentActivity->setObjectName("accountOnCurrentActivity");

        vlay->addWidget(accountOnCurrentActivity);

        label = new QLabel(ManageAccountWidget);
        label->setObjectName("label");

        vlay->addWidget(label);

        mFilterAccount = new QLineEdit(ManageAccountWidget);
        mFilterAccount->setObjectName("mFilterAccount");

        vlay->addWidget(mFilterAccount);

        hlay = new QHBoxLayout();
        hlay->setSpacing(6);
        hlay->setObjectName("hlay");
        mAccountList = new Akonadi::AgentInstanceWidget(ManageAccountWidget);
        mAccountList->setObjectName("mAccountList");

        hlay->addWidget(mAccountList);

        btn_vlay = new QVBoxLayout();
        btn_vlay->setSpacing(6);
        btn_vlay->setObjectName("btn_vlay");
        mAddAccountButton = new QPushButton(ManageAccountWidget);
        mAddAccountButton->setObjectName("mAddAccountButton");

        btn_vlay->addWidget(mAddAccountButton);

        mModifyAccountButton = new QPushButton(ManageAccountWidget);
        mModifyAccountButton->setObjectName("mModifyAccountButton");
        mModifyAccountButton->setEnabled(false);

        btn_vlay->addWidget(mModifyAccountButton);

        mRemoveAccountButton = new QPushButton(ManageAccountWidget);
        mRemoveAccountButton->setObjectName("mRemoveAccountButton");
        mRemoveAccountButton->setEnabled(false);

        btn_vlay->addWidget(mRemoveAccountButton);

        line = new QFrame(ManageAccountWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        btn_vlay->addWidget(line);

        mRestartAccountButton = new QPushButton(ManageAccountWidget);
        mRestartAccountButton->setObjectName("mRestartAccountButton");
        mRestartAccountButton->setEnabled(false);

        btn_vlay->addWidget(mRestartAccountButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        btn_vlay->addItem(verticalSpacer);


        hlay->addLayout(btn_vlay);


        vlay->addLayout(hlay);


        verticalLayout_3->addLayout(vlay);


        retranslateUi(ManageAccountWidget);

        QMetaObject::connectSlotsByName(ManageAccountWidget);
    } // setupUi

    void retranslateUi(QWidget *ManageAccountWidget)
    {
        accountOnCurrentActivity->setText(tr2i18n("Show only account on current activity", nullptr));
        label->setText(tr2i18n("Incoming accounts (add at least one):", nullptr));
        mFilterAccount->setPlaceholderText(tr2i18n("Filter\342\200\246", nullptr));
        mAddAccountButton->setText(tr2i18n("A&dd...", nullptr));
        mModifyAccountButton->setText(tr2i18n("&Modify...", nullptr));
        mRemoveAccountButton->setText(tr2i18n("R&emove", nullptr));
        mRestartAccountButton->setText(tr2i18n("Restart", nullptr));
        (void)ManageAccountWidget;
    } // retranslateUi

};

namespace Ui {
    class ManageAccountWidget: public Ui_ManageAccountWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGEACCOUNTWIDGET_H

