
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_abstractdifferencesreporter_wrapper.h"

// Wrappers providing overrides
#include "akonadi_abstractdifferencesreporter_wrapper.h"

// Argument includes
#include <QString>
#include <abstractdifferencesreporter.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_AbstractDifferencesReporter_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void AbstractDifferencesReporterWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

AbstractDifferencesReporterWrapper::AbstractDifferencesReporterWrapper()
{
}

void AbstractDifferencesReporterWrapper::addProperty(::Akonadi::AbstractDifferencesReporter::Mode mode, const ::QString & name, const ::QString & leftValue, const ::QString & rightValue)
{
    static const char *funcName = "addProperty";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.addProperty");
        return;
    }
    sbk_o_addProperty("AbstractDifferencesReporter", funcName, gil, pyOverride, mode, name, leftValue, rightValue);
}

void AbstractDifferencesReporterWrapper::sbk_o_addProperty([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::Akonadi::AbstractDifferencesReporter::Mode mode, [[maybe_unused]] const ::QString & name, [[maybe_unused]] const ::QString & leftValue, [[maybe_unused]] const ::QString & rightValue)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX]))), &mode),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &leftValue),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &rightValue)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX]))), &mode),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &leftValue),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &rightValue)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void AbstractDifferencesReporterWrapper::setLeftPropertyValueTitle(const ::QString & title)
{
    static const char *funcName = "setLeftPropertyValueTitle";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setLeftPropertyValueTitle");
        return;
    }
    sbk_o_setLeftPropertyValueTitle("AbstractDifferencesReporter", funcName, gil, pyOverride, title);
}

void AbstractDifferencesReporterWrapper::sbk_o_setLeftPropertyValueTitle([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QString & title)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &title)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &title)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void AbstractDifferencesReporterWrapper::setPropertyNameTitle(const ::QString & title)
{
    static const char *funcName = "setPropertyNameTitle";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setPropertyNameTitle");
        return;
    }
    AbstractDifferencesReporterWrapper::sbk_o_setLeftPropertyValueTitle("AbstractDifferencesReporter", funcName, gil, pyOverride, title);
}

void AbstractDifferencesReporterWrapper::setRightPropertyValueTitle(const ::QString & title)
{
    static const char *funcName = "setRightPropertyValueTitle";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setRightPropertyValueTitle");
        return;
    }
    AbstractDifferencesReporterWrapper::sbk_o_setLeftPropertyValueTitle("AbstractDifferencesReporter", funcName, gil, pyOverride, title);
}

AbstractDifferencesReporterWrapper::~AbstractDifferencesReporterWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_AbstractDifferencesReporter_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_AbstractDifferencesReporter_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("Akonadi::AbstractDifferencesReporter");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::AbstractDifferencesReporter >()))
        return -1;

    AbstractDifferencesReporterWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // AbstractDifferencesReporter::AbstractDifferencesReporter()
        cptr = new AbstractDifferencesReporterWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::AbstractDifferencesReporter >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_AbstractDifferencesReporterFunc_addProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AbstractDifferencesReporter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addProperty", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: AbstractDifferencesReporter::addProperty(Akonadi::AbstractDifferencesReporter::Mode,const QString&,const QString&,const QString&)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 0; // AbstractDifferencesReporter::addProperty(Akonadi::AbstractDifferencesReporter::Mode,const QString&,const QString&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addProperty", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);

    // Call function/method
    {
        ::Akonadi::AbstractDifferencesReporter::Mode cppArg0{Akonadi::AbstractDifferencesReporter::NormalMode};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AbstractDifferencesReporter::addProperty(Akonadi::AbstractDifferencesReporter::Mode,const QString&,const QString&,const QString&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.addProperty");
                return {};
            }
            cppSelf->addProperty(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AbstractDifferencesReporterFunc_setLeftPropertyValueTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AbstractDifferencesReporter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AbstractDifferencesReporter::setLeftPropertyValueTitle(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // AbstractDifferencesReporter::setLeftPropertyValueTitle(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLeftPropertyValueTitle", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AbstractDifferencesReporter::setLeftPropertyValueTitle(const QString&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setLeftPropertyValueTitle");
                return {};
            }
            cppSelf->setLeftPropertyValueTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AbstractDifferencesReporterFunc_setPropertyNameTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AbstractDifferencesReporter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AbstractDifferencesReporter::setPropertyNameTitle(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // AbstractDifferencesReporter::setPropertyNameTitle(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPropertyNameTitle", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AbstractDifferencesReporter::setPropertyNameTitle(const QString&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setPropertyNameTitle");
                return {};
            }
            cppSelf->setPropertyNameTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AbstractDifferencesReporterFunc_setRightPropertyValueTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AbstractDifferencesReporter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AbstractDifferencesReporter::setRightPropertyValueTitle(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // AbstractDifferencesReporter::setRightPropertyValueTitle(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRightPropertyValueTitle", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AbstractDifferencesReporter::setRightPropertyValueTitle(const QString&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("AbstractDifferencesReporter.setRightPropertyValueTitle");
                return {};
            }
            cppSelf->setRightPropertyValueTitle(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_AbstractDifferencesReporter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_AbstractDifferencesReporter_EnumFlagInfo[] = {
    "Mode:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_AbstractDifferencesReporter_methods[] = {
    {"addProperty", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AbstractDifferencesReporterFunc_addProperty), METH_VARARGS, nullptr},
    {"setLeftPropertyValueTitle", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AbstractDifferencesReporterFunc_setLeftPropertyValueTitle), METH_O, nullptr},
    {"setPropertyNameTitle", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AbstractDifferencesReporterFunc_setPropertyNameTitle), METH_O, nullptr},
    {"setRightPropertyValueTitle", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AbstractDifferencesReporterFunc_setRightPropertyValueTitle), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_AbstractDifferencesReporter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::AbstractDifferencesReporter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<AbstractDifferencesReporterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_AbstractDifferencesReporter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_AbstractDifferencesReporter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_AbstractDifferencesReporter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_AbstractDifferencesReporter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_AbstractDifferencesReporter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_AbstractDifferencesReporter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_AbstractDifferencesReporter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_AbstractDifferencesReporter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_AbstractDifferencesReporter_spec = {
    "1:AkonadiCore.Akonadi.AbstractDifferencesReporter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_AbstractDifferencesReporter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_AbstractDifferencesReporter_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::AbstractDifferencesReporter::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::AbstractDifferencesReporter::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_AbstractDifferencesReporter_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX])))
        return Enum_PythonToCpp_Akonadi_AbstractDifferencesReporter_Mode;
    return {};
}

static PyObject *Akonadi_AbstractDifferencesReporter_Mode_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::AbstractDifferencesReporter::Mode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::AbstractDifferencesReporter::Mode *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void AbstractDifferencesReporter_PythonToCpp_AbstractDifferencesReporter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_AbstractDifferencesReporter_PythonToCpp_AbstractDifferencesReporter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AbstractDifferencesReporter_TypeF()))
        return AbstractDifferencesReporter_PythonToCpp_AbstractDifferencesReporter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *AbstractDifferencesReporter_PTR_CppToPython_AbstractDifferencesReporter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_AbstractDifferencesReporter_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::AbstractDifferencesReporter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_AbstractDifferencesReporter_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_AbstractDifferencesReporter_SignatureStrings[] = {
    "AkonadiCore.Akonadi.AbstractDifferencesReporter(self)",
    "AkonadiCore.Akonadi.AbstractDifferencesReporter.addProperty(self,mode:AkonadiCore.Akonadi.AbstractDifferencesReporter.Mode,name:QString,leftValue:QString,rightValue:QString)",
    "AkonadiCore.Akonadi.AbstractDifferencesReporter.setLeftPropertyValueTitle(self,title:QString)",
    "AkonadiCore.Akonadi.AbstractDifferencesReporter.setPropertyNameTitle(self,title:QString)",
    "AkonadiCore.Akonadi.AbstractDifferencesReporter.setRightPropertyValueTitle(self,title:QString)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_AbstractDifferencesReporter_SignatureByteSize = 150;
static constexpr uint8_t Akonadi_AbstractDifferencesReporter_SignatureBytes[150] = {
    0x78, 0xda, 0xad, 0x8f, 0x41, 0x0a, 0xc2, 0x30, 0x14, 0x44, 0xf7, 0x9e, 0x44, 0x21, 0xe4, 0x00,
    0xdd, 0x05, 0x5d, 0xaa, 0x68, 0x15, 0xf7, 0xb1, 0x99, 0xd4, 0x60, 0x9a, 0x94, 0x9f, 0xef, 0xc2,
    0xdb, 0x9b, 0xb6, 0x14, 0x71, 0x67, 0xd0, 0xdd, 0x30, 0x30, 0x8f, 0x37, 0xea, 0x1e, 0x83, 0x36,
    0x6e, 0x1d, 0x09, 0x52, 0x4d, 0x59, 0xaa, 0x6b, 0x62, 0xd2, 0x0d, 0x6f, 0x9c, 0xb5, 0x20, 0x84,
    0x06, 0xa9, 0x46, 0x1f, 0x89, 0x41, 0xcb, 0x04, 0x6f, 0x57, 0x0b, 0x55, 0xb6, 0x92, 0xda, 0x98,
    0x03, 0xc5, 0x1e, 0xc4, 0xcf, 0x91, 0x20, 0xba, 0x68, 0x50, 0x95, 0x52, 0x76, 0x79, 0x24, 0x82,
    0xee, 0x50, 0x1d, 0x4f, 0x4c, 0x2e, 0xb4, 0xc2, 0xc3, 0xf2, 0x45, 0xfb, 0xc7, 0xbb, 0x21, 0xd7,
    0xde, 0x3e, 0xab, 0x72, 0xdb, 0x04, 0xde, 0x66, 0xf0, 0x6c, 0x3c, 0xd2, 0xce, 0x8e, 0x3d, 0x26,
    0x77, 0x1e, 0xe2, 0x4f, 0xf4, 0x99, 0xbc, 0xcf, 0x5f, 0xfe, 0x0a, 0xae, 0x87, 0xf7, 0x5f, 0x7a,
    0xbf, 0x00, 0x3e, 0x3e, 0xc0, 0x69
};
#endif

PyTypeObject *init_Akonadi_AbstractDifferencesReporter(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_AbstractDifferencesReporter_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "AbstractDifferencesReporter",
        "Akonadi::AbstractDifferencesReporter*",
        &Sbk_Akonadi_AbstractDifferencesReporter_spec,
        &Shiboken::callCppDestructor< Akonadi::AbstractDifferencesReporter >,
        Sbk_Akonadi_AbstractDifferencesReporter_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_AbstractDifferencesReporter_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_AbstractDifferencesReporter_SignatureBytes, Akonadi_AbstractDifferencesReporter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_AbstractDifferencesReporter_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        AbstractDifferencesReporter_PythonToCpp_AbstractDifferencesReporter_PTR,
        is_AbstractDifferencesReporter_PythonToCpp_AbstractDifferencesReporter_PTR_Convertible,
        AbstractDifferencesReporter_PTR_CppToPython_AbstractDifferencesReporter);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AbstractDifferencesReporter");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AbstractDifferencesReporter*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AbstractDifferencesReporter&");
    Shiboken::Conversions::registerConverterAlias(converter, "AbstractDifferencesReporter");
    Shiboken::Conversions::registerConverterAlias(converter, "AbstractDifferencesReporter*");
    Shiboken::Conversions::registerConverterAlias(converter, "AbstractDifferencesReporter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::AbstractDifferencesReporter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(AbstractDifferencesReporterWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_AbstractDifferencesReporter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "NormalMode",
        "ConflictMode",
        "AdditionalLeftMode",
        "AdditionalRightMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(Akonadi::AbstractDifferencesReporter::Mode::NormalMode),         //  0x00  0
        uint8_t(Akonadi::AbstractDifferencesReporter::Mode::ConflictMode),       //  0x01  1
        uint8_t(Akonadi::AbstractDifferencesReporter::Mode::AdditionalLeftMode), //  0x02  2
        uint8_t(Akonadi::AbstractDifferencesReporter::Mode::AdditionalRightMode) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.AbstractDifferencesReporter.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_AbstractDifferencesReporter_Mode_IDX].type = EType;
    // Register converter for enum 'Akonadi::AbstractDifferencesReporter::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_AbstractDifferencesReporter_Mode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_AbstractDifferencesReporter_Mode,
            is_Enum_PythonToCpp_Akonadi_AbstractDifferencesReporter_Mode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::AbstractDifferencesReporter::Mode");
        Shiboken::Conversions::registerConverterAlias(converter, "AbstractDifferencesReporter::Mode");
        Shiboken::Conversions::registerConverterAlias(converter, "Mode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Mode' enum.

    qRegisterMetaType< ::Akonadi::AbstractDifferencesReporter *>();
    qRegisterMetaType< ::Akonadi::AbstractDifferencesReporter::Mode >("AbstractDifferencesReporter::Mode");
    qRegisterMetaType< ::Akonadi::AbstractDifferencesReporter::Mode >("Akonadi::AbstractDifferencesReporter::Mode");

    return pyType;
}
