
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_statisticsproxymodel_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_StatisticsProxyModel_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void StatisticsProxyModelWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

StatisticsProxyModelWrapper::StatisticsProxyModelWrapper(::QObject * parent) : Akonadi::StatisticsProxyModel(parent)
{
}

::QVariant StatisticsProxyModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StatisticsProxyModel_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::StatisticsProxyModel::data(index, role);
    }
    return sbk_o_data("StatisticsProxyModel", funcName, gil, pyOverride, index, role);
}

::QVariant StatisticsProxyModelWrapper::sbk_o_data([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QModelIndex & index, [[maybe_unused]] int role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Ni)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &index),
        role
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant StatisticsProxyModelWrapper::extraColumnData(const ::QModelIndex & parent, int row, int extraColumn, int role) const
{
    static const char *funcName = "extraColumnData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StatisticsProxyModel_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::StatisticsProxyModel::extraColumnData(parent, row, extraColumn, role);
    }
    return sbk_o_extraColumnData("StatisticsProxyModel", funcName, gil, pyOverride, parent, row, extraColumn, role);
}

::QVariant StatisticsProxyModelWrapper::sbk_o_extraColumnData([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QModelIndex & parent, [[maybe_unused]] int row, [[maybe_unused]] int extraColumn, [[maybe_unused]] int role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &parent),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &row),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &extraColumn),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Niii)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &parent),
        row,
        extraColumn,
        role
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<Qt::ItemFlag> StatisticsProxyModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StatisticsProxyModel_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::StatisticsProxyModel::flags(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_flags("StatisticsProxyModel", funcName, gil, pyOverride, index);
}

::QList<QModelIndex> StatisticsProxyModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StatisticsProxyModel_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::StatisticsProxyModel::match(start, role, value, hits, flags);
    }
    return TrashFilterProxyModelWrapper::sbk_o_match("StatisticsProxyModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

void StatisticsProxyModelWrapper::setSourceModel(::QAbstractItemModel * model)
{
    static const char *funcName = "setSourceModel";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StatisticsProxyModel_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::StatisticsProxyModel::setSourceModel(model);
    }
    sbk_o_setSourceModel("StatisticsProxyModel", funcName, gil, pyOverride, model);
}

void StatisticsProxyModelWrapper::sbk_o_setSourceModel([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::QAbstractItemModel * model)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), model)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

StatisticsProxyModelWrapper::~StatisticsProxyModelWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_StatisticsProxyModel_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_StatisticsProxyModel_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::StatisticsProxyModel >()))
        return -1;

    StatisticsProxyModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:StatisticsProxyModel", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: StatisticsProxyModel::StatisticsProxyModel(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // StatisticsProxyModel(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // StatisticsProxyModel::StatisticsProxyModel(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);
            }
        }
    }

    // PyMI support
    Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::StatisticsProxyModel(QObject*=)
            cptr = new StatisticsProxyModelWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::StatisticsProxyModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_data(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:data", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: StatisticsProxyModel::data(const QModelIndex&,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // StatisticsProxyModel::data(const QModelIndex&,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = Qt::DisplayRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::data(const QModelIndex&,int=)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->::Akonadi::StatisticsProxyModel::data(*cppArg0, cppArg1)
                : const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_extraColumnData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "extraColumnData", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: StatisticsProxyModel::extraColumnData(const QModelIndex&,int,int,int)const->QVariant
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // StatisticsProxyModel::extraColumnData(const QModelIndex&,int,int,int)const->QVariant
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "extraColumnData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::extraColumnData(const QModelIndex&,int,int,int)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->::Akonadi::StatisticsProxyModel::extraColumnData(*cppArg0, cppArg1, cppArg2, cppArg3)
                : const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->extraColumnData(*cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_flags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StatisticsProxyModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // StatisticsProxyModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "flags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
            QFlags<Qt::ItemFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->::Akonadi::StatisticsProxyModel::flags(*cppArg0)
                : const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->flags(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX]))), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_isExtraColumnsEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // StatisticsProxyModel::isExtraColumnsEnabled()const->bool
        bool cppResult = const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->isExtraColumnsEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_isToolTipEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // StatisticsProxyModel::isToolTipEnabled()const->bool
        bool cppResult = const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->isToolTipEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_match(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:match", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: StatisticsProxyModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX]))), (pyArgs[4])))) {
                overloadId = 0; // StatisticsProxyModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "match", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"hits", 3}, {"flags", 4}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))))
                || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX]))), (pyArgs[4])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "match", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<Qt::MatchFlag> cppArg4 = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
            QList<QModelIndex> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->::Akonadi::StatisticsProxyModel::match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4)
                : const_cast<const ::Akonadi::StatisticsProxyModel *>(cppSelf)->match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QModelIndex_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_setExtraColumnsEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StatisticsProxyModel::setExtraColumnsEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // StatisticsProxyModel::setExtraColumnsEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtraColumnsEnabled", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::setExtraColumnsEnabled(bool)
            cppSelf->setExtraColumnsEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_setSourceModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StatisticsProxyModel::setSourceModel(QAbstractItemModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArg)))) {
        overloadId = 0; // StatisticsProxyModel::setSourceModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSourceModel", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::setSourceModel(QAbstractItemModel*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::StatisticsProxyModel::setSourceModel(cppArg0)
                : cppSelf->setSourceModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StatisticsProxyModelFunc_setToolTipEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StatisticsProxyModel::setToolTipEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // StatisticsProxyModel::setToolTipEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setToolTipEnabled", SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StatisticsProxyModel::setToolTipEnabled(bool)
            cppSelf->setToolTipEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_StatisticsProxyModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_StatisticsProxyModel_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"extraColumnData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_extraColumnData), METH_VARARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_flags), METH_O, nullptr},
    {"isExtraColumnsEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_isExtraColumnsEnabled), METH_NOARGS, nullptr},
    {"isToolTipEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_isToolTipEnabled), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_match), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setExtraColumnsEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_setExtraColumnsEnabled), METH_O, nullptr},
    {"setSourceModel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_setSourceModel), METH_O, nullptr},
    {"setToolTipEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StatisticsProxyModelFunc_setToolTipEnabled), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_StatisticsProxyModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::StatisticsProxyModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<StatisticsProxyModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_StatisticsProxyModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_StatisticsProxyModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_StatisticsProxyModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_StatisticsProxyModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_StatisticsProxyModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_StatisticsProxyModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_StatisticsProxyModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_StatisticsProxyModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_StatisticsProxyModel_spec = {
    "1:AkonadiCore.Akonadi.StatisticsProxyModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_StatisticsProxyModel_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void StatisticsProxyModel_PythonToCpp_StatisticsProxyModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_StatisticsProxyModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_StatisticsProxyModel_PythonToCpp_StatisticsProxyModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_StatisticsProxyModel_TypeF()))
        return StatisticsProxyModel_PythonToCpp_StatisticsProxyModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *StatisticsProxyModel_PTR_CppToPython_StatisticsProxyModel(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_StatisticsProxyModel_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::StatisticsProxyModel *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_StatisticsProxyModel_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_StatisticsProxyModel_SignatureStrings[] = {
    "AkonadiCore.Akonadi.StatisticsProxyModel(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.StatisticsProxyModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.StatisticsProxyModel.extraColumnData(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],row:int,extraColumn:int,role:int)->QVariant",
    "AkonadiCore.Akonadi.StatisticsProxyModel.flags(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.Qt.ItemFlag",
    "AkonadiCore.Akonadi.StatisticsProxyModel.isExtraColumnsEnabled(self)->bool",
    "AkonadiCore.Akonadi.StatisticsProxyModel.isToolTipEnabled(self)->bool",
    "AkonadiCore.Akonadi.StatisticsProxyModel.match(self,start:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int,value:QVariant,hits:int=1,flags:PySide6.QtCore.Qt.MatchFlag=Qt.MatchFlags(Qt.MatchStartsWith | Qt.MatchWrap))->QList[PySide6.QtCore.QModelIndex]",
    "AkonadiCore.Akonadi.StatisticsProxyModel.setExtraColumnsEnabled(self,enable:bool)",
    "AkonadiCore.Akonadi.StatisticsProxyModel.setSourceModel(self,model:PySide6.QtCore.QAbstractItemModel)",
    "AkonadiCore.Akonadi.StatisticsProxyModel.setToolTipEnabled(self,enable:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_StatisticsProxyModel_SignatureByteSize = 358;
static constexpr uint8_t Akonadi_StatisticsProxyModel_SignatureBytes[358] = {
    0x78, 0xda, 0xb5, 0x94, 0xc1, 0x4f, 0xc2, 0x30, 0x14, 0xc6, 0xef, 0xfe, 0x15, 0x1c, 0x5d, 0x52,
    0x9b, 0x78, 0xf1, 0xb0, 0x04, 0x93, 0x05, 0x30, 0x21, 0x91, 0xc8, 0x1c, 0xca, 0xc1, 0x70, 0xe8,
    0xb6, 0x07, 0x54, 0xbb, 0x76, 0x69, 0xdf, 0x94, 0x25, 0xfe, 0xf1, 0xb6, 0xc5, 0x09, 0x82, 0x9a,
    0xa1, 0x72, 0xeb, 0xeb, 0x5e, 0xbf, 0xef, 0xd7, 0xaf, 0x2f, 0x8b, 0x9e, 0x94, 0x64, 0x39, 0xef,
    0x29, 0x0d, 0x34, 0x5a, 0xaf, 0x69, 0x82, 0x0c, 0xb9, 0x41, 0x9e, 0x99, 0xb1, 0x56, 0xab, 0x7a,
    0xa4, 0x72, 0x10, 0xa7, 0x06, 0xc4, 0x9c, 0x94, 0x4c, 0x83, 0xc4, 0x70, 0x5c, 0x27, 0x3c, 0x87,
    0x0b, 0x1a, 0xa3, 0x3f, 0x17, 0xdf, 0xa4, 0x8f, 0x90, 0x61, 0x57, 0x56, 0x42, 0x94, 0xa8, 0x83,
    0x93, 0xa8, 0xa5, 0x28, 0xcd, 0x19, 0xb2, 0xb5, 0x32, 0x97, 0x39, 0xac, 0x42, 0xac, 0x4b, 0x2e,
    0x17, 0xf4, 0x4e, 0x72, 0x25, 0x1f, 0x76, 0x5d, 0xfc, 0x91, 0xa1, 0xeb, 0x23, 0x9d, 0xdd, 0x6f,
    0x63, 0xd0, 0xc6, 0xaa, 0x5b, 0xb8, 0x4d, 0xd7, 0x8c, 0x68, 0x25, 0x20, 0xe4, 0x12, 0xbb, 0x31,
    0xd2, 0x3e, 0x37, 0xa5, 0x60, 0xf5, 0xad, 0xdd, 0x0a, 0xce, 0x2e, 0xe3, 0x7b, 0xa6, 0x39, 0x93,
    0xd8, 0x1e, 0x15, 0x56, 0xa8, 0x59, 0x4f, 0x89, 0xaa, 0x90, 0xfd, 0x0f, 0xea, 0xf7, 0x3c, 0xfe,
    0x1d, 0xfb, 0xc5, 0x51, 0x93, 0x2d, 0x4b, 0x5f, 0x37, 0xd7, 0xf9, 0x15, 0xff, 0x5c, 0xb0, 0x85,
    0x39, 0x5e, 0xd6, 0x96, 0x69, 0xb7, 0x0f, 0xe9, 0x10, 0xa1, 0xb8, 0xb2, 0xbe, 0xed, 0x29, 0xb9,
    0x19, 0x6c, 0x2e, 0x6d, 0x06, 0x92, 0xa5, 0x02, 0x72, 0x4f, 0x6d, 0x0d, 0x52, 0xa5, 0xc4, 0x21,
    0x52, 0x13, 0xdb, 0x3f, 0xe1, 0xe5, 0x9f, 0x54, 0x0a, 0x86, 0xd9, 0x72, 0x1d, 0x9b, 0x41, 0xa6,
    0xf1, 0x58, 0x23, 0x4a, 0x9e, 0x99, 0xa8, 0x20, 0x6c, 0xde, 0x95, 0x2c, 0x39, 0x1a, 0x3f, 0xba,
    0xe7, 0xc4, 0xbf, 0x5c, 0xb8, 0x9f, 0xee, 0xc8, 0xa1, 0xb9, 0x78, 0xbb, 0xdb, 0x85, 0x39, 0x6d,
    0xaa, 0xc4, 0xf1, 0x9a, 0x29, 0xc7, 0x65, 0xe7, 0xb5, 0xd3, 0x6c, 0x4e, 0x35, 0x2b, 0x03, 0x37,
    0x40, 0xd7, 0x96, 0xe5, 0x07, 0xfe, 0x59, 0xfb, 0x88, 0x0c, 0xe0, 0x77, 0x8f, 0x46, 0xc0, 0x17,
    0xa1, 0xcb, 0x3c, 0x38, 0x48, 0x31, 0x51, 0x95, 0xce, 0x60, 0xeb, 0xd7, 0x53, 0xb8, 0xe5, 0x5e,
    0x0a, 0x51, 0x6a, 0xac, 0x73, 0x86, 0x6e, 0xd2, 0x7c, 0xf3, 0x61, 0x2e, 0x5f, 0x4c, 0xc8, 0x67,
    0xe4, 0x37, 0x40, 0xba, 0xe6, 0x53
};
#endif

PyTypeObject *init_Akonadi_StatisticsProxyModel(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_StatisticsProxyModel_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_StatisticsProxyModel_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "StatisticsProxyModel",
        "Akonadi::StatisticsProxyModel*",
        &Sbk_Akonadi_StatisticsProxyModel_spec,
        &Shiboken::callCppDestructor< Akonadi::StatisticsProxyModel >,
        Sbk_Akonadi_StatisticsProxyModel_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_StatisticsProxyModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_StatisticsProxyModel_SignatureBytes, Akonadi_StatisticsProxyModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_StatisticsProxyModel_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        StatisticsProxyModel_PythonToCpp_StatisticsProxyModel_PTR,
        is_StatisticsProxyModel_PythonToCpp_StatisticsProxyModel_PTR_Convertible,
        StatisticsProxyModel_PTR_CppToPython_StatisticsProxyModel);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StatisticsProxyModel");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StatisticsProxyModel*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StatisticsProxyModel&");
    Shiboken::Conversions::registerConverterAlias(converter, "StatisticsProxyModel");
    Shiboken::Conversions::registerConverterAlias(converter, "StatisticsProxyModel*");
    Shiboken::Conversions::registerConverterAlias(converter, "StatisticsProxyModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::StatisticsProxyModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(StatisticsProxyModelWrapper).name());

    qRegisterMetaType< ::Akonadi::StatisticsProxyModel *>();

    return pyType;
}
