/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Knut.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.Knut.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.Knut.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.Knut.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"dataFile\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setDataFile\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"readOnly\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setReadOnly\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"fileWatchingEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setFileWatchingEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(KnutSettings *parent);
    ~SettingsAdaptor() override;

    inline KnutSettings *parent() const
    { return static_cast<KnutSettings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString dataFile();
    bool fileWatchingEnabled();
    bool readOnly();
    void save();
    void setDataFile(const QString &in0);
    void setFileWatchingEnabled(bool in0);
    void setReadOnly(bool in0);
Q_SIGNALS: // SIGNALS
};

#endif
