
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_agentinstance_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <agentinstance.h>
#include <agenttype.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_AgentInstance_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_AgentInstance_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::AgentInstance >()))
        return -1;

    ::Akonadi::AgentInstance *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "AgentInstance", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: AgentInstance::AgentInstance()
    // 1: AgentInstance::AgentInstance(const Akonadi::AgentInstance&)
    if (numArgs == 0) {
        overloadId = 0; // AgentInstance()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), (pyArgs[0])))) {
        overloadId = 1; // AgentInstance::AgentInstance(const Akonadi::AgentInstance&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // AgentInstance()
        {

            // AgentInstance::AgentInstance()
            cptr = new ::Akonadi::AgentInstance();
            break;
        }
        case 1: // AgentInstance(const Akonadi::AgentInstance &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::AgentInstance cppArg0_local;
            ::Akonadi::AgentInstance *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // AgentInstance::AgentInstance(const Akonadi::AgentInstance&)
                cptr = new ::Akonadi::AgentInstance(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::AgentInstance >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_abortCurrentTask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::abortCurrentTask()const
        const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->abortCurrentTask();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_accountId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::accountId()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->accountId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_activities(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::activities()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->activities();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_activitiesEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::activitiesEnabled()const->bool
        bool cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->activitiesEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_configure(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "configure", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    if (PyArg_ParseTuple(args, "|O:configure", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: AgentInstance::configure(qlonglong=)
    if (numArgs == 0) {
        overloadId = 0; // configure(qlonglong)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))) {
        overloadId = 0; // AgentInstance::configure(qlonglong=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "configure", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("AgentInstance", "configure(qlonglong winId)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"winId", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "configure", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);
            }
        }
        qlonglong cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AgentInstance::configure(qlonglong=)
            cppSelf->configure(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_identifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::identifier()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->identifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_isOnline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::isOnline()const->bool
        bool cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->isOnline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::isValid()const->bool
        bool cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::name()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_progress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::progress()const->int
        int cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->progress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_reconfigure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::reconfigure()const
        const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->reconfigure();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_restart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::restart()const
        const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->restart();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_setActivities(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AgentInstance::setActivities(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // AgentInstance::setActivities(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActivities", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AgentInstance::setActivities(const QStringList&)
            cppSelf->setActivities(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_setActivitiesEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AgentInstance::setActivitiesEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // AgentInstance::setActivitiesEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActivitiesEnabled", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AgentInstance::setActivitiesEnabled(bool)
            cppSelf->setActivitiesEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_setIsOnline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AgentInstance::setIsOnline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // AgentInstance::setIsOnline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIsOnline", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AgentInstance::setIsOnline(bool)
            cppSelf->setIsOnline(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: AgentInstance::setName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // AgentInstance::setName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // AgentInstance::setName(const QString&)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::status()const->Akonadi::AgentInstance::Status
        Akonadi::AgentInstance::Status cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_Status_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_statusMessage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::statusMessage()const->QString
        QString cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->statusMessage();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_synchronize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::synchronize()
        cppSelf->synchronize();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_synchronizeCollectionTree(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::synchronizeCollectionTree()
        cppSelf->synchronizeCollectionTree();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_synchronizeTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::synchronizeTags()
        cppSelf->synchronizeTags();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_taskList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::taskList()const->QStringList
        QStringList cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->taskList();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstanceFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // AgentInstance::type()const->Akonadi::AgentType
        Akonadi::AgentType cppResult = const_cast<const ::Akonadi::AgentInstance *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentType_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_AgentInstance__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_AgentInstance_PropertyStrings[] = {
    "identifier:",
    "isOnline::",
    "isValid:",
    "name::",
    "progress:",
    "status:",
    "statusMessage:",
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_AgentInstance_EnumFlagInfo[] = {
    "Status:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_AgentInstance_methods[] = {
    {"abortCurrentTask", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_abortCurrentTask), METH_NOARGS, nullptr},
    {"accountId", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_accountId), METH_NOARGS, nullptr},
    {"activities", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_activities), METH_NOARGS, nullptr},
    {"activitiesEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_activitiesEnabled), METH_NOARGS, nullptr},
    {"configure", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_configure), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"identifier", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_identifier), METH_NOARGS, nullptr},
    {"isOnline", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_isOnline), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_name), METH_NOARGS, nullptr},
    {"progress", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_progress), METH_NOARGS, nullptr},
    {"reconfigure", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_reconfigure), METH_NOARGS, nullptr},
    {"restart", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_restart), METH_NOARGS, nullptr},
    {"setActivities", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_setActivities), METH_O, nullptr},
    {"setActivitiesEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_setActivitiesEnabled), METH_O, nullptr},
    {"setIsOnline", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_setIsOnline), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_setName), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_status), METH_NOARGS, nullptr},
    {"statusMessage", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_statusMessage), METH_NOARGS, nullptr},
    {"synchronize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_synchronize), METH_NOARGS, nullptr},
    {"synchronizeCollectionTree", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_synchronizeCollectionTree), METH_NOARGS, nullptr},
    {"synchronizeTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_synchronizeTags), METH_NOARGS, nullptr},
    {"taskList", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_taskList), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstanceFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_AgentInstance__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_Akonadi_AgentInstance_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), (pyArg)))) {
                // AgentInstance::operator==(const Akonadi::AgentInstance&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Akonadi::AgentInstance cppArg0_local;
                ::Akonadi::AgentInstance *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Akonadi_AgentInstance_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_AgentInstance_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_AgentInstance_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_AgentInstance_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_AgentInstance_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Akonadi_AgentInstance_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_AgentInstance_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_AgentInstance_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_AgentInstance_spec = {
    "1:AkonadiCore.Akonadi.AgentInstance",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_AgentInstance_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_AgentInstance_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::AgentInstance::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::AgentInstance::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_AgentInstance_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_Status_IDX])))
        return Enum_PythonToCpp_Akonadi_AgentInstance_Status;
    return {};
}

static PyObject *Akonadi_AgentInstance_Status_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::AgentInstance::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::AgentInstance::Status *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void AgentInstance_PythonToCpp_AgentInstance_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_AgentInstance_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_AgentInstance_PythonToCpp_AgentInstance_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AgentInstance_TypeF()))
        return AgentInstance_PythonToCpp_AgentInstance_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *AgentInstance_PTR_CppToPython_AgentInstance(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_AgentInstance_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_AgentInstance_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *AgentInstance_COPY_CppToPython_AgentInstance(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::AgentInstance *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_AgentInstance_TypeF(), new ::Akonadi::AgentInstance(*source), true, true);
}

// Python to C++ copy conversion.
static void AgentInstance_PythonToCpp_AgentInstance_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::AgentInstance *>(cppOut) = *reinterpret_cast< ::Akonadi::AgentInstance *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_AgentInstance_PythonToCpp_AgentInstance_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_AgentInstance_TypeF()))
        return AgentInstance_PythonToCpp_AgentInstance_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_AgentInstance_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.AgentInstance(self,*:KeywordOnly=None,isValid:bool=None,identifier:QString=None,name:QString=None,status:AkonadiCore.Akonadi.AgentInstance.Status=None,statusMessage:QString=None,progress:int=None,isOnline:bool=None)",
    "0:AkonadiCore.Akonadi.AgentInstance(self,other:AkonadiCore.Akonadi.AgentInstance,*:KeywordOnly=None,isValid:bool=None,identifier:QString=None,name:QString=None,status:AkonadiCore.Akonadi.AgentInstance.Status=None,statusMessage:QString=None,progress:int=None,isOnline:bool=None)",
    "AkonadiCore.Akonadi.AgentInstance.abortCurrentTask(self)",
    "AkonadiCore.Akonadi.AgentInstance.accountId(self)->QString",
    "AkonadiCore.Akonadi.AgentInstance.activities(self)->QStringList",
    "AkonadiCore.Akonadi.AgentInstance.activitiesEnabled(self)->bool",
    "AkonadiCore.Akonadi.AgentInstance.configure(self,winId:qlonglong=0)",
    "AkonadiCore.Akonadi.AgentInstance.identifier(self)->QString",
    "AkonadiCore.Akonadi.AgentInstance.isOnline(self)->bool",
    "AkonadiCore.Akonadi.AgentInstance.isValid(self)->bool",
    "AkonadiCore.Akonadi.AgentInstance.name(self)->QString",
    "AkonadiCore.Akonadi.AgentInstance.progress(self)->int",
    "AkonadiCore.Akonadi.AgentInstance.reconfigure(self)",
    "AkonadiCore.Akonadi.AgentInstance.restart(self)",
    "AkonadiCore.Akonadi.AgentInstance.setActivities(self,online:QStringList)",
    "AkonadiCore.Akonadi.AgentInstance.setActivitiesEnabled(self,enabled:bool)",
    "AkonadiCore.Akonadi.AgentInstance.setIsOnline(self,online:bool)",
    "AkonadiCore.Akonadi.AgentInstance.setName(self,name:QString)",
    "AkonadiCore.Akonadi.AgentInstance.status(self)->AkonadiCore.Akonadi.AgentInstance.Status",
    "AkonadiCore.Akonadi.AgentInstance.statusMessage(self)->QString",
    "AkonadiCore.Akonadi.AgentInstance.synchronize(self)",
    "AkonadiCore.Akonadi.AgentInstance.synchronizeCollectionTree(self)",
    "AkonadiCore.Akonadi.AgentInstance.synchronizeTags(self)",
    "AkonadiCore.Akonadi.AgentInstance.taskList(self)->QStringList",
    "AkonadiCore.Akonadi.AgentInstance.type(self)->AkonadiCore.Akonadi.AgentType",
    "AkonadiCore.Akonadi.AgentInstance.__copy__(self)->typing._Self",
    "AkonadiCore.Akonadi.AgentInstance.__eq__(self,other:AkonadiCore.Akonadi.AgentInstance)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_AgentInstance_SignatureByteSize = 396;
static constexpr uint8_t Akonadi_AgentInstance_SignatureBytes[396] = {
    0x78, 0xda, 0xdd, 0x95, 0xcd, 0x6e, 0xc2, 0x30, 0x10, 0x84, 0xef, 0x7d, 0x92, 0x52, 0xa5, 0x88,
    0x5e, 0x23, 0x51, 0x09, 0xa1, 0x1e, 0x50, 0x5b, 0xaa, 0x8a, 0xa8, 0xd7, 0xc8, 0x24, 0x4b, 0xb0,
    0x70, 0x77, 0xc1, 0x76, 0x8a, 0xd2, 0xa7, 0xaf, 0xf3, 0xe3, 0x92, 0xf4, 0x92, 0x35, 0xc7, 0x1e,
    0x90, 0x62, 0xe3, 0x6f, 0x32, 0xeb, 0x1d, 0x96, 0x87, 0x78, 0x71, 0x20, 0x14, 0xb9, 0x5c, 0x92,
    0x86, 0x69, 0xf7, 0x3c, 0x5d, 0x14, 0x80, 0x76, 0x85, 0xc6, 0x0a, 0xcc, 0xe0, 0xd6, 0x80, 0xda,
    0x45, 0x77, 0xf1, 0x33, 0x54, 0x67, 0xd2, 0xf9, 0x1b, 0xaa, 0x6a, 0xbe, 0x26, 0x84, 0x48, 0x9a,
    0x0f, 0xa1, 0x64, 0x1e, 0x6f, 0x89, 0x54, 0xb7, 0x93, 0x3b, 0x4e, 0xee, 0x24, 0xe8, 0xf8, 0x7d,
    0x63, 0xb5, 0xc4, 0xa2, 0xdd, 0x47, 0xf1, 0x09, 0xc3, 0x1d, 0x27, 0x6d, 0x4b, 0x33, 0xfe, 0xf2,
    0xe9, 0xa6, 0x39, 0xd8, 0x87, 0x5e, 0xc1, 0x18, 0x51, 0xfc, 0xd1, 0x3b, 0x6a, 0x2a, 0xb4, 0xfb,
    0x22, 0x96, 0x68, 0xbd, 0x3b, 0xe7, 0x54, 0x22, 0x5c, 0xec, 0x4d, 0x6e, 0x66, 0xdc, 0x6a, 0xc9,
    0xee, 0x5d, 0x0d, 0xa3, 0x87, 0xff, 0xc7, 0xad, 0x8c, 0xbf, 0x4e, 0x6c, 0x49, 0xdb, 0x65, 0xa9,
    0xb5, 0xdb, 0x4c, 0x84, 0x39, 0x34, 0x97, 0xc4, 0x02, 0xb3, 0x8c, 0x4a, 0xb7, 0xce, 0x5b, 0xe2,
    0xfe, 0xb1, 0xb3, 0xc7, 0x42, 0xad, 0xfc, 0x92, 0x56, 0x82, 0xf9, 0xc3, 0xbe, 0x48, 0x63, 0x83,
    0xf8, 0x27, 0x14, 0x5b, 0x05, 0xbf, 0x16, 0xea, 0xca, 0x19, 0x7c, 0x46, 0xb8, 0x93, 0x45, 0xa9,
    0xbb, 0x44, 0x9c, 0x25, 0xae, 0xf2, 0xf8, 0xa4, 0x08, 0x8b, 0xfa, 0x33, 0x9f, 0x71, 0xca, 0xbf,
    0x74, 0x3e, 0xbc, 0x7e, 0xdf, 0xa9, 0x40, 0xdb, 0x5d, 0xfc, 0x02, 0xa9, 0x3a, 0x8a, 0xe1, 0x16,
    0x7d, 0xbc, 0x3c, 0xe9, 0x52, 0xc6, 0xa0, 0x34, 0x0c, 0xaf, 0x76, 0xc2, 0x62, 0xdc, 0x83, 0xb6,
    0xec, 0xf3, 0x06, 0xec, 0x62, 0x98, 0x9f, 0x88, 0xda, 0xdc, 0xf7, 0x42, 0x14, 0x2c, 0xd4, 0x0f,
    0x52, 0x04, 0xed, 0xa2, 0xf9, 0x21, 0x31, 0x95, 0x56, 0xfd, 0x96, 0x7a, 0x43, 0x01, 0xfc, 0xda,
    0x77, 0x69, 0x30, 0x3a, 0x58, 0x70, 0x33, 0x23, 0x7c, 0x9f, 0xb8, 0xf3, 0x85, 0x2d, 0xdc, 0x0d,
    0x9f, 0xf0, 0x04, 0x99, 0x0a, 0xb3, 0xbd, 0x26, 0x94, 0xdf, 0xfc, 0x2c, 0xf4, 0x98, 0x25, 0x29,
    0x05, 0xae, 0x3d, 0x84, 0x89, 0x86, 0xab, 0x14, 0x12, 0x51, 0x18, 0x36, 0x67, 0xdd, 0xe8, 0xab,
    0x83, 0x73, 0xdd, 0x40, 0xb2, 0xd5, 0x11, 0x46, 0x3b, 0x90, 0xb8, 0x43, 0x0c, 0xad, 0x34, 0xcd,
    0xe8, 0x58, 0xa5, 0xa9, 0xd7, 0x73, 0xda, 0xce, 0xc8, 0x34, 0xdd, 0xb8, 0x25, 0x0b, 0x87, 0x53,
    0x07, 0x73, 0xff, 0xea, 0xfc, 0x2c, 0xf9, 0x01, 0xbd, 0x10, 0x07, 0x50
};
#endif

PyTypeObject *init_Akonadi_AgentInstance(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_AgentInstance_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "AgentInstance",
        "Akonadi::AgentInstance",
        &Sbk_Akonadi_AgentInstance_spec,
        &Shiboken::callCppDestructor< ::Akonadi::AgentInstance >,
        Sbk_Akonadi_AgentInstance_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_AgentInstance_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_AgentInstance_SignatureBytes, Akonadi_AgentInstance_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_AgentInstance_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        AgentInstance_PythonToCpp_AgentInstance_PTR,
        is_AgentInstance_PythonToCpp_AgentInstance_PTR_Convertible,
        AgentInstance_PTR_CppToPython_AgentInstance,
        AgentInstance_COPY_CppToPython_AgentInstance);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentInstance");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentInstance*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentInstance&");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentInstance");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentInstance*");
    Shiboken::Conversions::registerConverterAlias(converter, "AgentInstance&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::AgentInstance).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        AgentInstance_PythonToCpp_AgentInstance_COPY,
        is_AgentInstance_PythonToCpp_AgentInstance_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_AgentInstance_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "Idle",
        "Running",
        "Broken",
        "NotConfigured",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(Akonadi::AgentInstance::Status::Idle),         //  0x00  0
        uint8_t(Akonadi::AgentInstance::Status::Running),      //  0x01  1
        uint8_t(Akonadi::AgentInstance::Status::Broken),       //  0x02  2
        uint8_t(Akonadi::AgentInstance::Status::NotConfigured) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.AgentInstance.Status",
        Status_Initializer, Status_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_AgentInstance_Status_IDX].type = EType;
    // Register converter for enum 'Akonadi::AgentInstance::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_AgentInstance_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_AgentInstance_Status,
            is_Enum_PythonToCpp_Akonadi_AgentInstance_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::AgentInstance::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "AgentInstance::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    qRegisterMetaType< ::Akonadi::AgentInstance >("AgentInstance");
    qRegisterMetaType< ::Akonadi::AgentInstance >("Akonadi::AgentInstance");
    qRegisterMetaType< ::Akonadi::AgentInstance::Status >("AgentInstance::Status");
    qRegisterMetaType< ::Akonadi::AgentInstance::Status >("Akonadi::AgentInstance::Status");

    return pyType;
}
