/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Resource.Transport.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TRANSPORTADAPTOR_H
#define TRANSPORTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "transportresourcebase_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Resource.Transport
 */
class Akonadi__TransportAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Resource.Transport")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Resource.Transport\">\n"
"    <method name=\"send\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"itemId\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <signal name=\"transportResult\">\n"
"      <arg direction=\"out\" type=\"x\" name=\"itemId\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"result\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"message\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    Akonadi__TransportAdaptor(Akonadi::TransportResourceBasePrivate *parent);
    ~Akonadi__TransportAdaptor() override;

    inline Akonadi::TransportResourceBasePrivate *parent() const
    { return static_cast<Akonadi::TransportResourceBasePrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void send(qlonglong itemId);
Q_SIGNALS: // SIGNALS
    void transportResult(qlonglong itemId, int result, const QString &message);
};

#endif
