// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "akonadidbmigrator_debug.h"


Q_LOGGING_CATEGORY(AKONADIDBMIGRATOR_LOG, "org.kde.pim.akonadiserver.dbmigrator", QtInfoMsg)

