/********************************************************************************
** Form generated from reading UI file 'erroroverlay.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERROROVERLAY_H
#define UI_ERROROVERLAY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ErrorOverlay
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackWidget;
    QWidget *notRunningPage;
    QVBoxLayout *verticalLayout_5;
    QSpacerItem *verticalSpacer;
    QLabel *notRunningIcon;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_7;
    QLabel *notRunningDescription;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_5;
    QVBoxLayout *verticalLayout_2;
    QPushButton *startButton;
    QPushButton *quitButton;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_2;
    QWidget *brokenPage;
    QVBoxLayout *verticalLayout_6;
    QSpacerItem *verticalSpacer_5;
    QLabel *brokenIcon;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_9;
    QLabel *brokenDescription;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QVBoxLayout *verticalLayout_4;
    QPushButton *selfTestButton;
    QPushButton *detailsQuitButton;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_6;
    QWidget *progressPage;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *progressIcon;
    QProgressBar *progressBar;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_11;
    QLabel *progressDescription;
    QSpacerItem *horizontalSpacer_12;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *ErrorOverlay)
    {
        if (ErrorOverlay->objectName().isEmpty())
            ErrorOverlay->setObjectName("ErrorOverlay");
        ErrorOverlay->resize(400, 300);
        verticalLayout = new QVBoxLayout(ErrorOverlay);
        verticalLayout->setObjectName("verticalLayout");
        stackWidget = new QStackedWidget(ErrorOverlay);
        stackWidget->setObjectName("stackWidget");
        notRunningPage = new QWidget();
        notRunningPage->setObjectName("notRunningPage");
        verticalLayout_5 = new QVBoxLayout(notRunningPage);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalSpacer = new QSpacerItem(20, 95, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer);

        notRunningIcon = new QLabel(notRunningPage);
        notRunningIcon->setObjectName("notRunningIcon");
        notRunningIcon->setAlignment(Qt::AlignCenter);

        verticalLayout_5->addWidget(notRunningIcon);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_7);

        notRunningDescription = new QLabel(notRunningPage);
        notRunningDescription->setObjectName("notRunningDescription");
        notRunningDescription->setMaximumSize(QSize(550, 16777215));
        notRunningDescription->setAlignment(Qt::AlignCenter);
        notRunningDescription->setWordWrap(true);

        horizontalLayout_4->addWidget(notRunningDescription);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_8);

        horizontalLayout_4->setStretch(1, 1);

        verticalLayout_5->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        startButton = new QPushButton(notRunningPage);
        startButton->setObjectName("startButton");

        verticalLayout_2->addWidget(startButton);

        quitButton = new QPushButton(notRunningPage);
        quitButton->setObjectName("quitButton");

        verticalLayout_2->addWidget(quitButton);


        horizontalLayout_3->addLayout(verticalLayout_2);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);


        verticalLayout_5->addLayout(horizontalLayout_3);

        verticalSpacer_2 = new QSpacerItem(20, 96, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        stackWidget->addWidget(notRunningPage);
        brokenPage = new QWidget();
        brokenPage->setObjectName("brokenPage");
        verticalLayout_6 = new QVBoxLayout(brokenPage);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalSpacer_5 = new QSpacerItem(20, 95, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_5);

        brokenIcon = new QLabel(brokenPage);
        brokenIcon->setObjectName("brokenIcon");
        brokenIcon->setAlignment(Qt::AlignCenter);

        verticalLayout_6->addWidget(brokenIcon);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_9);

        brokenDescription = new QLabel(brokenPage);
        brokenDescription->setObjectName("brokenDescription");
        brokenDescription->setMaximumSize(QSize(550, 16777215));
        brokenDescription->setAlignment(Qt::AlignCenter);
        brokenDescription->setWordWrap(true);

        horizontalLayout_5->addWidget(brokenDescription);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_10);

        horizontalLayout_5->setStretch(1, 1);

        verticalLayout_6->addLayout(horizontalLayout_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        selfTestButton = new QPushButton(brokenPage);
        selfTestButton->setObjectName("selfTestButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(selfTestButton->sizePolicy().hasHeightForWidth());
        selfTestButton->setSizePolicy(sizePolicy);

        verticalLayout_4->addWidget(selfTestButton);

        detailsQuitButton = new QPushButton(brokenPage);
        detailsQuitButton->setObjectName("detailsQuitButton");

        verticalLayout_4->addWidget(detailsQuitButton);


        horizontalLayout_2->addLayout(verticalLayout_4);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout_6->addLayout(horizontalLayout_2);

        verticalSpacer_6 = new QSpacerItem(20, 96, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_6);

        stackWidget->addWidget(brokenPage);
        progressPage = new QWidget();
        progressPage->setObjectName("progressPage");
        verticalLayout_3 = new QVBoxLayout(progressPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer_3 = new QSpacerItem(20, 113, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        progressIcon = new QLabel(progressPage);
        progressIcon->setObjectName("progressIcon");
        progressIcon->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(progressIcon);

        progressBar = new QProgressBar(progressPage);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);
        progressBar->setValue(7229);

        horizontalLayout->addWidget(progressBar);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_11);

        progressDescription = new QLabel(progressPage);
        progressDescription->setObjectName("progressDescription");
        progressDescription->setMaximumSize(QSize(550, 16777215));
        progressDescription->setAlignment(Qt::AlignCenter);
        progressDescription->setWordWrap(true);

        horizontalLayout_6->addWidget(progressDescription);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_12);

        horizontalLayout_6->setStretch(1, 1);

        verticalLayout_3->addLayout(horizontalLayout_6);

        verticalSpacer_4 = new QSpacerItem(20, 113, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_4);

        stackWidget->addWidget(progressPage);

        verticalLayout->addWidget(stackWidget);


        retranslateUi(ErrorOverlay);

        stackWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ErrorOverlay);
    } // setupUi

    void retranslateUi(QWidget *ErrorOverlay)
    {
#if QT_CONFIG(tooltip)
        notRunningPage->setToolTip(tr2i18n("A required background service is not running. This application cannot be used without it.", nullptr));
#endif // QT_CONFIG(tooltip)
        notRunningIcon->setText(QString());
        notRunningDescription->setText(tr2i18n("A required background service is not running. This application cannot be used without it.", nullptr));
        startButton->setText(tr2i18n("Start", "@action:button Start the Akonadi server"));
#if QT_CONFIG(tooltip)
        brokenPage->setToolTip(tr2i18n("A required background service is not operational.\n"
"Click on \"Details...\" to obtain detailed information on this problem.", nullptr));
#endif // QT_CONFIG(tooltip)
        brokenIcon->setText(QString());
        brokenDescription->setText(tr2i18n("<html><head/><body><p>A required background service is not operational.</p><p>See <a href=\"https://userbase.kde.org/Akonadi#If_Akonadi_Reports_Broken_or_Non-operational\">FAQ</a> for troubleshooting tips.</p></body></html>", nullptr));
        selfTestButton->setText(tr2i18n("Details...", nullptr));
        progressIcon->setText(QString());
        progressDescription->setText(QString());
        (void)ErrorOverlay;
    } // retranslateUi

};

namespace Ui {
    class ErrorOverlay: public Ui_ErrorOverlay {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ERROROVERLAY_H

