/********************************************************************************
** Form generated from reading UI file 'tageditwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGEDITWIDGET_H
#define UI_TAGEDITWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TagEditWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *selectLabel;
    KMessageWidget *mMessageWidget;
    QListView *tagsView;
    QHBoxLayout *horizontalLayout;
    QLineEdit *newTagEdit;
    QPushButton *newTagButton;

    void setupUi(QWidget *TagEditWidget)
    {
        if (TagEditWidget->objectName().isEmpty())
            TagEditWidget->setObjectName("TagEditWidget");
        TagEditWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(TagEditWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        selectLabel = new QLabel(TagEditWidget);
        selectLabel->setObjectName("selectLabel");

        verticalLayout->addWidget(selectLabel);

        mMessageWidget = new KMessageWidget(TagEditWidget);
        mMessageWidget->setObjectName("mMessageWidget");
        mMessageWidget->setCloseButtonVisible(true);

        verticalLayout->addWidget(mMessageWidget);

        tagsView = new QListView(TagEditWidget);
        tagsView->setObjectName("tagsView");
        tagsView->setMouseTracking(true);
        tagsView->setSelectionMode(QAbstractItemView::SelectionMode::NoSelection);

        verticalLayout->addWidget(tagsView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        newTagEdit = new QLineEdit(TagEditWidget);
        newTagEdit->setObjectName("newTagEdit");

        horizontalLayout->addWidget(newTagEdit);

        newTagButton = new QPushButton(TagEditWidget);
        newTagButton->setObjectName("newTagButton");
        newTagButton->setEnabled(false);

        horizontalLayout->addWidget(newTagButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(TagEditWidget);

        QMetaObject::connectSlotsByName(TagEditWidget);
    } // setupUi

    void retranslateUi(QWidget *TagEditWidget)
    {
        selectLabel->setText(tr2i18n("Select tags that should be applied.", nullptr));
#if QT_CONFIG(tooltip)
        newTagEdit->setToolTip(tr2i18n("Enter the name for a new tag", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newTagEdit->setWhatsThis(tr2i18n("To create and select a new tag, enter a name for the new tag and then press the \"Create new tag\" button.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        newTagButton->setToolTip(tr2i18n("Create and select a new tag", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        newTagButton->setWhatsThis(tr2i18n("Press this button to create a new tag with the name specified in the adjacent line editor.  The new tag is automatically selected.", nullptr));
#endif // QT_CONFIG(whatsthis)
        newTagButton->setText(tr2i18n("Create new tag", nullptr));
        (void)TagEditWidget;
    } // retranslateUi

};

namespace Ui {
    class TagEditWidget: public Ui_TagEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TAGEDITWIDGET_H

