/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Status.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef STATUSINTERFACE_H
#define STATUSINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.Agent.Status
 */
class OrgFreedesktopAkonadiAgentStatusInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.Agent.Status"; }

public:
    OrgFreedesktopAkonadiAgentStatusInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiAgentStatusInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> isOnline()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isOnline"), argumentList);
    }

    inline QDBusPendingReply<int> progress()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("progress"), argumentList);
    }

    Q_NOREPLY inline void setOnline(bool state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(state);
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("setOnline"), argumentList);
    }

    inline QDBusPendingReply<int> status()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("status"), argumentList);
    }

    inline QDBusPendingReply<QString> statusMessage()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("statusMessage"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void advancedStatus(const QVariantMap &status);
    void error(const QString &message);
    void onlineChanged(bool state);
    void percent(int percent);
    void status(int status, const QString &message);
    void warning(const QString &message);
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      namespace Agent {
        using Status = ::OrgFreedesktopAkonadiAgentStatusInterface;
      }
    }
  }
}

#endif
