#ifndef SBK_ENTITYDELETEDATTRIBUTEWRAPPER_H
#define SBK_ENTITYDELETEDATTRIBUTEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <entitydeletedattribute.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class EntityDeletedAttributeWrapper : public Akonadi::EntityDeletedAttribute
{
public:
    EntityDeletedAttributeWrapper();
    EntityDeletedAttributeWrapper(const EntityDeletedAttributeWrapper &) = delete;
    EntityDeletedAttributeWrapper& operator=(const EntityDeletedAttributeWrapper &) = delete;
    EntityDeletedAttributeWrapper(EntityDeletedAttributeWrapper &&) = delete;
    EntityDeletedAttributeWrapper& operator=(EntityDeletedAttributeWrapper &&) = delete;
    ~EntityDeletedAttributeWrapper() override;

    ::Akonadi::EntityDeletedAttribute * clone() const override;
    static ::Akonadi::EntityDeletedAttribute * sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride);
    void deserialize(const ::QByteArray & data) override;
    ::QByteArray serialized() const override;
    ::QByteArray type() const override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    mutable std::array<PyObject *, 4> m_PyMethodCache = {nullptr, nullptr, nullptr, nullptr};
};

#endif // SBK_ENTITYDELETEDATTRIBUTEWRAPPER_H
