/********************************************************************************
** Form generated from reading UI file 'renamefavoritedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RENAMEFAVORITEDIALOG_H
#define UI_RENAMEFAVORITEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RenameFavoriteDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLineEdit *lineEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *RenameFavoriteDialog)
    {
        if (RenameFavoriteDialog->objectName().isEmpty())
            RenameFavoriteDialog->setObjectName("RenameFavoriteDialog");
        RenameFavoriteDialog->resize(400, 108);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RenameFavoriteDialog->sizePolicy().hasHeightForWidth());
        RenameFavoriteDialog->setSizePolicy(sizePolicy);
        RenameFavoriteDialog->setMinimumSize(QSize(350, 0));
        RenameFavoriteDialog->setModal(true);
        verticalLayout = new QVBoxLayout(RenameFavoriteDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(RenameFavoriteDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        lineEdit = new QLineEdit(RenameFavoriteDialog);
        lineEdit->setObjectName("lineEdit");

        verticalLayout->addWidget(lineEdit);

        buttonBox = new QDialogButtonBox(RenameFavoriteDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(RenameFavoriteDialog);

        QMetaObject::connectSlotsByName(RenameFavoriteDialog);
    } // setupUi

    void retranslateUi(QDialog *RenameFavoriteDialog)
    {
        RenameFavoriteDialog->setWindowTitle(tr2i18n("Rename Favorite", nullptr));
        label->setText(tr2i18n("Name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RenameFavoriteDialog: public Ui_RenameFavoriteDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RENAMEFAVORITEDIALOG_H

