/****************************************************************************
** Meta object code from reading C++ file 'tracernotificationadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "tracernotificationadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tracernotificationadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25TracerNotificationAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto TracerNotificationAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN25TracerNotificationAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TracerNotificationAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.TracerNotification",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.TracerNotification\">\n"
        "    <signal name=\"connectionStarted\">\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"identifier\"/>\n      <arg direction=\"out\""
        " type=\"s\" name=\"msg\"/>\n    </signal>\n    <signal name=\"conn"
        "ectionEnded\">\n      <arg direction=\"out\" type=\"s\" name=\"ide"
        "ntifier\"/>\n      <arg direction=\"out\" type=\"s\" name=\"msg\"/"
        ">\n    </signal>\n    <signal name=\"connectionDataInput\">\n     "
        " <arg direction=\"out\" type=\"s\" name=\"identifier\"/>\n      <a"
        "rg direction=\"out\" type=\"s\" name=\"msg\"/>\n    </signal>\n   "
        " <signal name=\"connectionDataOutput\">\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"identifier\"/>\n      <arg direction=\"out\""
        " type=\"s\" name=\"msg\"/>\n    </signal>\n    <signal name=\"sign"
        "alEmitted\">\n      <arg direction=\"out\" type=\"s\" name=\"signa"
        "lName\"/>\n      <arg direction=\"out\" type=\"s\" name=\"msg\"/>\n"
        "    </signal>\n    <signal name=\"warningEmitted\">\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"componentName\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"msg\"/>\n    </signal>\n    <sig"
        "nal name=\"errorEmitted\">\n      <arg direction=\"out\" type=\"s\""
        " name=\"componentName\"/>\n      <arg direction=\"out\" type=\"s\""
        " name=\"msg\"/>\n    </signal>\n  </interface>\n",
        "connectionDataInput",
        "",
        "identifier",
        "msg",
        "connectionDataOutput",
        "connectionEnded",
        "connectionStarted",
        "errorEmitted",
        "componentName",
        "signalEmitted",
        "signalName",
        "warningEmitted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionDataInput'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'connectionDataOutput'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'connectionEnded'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'connectionStarted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'errorEmitted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'signalEmitted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'warningEmitted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TracerNotificationAdaptor, qt_meta_tag_ZN25TracerNotificationAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TracerNotificationAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25TracerNotificationAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25TracerNotificationAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25TracerNotificationAdaptorE_t>.metaTypes,
    nullptr
} };

void TracerNotificationAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TracerNotificationAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionDataInput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->connectionDataOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->connectionEnded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->connectionStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->errorEmitted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->signalEmitted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->warningEmitted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::connectionDataInput, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::connectionDataOutput, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::connectionEnded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::connectionStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::errorEmitted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::signalEmitted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracerNotificationAdaptor::*)(const QString & , const QString & )>(_a, &TracerNotificationAdaptor::warningEmitted, 6))
            return;
    }
}

const QMetaObject *TracerNotificationAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TracerNotificationAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25TracerNotificationAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int TracerNotificationAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void TracerNotificationAdaptor::connectionDataInput(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TracerNotificationAdaptor::connectionDataOutput(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void TracerNotificationAdaptor::connectionEnded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TracerNotificationAdaptor::connectionStarted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void TracerNotificationAdaptor::errorEmitted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void TracerNotificationAdaptor::signalEmitted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void TracerNotificationAdaptor::warningEmitted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
