/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Tracer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "traceradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class TracerAdaptor
 */

TracerAdaptor::TracerAdaptor(Akonadi::Server::Tracer *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

TracerAdaptor::~TracerAdaptor()
{
    // destructor
}

void TracerAdaptor::error(const QString &componentName, const QString &msg)
{
    // handle method call org.freedesktop.Akonadi.Tracer.error
    parent()->error(componentName, msg);
}

void TracerAdaptor::signal(const QString &signalName, const QString &msg)
{
    // handle method call org.freedesktop.Akonadi.Tracer.signal
    parent()->signal(signalName, msg);
}

void TracerAdaptor::warning(const QString &componentName, const QString &msg)
{
    // handle method call org.freedesktop.Akonadi.Tracer.warning
    parent()->warning(componentName, msg);
}


#include "moc_traceradaptor.cpp"
