
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_itemmonitor_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <item.h>
#include <itemfetchscope.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ItemMonitor_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void ItemMonitorWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

ItemMonitorWrapper::ItemMonitorWrapper()
{
}

void ItemMonitorWrapper::itemChanged(const ::Akonadi::Item & item)
{
    static const char *funcName = "itemChanged";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMonitor_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::ItemMonitor::itemChanged(item);
    }
    sbk_o_itemChanged("ItemMonitor", funcName, gil, pyOverride, item);
}

void ItemMonitorWrapper::sbk_o_itemChanged([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::Akonadi::Item & item)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &item)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &item)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void ItemMonitorWrapper::itemRemoved()
{
    static const char *funcName = "itemRemoved";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMonitor_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::ItemMonitor::itemRemoved();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("ItemMonitor", funcName, gil, pyOverride);
}

ItemMonitorWrapper::~ItemMonitorWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_ItemMonitor_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_ItemMonitor_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::ItemMonitor >()))
        return -1;

    ItemMonitorWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // ItemMonitor::ItemMonitor()
        cptr = new ItemMonitorWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::ItemMonitor >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_fetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemMonitor::fetchScope()->Akonadi::ItemFetchScope&
        Akonadi::ItemFetchScope & cppResult = cppSelf->fetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_item(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemMonitor::item()const->Akonadi::Item
        Akonadi::Item cppResult = const_cast<const ::Akonadi::ItemMonitor *>(cppSelf)->item();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_itemChanged(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemMonitor::itemChanged(const Akonadi::Item&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
        overloadId = 0; // ItemMonitor::itemChanged(const Akonadi::Item&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemChanged", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemMonitor::itemChanged(const Akonadi::Item&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::ItemMonitor::itemChanged(*cppArg0)
                : cppSelf->itemChanged(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_itemRemoved(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemMonitor::itemRemoved()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::Akonadi::ItemMonitor::itemRemoved()
            : cppSelf->itemRemoved();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_setFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemMonitor::setFetchScope(const Akonadi::ItemFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // ItemMonitor::setFetchScope(const Akonadi::ItemFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::ItemFetchScope cppArg0_local;
        ::Akonadi::ItemFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemMonitor::setFetchScope(const Akonadi::ItemFetchScope&)
            cppSelf->setFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemMonitorFunc_setItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemMonitor::setItem(const Akonadi::Item&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
        overloadId = 0; // ItemMonitor::setItem(const Akonadi::Item&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItem", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemMonitor::setItem(const Akonadi::Item&)
            cppSelf->setItem(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_ItemMonitor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ItemMonitor_methods[] = {
    {"fetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_fetchScope), METH_NOARGS, nullptr},
    {"item", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_item), METH_NOARGS, nullptr},
    {"itemChanged", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_itemChanged), METH_O, nullptr},
    {"itemRemoved", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_itemRemoved), METH_NOARGS, nullptr},
    {"setFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_setFetchScope), METH_O, nullptr},
    {"setItem", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMonitorFunc_setItem), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_ItemMonitor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::ItemMonitor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<ItemMonitorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_ItemMonitor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ItemMonitor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ItemMonitor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_ItemMonitor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ItemMonitor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ItemMonitor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ItemMonitor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ItemMonitor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ItemMonitor_spec = {
    "1:AkonadiCore.Akonadi.ItemMonitor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ItemMonitor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ItemMonitor_PythonToCpp_ItemMonitor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ItemMonitor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ItemMonitor_PythonToCpp_ItemMonitor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ItemMonitor_TypeF()))
        return ItemMonitor_PythonToCpp_ItemMonitor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ItemMonitor_PTR_CppToPython_ItemMonitor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_ItemMonitor_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::ItemMonitor *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_ItemMonitor_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ItemMonitor_SignatureStrings[] = {
    "AkonadiCore.Akonadi.ItemMonitor(self)",
    "AkonadiCore.Akonadi.ItemMonitor.fetchScope(self)->AkonadiCore.Akonadi.ItemFetchScope",
    "AkonadiCore.Akonadi.ItemMonitor.item(self)->AkonadiCore.Akonadi.Item",
    "AkonadiCore.Akonadi.ItemMonitor.itemChanged(self,item:AkonadiCore.Akonadi.Item)",
    "AkonadiCore.Akonadi.ItemMonitor.itemRemoved(self)",
    "AkonadiCore.Akonadi.ItemMonitor.setFetchScope(self,fetchScope:AkonadiCore.Akonadi.ItemFetchScope)",
    "AkonadiCore.Akonadi.ItemMonitor.setItem(self,item:AkonadiCore.Akonadi.Item)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ItemMonitor_SignatureByteSize = 125;
static constexpr uint8_t Akonadi_ItemMonitor_SignatureBytes[125] = {
    0x78, 0xda, 0x73, 0xcc, 0xce, 0xcf, 0x4b, 0x4c, 0xc9, 0x74, 0xce, 0x2f, 0x4a, 0xd5, 0x73, 0x84,
    0xb0, 0xf5, 0x3c, 0x4b, 0x52, 0x73, 0x7d, 0xf3, 0xf3, 0x32, 0x4b, 0xf2, 0x8b, 0x34, 0x8a, 0x53,
    0x73, 0xd2, 0x34, 0xb9, 0x1c, 0xf1, 0xab, 0xd2, 0x4b, 0x4b, 0x2d, 0x49, 0xce, 0x08, 0x4e, 0xce,
    0x2f, 0x48, 0x85, 0x68, 0xd0, 0xb5, 0xc3, 0xa5, 0xc3, 0x0d, 0xae, 0x92, 0xa0, 0xa1, 0x99, 0x40,
    0x36, 0x21, 0xe3, 0x88, 0x32, 0xc4, 0x39, 0x23, 0x31, 0x2f, 0x3d, 0x35, 0x05, 0x6c, 0x96, 0x0e,
    0x48, 0xc0, 0x0a, 0x97, 0x2e, 0x4d, 0xa2, 0xcc, 0x0b, 0x4a, 0xcd, 0xcd, 0x2f, 0x83, 0x9a, 0x47,
    0x58, 0x47, 0x71, 0x6a, 0x89, 0x1b, 0x6a, 0xf0, 0xe8, 0x20, 0x82, 0xcb, 0x8a, 0x70, 0x38, 0x11,
    0x65, 0x83, 0x27, 0x2c, 0xac, 0x08, 0xf9, 0x0f, 0x00, 0xb8, 0xdb, 0xb5, 0xf2
};
#endif

PyTypeObject *init_Akonadi_ItemMonitor(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMonitor_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_ItemMonitor_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ItemMonitor",
        "Akonadi::ItemMonitor*",
        &Sbk_Akonadi_ItemMonitor_spec,
        &Shiboken::callCppDestructor< Akonadi::ItemMonitor >,
        Sbk_Akonadi_ItemMonitor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ItemMonitor_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ItemMonitor_SignatureBytes, Akonadi_ItemMonitor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ItemMonitor_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ItemMonitor_PythonToCpp_ItemMonitor_PTR,
        is_ItemMonitor_PythonToCpp_ItemMonitor_PTR_Convertible,
        ItemMonitor_PTR_CppToPython_ItemMonitor);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMonitor");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMonitor*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMonitor&");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMonitor");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMonitor*");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMonitor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ItemMonitor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(ItemMonitorWrapper).name());

    qRegisterMetaType< ::Akonadi::ItemMonitor *>();

    return pyType;
}
