
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_itemfetchscope_wrapper.h"

// Argument includes
#include <QSet>
#include <itemfetchscope.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <tagfetchscope.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ItemFetchScope_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_ItemFetchScope_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::ItemFetchScope >()))
        return -1;

    ::Akonadi::ItemFetchScope *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ItemFetchScope", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ItemFetchScope::ItemFetchScope()
    // 1: ItemFetchScope::ItemFetchScope(const Akonadi::ItemFetchScope&)
    if (numArgs == 0) {
        overloadId = 0; // ItemFetchScope()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), (pyArgs[0])))) {
        overloadId = 1; // ItemFetchScope::ItemFetchScope(const Akonadi::ItemFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // ItemFetchScope()
        {

            // ItemFetchScope::ItemFetchScope()
            cptr = new ::Akonadi::ItemFetchScope();
            break;
        }
        case 1: // ItemFetchScope(const Akonadi::ItemFetchScope &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::ItemFetchScope cppArg0_local;
            ::Akonadi::ItemFetchScope *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ItemFetchScope::ItemFetchScope(const Akonadi::ItemFetchScope&)
                cptr = new ::Akonadi::ItemFetchScope(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Akonadi::ItemFetchScope >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_allAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::allAttributes()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->allAttributes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_ancestorRetrieval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::ancestorRetrieval()const->Akonadi::ItemFetchScope::AncestorRetrieval
        Akonadi::ItemFetchScope::AncestorRetrieval cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->ancestorRetrieval();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::attributes()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_cacheOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::cacheOnly()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->cacheOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_checkForCachedPayloadPartsOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::checkForCachedPayloadPartsOnly()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->checkForCachedPayloadPartsOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchAllAttributes(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchAllAttributes", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|O:fetchAllAttributes", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ItemFetchScope::fetchAllAttributes(bool=)
    if (numArgs == 0) {
        overloadId = 0; // fetchAllAttributes(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // ItemFetchScope::fetchAllAttributes(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchAllAttributes", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchAllAttributes", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::fetchAllAttributes(bool=)
            cppSelf->fetchAllAttributes(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchAttribute(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fetchAttribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ItemFetchScope::fetchAttribute(const QByteArray&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fetchAttribute(QByteArray,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // ItemFetchScope::fetchAttribute(const QByteArray&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchAttribute", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchAttribute", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::fetchAttribute(const QByteArray&,bool=)
            cppSelf->fetchAttribute(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchChangedSince(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchChangedSince()const->QDateTime
        QDateTime cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchChangedSince();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchFullPayload(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchFullPayload", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|O:fetchFullPayload", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ItemFetchScope::fetchFullPayload(bool=)
    if (numArgs == 0) {
        overloadId = 0; // fetchFullPayload(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // ItemFetchScope::fetchFullPayload(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchFullPayload", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchFullPayload", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::fetchFullPayload(bool=)
            cppSelf->fetchFullPayload(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchGid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchGid()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchGid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchModificationTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchModificationTime()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchModificationTime();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchPayloadPart(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fetchPayloadPart", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fetchPayloadPart", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ItemFetchScope::fetchPayloadPart(const QByteArray&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fetchPayloadPart(QByteArray,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // ItemFetchScope::fetchPayloadPart(const QByteArray&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fetchPayloadPart", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"fetch", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fetchPayloadPart", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::fetchPayloadPart(const QByteArray&,bool=)
            cppSelf->fetchPayloadPart(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchRemoteIdentification(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchRemoteIdentification()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchRemoteIdentification();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchTags()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchTags();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fetchVirtualReferences(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fetchVirtualReferences()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fetchVirtualReferences();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_fullPayload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::fullPayload()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->fullPayload();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_ignoreRetrievalErrors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::ignoreRetrievalErrors()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->ignoreRetrievalErrors();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::isEmpty()const->bool
        bool cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_payloadParts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::payloadParts()const->QSet<QByteArray>
        QSet<QByteArray> cppResult = const_cast<const ::Akonadi::ItemFetchScope *>(cppSelf)->payloadParts();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QSet_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setAncestorRetrieval(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setAncestorRetrieval(Akonadi::ItemFetchScope::AncestorRetrieval)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX]))), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setAncestorRetrieval(Akonadi::ItemFetchScope::AncestorRetrieval)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAncestorRetrieval", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        ::Akonadi::ItemFetchScope::AncestorRetrieval cppArg0{Akonadi::ItemFetchScope::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setAncestorRetrieval(Akonadi::ItemFetchScope::AncestorRetrieval)
            cppSelf->setAncestorRetrieval(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setCacheOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setCacheOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setCacheOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCacheOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setCacheOnly(bool)
            cppSelf->setCacheOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setCheckForCachedPayloadPartsOnly(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCheckForCachedPayloadPartsOnly", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    if (PyArg_ParseTuple(args, "|O:setCheckForCachedPayloadPartsOnly", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ItemFetchScope::setCheckForCachedPayloadPartsOnly(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setCheckForCachedPayloadPartsOnly(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // ItemFetchScope::setCheckForCachedPayloadPartsOnly(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCheckForCachedPayloadPartsOnly", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"check", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setCheckForCachedPayloadPartsOnly", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setCheckForCachedPayloadPartsOnly(bool=)
            cppSelf->setCheckForCachedPayloadPartsOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchChangedSince(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchChangedSince(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchChangedSince(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchChangedSince", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchChangedSince(const QDateTime&)
            cppSelf->setFetchChangedSince(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchGid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchGid(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchGid(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchGid", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchGid(bool)
            cppSelf->setFetchGid(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchModificationTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchModificationTime(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchModificationTime(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchModificationTime", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchModificationTime(bool)
            cppSelf->setFetchModificationTime(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchRemoteIdentification(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchRemoteIdentification(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchRemoteIdentification(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchRemoteIdentification", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchRemoteIdentification(bool)
            cppSelf->setFetchRemoteIdentification(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchTags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchTags(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchTags(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchTags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchTags(bool)
            cppSelf->setFetchTags(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setFetchVirtualReferences(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setFetchVirtualReferences(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setFetchVirtualReferences(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFetchVirtualReferences", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setFetchVirtualReferences(bool)
            cppSelf->setFetchVirtualReferences(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setIgnoreRetrievalErrors(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setIgnoreRetrievalErrors(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setIgnoreRetrievalErrors(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIgnoreRetrievalErrors", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setIgnoreRetrievalErrors(bool)
            cppSelf->setIgnoreRetrievalErrors(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_setTagFetchScope(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ItemFetchScope::setTagFetchScope(const Akonadi::TagFetchScope&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), (pyArg)))) {
        overloadId = 0; // ItemFetchScope::setTagFetchScope(const Akonadi::TagFetchScope&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTagFetchScope", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::TagFetchScope cppArg0_local;
        ::Akonadi::TagFetchScope *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ItemFetchScope::setTagFetchScope(const Akonadi::TagFetchScope&)
            cppSelf->setTagFetchScope(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemFetchScopeFunc_tagFetchScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemFetchScope::tagFetchScope()->Akonadi::TagFetchScope&
        Akonadi::TagFetchScope & cppResult = cppSelf->tagFetchScope();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_TagFetchScope_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemFetchScope__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Akonadi_ItemFetchScope_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_ItemFetchScope_EnumFlagInfo[] = {
    "AncestorRetrieval:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ItemFetchScope_methods[] = {
    {"allAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_allAttributes), METH_NOARGS, nullptr},
    {"ancestorRetrieval", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_ancestorRetrieval), METH_NOARGS, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_attributes), METH_NOARGS, nullptr},
    {"cacheOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_cacheOnly), METH_NOARGS, nullptr},
    {"checkForCachedPayloadPartsOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_checkForCachedPayloadPartsOnly), METH_NOARGS, nullptr},
    {"fetchAllAttributes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchAllAttributes), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchAttribute", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchAttribute), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchChangedSince", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchChangedSince), METH_NOARGS, nullptr},
    {"fetchFullPayload", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchFullPayload), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchGid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchGid), METH_NOARGS, nullptr},
    {"fetchModificationTime", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchModificationTime), METH_NOARGS, nullptr},
    {"fetchPayloadPart", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchPayloadPart), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fetchRemoteIdentification", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchRemoteIdentification), METH_NOARGS, nullptr},
    {"fetchTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchTags), METH_NOARGS, nullptr},
    {"fetchVirtualReferences", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fetchVirtualReferences), METH_NOARGS, nullptr},
    {"fullPayload", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_fullPayload), METH_NOARGS, nullptr},
    {"ignoreRetrievalErrors", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_ignoreRetrievalErrors), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_isEmpty), METH_NOARGS, nullptr},
    {"payloadParts", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_payloadParts), METH_NOARGS, nullptr},
    {"setAncestorRetrieval", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setAncestorRetrieval), METH_O, nullptr},
    {"setCacheOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setCacheOnly), METH_O, nullptr},
    {"setCheckForCachedPayloadPartsOnly", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setCheckForCachedPayloadPartsOnly), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFetchChangedSince", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchChangedSince), METH_O, nullptr},
    {"setFetchGid", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchGid), METH_O, nullptr},
    {"setFetchModificationTime", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchModificationTime), METH_O, nullptr},
    {"setFetchRemoteIdentification", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchRemoteIdentification), METH_O, nullptr},
    {"setFetchTags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchTags), METH_O, nullptr},
    {"setFetchVirtualReferences", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setFetchVirtualReferences), METH_O, nullptr},
    {"setIgnoreRetrievalErrors", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setIgnoreRetrievalErrors), METH_O, nullptr},
    {"setTagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_setTagFetchScope), METH_O, nullptr},
    {"tagFetchScope", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScopeFunc_tagFetchScope), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemFetchScope__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Akonadi_ItemFetchScope_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ItemFetchScope_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ItemFetchScope_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ItemFetchScope_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ItemFetchScope_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ItemFetchScope_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ItemFetchScope_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ItemFetchScope_spec = {
    "1:AkonadiCore.Akonadi.ItemFetchScope",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ItemFetchScope_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_ItemFetchScope_AncestorRetrieval(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ItemFetchScope::AncestorRetrieval>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ItemFetchScope::AncestorRetrieval *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ItemFetchScope_AncestorRetrieval_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX])))
        return Enum_PythonToCpp_Akonadi_ItemFetchScope_AncestorRetrieval;
    return {};
}

static PyObject *Akonadi_ItemFetchScope_AncestorRetrieval_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ItemFetchScope::AncestorRetrieval>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ItemFetchScope::AncestorRetrieval *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ItemFetchScope_PythonToCpp_ItemFetchScope_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ItemFetchScope_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ItemFetchScope_PythonToCpp_ItemFetchScope_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ItemFetchScope_TypeF()))
        return ItemFetchScope_PythonToCpp_ItemFetchScope_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ItemFetchScope_PTR_CppToPython_ItemFetchScope(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_ItemFetchScope_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_Akonadi_ItemFetchScope_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *ItemFetchScope_COPY_CppToPython_ItemFetchScope(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::Akonadi::ItemFetchScope *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Akonadi_ItemFetchScope_TypeF(), new ::Akonadi::ItemFetchScope(*source), true, true);
}

// Python to C++ copy conversion.
static void ItemFetchScope_PythonToCpp_ItemFetchScope_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::Akonadi::ItemFetchScope *>(cppOut) = *reinterpret_cast< ::Akonadi::ItemFetchScope *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_ItemFetchScope_PythonToCpp_ItemFetchScope_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ItemFetchScope_TypeF()))
        return ItemFetchScope_PythonToCpp_ItemFetchScope_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ItemFetchScope_SignatureStrings[] = {
    "1:AkonadiCore.Akonadi.ItemFetchScope(self)",
    "0:AkonadiCore.Akonadi.ItemFetchScope(self,other:AkonadiCore.Akonadi.ItemFetchScope)",
    "AkonadiCore.Akonadi.ItemFetchScope.allAttributes(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.ancestorRetrieval(self)->AkonadiCore.Akonadi.ItemFetchScope.AncestorRetrieval",
    "AkonadiCore.Akonadi.ItemFetchScope.attributes(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.ItemFetchScope.cacheOnly(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.checkForCachedPayloadPartsOnly(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchAllAttributes(self,fetch:bool=true)",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchAttribute(self,type:typing.Union[PySide6.QtCore.QByteArray, char*],fetch:bool=true)",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchChangedSince(self)->PySide6.QtCore.QDateTime",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchFullPayload(self,fetch:bool=true)",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchGid(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchModificationTime(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchPayloadPart(self,part:typing.Union[PySide6.QtCore.QByteArray, char*],fetch:bool=true)",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchRemoteIdentification(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchTags(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fetchVirtualReferences(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.fullPayload(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.ignoreRetrievalErrors(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.isEmpty(self)->bool",
    "AkonadiCore.Akonadi.ItemFetchScope.payloadParts(self)->QSet[PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.ItemFetchScope.setAncestorRetrieval(self,ancestorDepth:AkonadiCore.Akonadi.ItemFetchScope.AncestorRetrieval)",
    "AkonadiCore.Akonadi.ItemFetchScope.setCacheOnly(self,cacheOnly:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setCheckForCachedPayloadPartsOnly(self,check:bool=true)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchChangedSince(self,changedSince:PySide6.QtCore.QDateTime)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchGid(self,retrieveGID:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchModificationTime(self,retrieveMtime:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchRemoteIdentification(self,retrieveRid:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchTags(self,fetchTags:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setFetchVirtualReferences(self,fetchVRefs:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setIgnoreRetrievalErrors(self,enabled:bool)",
    "AkonadiCore.Akonadi.ItemFetchScope.setTagFetchScope(self,fetchScope:AkonadiCore.Akonadi.TagFetchScope)",
    "AkonadiCore.Akonadi.ItemFetchScope.tagFetchScope(self)->AkonadiCore.Akonadi.TagFetchScope",
    "AkonadiCore.Akonadi.ItemFetchScope.__copy__(self)->typing._Self",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ItemFetchScope_SignatureByteSize = 492;
static constexpr uint8_t Akonadi_ItemFetchScope_SignatureBytes[492] = {
    0x78, 0xda, 0xbd, 0x96, 0xdf, 0x4f, 0x83, 0x30, 0x10, 0xc7, 0xdf, 0xf7, 0x57, 0xf8, 0xe8, 0x4c,
    0x25, 0xfa, 0xe2, 0x03, 0x89, 0x26, 0xb8, 0x89, 0xd9, 0x83, 0x71, 0x1b, 0xd3, 0x17, 0xb3, 0x90,
    0x0e, 0x8e, 0xd1, 0xd8, 0xb5, 0xa4, 0xdc, 0x4c, 0xf8, 0xef, 0x2d, 0x63, 0xe0, 0x7e, 0x91, 0xb5,
    0x68, 0x7c, 0xa1, 0x3f, 0xe8, 0x7d, 0xae, 0x77, 0xd7, 0x7e, 0xe1, 0xd6, 0xf5, 0x3e, 0xa5, 0xa0,
    0x31, 0x1b, 0x48, 0x05, 0xce, 0xb6, 0xef, 0x8c, 0x10, 0x56, 0x3e, 0x60, 0x94, 0x06, 0x91, 0xcc,
    0xe0, 0x32, 0x07, 0x9e, 0xf4, 0x7b, 0x37, 0xa6, 0x4b, 0x89, 0xc4, 0x14, 0x94, 0xc1, 0xea, 0x7e,
    0xef, 0xfc, 0x1a, 0x87, 0x72, 0xee, 0x21, 0x2a, 0xb6, 0x58, 0x23, 0xe4, 0xd5, 0x56, 0xae, 0x1f,
    0x16, 0x52, 0x72, 0x23, 0x63, 0x11, 0x41, 0x8e, 0x52, 0x4d, 0x41, 0x13, 0xe0, 0x8b, 0xf2, 0x1a,
    0x60, 0x60, 0xeb, 0x1d, 0xda, 0x1a, 0x39, 0x3c, 0xda, 0xea, 0x24, 0x00, 0xfc, 0x18, 0x17, 0x01,
    0x8b, 0xe1, 0xce, 0x99, 0xe0, 0xc6, 0x78, 0xf2, 0x58, 0x20, 0x78, 0x4a, 0xd1, 0x62, 0x6e, 0x02,
    0x8d, 0x68, 0x94, 0xc2, 0xab, 0xe0, 0x85, 0x6d, 0xf8, 0xda, 0x2c, 0xfa, 0xf4, 0xa5, 0x1a, 0x94,
    0x80, 0x78, 0x4c, 0x0b, 0x2e, 0xa9, 0x6e, 0x14, 0xe6, 0x5d, 0x68, 0x49, 0xd9, 0xf5, 0x8e, 0xca,
    0x41, 0x36, 0xf3, 0x6e, 0x49, 0xb9, 0x47, 0xb5, 0x36, 0xab, 0x6a, 0xc5, 0xaa, 0x41, 0x15, 0x07,
    0x8b, 0x0c, 0x5c, 0xfd, 0x60, 0x62, 0xe9, 0xbc, 0x09, 0x26, 0x45, 0x7b, 0xda, 0xc8, 0x45, 0x94,
    0x52, 0x75, 0x35, 0xef, 0xee, 0x7b, 0x90, 0x52, 0xb1, 0x84, 0x38, 0x60, 0xba, 0xca, 0x75, 0x22,
    0x0e, 0xdd, 0x0d, 0x29, 0xc2, 0x8c, 0xad, 0xc0, 0x18, 0xea, 0xaf, 0x39, 0xdf, 0x66, 0xf9, 0x97,
    0xa9, 0x79, 0x66, 0x71, 0xa7, 0xf2, 0xbc, 0xc8, 0x98, 0x25, 0x2c, 0xa2, 0xa8, 0xd3, 0x57, 0x6e,
    0xbd, 0x13, 0x64, 0xe7, 0xa0, 0x54, 0x61, 0x64, 0xba, 0xf7, 0x6f, 0x95, 0x99, 0xc2, 0x4a, 0x22,
    0x8c, 0x62, 0x10, 0xd8, 0x84, 0xd2, 0x29, 0x8c, 0x19, 0x5d, 0xe6, 0x9d, 0x0c, 0xdf, 0x99, 0xc2,
    0x35, 0xe5, 0x53, 0x48, 0x40, 0x41, 0xa9, 0x02, 0xd6, 0x94, 0x83, 0x73, 0x60, 0x61, 0xca, 0x96,
    0x42, 0xbf, 0x6d, 0x34, 0xe7, 0x49, 0x29, 0xa9, 0xac, 0xfd, 0xb3, 0xfc, 0x69, 0x95, 0xa1, 0xf5,
    0x05, 0xcf, 0x76, 0x04, 0xe2, 0x0f, 0xe5, 0x2b, 0x07, 0xf4, 0x4e, 0xea, 0x30, 0xa9, 0xe5, 0x79,
    0x08, 0x19, 0xa6, 0x6e, 0x17, 0x4d, 0xee, 0x1b, 0x6e, 0x60, 0xb0, 0x27, 0xa1, 0xa4, 0x51, 0xd4,
    0xcd, 0x01, 0x35, 0x86, 0x9c, 0x97, 0x53, 0xb2, 0x91, 0x5c, 0xcb, 0x63, 0xaf, 0xd1, 0xfe, 0x49,
    0x4d, 0xd2, 0xb4, 0x9f, 0x19, 0xb7, 0x4d, 0x9e, 0xac, 0x7c, 0xd4, 0xc2, 0x42, 0x54, 0x95, 0x42,
    0x78, 0x1e, 0x0d, 0xad, 0x92, 0xe0, 0xb7, 0xca, 0x4c, 0x83, 0x7c, 0x41, 0x3d, 0x65, 0x0f, 0x6d,
    0xbd, 0xf8, 0x0d, 0x78, 0xca, 0x62, 0x7b, 0x6c, 0x23, 0x03, 0xa4, 0x51, 0x05, 0x7b, 0xc8, 0x69,
    0x49, 0xa8, 0x88, 0xef, 0x7a, 0xd6, 0x0e, 0x39, 0x6a, 0xbd, 0xe4, 0x04, 0x04, 0x5d, 0x70, 0xb0,
    0x0b, 0x53, 0x87, 0x74, 0xf8, 0x0b, 0x96, 0x34, 0xe3, 0x93, 0xd7, 0x6a, 0xcf, 0xc2, 0xc8, 0x0d,
    0x1e, 0xf9, 0x68, 0xf9, 0x8b, 0xda, 0x43, 0x9b, 0x90, 0xc3, 0x50, 0x37, 0x45, 0x18, 0xd6, 0xd0,
    0xed, 0x77, 0x26, 0x0c, 0xf4, 0xb0, 0xf7, 0x0d, 0x3b, 0xc9, 0xeb, 0x6b
};
#endif

PyTypeObject *init_Akonadi_ItemFetchScope(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_Akonadi_ItemFetchScope_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ItemFetchScope",
        "Akonadi::ItemFetchScope",
        &Sbk_Akonadi_ItemFetchScope_spec,
        &Shiboken::callCppDestructor< ::Akonadi::ItemFetchScope >,
        Sbk_Akonadi_ItemFetchScope_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ItemFetchScope_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ItemFetchScope_SignatureBytes, Akonadi_ItemFetchScope_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ItemFetchScope_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ItemFetchScope_PythonToCpp_ItemFetchScope_PTR,
        is_ItemFetchScope_PythonToCpp_ItemFetchScope_PTR_Convertible,
        ItemFetchScope_PTR_CppToPython_ItemFetchScope,
        ItemFetchScope_COPY_CppToPython_ItemFetchScope);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemFetchScope");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemFetchScope*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemFetchScope&");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemFetchScope");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemFetchScope*");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemFetchScope&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ItemFetchScope).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        ItemFetchScope_PythonToCpp_ItemFetchScope_COPY,
        is_ItemFetchScope_PythonToCpp_ItemFetchScope_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_ItemFetchScope_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'AncestorRetrieval'.
    const char *AncestorRetrieval_Initializer[] = {
        "None_",
        "Parent",
        "All",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AncestorRetrieval_InitializerValues[] = {
        uint8_t(Akonadi::ItemFetchScope::AncestorRetrieval::None),   //  0x00  0
        uint8_t(Akonadi::ItemFetchScope::AncestorRetrieval::Parent), //  0x01  1
        uint8_t(Akonadi::ItemFetchScope::AncestorRetrieval::All)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.ItemFetchScope.AncestorRetrieval",
        AncestorRetrieval_Initializer, AncestorRetrieval_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemFetchScope_AncestorRetrieval_IDX].type = EType;
    // Register converter for enum 'Akonadi::ItemFetchScope::AncestorRetrieval'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ItemFetchScope_AncestorRetrieval_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ItemFetchScope_AncestorRetrieval,
            is_Enum_PythonToCpp_Akonadi_ItemFetchScope_AncestorRetrieval_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemFetchScope::AncestorRetrieval");
        Shiboken::Conversions::registerConverterAlias(converter, "ItemFetchScope::AncestorRetrieval");
        Shiboken::Conversions::registerConverterAlias(converter, "AncestorRetrieval");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AncestorRetrieval' enum.

    qRegisterMetaType< ::Akonadi::ItemFetchScope >("ItemFetchScope");
    qRegisterMetaType< ::Akonadi::ItemFetchScope >("Akonadi::ItemFetchScope");
    qRegisterMetaType< ::Akonadi::ItemFetchScope::AncestorRetrieval >("ItemFetchScope::AncestorRetrieval");
    qRegisterMetaType< ::Akonadi::ItemFetchScope::AncestorRetrieval >("Akonadi::ItemFetchScope::AncestorRetrieval");

    return pyType;
}
