/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.AgentManager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef AGENTMANAGERINTERFACE_H
#define AGENTMANAGERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.Akonadi.AgentManager
 */
class OrgFreedesktopAkonadiAgentManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.AgentManager"; }

public:
    OrgFreedesktopAkonadiAgentManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiAgentManagerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QStringList> agentCapabilities(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentCapabilities"), argumentList);
    }

    inline QDBusPendingReply<QString> agentComment(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentComment"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> agentCustomProperties(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentCustomProperties"), argumentList);
    }

    inline QDBusPendingReply<QString> agentIcon(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentIcon"), argumentList);
    }

    inline QDBusPendingReply<QString> agentInstanceAccountId(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceAccountId"), argumentList);
    }

    inline QDBusPendingReply<QStringList> agentInstanceActivities(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceActivities"), argumentList);
    }

    inline QDBusPendingReply<bool> agentInstanceActivitiesEnabled(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceActivitiesEnabled"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceConfigure(const QString &identifier, qlonglong windowId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(windowId);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceConfigure"), argumentList);
    }

    inline QDBusPendingReply<QString> agentInstanceName(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceName"), argumentList);
    }

    inline QDBusPendingReply<bool> agentInstanceOnline(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceOnline"), argumentList);
    }

    inline QDBusPendingReply<uint> agentInstanceProgress(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceProgress"), argumentList);
    }

    inline QDBusPendingReply<QString> agentInstanceProgressMessage(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceProgressMessage"), argumentList);
    }

    inline QDBusPendingReply<int> agentInstanceStatus(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceStatus"), argumentList);
    }

    inline QDBusPendingReply<QString> agentInstanceStatusMessage(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceStatusMessage"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceSynchronize(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceSynchronize"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection, bool recursive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(collection) << QVariant::fromValue(recursive);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceSynchronizeCollection"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceSynchronizeCollection(const QString &identifier, qlonglong collection)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(collection);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceSynchronizeCollection"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceSynchronizeCollectionTree(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceSynchronizeCollectionTree"), argumentList);
    }

    inline QDBusPendingReply<> agentInstanceSynchronizeTags(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceSynchronizeTags"), argumentList);
    }

    inline QDBusPendingReply<QString> agentInstanceType(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentInstanceType"), argumentList);
    }

    inline QDBusPendingReply<QStringList> agentInstances()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("agentInstances"), argumentList);
    }

    inline QDBusPendingReply<QStringList> agentMimeTypes(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentMimeTypes"), argumentList);
    }

    inline QDBusPendingReply<QString> agentName(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("agentName"), argumentList);
    }

    inline QDBusPendingReply<QStringList> agentTypes()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("agentTypes"), argumentList);
    }

    inline QDBusPendingReply<QString> createAgentInstance(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("createAgentInstance"), argumentList);
    }

    inline QDBusPendingReply<> removeAgentInstance(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("removeAgentInstance"), argumentList);
    }

    inline QDBusPendingReply<> restartAgentInstance(const QString &identifier)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier);
        return asyncCallWithArgumentList(QStringLiteral("restartAgentInstance"), argumentList);
    }

    inline QDBusPendingReply<> setAgentInstanceActivities(const QString &identifier, const QStringList &activities)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(activities);
        return asyncCallWithArgumentList(QStringLiteral("setAgentInstanceActivities"), argumentList);
    }

    inline QDBusPendingReply<> setAgentInstanceActivitiesEnabled(const QString &identifier, bool en)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(en);
        return asyncCallWithArgumentList(QStringLiteral("setAgentInstanceActivitiesEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setAgentInstanceName(const QString &identifier, const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("setAgentInstanceName"), argumentList);
    }

    inline QDBusPendingReply<> setAgentInstanceOnline(const QString &identifier, bool state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(identifier) << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("setAgentInstanceOnline"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void agentInstanceAccountIdChanged(const QString &agentIdentifier, const QString &accountId);
    void agentInstanceAdded(const QString &agentIdentifier);
    void agentInstanceAdvancedStatusChanged(const QString &agentIdentifier, const QVariantMap &status);
    void agentInstanceError(const QString &agentIdentifier, const QString &message);
    void agentInstanceNameChanged(const QString &agentIdentifier, const QString &name);
    void agentInstanceOnlineChanged(const QString &agentIdentifier, bool state);
    void agentInstanceProgressChanged(const QString &agentIdentifier, uint progress, const QString &message);
    void agentInstanceRemoved(const QString &agentIdentifier);
    void agentInstanceStatusChanged(const QString &agentIdentifier, int status, const QString &message);
    void agentInstanceWarning(const QString &agentIdentifier, const QString &message);
    void agentTypeAdded(const QString &agentType);
    void agentTypeRemoved(const QString &agentType);
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      using AgentManager = ::OrgFreedesktopAkonadiAgentManagerInterface;
    }
  }
}

#endif
