/****************************************************************************
** Meta object code from reading C++ file 'resourceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "resourceadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi__ResourceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi__ResourceAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Resource",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Akonadi.Resource\">\n    <sign"
        "al name=\"nameChanged\">\n      <arg direction=\"out\" type=\"s\" "
        "name=\"name\"/>\n    </signal>\n    <signal name=\"synchronized\"/"
        ">\n    <signal name=\"attributesSynchronized\">\n      <arg type=\""
        "x\" name=\"collectionId\"/>\n    </signal>\n    <signal name=\"col"
        "lectionTreeSynchronized\"/>\n    <method name=\"taskList\">\n     "
        " <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <method "
        "name=\"requestItemDelivery\">\n      <annotation value=\"QList&lt;"
        "qlonglong&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n  "
        "    <arg direction=\"in\" type=\"ax\" name=\"uids\"/>\n      <anno"
        "tation value=\"QByteArrayList\" name=\"org.qtproject.QtDBus.QtType"
        "Name.In1\"/>\n      <arg direction=\"in\" type=\"aay\" name=\"part"
        "s\"/>\n    </method>\n    <method name=\"synchronize\">\n      <an"
        "notation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply"
        "\"/>\n    </method>\n    <method name=\"synchronizeCollectionTree\""
        ">\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.Me"
        "thod.NoReply\"/>\n    </method>\n    <method name=\"synchronizeCol"
        "lection\">\n      <arg direction=\"in\" type=\"x\" name=\"collecti"
        "onId\"/>\n      <annotation value=\"true\" name=\"org.freedesktop."
        "DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"synchro"
        "nizeCollection\">\n      <arg direction=\"in\" type=\"x\" name=\"c"
        "ollectionId\"/>\n      <arg direction=\"in\" type=\"b\" name=\"rec"
        "ursive\"/>\n      <annotation value=\"true\" name=\"org.freedeskto"
        "p.DBus.Method.NoReply\"/>\n    </method>\n    <method name=\"synch"
        "ronizeCollectionAttributes\">\n      <arg direction=\"in\" type=\""
        "x\" name=\"collectionId\"/>\n      <annotation value=\"true\" name"
        "=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <me"
        "thod name=\"synchronizeTags\">\n      <annotation value=\"true\" n"
        "ame=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    "
        "<method name=\"setName\">\n      <arg direction=\"in\" type=\"s\" "
        "name=\"name\"/>\n    </method>\n    <method name=\"name\">\n      "
        "<arg direction=\"out\" type=\"s\"/>\n    </method>\n    <method na"
        "me=\"setActivities\">\n      <arg direction=\"in\" type=\"as\" nam"
        "e=\"name\"/>\n    </method>\n    <method name=\"activities\">\n   "
        "   <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <metho"
        "d name=\"setActivitiesEnabled\">\n      <arg direction=\"in\" type"
        "=\"b\" name=\"en\"/>\n    </method>\n    <method name=\"activities"
        "Enabled\">\n      <arg direction=\"out\" type=\"b\"/>\n    </metho"
        "d>\n  </interface>\n",
        "attributesSynchronized",
        "",
        "collectionId",
        "collectionTreeSynchronized",
        "nameChanged",
        "name",
        "synchronized",
        "activities",
        "activitiesEnabled",
        "requestItemDelivery",
        "QList<qlonglong>",
        "uids",
        "QByteArrayList",
        "parts",
        "setActivities",
        "setActivitiesEnabled",
        "en",
        "setName",
        "synchronize",
        "Q_NOREPLY",
        "synchronizeCollection",
        "recursive",
        "synchronizeCollectionAttributes",
        "synchronizeCollectionTree",
        "synchronizeTags",
        "taskList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'attributesSynchronized'
        QtMocHelpers::SignalData<void(qlonglong)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Signal 'collectionTreeSynchronized'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'synchronized'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activities'
        QtMocHelpers::SlotData<QStringList()>(12, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'activitiesEnabled'
        QtMocHelpers::SlotData<bool()>(13, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'name'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'requestItemDelivery'
        QtMocHelpers::SlotData<void(const QList<qlonglong> &, const QByteArrayList &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setActivities'
        QtMocHelpers::SlotData<void(const QStringList &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Slot 'setActivitiesEnabled'
        QtMocHelpers::SlotData<void(bool)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'synchronize'
        QtMocHelpers::SlotData<void()>(23, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeCollection'
        QtMocHelpers::SlotData<void(qlonglong, bool)>(25, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'synchronizeCollection'
        QtMocHelpers::SlotData<void(qlonglong)>(25, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'synchronizeCollectionAttributes'
        QtMocHelpers::SlotData<void(qlonglong)>(27, 24, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'synchronizeCollectionTree'
        QtMocHelpers::SlotData<void()>(28, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeTags'
        QtMocHelpers::SlotData<void()>(29, 24, QMC::AccessPublic, QMetaType::Void),
        // Slot 'taskList'
        QtMocHelpers::SlotData<QStringList()>(30, 6, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Akonadi__ResourceAdaptor, qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi__ResourceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>.metaTypes,
    nullptr
} };

void Akonadi__ResourceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Akonadi__ResourceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->attributesSynchronized((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: _t->collectionTreeSynchronized(); break;
        case 2: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->synchronized(); break;
        case 4: { QStringList _r = _t->activities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->activitiesEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->requestItemDelivery((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[2]))); break;
        case 8: _t->setActivities((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 9: _t->setActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->synchronize(); break;
        case 12: _t->synchronizeCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->synchronizeCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 14: _t->synchronizeCollectionAttributes((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 15: _t->synchronizeCollectionTree(); break;
        case 16: _t->synchronizeTags(); break;
        case 17: { QStringList _r = _t->taskList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ResourceAdaptor::*)(qlonglong )>(_a, &Akonadi__ResourceAdaptor::attributesSynchronized, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ResourceAdaptor::*)()>(_a, &Akonadi__ResourceAdaptor::collectionTreeSynchronized, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ResourceAdaptor::*)(const QString & )>(_a, &Akonadi__ResourceAdaptor::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Akonadi__ResourceAdaptor::*)()>(_a, &Akonadi__ResourceAdaptor::synchronized, 3))
            return;
    }
}

const QMetaObject *Akonadi__ResourceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi__ResourceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24Akonadi__ResourceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Akonadi__ResourceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Akonadi__ResourceAdaptor::attributesSynchronized(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi__ResourceAdaptor::collectionTreeSynchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Akonadi__ResourceAdaptor::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Akonadi__ResourceAdaptor::synchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
