
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_itemmovejob_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"
#include "akonadi_specialcollectionsdiscoveryjob_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <collection.h>
#include <item.h>
#include <kjob.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ItemMoveJob_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void ItemMoveJobWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

ItemMoveJobWrapper::ItemMoveJobWrapper(const ::Akonadi::Item & item, const ::Akonadi::Collection & destination, ::QObject * parent) : Akonadi::ItemMoveJob(item, destination, parent)
{
}

ItemMoveJobWrapper::ItemMoveJobWrapper(const ::QList<Akonadi::Item> & items, const ::Akonadi::Collection & destination, ::QObject * parent) : Akonadi::ItemMoveJob(items, destination, parent)
{
}

ItemMoveJobWrapper::ItemMoveJobWrapper(const ::QList<Akonadi::Item> & items, const ::Akonadi::Collection & source, const ::Akonadi::Collection & destination, ::QObject * parent) : Akonadi::ItemMoveJob(items, source, destination, parent)
{
}

bool ItemMoveJobWrapper::addSubjob(::KJob * job)
{
    static const char *funcName = "addSubjob";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Job::addSubjob(job);
    }
    return SpecialCollectionsDiscoveryJobWrapper::sbk_o_addSubjob("ItemMoveJob", funcName, gil, pyOverride, job);
}

void ItemMoveJobWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("ItemMoveJob", funcName, gil, pyOverride, event);
}

void ItemMoveJobWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("ItemMoveJob", funcName, gil, pyOverride, signal);
}

void ItemMoveJobWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("ItemMoveJob", funcName, gil, pyOverride, event);
}

void ItemMoveJobWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("ItemMoveJob", funcName, gil, pyOverride, signal);
}

bool ItemMoveJobWrapper::doKill()
{
    static const char *funcName = "doKill";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Job::doKill();
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("ItemMoveJob", funcName, gil, pyOverride);
}

bool ItemMoveJobWrapper::doResume()
{
    static const char *funcName = "doResume";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KJob::doResume();
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("ItemMoveJob", funcName, gil, pyOverride);
}

void ItemMoveJobWrapper::doStart()
{
    static const char *funcName = "doStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::ItemMoveJob::doStart();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("ItemMoveJob", funcName, gil, pyOverride);
}

bool ItemMoveJobWrapper::doSuspend()
{
    static const char *funcName = "doSuspend";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::KJob::doSuspend();
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("ItemMoveJob", funcName, gil, pyOverride);
}

bool ItemMoveJobWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("ItemMoveJob", funcName, gil, pyOverride, event);
}

bool ItemMoveJobWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("ItemMoveJob", funcName, gil, pyOverride, watched, event);
}

bool ItemMoveJobWrapper::removeSubjob(::KJob * job)
{
    static const char *funcName = "removeSubjob";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Job::removeSubjob(job);
    }
    return SpecialCollectionsDiscoveryJobWrapper::sbk_o_addSubjob("ItemMoveJob", funcName, gil, pyOverride, job);
}

void ItemMoveJobWrapper::slotInfoMessage(::KJob * job, const ::QString & message)
{
    static const char *funcName = "slotInfoMessage";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCompositeJob::slotInfoMessage(job, message);
    }
    SpecialCollectionsDiscoveryJobWrapper::sbk_o_slotInfoMessage("ItemMoveJob", funcName, gil, pyOverride, job, message);
}

void ItemMoveJobWrapper::slotResult(::KJob * job)
{
    static const char *funcName = "slotResult";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Job::slotResult(job);
    }
    SpecialCollectionsDiscoveryJobWrapper::sbk_o_slotResult("ItemMoveJob", funcName, gil, pyOverride, job);
}

void ItemMoveJobWrapper::start()
{
    static const char *funcName = "start";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::Job::start();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("ItemMoveJob", funcName, gil, pyOverride);
}

void ItemMoveJobWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ItemMoveJob_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("ItemMoveJob", funcName, gil, pyOverride, event);
}

const QMetaObject *ItemMoveJobWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::ItemMoveJob::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int ItemMoveJobWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::ItemMoveJob::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *ItemMoveJobWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< ItemMoveJobWrapper *>(this));
    }
    return Akonadi::ItemMoveJob::qt_metacast(_clname);
}

ItemMoveJobWrapper::~ItemMoveJobWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_ItemMoveJob_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_ItemMoveJob_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::ItemMoveJob >()))
        return -1;

    ItemMoveJobWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOO:ItemMoveJob", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ItemMoveJob::ItemMoveJob(const Akonadi::Item&,const Akonadi::Collection&,QObject*=)
    // 1: ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,QObject*=)
    // 2: ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,const Akonadi::Collection&,QObject*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // ItemMoveJob(Akonadi::Item,Akonadi::Collection,QObject*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 0; // ItemMoveJob::ItemMoveJob(const Akonadi::Item&,const Akonadi::Collection&,QObject*=)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Item_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // ItemMoveJob(QList<Akonadi::Item>,Akonadi::Collection,QObject*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // ItemMoveJob(QList<Akonadi::Item>,Akonadi::Collection,Akonadi::Collection,QObject*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))) {
                overloadId = 2; // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,const Akonadi::Collection&,QObject*=)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            overloadId = 1; // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,QObject*=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);

    // Resolve keyword arguments
    switch (overloadId) {
        case 0: // ItemMoveJob::ItemMoveJob(const Akonadi::Item&,const Akonadi::Collection&,QObject*=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);
                }
            }
            break;
        }
        case 1: // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,QObject*=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);
                }
            }
            break;
        }
        case 2: // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,const Akonadi::Collection&,QObject*=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 3}};
                if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[3])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);
                }
            }
            break;
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // ItemMoveJob(const Akonadi::Item &item, const Akonadi::Collection &destination, QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::Akonadi::Collection cppArg1_local;
            ::Akonadi::Collection *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ItemMoveJob::ItemMoveJob(const Akonadi::Item&,const Akonadi::Collection&,QObject*=)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) ItemMoveJobWrapper(*cppArg0, *cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new ItemMoveJobWrapper(*cppArg0, *cppArg1, cppArg2);
                }

            }
            break;
        }
        case 1: // ItemMoveJob(const QList<Akonadi::Item> &items, const Akonadi::Collection &destination, QObject *parent)
        {
            ::QList<Akonadi::Item> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::Akonadi::Collection cppArg1_local;
            ::Akonadi::Collection *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,QObject*=)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) ItemMoveJobWrapper(cppArg0, *cppArg1, cppArg2);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new ItemMoveJobWrapper(cppArg0, *cppArg1, cppArg2);
                }

            }
            break;
        }
        case 2: // ItemMoveJob(const QList<Akonadi::Item> &items, const Akonadi::Collection &source, const Akonadi::Collection &destination, QObject *parent)
        {
            ::QList<Akonadi::Item> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::Akonadi::Collection cppArg1_local;
            ::Akonadi::Collection *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::Akonadi::Collection cppArg2_local;
            ::Akonadi::Collection *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return -1;
            ::QObject *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ItemMoveJob::ItemMoveJob(const QList<Akonadi::Item>&,const Akonadi::Collection&,const Akonadi::Collection&,QObject*=)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) ItemMoveJobWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new ItemMoveJobWrapper(cppArg0, *cppArg1, *cppArg2, cppArg3);
                }

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::ItemMoveJob >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_ItemMoveJobFunc_destinationCollection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMoveJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemMoveJob::destinationCollection()const->Akonadi::Collection
        Akonadi::Collection cppResult = const_cast<const ::Akonadi::ItemMoveJob *>(cppSelf)->destinationCollection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_ItemMoveJobFunc_doStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMoveJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Job::doStart()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::Akonadi::ItemMoveJob::doStart()
            : cppSelf->doStart();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ItemMoveJobFunc_items(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ItemMoveJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ItemMoveJob::items()const->QList<Akonadi::Item>
        QList<Akonadi::Item> cppResult = const_cast<const ::Akonadi::ItemMoveJob *>(cppSelf)->items();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Item_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_ItemMoveJob_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ItemMoveJob_methods[] = {
    {"destinationCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMoveJobFunc_destinationCollection), METH_NOARGS, nullptr},
    {"doStart", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMoveJobFunc_doStart), METH_NOARGS, nullptr},
    {"items", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ItemMoveJobFunc_items), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_ItemMoveJob_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::ItemMoveJob *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<ItemMoveJobWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_ItemMoveJob_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ItemMoveJob_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ItemMoveJob_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_ItemMoveJob_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ItemMoveJob_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ItemMoveJob_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ItemMoveJob_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ItemMoveJob_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ItemMoveJob_spec = {
    "1:AkonadiCore.Akonadi.ItemMoveJob",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ItemMoveJob_slots
};

} //extern "C"

static void *Sbk_Akonadi_ItemMoveJob_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::ItemMoveJob *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ItemMoveJob_PythonToCpp_ItemMoveJob_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ItemMoveJob_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ItemMoveJob_PythonToCpp_ItemMoveJob_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ItemMoveJob_TypeF()))
        return ItemMoveJob_PythonToCpp_ItemMoveJob_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ItemMoveJob_PTR_CppToPython_ItemMoveJob(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::ItemMoveJob *>(const_cast<void *>(cppIn)), Sbk_Akonadi_ItemMoveJob_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ItemMoveJob_SignatureStrings[] = {
    "2:AkonadiCore.Akonadi.ItemMoveJob(self,item:AkonadiCore.Akonadi.Item,destination:AkonadiCore.Akonadi.Collection,parent:PySide6.QtCore.QObject=nullptr)",
    "1:AkonadiCore.Akonadi.ItemMoveJob(self,items:QList[AkonadiCore.Akonadi.Item],destination:AkonadiCore.Akonadi.Collection,parent:PySide6.QtCore.QObject=nullptr)",
    "0:AkonadiCore.Akonadi.ItemMoveJob(self,items:QList[AkonadiCore.Akonadi.Item],source:AkonadiCore.Akonadi.Collection,destination:AkonadiCore.Akonadi.Collection,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.ItemMoveJob.destinationCollection(self)->AkonadiCore.Akonadi.Collection",
    "AkonadiCore.Akonadi.ItemMoveJob.doStart(self)",
    "AkonadiCore.Akonadi.ItemMoveJob.items(self)->QList[AkonadiCore.Akonadi.Item]",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ItemMoveJob_SignatureByteSize = 174;
static constexpr uint8_t Akonadi_ItemMoveJob_SignatureBytes[174] = {
    0x78, 0xda, 0x33, 0xb2, 0x72, 0xcc, 0xce, 0xcf, 0x4b, 0x4c, 0xc9, 0x74, 0xce, 0x2f, 0x4a, 0xd5,
    0x83, 0xb2, 0xf5, 0x3c, 0x4b, 0x52, 0x73, 0x7d, 0xf3, 0xcb, 0x52, 0xbd, 0xf2, 0x93, 0x34, 0x8a,
    0x53, 0x73, 0xd2, 0x74, 0x32, 0x81, 0x02, 0x38, 0x55, 0xea, 0xa4, 0xa4, 0x16, 0x97, 0x64, 0xe6,
    0x25, 0x96, 0x64, 0xe6, 0xe7, 0x61, 0x55, 0xe4, 0x9c, 0x9f, 0x93, 0x93, 0x9a, 0x0c, 0x92, 0xd6,
    0x29, 0x48, 0x2c, 0x4a, 0xcd, 0x2b, 0xb1, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b,
    0x2c, 0x01, 0x2b, 0x0c, 0xf4, 0x4f, 0xca, 0x02, 0x2a, 0xb0, 0xcd, 0x2b, 0xcd, 0xc9, 0x29, 0x28,
    0x29, 0xd2, 0xe4, 0x32, 0x24, 0xde, 0x59, 0xc5, 0x56, 0x81, 0x3e, 0x99, 0xc5, 0x25, 0xd1, 0xb8,
    0x34, 0xc4, 0xd2, 0xc0, 0x79, 0x06, 0xd4, 0x74, 0x5e, 0x71, 0x7e, 0x69, 0x51, 0x72, 0x2a, 0x21,
    0x97, 0x51, 0xdf, 0x13, 0x04, 0xbc, 0xa0, 0x87, 0x64, 0x23, 0xc2, 0x70, 0xb0, 0xc7, 0x34, 0x75,
    0xed, 0xf0, 0x3b, 0x81, 0xb0, 0xd9, 0xf9, 0xc1, 0x25, 0x89, 0x45, 0x25, 0x10, 0xd3, 0x08, 0xaa,
    0x06, 0x87, 0x23, 0xcc, 0x66, 0x02, 0xc1, 0xc9, 0x05, 0x00, 0xc6, 0xf8, 0x09, 0xba
};
#endif

PyTypeObject *init_Akonadi_ItemMoveJob(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_ItemMoveJob_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Job_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_ItemMoveJob_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ItemMoveJob",
        "Akonadi::ItemMoveJob*",
        &Sbk_Akonadi_ItemMoveJob_spec,
        &Shiboken::callCppDestructor< Akonadi::ItemMoveJob >,
        Sbk_Akonadi_ItemMoveJob_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ItemMoveJob_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ItemMoveJob_SignatureBytes, Akonadi_ItemMoveJob_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ItemMoveJob_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ItemMoveJob_PythonToCpp_ItemMoveJob_PTR,
        is_ItemMoveJob_PythonToCpp_ItemMoveJob_PTR_Convertible,
        ItemMoveJob_PTR_CppToPython_ItemMoveJob);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMoveJob");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMoveJob*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ItemMoveJob&");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMoveJob");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMoveJob*");
    Shiboken::Conversions::registerConverterAlias(converter, "ItemMoveJob&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ItemMoveJob).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(ItemMoveJobWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_ItemMoveJob_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::ItemMoveJob::staticMetaObject, sizeof(ItemMoveJobWrapper));

    return pyType;
}
