/****************************************************************************
** Meta object code from reading C++ file 'agentmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.07.90/src/akonadicontrol/agentmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agentmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AgentManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto AgentManager::qt_create_metaobjectdata<qt_meta_tag_ZN12AgentManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AgentManager",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.AgentManager",
        "agentTypeAdded",
        "",
        "agentType",
        "agentTypeRemoved",
        "agentInstanceAdded",
        "agentIdentifier",
        "agentInstanceRemoved",
        "agentInstanceStatusChanged",
        "status",
        "message",
        "agentInstanceAdvancedStatusChanged",
        "QVariantMap",
        "agentInstanceProgressChanged",
        "progress",
        "agentInstanceWarning",
        "agentInstanceError",
        "agentInstanceNameChanged",
        "name",
        "agentInstanceOnlineChanged",
        "state",
        "agentInstanceAccountIdChanged",
        "accountId",
        "updatePluginInfos",
        "serviceOwnerChanged",
        "oldOwner",
        "newOwner",
        "agentExeChanged",
        "fileName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'agentTypeAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'agentTypeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'agentInstanceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'agentInstanceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'agentInstanceStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::Int, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'agentInstanceAdvancedStatusChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 14, 11 },
        }}),
        // Signal 'agentInstanceProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::UInt, 16 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'agentInstanceWarning'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'agentInstanceError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'agentInstanceNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'agentInstanceOnlineChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::Bool, 22 },
        }}),
        // Signal 'agentInstanceAccountIdChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'updatePluginInfos'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'serviceOwnerChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(26, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 27 }, { QMetaType::QString, 28 },
        }}),
        // Slot 'agentExeChanged'
        QtMocHelpers::SlotData<void(const QString &)>(29, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AgentManager, qt_meta_tag_ZN12AgentManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AgentManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AgentManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AgentManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AgentManagerE_t>.metaTypes,
    nullptr
} };

void AgentManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgentManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->agentTypeAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->agentTypeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->agentInstanceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->agentInstanceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->agentInstanceStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->agentInstanceAdvancedStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 6: _t->agentInstanceProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->agentInstanceWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->agentInstanceError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->agentInstanceNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->agentInstanceOnlineChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->agentInstanceAccountIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->updatePluginInfos(); break;
        case 13: _t->serviceOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->agentExeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & )>(_a, &AgentManager::agentTypeAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & )>(_a, &AgentManager::agentTypeRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & )>(_a, &AgentManager::agentInstanceAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & )>(_a, &AgentManager::agentInstanceRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , int , const QString & )>(_a, &AgentManager::agentInstanceStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , const QVariantMap & )>(_a, &AgentManager::agentInstanceAdvancedStatusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , uint , const QString & )>(_a, &AgentManager::agentInstanceProgressChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , const QString & )>(_a, &AgentManager::agentInstanceWarning, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , const QString & )>(_a, &AgentManager::agentInstanceError, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , const QString & )>(_a, &AgentManager::agentInstanceNameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , bool )>(_a, &AgentManager::agentInstanceOnlineChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgentManager::*)(const QString & , const QString & )>(_a, &AgentManager::agentInstanceAccountIdChanged, 11))
            return;
    }
}

const QMetaObject *AgentManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AgentManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AgentManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int AgentManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void AgentManager::agentTypeAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AgentManager::agentTypeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AgentManager::agentInstanceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AgentManager::agentInstanceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AgentManager::agentInstanceStatusChanged(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void AgentManager::agentInstanceAdvancedStatusChanged(const QString & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void AgentManager::agentInstanceProgressChanged(const QString & _t1, uint _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void AgentManager::agentInstanceWarning(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void AgentManager::agentInstanceError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void AgentManager::agentInstanceNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void AgentManager::agentInstanceOnlineChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void AgentManager::agentInstanceAccountIdChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}
QT_WARNING_POP
