/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Preprocessor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "preprocessoradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Akonadi__PreprocessorAdaptor
 */

Akonadi__PreprocessorAdaptor::Akonadi__PreprocessorAdaptor(Akonadi::PreprocessorBasePrivate *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Akonadi__PreprocessorAdaptor::~Akonadi__PreprocessorAdaptor()
{
    // destructor
}

void Akonadi__PreprocessorAdaptor::beginProcessItem(qlonglong id, qlonglong collectionId, const QString &mimeType)
{
    // handle method call org.freedesktop.Akonadi.Preprocessor.beginProcessItem
    parent()->beginProcessItem(id, collectionId, mimeType);
}


#include "moc_preprocessoradaptor.cpp"
